VII3<-function(data, variables, group=NULL, test=c(8),
graph=TRUE, compress=TRUE, xlim=NULL, ylim=NULL,
spacing=spacing_conditional(sp=0), keep_aspect_ratio=FALSE, xscale=0.9,
yspace=unit(0.5, "lines"), main=NULL, sub=NULL, residuals_type="Pearson",
shade=TRUE, gp_axis=gpar(lty = 3, lwd=2, col="black"), grid.edit=FALSE,
text.grid="rect:", gp.grid = gpar(fill="red"), labeling=labeling_border,
labeling_args=list(), margins=unit(3, "lines"), legend_width=unit(5, "lines"),
gp_varnames=gpar(fontsize=12, fontface=1), gp_labels=gpar(fontsize=12,
fontface=1), main_gp=gpar(fontsize=20, fontface=2), sub_gp=gpar(fontsize=15,
fontface=1), legend = legend_resbased(fontsize=12, fontfamily="Arial",
x= unit(1, "lines"), y=unit(0.1,"npc"), height=unit(0.8, "npc"), width=unit(0.7, "lines"),
digits=2, check_overlap=TRUE, text=NULL, steps=200, ticks=10, pvalue=TRUE),
gp= shading_hcl, file="Output.txt"){


datos<-data


if(graph==TRUE){

if(!is.null(group)) subcon<-c(variables,group) else subcon<-variables

subcon<-as.character(subcon)
dati<-datos[,subcon]

long<-length(subcon)

aaaa<-seq(long)

#La matriz de datos se convierte a una tabla
tabla<-with(dati, table(dati[,subcon]))

TC <- margin.table(tabla, aaaa)

vcd::assoc(x = TC, shade=shade, compress=compress, xlim=xlim, ylim=ylim, spacing=spacing,
keep_aspect_ratio=keep_aspect_ratio, xscale=xscale, yspace=yspace, main=main,
sub=sub, residuals_type=residuals_type, gp_axis=gp_axis, labeling=labeling,
labeling_args=labeling_args, margins=margins, legend_width=legend_width,
main_gp=main_gp, sub_gp=sub_gp, gp_varnames=gp_varnames, gp_labels=gp_labels,
legend=legend, gp=gp)


if(grid.edit==TRUE){
grid.edit(text.grid, gp = gp.grid)
}
else{
}



}
else{
}



# Log-likelihood tests of independence & goodness of fit
# Does Williams' and Yates' correction
#
# G & q calculation from Sokal & Rohlf (1995) Biometry 3rd ed.
# TOI Yates' correction taken from Mike Camann's 2x2 G-test fn.
# GOF Yates' correction as described in Zar (2000)
# more stuff taken from ctest's chisq.test()
#
# ToDo:
# 1) Beautify
# 2) Add warnings for violations
# 3) Make appropriate corrections happen by default
#
# V3.3 Pete Hurd Sept 29 2001. phurd@ualberta.ca

g.test <- function(x, y = NULL, correct="none",p = rep(1/length(x), length(x)))
{
  DNAME <- deparse(substitute(x))
  if (is.data.frame(x)) x <- as.matrix(x)
  if (is.matrix(x)) {
    if (min(dim(x)) == 1) 
      x <- as.vector(x)
  }
  if (!is.matrix(x) && !is.null(y)) {
    if (length(x) != length(y)) 
      stop("x and y must have the same length")
    DNAME <- paste(DNAME, "and", deparse(substitute(y)))
    OK <- complete.cases(x, y)
    x <- as.factor(x[OK])
    y <- as.factor(y[OK])
    if ((nlevels(x) < 2) || (nlevels(y) < 2)) 
      stop("x and y must have at least 2 levels")
    x <- table(x, y)
  }
  if (any(x < 0) || any(is.na(x))) 
    stop("all entries of x must be nonnegative and finite")
  if ((n <- sum(x)) == 0) 
    stop("at least one entry of x must be positive")
  #If x is matrix, do test of independence
  if (is.matrix(x)) {
    #Test of Independence
    nrows<-nrow(x)
    ncols<-ncol(x)
    if (correct=="yates"){ # Do Yates' correction?
      if(dim(x)[1]!=2 || dim(x)[2]!=2) # check for 2x2 matrix
        stop("Yates' correction requires a 2 x 2 matrix")
      if((x[1,1]*x[2,2])-(x[1,2]*x[2,1]) > 0)
        {
          x[1,1] <- x[1,1] - 0.5
          x[2,2] <- x[2,2] - 0.5
          x[1,2] <- x[1,2] + 0.5
          x[2,1] <- x[2,1] + 0.5
        }
      else
        {
          x[1,1] <- x[1,1] + 0.5
          x[2,2] <- x[2,2] + 0.5
          x[1,2] <- x[1,2] - 0.5
          x[2,1] <- x[2,1] - 0.5
        }
    }

    sr <- apply(x,1,sum)
    sc <- apply(x,2,sum)
    E <- outer(sr,sc, "*")/n
      # calculate G
      g <- 0
      for (i in 1:nrows){
        for (j in 1:ncols){
          if (x[i,j] != 0) g <- g + x[i,j] * log(x[i,j]/E[i,j])
        }
      }
      q <- 1
      if (correct=="williams"){ # Do Williams' correction
        row.tot <- col.tot <- 0    
        for (i in 1:nrows){ row.tot <- row.tot + 1/(sum(x[i,])) }
        for (j in 1:ncols){ col.tot <- col.tot + 1/(sum(x[,j])) }
        q <- 1+ ((n*row.tot-1)*(n*col.tot-1))/(6*n*(ncols-1)*(nrows-1))
      }
      STATISTIC <- G <- 2 * g / q
      PARAMETER <- (nrow(x)-1)*(ncol(x)-1)
      PVAL <- 1-pchisq(STATISTIC,df=PARAMETER)
      if(correct=="none")
        METHOD <- "Log likelihood ratio (G-test) test of independence without correction"
      if(correct=="williams")
        METHOD <- "Log likelihood ratio (G-test) test of independence with Williams' correction"
      if(correct=="yates")
        METHOD <- "Log likelihood ratio (G-test) test of independence with Yates' correction"
  }
  else {
    # x is not a matrix, so we do Goodness of Fit
    METHOD <- "Log likelihood ratio (G-test) goodness of fit test"
    if (length(x) == 1) 
      stop("x must at least have 2 elements")
    if (length(x) != length(p)) 
      stop("x and p must have the same number of elements")
    E <- n * p
    
    if (correct=="yates"){ # Do Yates' correction
      if(length(x)!=2)
        stop("Yates' correction requires 2 data values")
      if ( (x[1]-E[1]) > 0.25) {
        x[1] <- x[1]-0.5
        x[2] <- x[2]+0.5
      }
      else if ( (E[1]-x[1]) > 0.25){
        x[1] <- x[1]+0.5
        x[2] <- x[2]-0.5
      }
    }
    names(E) <- names(x)
    g <- 0
    for (i in 1:length(x)){
      if (x[i] != 0) g <- g + x[i] * log(x[i]/E[i])
    }
    q <- 1
    if (correct=="williams"){ # Do Williams' correction
      q <- 1+(length(x)+1)/(6*n)
    }
    STATISTIC <- G <- 2*g/q
    PARAMETER <- length(x) - 1
    PVAL <- pchisq(STATISTIC, PARAMETER, lower.tail = FALSE)
  }
  names(STATISTIC) <- "Log likelihood ratio statistic (G)"
  names(PARAMETER) <- "X-squared df"
  names(PVAL) <- "p.value"
  structure(list(statistic=STATISTIC,parameter=PARAMETER,p.value=PVAL,
            method=METHOD,data.name=DNAME, observed=x, expected=E),
            class="htest")
}

# Autor: Marc Schwartz
cochranq.test <- function(mat)
{
  k <- ncol(mat)

  C <- sum(colSums(mat) ^ 2)
  R <- sum(rowSums(mat) ^ 2)
  T <- sum(rowSums(mat))


  num <- (k - 1) * ((k * C) - (T ^ 2))
  den <- (k * T) - R

  Q <- num / den

  df <- k - 1
  names(df) <- "df"
  names(Q) <- "Cochran's Q"

  p.val <- pchisq(Q, df, lower.tail = FALSE)

  QVAL <- list(statistic = Q, parameter = df, p.value = p.val,

               method = "Cochran's Q Test for Dependent Samples",
               data.name = deparse(substitute(mat)))

  class(QVAL) <- "htest"
  return(QVAL)
} 



tablaDobleEntrada<-function(datos,variables,test){
  tbl1<-table(datos[,variables])
  listaPruebas<-NULL
  for (i in test){
    if (i==1) listaPruebas<-c(listaPruebas,list(chisq.test(tbl1,correct=FALSE)))
    if (i==2) listaPruebas<-c(listaPruebas,list(g.test(tbl1)))
    if (i==3) listaPruebas<-c(listaPruebas,list(g.test(tbl1,correct="williams")))
    if (i==4) listaPruebas<-c(listaPruebas,list(chisq.test(tbl1,correct=TRUE)))
    if (i==5) listaPruebas<-c(listaPruebas,list(fisher.test(tbl1)))
    if (i==6) listaPruebas<-c(listaPruebas,list(fisher.test(tbl1,alternative="less")))
    if (i==7) listaPruebas<-c(listaPruebas,list(fisher.test(tbl1,alternative="greater")))
    if (i==8) {
              datos<-datos[,variables]
              tbl1<-tapply(datos[,1],datos[,2],mean)
              tbl1<-cbind(tbl1,tapply(datos[,1],datos[,2],sd))
              tbl1<-as.table(tbl1)
              colnames(tbl1)<-c("means","SD")
              rownames(tbl1)<-paste(names(datos)[2],row.names(tbl1))
              varInt<-datos[,1]
              varFact<-datos[,2]
              varBloque<-datos[,3]
              listaPruebas<-c(listaPruebas,list(friedman.test(varInt,factor(varFact),factor(varBloque))))
              }
     if (i==9) listaPruebas<-c(listaPruebas,list(mcnemar.test(tbl1,correct=FALSE)))
     if (i==10) listaPruebas<-c(listaPruebas,list(mcnemar.test(tbl1,correct=TRUE)))
     if (i==11){
               datos<-datos[,variables]
               if (length(variables)>=1) datos1<-factor(datos[,1])
               if (length(variables)>=2) datos2<-factor(datos[,2])
               if (length(variables)>=3) datos3<-factor(datos[,3])
               if (length(variables)>=4) datos4<-factor(datos[,4])
               if (length(variables)>=5) datos5<-factor(datos[,5])
               if (length(variables)>=6) datos6<-factor(datos[,6])
               if (length(variables)>=7) datos7<-factor(datos[,7])
               if (length(variables)>=8) datos8<-factor(datos[,8])
               if (length(variables)>=9) datos9<-factor(datos[,9])
               if (length(variables)>=10) datos10<-factor(datos[,10])
               if (length(variables)>=11) datos11<-factor(datos[,11])
               if (length(variables)>=12) datos12<-factor(datos[,12])
               if (length(variables)>=13) datos13<-factor(datos[,13])
               if (length(variables)>=14) datos14<-factor(datos[,14])
               if (length(variables)>=15) datos15<-factor(datos[,15])
               if (length(variables)>=16) datos16<-factor(datos[,16])
               if (length(variables)>=17) datos17<-factor(datos[,17])
               if (length(variables)>=18) datos18<-factor(datos[,18])
               if (length(variables)>=19) datos19<-factor(datos[,19])
               if (length(variables)>=20) datos20<-factor(datos[,20])
                              
               if (length(variables)>=1) datos<-data.frame(datos1)
               if (length(variables)>=2) datos<-data.frame(datos1,datos2)
               if (length(variables)>=3) datos<-data.frame(datos1,datos2,datos3)
               if (length(variables)>=4) datos<-data.frame(datos1,datos2,datos3,datos4)
               if (length(variables)>=5) datos<-data.frame(datos1,datos2,datos3,datos4,datos5)
               if (length(variables)>=6) datos<-data.frame(datos1,datos2,datos3,datos4,datos5,datos6)
               if (length(variables)>=7) datos<-data.frame(datos1,datos2,datos3,datos4,datos5,datos6,datos7)
               if (length(variables)>=8) datos<-data.frame(datos1,datos2,datos3,datos4,datos5,datos6,datos7,datos8)
               if (length(variables)>=9) datos<-data.frame(datos1,datos2,datos3,datos4,datos5,datos6,datos7,datos8,datos9)
               if (length(variables)>=10) datos<-data.frame(datos1,datos2,datos3,datos4,datos5,datos6,datos7,datos8,datos9,datos10)
               if (length(variables)>=11) datos<-data.frame(datos1,datos2,datos3,datos4,datos5,datos6,datos7,datos8,datos9,datos10,datos11)
               if (length(variables)>=12) datos<-data.frame(datos1,datos2,datos3,datos4,datos5,datos6,datos7,datos8,datos9,datos10,datos11,datos12)
               if (length(variables)>=13) datos<-data.frame(datos1,datos2,datos3,datos4,datos5,datos6,datos7,datos8,datos9,datos10,datos11,datos12,datos13)
               if (length(variables)>=14) datos<-data.frame(datos1,datos2,datos3,datos4,datos5,datos6,datos7,datos8,datos9,datos10,datos11,datos12,datos13,datos14)
               if (length(variables)>=15) datos<-data.frame(datos1,datos2,datos3,datos4,datos5,datos6,datos7,datos8,datos9,datos10,datos11,datos12,datos13,datos14,datos15)
               if (length(variables)>=16) datos<-data.frame(datos1,datos2,datos3,datos4,datos5,datos6,datos7,datos8,datos9,datos10,datos11,datos12,datos13,datos14,datos15,datos16)
               if (length(variables)>=17) datos<-data.frame(datos1,datos2,datos3,datos4,datos5,datos6,datos7,datos8,datos9,datos10,datos11,datos12,datos13,datos14,datos15,datos16,datos17)
               if (length(variables)>=18) datos<-data.frame(datos1,datos2,datos3,datos4,datos5,datos6,datos7,datos8,datos9,datos10,datos11,datos12,datos13,datos14,datos15,datos16,datos17,datos18)
               if (length(variables)>=19) datos<-data.frame(datos1,datos2,datos3,datos4,datos5,datos6,datos7,datos8,datos9,datos10,datos11,datos12,datos13,datos14,datos15,datos16,datos17,datos18,datos19)
               if (length(variables)>=20) datos<-data.frame(datos1,datos2,datos3,datos4,datos5,datos6,datos7,datos8,datos9,datos10,datos11,datos12,datos13,datos14,datos15,datos16,datos17,datos18,datos19,datos20)
               niv1<-levels(datos[,1])[1]
               niv2<-levels(datos[,1])[2]
               datos<-(datos==niv1)*1
               total<-apply(datos,2,length)
               tbl1<-apply(datos,2,sum)/total*100
               tbl1<-cbind(tbl1,100-tbl1)
               colnames(tbl1)<-c(paste("Percentage",niv1),paste("Percentage",niv2))
               listaPruebas<-c(listaPruebas,list(cochranq.test(datos)))
               }
  }
  return(list(tabla=tbl1,listaPruebas=listaPruebas))
}

if (length(variables)!=2 & !any((c(8,11) %in% test))) stop("Must be two dependent variables")
if (length(variables)!=3 & (8 %in% test)) stop("Friedman test must have three variables: Independent, Factor and Cases")
if (sum(variables %in% group)>0) stop("Dependent variable must be different than group")

if (is.null(group)){ 
    listaR<-tablaDobleEntrada(datos,variables,test)
}else{
    lista1<-split(datos,datos[,group])
    listaR<-lapply(lista1,tablaDobleEntrada,variables,test)
}


print(listaR)

if(!is.null(file)){
 sink(file)
 print(listaR)
 sink()
}



}

