\name{II1}
\alias{II1}
\encoding{latin1}
\title{DESCRIPTIVE STATISTICS}
\description{Descriptive statistics, these include measures of position such as arithmetic mean, geometric mean, harmonic mean, weighted average, mode, median, etc., measures of dispersion or sampling variability as variance, standard deviation, coefficient of variation, etc., and measures of distribution as skewness and kurtosis.} 
\usage{
II1(data, variables, group=NULL, trim=0.05, quantile=c(0.025,0.05,0.95,0.975),
variablesWM=NULL, variablesW=NULL, groupWM=NULL, file1="Output1.csv",
file2="Output2.csv", na="NA", dec=",", row.names=FALSE)
}
\arguments{
  \item{data}{Data file.}
  \item{variables}{Variables for which statistical measures can be calculated.}
  \item{group}{Variables with grouped data to perform statistical calculations. In case of selecting NULL, no grouping would be carried out and calculations would be made taking into account all the data in each column.}
  \item{trim}{Cutoff point of the trimmed mean.}
  \item{quantile}{Quantile values to be calculated.}
  \item{variablesWM}{If the weighted average interests, the variable or variables for which the weighted average is obtained must be specified. If NULL is selected, the weighted average will not be calculated.}
  \item{variablesW}{Variable or variables that are used to weight. As before, if NULL is selected, the weighted average will not be calculated.}
  \item{groupWM}{Variables with grouped data to make weighted average calculations. In case of selecting NULL, any grouping would take place and this would be calculated considering all the data in each columnn.}
  \item{file1}{CSV FILES. Filename of descriptive statistics.}
  \item{file2}{CSV FILES. Filename of the weighted average.}
  \item{na}{CSV FILES. Text that is used in the cells without data.}
  \item{dec}{CSV FILES. Defining if comma "," or point "." is used as decimal separator.}
  \item{row.names}{CSV FILES. Logical value that specifies if identifiers are placed in rows or if a vector with a text is placed for each of the rows.}
}
\value{A CSV file is exported with position measurements such as  
arithmetic mean, geometric mean, harmonic mean, mode, median, etc. and measures of dispersion or sampling variability as variance, standard deviation, coefficient variation, etc. Optionally, a second CSV file, that includes the weighted average, is exported.}
\details{
\strong{II. DESCRIPTIVE STATISTICS}

\strong{II.1. MEASURES OF POSITION}

The first step in dealing with data is to find some kind of measure that allows us to characterize, differentiate and distinguish the data series. This can be done by determining the position of the data. Within this group are the so-called measures of centrality and other measures that consider different positions of data. Ones or others are used depending on the type of data that you are working with.

\strong{II.1.1. Measures of central tendency}

\emph{II.1.1.1. Arithmetic mean}

The arithmetic mean (\eqn{\bar{x}}), which is also known simply as mean, or average is calculated using the following formula:
\deqn{\bar{x}=\frac{\displaystyle\sum_{i=1}^{n}x_i}{n}}

where \emph{x} are each of the variable values \emph{i} and \emph{n} the number of data. 

When the average is a set of all population, it is usually denoted by the symbol \eqn{\mu} and, when this is the average of a sample of the population, then used \eqn{\bar{x}}.

For grouped data (frequency table) the average is calculated using the following formula:
\deqn{\bar{x}=\frac{\displaystyle\sum_{i=1}^{k}m_if_i}{n}}

where \emph{m} and \emph{f} are the mean value and the frequency (number of data) of the class \emph{i}, respectively, and \emph{k} the number of intervals or classes. 

The arithmetic mean is the most frequently used because it has a smaller standard error, it is easier to estimate, this tends towards a Normal distribution even if the original data do not present this distribution and, finally, is more sensitive to changes than other measures of position in the distribution of data, which is very important in statistics to determine differences between data series (Sokal & Rohlf, 1981). The problem posed by the arithmetic mean also derives from its sensitivity, which is most affected when rare data is coming out of range.

\emph{II.1.1.2. Geometric mean}

The geometric mean \emph{GM} is used in some cases with relative data as percentages or growth rates and is calculated using the following formula:
\deqn{GM=\sqrt[n]{x_1x_2....x_n}}

\emph{II.1.1.3. Harmonic mean}

The harmonic mean \emph{AM} is used, for example, in some cases where it is necessary to average variations with respect to time. It is calculated as follows: 
\deqn{AM=\frac{1}{\frac{1}{n}(\frac{1}{x_1}+\frac{1}{x_2}....\frac{1}{x_n})}}

The harmonic mean is always less than or equal to the geometric mean, which in turn is always less than or equal to the arithmetric mean.

\emph{II.1.1.4. Mode}

Sometimes it is necessary to determine the position of variables that are not numeric but qualitative as, for example, the species that belong to different individuals. In this case we can not use any of the above-mentioned means and, therefore, we must resort to measures like mode. It can also be used for quantitative variables.

The mode of a set of observations is defined as the value that occurs most frequently, i.e., a greater number of times. Mode can be denoted by \emph{Mo}. 

If only one value is repeated more times, the distribution will be unimodal, because it only has one mode. In the event that no value is repeated, then by definition, it is considered that there is no mode. It may be the case where two points have the same highest frequency, resulting, in this case, in a bimodal distribution. The multimodal distribution would be in those situations where there are more than two values with the same maximum frequency. Finally, in rare situations in which the distribution of the data is U-shaped, the mid-point of the distribution is called antimode. 

\emph{II.1.1.5. Median}

In a set of observations median is the value arranged in increasing order, half of these are less than this value and half are higher. Be \eqn{x_1,x_2,....x_n} a ramdon sample of \emph{n} observations sorted increasingly, the median of these data is calculated as follows:

If \emph{n} is an odd number.
\deqn{X_{(\frac{n+1}{2})}}

If \emph{n} is an even number.
\deqn{\frac{{X_\frac{n}{2}}+X_{(\frac{n}{2}+1)}}{2}}

The median is often used in data sets which have a very asymmetric distribution since in these cases it is not always suitable to use the arithmetic mean.
Finally, it is not affected by rare values that get much out of the normal range, as happens to the arithmetic mean.

\emph{II.1.1.6. Trimmed mean}

Another measure of central tendency that is often used for exploratory purposes is the trimmed mean, because it is more resistant to extreme values than the average and is not as callous as the median might be. The trimmed mean is defined as the average of the values where a certain percentage of the population on either side of the extreme values has been excluded. For its calculation three steps must be followed: 1) The data is sorted; 2) The percentage of data at each end of the population or sample is discarded and 3) The average is calculated using the remaining data.

This measure serves as an exploratory parameter, it shows the impact of the extreme values on the estimation of averages, because it is calculated at different percentages. It also facilitates the detection of unusual values, which warn researchers of possible data errors that may not be part of the target population of the study or outliers that indicate new directions in research.

\emph{II.1.1.7. Weighted average}

The weighted average (\eqn{\bar{x}_w}) is used in cases where each value is in turn an average. This can also be used when some data is more reliable than other data, simply because some data have been calculated with a greater effort or for any other reason and, therefore, it is necessary to give more weight to these values when estimating the mean. The calculation is based on the following formula:

\deqn{\bar{x}_w=\frac{\displaystyle\sum_{i=1}^{n}w_ix_i}{\displaystyle\sum_{i=1}^{n}w_i}}

where \emph{x} are each of the values \emph{i} of the variable, \emph{w} the weight given to the data and \emph{n} the number of data.

An application of the weighted average that deserves special mention, because it can give a lot of information, is to obtain the center of gravity of a distribution of data according to a particular variable. Ecology is a parameter that quantifies the ecological niche of a species, since it provides information on the average value of its distribution for a given variable. For example, one can obtain the temperature, salinity, oxygen concentration, etc. mean that a species may be present. In this case, \emph{w} are each values \emph{i} of the species abundance data, \emph{x} the value of the variable to the value \emph{w} and \emph{n} the number of data..

\strong{II.1.2. Other measures of position}

Quantile of order \emph{k} is defined as the value of the variable, assuming that this is ranked from least to greatest, that divided it into \emph{k} parts with the same frequency of observations. So there will be \emph{k - 1} quantiles of order \emph{k}.

The first quantile of order \emph{k} lets the \emph{1/k} fraction on the left of the frequency of observations. The second quantile of order \emph{k} lets the \emph{2/k} fraction on the left of the frequency of observations. The rth quantile of order \emph{k} lets the \emph{r/k} fraction on the left of the frequency of observations. For instance, the 15 quantile of order 100 leaves below the 15\% of the total value of the full range of values.

The most commonly used quantiles are \strong{percentiles}, \strong{cuartiles} and \strong{deciles}, which are described below.

The \strong{percentiles} are the 99 points that divide the distribution into 100 parts, such that within each 1\% of the values of the distribution is included. 

The \strong{quartiles} are the three values that divide the variable distribution in 4 equal parts, i.e., in 4 intervals within each 25\% of distribution values is included. The 25 percentile \emph{(\eqn{P_{25}})} would be equal to quartile 1 \emph{(\eqn{Q_1})}, the 50 percentile \emph{(\eqn{P_{50}})} would be equal to quartile 2 (\emph{\eqn{Q_2}}, also equal to the median), etc.

The \strong{deciles} are the 9 points that divide the distribution into 10 parts, such that within each one is included the 10\% of the values of the distribution. The 10 percentil \emph{(\eqn{P_{10}})} would be equal to decil 1 \emph{(\eqn{D_1})}, The 20  percentil \emph{(\eqn{P_{20}})} would be equal to decil 2 \emph{(\eqn{D_2})}, etc.

The procedure to find the value of the \emph{j} quantile of \emph{k} order from sorted data from least to greatest, is as follows:

1. Find the \emph{i} position of the \emph{j} th quantile by calculating \emph{nj/k}.

2. If \emph{nj/k} is not an integer, then the \emph{i} position is the next larger integer and the value of the quantile is the data arranged in the position of this larger whole.

3. If \emph{nj/k} is an integer, then the position of the quantile will be \emph{i=nj/k} + 0,5 and, thus, the quantile value is the average number of sorted observations \emph{nj/k} y \emph{nj/k} + 1.

\strong{II.2. MEASURES OF DISPERSION}

In addition to the position, it is also important the dispersion or variability of the data. Two sets of data can have the same mean, but the variability may be different between the two. 

Dispersion measures aim to study to what extent, for a given distribution of data, position measurements represent well the distribution set.

For example, if you want to determine whether an arithmetic mean marks a generalized central tendency of behavior of all elements in the set studied, we will have to look at the separation or deviation of each value with respect to the mean. If all values are close to the mean value, it will be representative of them.

That is, the more representative the arithmetic mean of a variable, the more grouped around it are the averaged values and, conversely, it will be more objectionable for not being representative how much greater dispersion of the variable values there is from the average (mean).

Therefore, another type of parameters which measure the dispersion or variability of the data are necessary to complement the information obtained from the mean, as shown below.

\strong{II.2.1. Amplitude}

The simplest method of estimating the dispersion of the data is by means of the amplitude, also known as range, that is, the difference between the minimum and maximum values of the data series.

\strong{II.2.2. Variance and quasi-variance}

The best way to measure the dispersion of a set of data is to compare each of them with the mean of the series, and this is exactly what the variance makes (\eqn{\sigma^2}):
\deqn{\sigma^2=\frac{\displaystyle\sum_{i=1}^{n}(x_i-\bar{x})^2}{n}}

Often we use the variance of a sample as a proxy or estimate of the unknown variance of the population from which that sample comes. In these cases, the mistake is usually smaller if, instead of considering the variance as an estimator of the sample, is used what is known as quasi-variance (\eqn{s^2}), which is calculated as the previous one, but changing the denominator by \emph{n} - 1:
\deqn{s^2=\frac{\displaystyle\sum_{i=1}^{n}(x_i-\bar{x})^2}{n-1}}

In cases where population data is available, \emph{n} should be used and no \emph{n} - 1. However, as these data are a sample of a larger population, the proper way to proceed is to use the quasi-variance instead variance.

Often reference is made to the variance when you are actually calculating the quasi-variance (estimated variance). Most statistics programs only use quasi-variance and not the variance. It is also common to observe that \eqn{\sigma^2} and \eqn{s^2} are used interchangeably to indicate quasi-variance or variance without a defined criterion.

\strong{II.2.3. Standard deviation and stardard quasi-deviation}

The problem with variance is that to avoid negative values, the differences are squared. In order to have the measure of dispersion in the same units as the mean, the standard deviation is more often used than the variance (\eqn{\sigma}) which is simply the square root of the variance.
\deqn{\sigma=\sqrt{\frac{\displaystyle\sum_{i=1}^{n}(x_i-\bar{x})^2}{n}}}

As is the case with the variance, except in the case that the sample size is identical to the population, it is preferable to use the typical quasi-standard deviation (\emph{s}), instead of the standard deviation. To calculate the quasi-standard deviation, divide by the number of degrees of freedom (\emph{n} - 1) instead of dividing by the total number of data (\emph{n}).
\deqn{s=\sqrt{\frac{\displaystyle\sum_{i=1}^{n}(x_i-\bar{x})^2}{n-1}}}

It should be mentioned that most of the statistical programs only use quasi-standard deviation and, as the same with variance, it is frequently observed that the standard deviation occurs when the quasi-standard deviation is calculated. It is also often observed that \eqn{\sigma} and \eqn{s} are used interchangeably for quasi-deviation or standard deviation without a defined criterion. 

\strong{II.2.4. Absolute deviation with respect to the average and the median}

A measure of dispersion that is often used is the mean absolute deviation which is defined as:
\deqn{ADM=\frac{1}{n}\displaystyle\sum_{i=1}^{n}|x_i-\bar{x}|}

and the median as:
\deqn{ADMed=\frac{1}{n}\displaystyle\sum_{i=1}^{n}|x_i-Median|}

This measure indicates the average of the deviations either negative or positive with respect to the overall average and facilitates the interpretation and analysis of the degree of dispersion of the data.

\strong{II.2.5. Coefficient of variation}

When data sets with different means are compared, the standard deviation does not allow to properly compare which of the two sets of data shows greater variation, since the dataset with higher average also tends to have greater variability. In this case the use of the coefficient of variation is more advisable \emph{CV}, which is calculated as the percentage represented by the standard deviation relative to the average. If the standard deviation is unknown because our data are in a sample, the quasi-standard deviation as an estimator of population standard deviation is used.
\deqn{CV=\frac{s*100}{\bar{x}}}

\strong{II.2.6. Standard error of the mean}

It provides a measure of the accuracy of the estimate of the population mean based on a sample, while the standard deviation measures the variability of the data with respect to the mean in the sample. The standard error is calculated from the standard deviation. When this is known, the quasi-standard deviation is used to obtain the estimated standard error. 

\deqn{SE=\frac{s}{\sqrt{n}}}

\strong{II.2.7. Interquartile range}

The interquartile range \emph{Q} is calculated from the 75 (\eqn{P_{75}}) and 25 (\eqn{P_{25}}) percentiles as follows:
\deqn{Q=P_{75}-P_{25}=Q_3-Q_1}

This measure of dispersion is used when the central position is expressed by means of the median.

\strong{II.3. MEASURES OF DISTRIBUTION}

\strong{II.3.1. Asymmetry}

Measures of asymmetry are intended to determine whether a variable is distributed symmetrically with respect to a central value, or if the distribution data has a different shape on the right side than the left side.

The distribution is symmetric if the right and left side of the central value of the data distribution is the same. The distribution is positively skewed if the higher frequencies are on the left side of the mean, while on the right there are smaller frequencies. Skewness is negative when the frequencies are smaller on the left side (Figure II.1).

\tabular{clll}{
\strong{Figure II.1.} Different types of asymmetry\cr
\figure{FII1}{options: width=4in}
}

The arithmetic mean is commonly used as a central reference value, but also the median can be used.

There are many ways of measuring the symmetry and one of them is the formula that is shown below (Fisher asymmetry coefficient) which uses the arithmetic average as a central value:

\deqn{A=\frac{n\left(\displaystyle\sum_{i=1}^{n}(x_i-\bar{x})^3\right)}{(n-1)(n-2)\sigma^3}}

Being \eqn{\sigma} the estimated standard deviation or sample quasi-standard deviation. When the value is close to zero the distribution is symmetric, the asymmetry is positive when the value is greater than zero and negative when the
value is less than zero.

\strong{II.3.2. Kurtosis}

Kurtosis measure characterizes the tails (or outlier potential) of distribution of the data. Historically, it was thought that higher kurtosis implies a more or less "pointed" distribution. For this reason, kurtosis was historically called a measure of "peakedness", "pointiness", or "central concentration". However, the notion that kurtosis somehow measures "peakedness" (flatness, pointiness or modality) is incorrect. Kurtosis is not informative about the shape of the peak - its only unambiguous interpretation is in terms of tail extremity; i.e., either existing outliers (for the sample kurtosis) or propensity to produce outliers (for the kurtosis of a probability distribution) (see Westfall, 2014). 

When the kurtosis value is positive, the distribution is leptokurtic, meaning that the outlier character of the distribution is more extreme than that of a normal distribution (Figure II.2, left panel). When the kurtosis value is zero or close to zero, the distribution has similar outlier characteristic as the Normal distribution, and is called mesokurtic (Figure II.2, central panel). Finally, when the kurtosis value is negative, the distribution is platykurtic, meaning that the outlier character of the distribution is less extreme than that of a normal distribution (Figure II.2, right panel)
\tabular{clll}{
\strong{Figure II.2.} Types of kurtosis (bars) compared to the Normal distribution (solid line).\cr
\figure{FII2}{options: width=4.5in}
}
As with asymmetry, there are several ways to estimate kurtosis of a data distribution, but one of the most used is Fisher's correlation coefficient as shown below:

\deqn{C=\frac{n(n+1)\displaystyle\sum_{i=1}^{n}(x_i-\bar{x})^4-3\left(\displaystyle\sum_{i=1}^{n}(x_i-\bar{x})^2\right)\left(\displaystyle\sum_{i=1}^{n}(x_i-\bar{x})^2\right)(n-1)}{(n-1)(n-2)(n-3)\sigma^4}}

\strong{EXAMPLE}

Position measurements such as average arithmetic, geometric mean, harmonic mean, median, etc., and measures of dispersion or sampling variability such as variance, standard deviation, coefficient of variation, etc., are estimated from the abundance of several fish species in two zones (S1 and S2). These parameters were estimated by performing the calculations for each family and genus. The weighted average of the temperature for the two sampling sites based on the abundance of the species is also calculated.

}
\references{
Sokal RR & Rohlf FJ (1981) \emph{Biometry}. WH Freeman and Company, New York.

Westfall, R.H. (2014) Kurtosis as Peakedness, 1905. \emph{RIP} (2014) \emph{American Statistician}, 68: 191-195.}
\examples{

data(ZII1)

II1(data=ZII1, variables=c("S1","S2"),group=c("Family","Genus"),
variablesWM=c("Temperature"), variablesW=c("S1","S2") )

}
\keyword{II1}
