\name{III1}
\alias{III1}
\encoding{latin1}
\title{NORMAL DISTRIBUTION}
\description{It calculates the probability of a Normal distribution indicating the mean and standard deviation.} 
\usage{
III1(value, mean, sd, prob.g=FALSE)
}
\arguments{
  \item{value}{Value for which the probability of the Normal distribution will be calculated.}
  \item{mean}{Mean of the Normal distribution.}
  \item{sd}{Standard deviation of the Normal distribution.}
  \item{prob.g}{It indicates if you want to get the greater TRUE or lesser probability FALSE of the value.}
}
\value{The probability value for the specified mean and deviation, is obtained considering a Normal distribution.}
\details{
\strong{III. DISTRIBUTION}

Another important information is related to the distribution that a variable has. It may be the case that two variables have exactly the same mean and dispersion, but different types of distribution. Therefore, in addition to the information about the position and dispersion measures, which is explained in function \link{II1}, it is necessary to know the distribution of the values of the variable.
For studying the distribution of a variable, and even compare averages and variances between variables, what is done is to compare the frequencies of the values of the variable with the probabilities resulting from theoretical models of distributions. The theoretical distribution model used varies depending on the variable on which we are working.

\strong{III.1. TYPES OF VARIABLES}

There are basically two types of variables: \emph{qualitative} and \emph{quantitative}. The first are not expressed numerically (gender, species to which an individual belongs, province of birth) while numeric codes can be used to represent their values (for example in the variable gender, instead of male and female can be appointed as 1 and 2). The quantitative is directly expressed in numerical terms (number of leaves of a plant, age, length, temperature, etc.) 

Qualitative variables can in turn be of two types: \emph{nominal}, if values are not ordered in a natural way (birthplace, species), and ordinal if values have a rank (order) (for example a variable toxicity that takes values such as nothing, little, pretty and very toxic).

Quantitative variables can also be of two types: \emph{discrete} and \emph{continuous}. They are discrete variables when they can only take specific values, and when any value is possible between two consecutive ones (number of children that can have a family, number of leaves of a plant, etc.). In the case of discrete variables, the  corresponding probability is assigned to every value of the variable on which the number of times that value is repeated will depend in relation to the remaining values. A correspondence between values and their respective probabilities is called \emph{probability function}.

Continuous quantitative variables are those that can take any value along a continuum, so there are no consecutive values, as between any two values remain infinite possible values (temperature, length). Continuous variables can be grouped into categories, but in an arbitrary way. For example, the variable height can be divided into categories as small, normal and high, and the limits of each of these categories can be set arbitrarily.  Unlike discrete variables, for continuous variables it is not useful to establish the correspondence between values and probabilities. What is done is to calculate the probability contained in a given segment or range of values that divided by the amplitude of the segment is the mean probability density of the segment, from which the probability density for each value is determined. The correspondence between the values and their respective probability density is called  \emph{density function}.

The distinction between these four types of variables is important for several reasons: 

1. The calculation of some dispersion or position measures does not make sense with qualitative variables, for example in the case of the gender variable.

2. For the correct application of techniques of statistical analysis: the majority of non-parametric tests require that the variable be at least ordinal, and many methods of multivariate analysis require variables be quantitative (e.g. factor analysis or discriminant analysis).

\strong{III.2. DISTRIBUTIONS FOR CONTINUOUS VARIABLES}

\strong{III.2.1. Normal}

The normal distribution is one of the most important because it is seen in many series of data and, also, different types of statistical analyzes have as a condition for being applied to the data series, that this type of distribution exists. Several mathematicians took part in its development, including the mathematician and astronomer Carl Friedrich Gauss (1777-1885), so it is sometimes called "bell shaped curve" or Gaussian distribution in his honor. The density function of the Normal distribution is described by using the following formula:

\deqn{f(x)=\frac{1}{\sigma\sqrt{2\pi}}e^{\frac{1}{2}\left[\frac{x-\mu}{\sigma}\right]^2}}

where \emph{f(x)} is the probability density of the value \emph{x}, \eqn{\mu} is the mean and \eqn{\sigma} is the standard deviation.

The shape of the normal distribution varies depending on the media \eqn{\mu} and the standard deviation \eqn{\sigma} as shown in Figure III.1.
\tabular{clll}{
\strong{Figure III.1.} Normal distributions with different means\cr
and standard deviations.\cr
\figure{FIII1}{options: width=1.9in}
}
\emph{III.2.1.1. Applications of the Normal distribution}

The table of the Normal distribution N(0,1), that is to say with  \eqn{\mu} = 0  and \eqn{\sigma} = 1 (Table 1 of Appendix I in Guisande et al., 2011), allows to calculate probabilities relating to any other normal distribution with different \eqn{\mu} and \eqn{\sigma}. To do this, simply define the variable, that is, calculate the value \emph{Z} (deviation units compared with the average) corresponding to the values \emph{x} indicated by the operation:

\deqn{Z=\left(\frac{x-\mu}{\sigma}\right)}

This value \emph{Z} which is calculated from the variable  \emph{X} allows us to obtain the probabilities corresponding to any interval (see example) in the tables.

\strong{III.2.2. t of Student}

When a variable follows a Normal distribution, the mean of a random sample of that variable also has a Normal distribution, and its mean is the unknown population mean \eqn{\mu}. This can be used to estimate \eqn{\mu}. However, the standard deviation of the population is not often known \eqn{\sigma} (it only works with a sample of individuals of the total population) and, in addition, it may happen that the number of observations in the sample is small (less than 30). In these cases, you can use the quasi-standard deviation of the sample (\emph{S}) together with the distribution \emph{t} of Student:

\deqn{t=\frac{\bar{x}-\mu}{\frac{S}{\sqrt{n}}}}

The probability density function of the distribution \emph{t} of Student is given by the following expression:

\deqn{f(x)=\frac{1}{\sqrt{\upsilon\pi}}\frac{\Gamma\left(\frac{\upsilon+1}{2}\right)}{\Gamma\frac{\upsilon}{2}}\left(1+\frac{x^2}{\upsilon}\right)^{-\left(\frac{\upsilon+1}{2}\right)}}

The \emph{t} Student distribution can have different forms depending on the degrees of freedom (\eqn{\upsilon}) (Figure III.2). The general appearance of the distribution \emph{t} is similar to the standard Normal distribution. However, the distribution \emph{t} has broader queues than the Normal one, that is to say, the probability of the queues is greater than the Normal distribution. The distribution \emph{t} is transformed into a Normal distribution when the number of data tends to infinity. The critical values for different levels of significance and different degrees of freedom can be seen in Table 2 of Appendix I in Guisande et al. (2011). 
\tabular{clll}{
\strong{Figure III.2.} The distribution density functions of Student\cr
for 1 (circle) and 10 (square) degrees of freedom.\cr
\figure{FIII2}{options: width=1.9in}
}
The main applications of the distribution \emph{t} of Student in statistical inference are: 1) To estimate, using confidence intervals, the population mean and 2) Estimating and testing hypotheses on a mean difference.

Hypotheses or assumptions to apply the \emph{t} of Student
are in each group that the studied variable follows a Normal distribution and that dispersion in both groups should be homogeneous (hypothesis of homoscedasticity = equality of variances) although this statistic can also be used without assuming equality of variances. 

\strong{III.2.3. Chi-square}

The density function of the Chi-square (\eqn{\chi^2})distribution is described by the following expression:

\deqn{f(x)=\frac{1}{2^{\frac{\upsilon}{2}}\Gamma\left(\frac{\upsilon}{2}\right)}x^{\left(\frac{\upsilon}{2}-1\right)}e^{-\frac{x}{2}}}

where \eqn{\upsilon} are the degrees of freedom and \emph{x} is not negative.

Unlike the Normal distribution, since the distribution \eqn{ \chi^ 2} depends on the degrees of freedom, there is no typical curve but the distribution \eqn{\chi^2} can have different shapes depending on the degrees of freedom (Figure III.3).

\tabular{clll}{
\strong{Figure III.3.} The distribution density functions of \eqn{\chi^2} for 1\cr
(circle), 5 (rhombus) y 10 (square) degrees of freedom.\cr
\figure{FIII3}{options: width=1.9in}
}

The value of the variable that leaves on its right an area \eqn{ \alpha} under the density curve is called the corresponding critical point to the level of significance \eqn{\alpha}. The critical points of different levels of significance and different degrees of freedom are tabulated (Table 3 of Appendix I Guisande et al., 2011).

There are three main applications that have the distribution \eqn{\chi^2}: The goodness-of-fit test, the test of independence and the homogeneity test. Moreover, this distribution plays an important role in many other statistical tests.

1. The goodness-of-fit test is the approach of how a sample can be considered as belonging to a population with a known theoretical distribution. It is a method frequently used to determine if a data set has a Normal distribution, Poisson, etc.

2. The test of independence determines if two characters \emph{X} and \emph{Y} of a population are dependent or independent. For example, to determine if the survival of the descendants of the females in a population is independent or dependent of the daily amount of food that females receive.

3. The homogeneity test allows to determine if multiple samples that are studying the same character \emph{A} have been taken or not in the same population, with respect to the \emph{A} feature. For example, several groups of individuals in a population who have undergone the same dose of different metals have been selected and to determine if metals affect the survival of individuals differently.


\strong{III.2.4. \emph{F} of Fisher-Snedecor}

The probability density function of the distribution \emph{F} Fisher-Snedecor is given by the following expression:

\deqn{f(x)=\frac{\Gamma\left(\frac{\upsilon+\omega}{2}\right)}{\Gamma\frac{\upsilon}{2}\Gamma\frac{\omega}{2}}\upsilon^{\frac{\upsilon}{2}}\omega^{\frac{\omega}{2}}\frac{x^{\frac{\upsilon}{2}-1}}{\left(\omega+x\upsilon\right)^{\frac{\upsilon+\omega}{2}}}}

where \eqn{\upsilon} y \eqn{\omega} are the degrees of freedom of the numerator and denominator respectively, being \emph{x} nonnegative. By relying on two types of degrees of freedom, the density function can have different forms (Figure III.4).
\tabular{clll}{
\strong{Figure III.4.} The distribution density functions of\emph{F} Fisher-Snedecor\cr
for different degrees of freedom\eqn{F_{(30,5)}} (circle) and \eqn{F_{(5,30)}} (square).\cr
\figure{FIII4}{options: width=2.1in}
}
The critical values of the distribution \emph{F} Fisher-Snedecor with different levels of significance and degrees of freedom are shown in Table 4 of Appendix I Guisande et al. (2011).

This distribution is mainly used in two types of situations, requiring in both cases that the distribution of the variables be Normal:

1. To test whether two samples come from populations with equal variances. This is a useful test to determine if a Normal population has a greater variation than the other and it is important because, when it compares averages, several statisticians present the homogeneity of variances as requirement.

2. It also applies when it comes to simultaneously compare several population means.

\strong{EXAMPLES}

The body length of a species in a given population is distributed according to Normal \eqn{\mu} = 10.8 cm and \eqn{\sigma} = 3.7 cm.

\strong{Case 1.} Calculate the probability that an individual may have a size of 8.9 cm.

Result: 0.3038

\strong{Case 2.} Calculate the probability that an individual may have a size between 8.9 and 12.4 cm.

Result: 0.3635

}
\references{
Guisande, C., Vaamonde, A. & Barreiro, A. (2011) \emph{Tratamiento de datos con R, SPSS y STATISTICA}. Ediciones Diaz de Santos, Madrid, 978 pp.
}
\examples{

#Case 1
III1(value=8.9, mean=10.8, sd=3.7, prob.g=FALSE)

#Case 2

III1(value=12.4, mean=10.8, sd=3.7, prob.g=FALSE)-III1(value=8.9,
mean=10.8, sd=3.7, prob.g=FALSE)

}
\keyword{III1}

