\name{III3}
\alias{III3}
\encoding{latin1}
\title{HYPERGEOMETRIC DISTRIBUTION}
\description{Calculate the probability of a hypergeometric distribution.} 
\usage{
  III3(N=NULL, N.p=NULL, n=NULL, x=NULL, option=1)
}
\arguments{
  \item{N}{Total number of elements in the population.}
  \item{N.p}{Value of Np, number of elements with initial probability p.}
  \item{n}{Sample size.}
  \item{x}{Value of the random variable for which the probability is calculated.}
  \item{option}{
1. Exactly the probability p(X=x).

2. Probability that is greater or equal than p(X>=x).

3. Probability that is strictly greater than p(X>x).

4. Probability that is less or equal than p(X<=x).

5. Probability that is strictly less than p(X<x).}
}
\value{The probability value is obtained by considering a hypergeometric distribution.}
\details{
\strong{III. DISTRIBUTION}

\strong{III.3. DISTRIBUTIONS FOR DISCRETE VARIABLES}

\strong{III.3.2. Hypergeometric distribution}

In the hypergeometric distribution the variable is also random and dichotomous as in the binomial distribution, but differs from the latter in two important characteristics: the population is finite, while the binomial can be infinite and, in addition, the probability \emph{p} changes, it is not constant, because the result of each test depends on the result of the previous ones. The probability function is expressed by the following formula:


\deqn{f(x)=\frac{\frac{N_p!}{x!(N_p-x)!}\frac{N_q!}{(n-x)!(N_q-n+x)!}}{\frac{N!}{n!(N-n)!}}}

where \eqn{N_p} and \eqn{N_q} are the number of elements with initial probability \eqn{p} and \eqn{q}, respectively (i.e.,  \eqn{p} = \eqn{N_p/N} and \eqn{q} = \eqn{N_q/N}), \eqn{N} the total number of elements and \eqn{n} the number of elements in the sample extracted from the \eqn{N} of the population.

\strong{EXAMPLES}

It has been proven that in a batch of 30 vaccines, 8 are in poor condition. 4 vaccines of the lot have already been used.

\strong{Case 1.} What is the probability that at least one of the vaccines supplied is in poor condition?

The probability that none of the vaccines supplied is in poor condition is calculated

\deqn{1-\frac{\frac{22!}{4!(22-4)!}\frac{8!}{(4-4)!(8-4+4)!}}{\frac{30!}{4!(30-4)!}}=0.733}

Result: 0.733

\strong{Case 2.} What is the probability that 3 of the vaccines supplied are in poor condition?
\deqn{\frac{\frac{22!}{1!(22-1)!}\frac{8!}{(4-1)!(8-4+1)!}}{\frac{30!}{4!(30-4)!}}=0.045}

Result: 0.045

}
\examples{

#Case 1
1- III3(N=30, N.p=8, n=4, x=0, option=1)

#Case 2
III3(N=30, N.p=8, n=4, x=3, option=1)

}
\keyword{III3}
