\name{IV1}
\alias{IV1}
\encoding{latin1}
\title{CONFIDENCE INTERVAL FOR THE MEAN OF A NORMAL POPULATION}
\description{Calculate the confidence interval for the mean of a Normal population.} 
\usage{
IV1(data, variables, group=NULL, alfa=0.05, total=FALSE, file="Output.csv",
na="NA", dec=",", row.names=FALSE)
}
\arguments{
  \item{data}{Data file.}
  \item{variables}{Variable or variables for which the interval confidence is calculated.}
  \item{group}{Variables that gather data for the calculations. In case of selecting NULL, there would be no grouping and it would be calculated considering all the data of the selected variables.}
  \item{alfa}{Confidence level.}
  \item{total}{Logical value that if FALSE means that the entire population has not been sampled, which will be in most of the studies, and if TRUE means that the entire population has been sampled.}
  \item{file}{CSV FILE. Output file name.}
  \item{na}{CSV FILE. Text that is used in cells without data.}
  \item{dec}{CSV FILE. Defining if comma "," or point "." is used as decimal separator.}
  \item{row.names}{CSV FILE. Logical value that defines if identifiers are put in rows or a vector with a text for each of the rows.}
}
\value{A CSV file is obtained with the lower and upper range limits of the confidence interval and the mean value.}
\details{
\strong{IV. CONFIDENCE INTERVALS}

A way to estimate certain parameters, such as different types of mean, variance, standard deviation, etc., that allow us to have information about the variables we are studying was described in the function \link{II1}. In most cases, these parameters are estimated from the data of a sample, and not from the whole population. To measure the reliability of the estimate, it is necessary to estimate the confidence interval of the parameter.

The confidence interval of a parameter to the confidence level 1 - \eqn{\alpha} is one that satisfies the property from the probability of their ends taking such values and which the parameter between them is equal to 1 - \eqn{\alpha} (Viedma, 1989).  The ends of the confidence interval of a parameter are called confidence limits.

\strong{IV.1. CONFIDENCE INTERVAL FOR THE MEAN OF A NORMAL POPULATION}

\strong{IV.1.1. Known standard deviation}

On the assumption that the standard deviation of the population is known, the confidence interval of the mean at the level of \eqn{1 - \alpha\left(I_{\mu}^{1-\alpha}\right)} is calculated by the following interval estimation:
\deqn{I_{\mu}^{1-\alpha}=\left(\bar{x}-z_{\frac{\alpha}{2}}\frac{\sigma}{\sqrt{n}},\bar{x}+z_{\frac{\alpha}{2}}\frac{\sigma}{\sqrt{n}}\right)}

The critical values used are the areas under the standard Normal curve (Table 1 Appendix I Guisande et al., 2011).

\strong{IV.1.2. Unknown standard deviation}

The most common is to work with a few elements of the total 
population. This means that we do not know the standard deviation of the entire population. In this type of situation, the confidence interval is calculated in two different ways depending on the size of the sample.

\emph{IV.1.2.1. Small sample size (<30)}

If the sample size is small, instead of using the Normal distribution and, therefore, the statistical \emph{Z}, what is used is the distribution \emph{t} of Student with \emph{n} - 1 degrees of freedom. The confidence interval of the mean level of confidence \eqn{1 - \alpha\left(I_{\mu}^{1-\alpha}\right)} is:
\deqn{I_{\mu}^{1-\alpha}=\left(\bar{x}-t_{\frac{\alpha}{2};n-1}\frac{s}{\sqrt{n}},\bar{x}+t_{\frac{\alpha}{2};n-1}\frac{s}{\sqrt{n}}\right)}

The critical values of the \emph{t} Student distribution are used (Table 2 Appendix I Guisande et al., 2011).
\emph{IV.1.2.2. Large sample size (\eqn{\geq}30)}

When the sample size tends to infinity, the \emph{t} of student tends to a standard Normal distribution. For this reason, most of the tables of the distribution \emph{t} have only values corresponding to a number of degrees of freedom between 1 and 30; when this is higher, the table of the Normal is directly used as approximation, since differences obtained are very small.

The statistical programs do not need to use this Normal approach, because they can calculate the exact value of \emph{t} whatever the number of degrees of freedom. The differences observed between the intervals obtained with STATISTICA or SPSS and this function are due to the statistical programs which do not take into account if the number of data is small (< 30) or large (\eqn{\geq} 30), since they are always working with the distribution \emph{t} of Student and never use the Normal approach.

If the sample size is large, the same expression as described above for the case of known standard deviation is used, but with the difference that the  quasi-standard deviation sampling (\emph{s}) is used instead of the population standard deviation (\eqn{\sigma}). 
\deqn{I_{\mu}^{1-\alpha}=\left(\bar{x}-z_{\frac{\alpha}{2}}\frac{s}{\sqrt{n}},\bar{x}+z_{\frac{\alpha}{2}}\frac{s}{\sqrt{n}}\right)}

The critical values used are the areas under the standard Normal curve (Table 1 Appendix I Guisande et al., 2011).

\strong{EXAMPLE}

Data on height and weight in men and women from different countries and cities. It is intended to calculate confidence intervals to 95\% of the height and weight for both men and women. Further calculations are done for each country and city.

The results obtained are shown in the following table, indicating the estimated value in each group, and the confidence limits to 95\% for the corresponding population mean. It is assumed that the variable has Normal distribution, and that the population standard deviation is unknown and must be estimated using the sampling data.
\tabular{clll}{
\figure{RIV1}
}


}
\references{
Guisande, C., Vaamonde, A. & Barreiro, A. (2011) \emph{Tratamiento de datos con R, SPSS y STATISTICA}. Ediciones Daz de Santos, Madrid, 978 pp.

Viedma, J.A. (1989) Bioestadstica. \emph{Mtodos en Medicina y Biologa}. Librera Universitaria, Alicante.
}
\examples{
\dontrun{

data(ZIV1)

IV1(data=ZIV1, variables=c("Height","Weight"),
group=c("Country","City","Gender"), alfa=0.05, total=FALSE)

}
}
\keyword{IV1}
