\name{IV2}
\alias{IV2}
\encoding{latin1}
\title{CONFIDENCE INTERVAL OF THE DIFFERENCE BETWEEN NORMAL POPULATION MEANS}
\description{Calculate the confidence interval of the difference between Normal population means.} 
\usage{
IV2(data, variables, varSel, group=NULL, alfa=0.05,  file="Output.csv",
na="NA", dec=",", row.names=FALSE)
}
\arguments{
  \item{data}{Data file.}
  \item{variables}{Variable or variables for which the confidence interval will be calculated.}
  \item{varSel}{It specifies the variable or variables that two studied groups have. It is important to mention that if the variable was previously defined as grouping variable, it can not be used in this section. If the variable has more than two groups, it is necessary to specify which are the groups that are going to be studied. In the example, the confidence interval on the difference between means of the City 1 and City 2 was calculated. If the variable has only 2 groups, as for example sex, it is not necessary to specify the groups to analyze.}
  \item{group}{Variables that gather data for calculations. In case of selecting NULL, there would be no grouping and it would be calculated considering all the data of the selected variables.}
  \item{alfa}{Confidence level.}
  \item{file}{CSV FILE. Output file name.}
  \item{na}{CSV FILE. Text used in cells without data.}
  \item{dec}{CSV FILE. Defines whether the comma "," or dot 
"."  is used as decimal separator.}
  \item{row.names}{CSV FILE. Logical value that specifies whether identifiers are placed in rows or a vector with a text for each of the rows.}
}
\value{A CSV file is obtained with the lower and upper limits of the confidence interval of the difference between means of Normal populations.}
\details{
\strong{IV. CONFIDENCE INTERVALS}

\strong{IV.2. CONFIDENCE INTERVAL FOR THE DIFFERENCE IN TWO NORMAL POPULATION MEANS}

When comparing means of different populations, it is important to estimate the confidence interval for the  difference between means. As with the range that was analyzed in function \link{IV1}, the calculation is different depending on whether the population standard deviation (known variance) is known or should be estimated with sampling data (unknown variance).

\strong{IV.2.1. Known variances}

The confidence interval \eqn{\mu_1-\mu_2} to confidence level \eqn{1 - \alpha\left(I_{\mu_1-\mu_2}^{1-\alpha}\right)} is calculated by using the following expression:
\deqn{I_{\mu_1-\mu_2}^{1-\alpha}=\left[\left(\bar{x}_1-\bar{x}_2\right)-z_{\frac{\alpha}{2}}\sqrt{\frac{\sigma_{1}^{2}}{n_1}+\frac{\sigma_{2}^{2}}{n_2}},\left(\bar{x}_1-\bar{x}_2\right)+z_{\frac{\alpha}{2}}\sqrt{\frac{\sigma_{1}^{2}}{n_1}+\frac{\sigma_{2}^{2}}{n_2}}\right]}

The critical values used are the areas under the standard Normal curve (Table 1 Appendix I Guisande et al., 2011).

\strong{IV.2.2. Unknown variances}

In the event that two means are compared, being the independent variables with Normal distribution, but the population variances are unknown, other different expressions  depending on the size of the sample must be applied.

\emph{IV.2.2.1. Large sample size (\eqn{\geq}30)}

For large samples, the confidence interval \eqn{\mu_1-\mu_2} to confidence level \eqn{1 - \alpha\left(I_{\mu_1-\mu_2}^{1-\alpha}\right)} is calculated by using the following expression:
\deqn{I_{\mu_1-\mu_2}^{1-\alpha}=\left[\left(\bar{x}_1-\bar{x}_2\right)-z_{\frac{\alpha}{2}}\sqrt{\frac{s_{1}^{2}}{n_1}+\frac{s_{2}^{2}}{n_2}},\left(\bar{x}_1-\bar{x}_2\right)+z_{\frac{\alpha}{2}}\sqrt{\frac{s_{1}^{2}}{n_1}+\frac{s_{2}^{2}}{n_2}}\right]}

As seen, the only difference from the situation in which the variances are known, is that the quasi-variance is used instead of variance. 

The critical values used are the areas under the standard Normal curve (Table 1 Appendix I  Guisande et al., 2011).

\emph{IV.2.2.2. Small sample size (<30)}

There are two possible situations: equal or unequal variances.

IV.2.2.2.1. Equal variances

Assuming that the variances are unknown, but knowing that there are no significant differences between them, in this case the distribution \emph{t} of Student is used and the confidence interval \eqn{\mu_1-\mu_2} to the confidence level \eqn{1 - \alpha\left(I_{\mu_1-\mu_2}^{1-\alpha}\right)} is calculated by means of the following expression:

\deqn{I_{\mu_1-\mu_2}^{1-\alpha}=\left[
\begin{array}{ll}
\left(\bar{x}_1-\bar{x}_2\right)-t_{\frac{\alpha}{2};n_1+n_2-2}\sqrt{\frac{1}{n_1}+\frac{1}{n_2}}\sqrt{\frac{(n_1-1)s_{1}^{2}+(n_2-1)s_{2}^{2}}{n_1+n_2-2}}, \\
\left(\bar{x}_1-\bar{x}_2\right)+t_{\frac{\alpha}{2};n_1+n_2-2}\sqrt{\frac{1}{n_1}+\frac{1}{n_2}}\sqrt{\frac{(n_1-1)s_{1}^{2}+(n_2-1)s_{2}^{2}}{n_1+n_2-2}}
\end{array}
\right]}

The critical values of the distribution \emph{t} of Student are used (Table 2 Appendix I Guisande et al., 2011).

IV.2.2.2.2. Unequal variances

In those cases where the variances are unknown and, furthermore, there are significant differences between them, or are simply not known whether the variances are equal or not, the interval \eqn{\mu_1-\mu_2} al nivel de confianza \eqn{1 - \alpha\left(I_{\mu_1-\mu_2}^{1-\alpha}\right)} is calculated as follows:  
\deqn{I_{\mu_1-\mu_2}^{1-\alpha}=\left[\left(\bar{x}_1-\bar{x}_2\right)-t_{\frac{\alpha}{2},f}\sqrt{\frac{s_{1}^{2}}{n_1}+\frac{s_{2}^{2}}{n_2}},\left(\bar{x}_1-\bar{x}_2\right)+t_{\frac{\alpha}{2},f}\sqrt{\frac{s_{1}^{2}}{n_1}+\frac{s_{2}^{2}}{n_2}}\right]}

where \emph{f} are the degrees of freedom, called approximation of Welch, which is calculated as follows, taking \emph{f} the value of the nearest integer:

\deqn{f=\frac{\left(\frac{s_{1}^{2}}{n_1}+\frac{s_{2}^{2}}{n_2}\right)^2}{\frac{\left(\frac{s_1^2}{n_1}\right)^2}{n_1+1}+\frac{\left(\frac{s_2^2}{n_2}\right)^2}{n_2+1}}-2}

The critical values of the distribution \emph{t} of Student are used (Table 2 Appendix I Guisande et al., 2011).

\strong{EXAMPLE}

Data of height and weight in men and women from different countries and cities. The objective is to estimate the confidence interval for the difference between means in weight and height, in men and women, between cities. Calculations are performed for each country and by gender. 

The results obtained are shown in the following table, which shows, for the selection made, the sample sizes, the estimated mean difference and the confidence interval at 95\% for the difference between population means, and the P values of the contrast of invalidity of the mean difference
(a value less than 0.05 evidences that the means are different), and contrast of equal variances (P value greater than 0.05 can accept that the variances are equal in both groups). In all cases it is assumed that the variable has Normal distribution and that the population variance is unknown, so it is estimated with the sample data.
\tabular{clll}{
\figure{RIV2}{options: width=5.2in}
}
}
\references{
Guisande, C., Vaamonde, A. & Barreiro, A. (2011) \emph{Tratamiento de datos con R, SPSS y STATISTICA}. Ediciones Daz de Santos, Madrid, 978 pp.
}
\examples{
\dontrun{

data(ZIV1)

IV2(data=ZIV1, variables=c("Height","Weight"),
group=c("Country","Gender"), alfa=0.05, varSel=list(c("City","1","2")))

}
}
\keyword{IV2}
