\name{IV3}
\alias{IV3}
\encoding{latin1}
\title{CONFIDENCE INTERVAL OF THE VARIANCE AND STANDARD DEVIATION OF A NORMAL POPULATION}
\description{It calculates the confidence interval of the variance and standard deviation of a Normal population.} 
\usage{
IV3(data, variables, group=NULL, alfa=0.05, IntervType="sd", file="Output.csv",
na="NA", dec= ",", row.names=FALSE)
}
\arguments{
  \item{data}{Data file.}
  \item{variables}{Variable or variables whose variance will be used to calculate the confidence interval.}
  \item{group}{Variables that gather data for calculations. In case of selecting NULL, there would be no grouping and it would be calculated considering all the data of the selected variables.}
  \item{alfa}{Confidence level.}
  \item{IntervType}{It specifies if the confidence interval of the variance "Variance" or standard deviation "sd" is performed.}
  \item{file}{CSV FILE. Output file name.}
  \item{na}{CSV FILE. Text used in cells without data.}
  \item{dec}{CSV FILE. Defines whether the comma "," or dot 
"."  is used as decimal separator.}
  \item{row.names}{CSV FILE. Logical value that specifies whether identifiers are placed in rows or a vector with a text for each of the rows.}
}
\value{A CSV file is obtained with the lower and upper limits of the confidence interval for the variance or standard deviation of a Normal population.}
\details{
\strong{IV. CONFIDENCE INTERVALS}

\strong{IV.3. CONFIDENCE INTERVAL OF THE VARIANCE AND STANDARD DEVIATION OF A NORMAL POPULATION}

Sometimes it is important to study the greater or lesser concentration of values around the mean. For example, the time that an individual remains immune after being vaccinated, it is not only important to know the average length, but also that the variability of the duration of the effect will not be very large from one individual to another. For this reason the variance or standard deviation can be estimated using a confidence interval.

The interval of the variance at a confidence level \eqn{1 - \alpha\left(I_{\sigma^2}^{1-\alpha}\right)} is calculated by the following interval estimator, where, \eqn{s^2} is the quasi-variance of the sample:
\deqn{I_{\sigma^2}^{1-\alpha}=\left(\frac{(n-1)s^2}{\chi_{\frac{\alpha}{2};n-1}^{2}},\frac{(n-1)s^2}{\chi_{1-\frac{\alpha}{2};n-1}^{2}}\right)}

The confidence interval of the standard deviation at a confidence level \eqn{1 - \alpha\left(I_{\sigma}^{1-\alpha}\right)} is estimated using the following interval estimator: \deqn{I_{\sigma}^{1-\alpha}=\left(\frac{\sqrt{n-1}s}{\sqrt{\chi_{\frac{\alpha}{2};n-1}^{2}}},\frac{\sqrt{n-1}s}{\sqrt{\chi_{1-\frac{\alpha}{2};n-1}^{2}}}\right)}

The critical values of the distribution \eqn{\chi^2} are used. (Table 3 Appendix I Guisande et al., 2011).

\strong{EXAMPLE}

Time data (in months) that a group of women and men remain immune after they are given a vaccine. It is necessary to know a confidence interval at 95\% of the standard deviation of women and men. The results obtained are shown in the table below, which shows the estimated standard deviation along with its 95\%, confidence limits, assuming that the variable has a Normal distribution.
\tabular{c}{
\figure{RIV3}
}
}
\references{
Guisande, C., Vaamonde, A. & Barreiro, A. (2011) \emph{Tratamiento de datos con R, SPSS y STATISTICA}. Ediciones Daz de Santos, Madrid, 978 pp.
}
\examples{
\dontrun{

data(ZIV3)

IV3(data=ZIV3, variables=c("Time"), group=c("Gender"))

}
}
\keyword{IV3}
