\name{IV4}
\alias{IV4}
\encoding{latin1}
\title{CONFIDENCE INTERVAL OF THE RATIO OF VARIANCES AND TEST FOR HOMOGENEITY OF VARIANCES BETWEEN NORMAL POPULATIONS}
\description{It calculates the confidence interval of the ratio of variances of Normal populations and the test for homogeneity of variances.} 
\usage{
IV4(data, variables, varSel, group=NULL, alfa=0.05, file="Output.csv",
na="NA", dec=",", row.names=FALSE)
}
\arguments{
  \item{data}{Data file.}
  \item{variables}{Variable or variables for which the confidence interval will be calculated for the ratio of variances and the test of homogeneity.}
  \item{varSel}{It specifies the variable or variables that two studied groups have. It is important to mention that if the variable was previously defined as grouping variable, it can not be used in this section. If the variable has more than two groups, it is necessary to specify which are the groups that are going to be studied.}
  \item{group}{Variables that gather data for calculations. In case of selecting NULL, there would be no grouping and it would be calculated considering all the data of the selected variables.}
  \item{alfa}{Confidence level.}
  \item{file}{CSV FILE. Output file name.}
  \item{na}{CSV FILE. Text used in cells without data.}
  \item{dec}{CSV FILE. Defines whether the comma "," or dot 
"."  is used as decimal separator.}
  \item{row.names}{CSV FILE. Logical value that specifies whether identifiers are placed in rows or a vector with a text for each of the rows.}
}
\value{A CSV file is obtained with a confidence interval for the ratio of variances and the Levene test and Brown & Forsythe test, which allows to determine if there is a homogeneity of variances in the analyzed groups.}
\details{
\strong{IV. CONFIDENCE INTERVALS}

\strong{IV.4. CONFIDENCE INTERVAL OF THE RATIOS OF VARIANCES OF TWO NORMAL POPULATIONS}

To determine the confidence interval of the ratio of variances is important, for example when we want to compare the variability of two methods at the time of making a biochemical analysis or the variability of two devices that give us the same type of measure. The comparison of variances between the variables is also important because one of the requirements of the parametric tests of contrasts of homogeneity, \emph{t} test (\link{IX1},\link{IX2}), ANOVA (\link{IX3}), ANCOVA (\link{IX4}), etc., is the fact that there is homogeneity of variances between the variables that are compared.

The interval of the ratio of variances at the level of confidence \eqn{1 - \alpha\left(I_{\sigma_{1}^{2}/\sigma_{2}^{2}}^{1-\alpha}\right)} is calculated as follows: 
\deqn{I_{\sigma_{1}^{2}/\sigma_{2}^{2}}^{1-\alpha}=\left(\frac{s_{1}^{2}}{s_{2}^{2}}\frac{1}{F_{\frac{\alpha}{2};n_1-1,n_2-1}},\frac{s_{1}^{2}}{s_{2}^{2}}F_{\frac{\alpha}{2};n_2-1,n_1-1}\right)}

A confidence interval for the standard deviations at the level of confidence \eqn{1 - \alpha\left(I_{\sigma_{1}/\sigma_{2}}^{1-\alpha}\right)} is calculated as follows:
\deqn{I_{\sigma_{1}/\sigma_{2}}^{1-\alpha}=\left(\frac{s_{1}}{s_{2}}\frac{1}{\sqrt{F_{\frac{\alpha}{2};n_1-1,n_2-1}}},\frac{s_{1}}{s_{2}}\sqrt{F_{\frac{\alpha}{2};n_2-1,n_1-1}}\right)}

The critical values of the distribution \emph{F} are used (Table 4 of Appendix I Guisande et al., 2011).

\strong{EXAMPLE}

Data of height and weight in men and women from different countries and cities. The objective is to estimate the interval of confidence of the ratio of variances in weight and height, in men and women, between different cities, and determine if the variances are homogeneous.

For example, in the case of comparing the height of men between the cities 1 and 2, the confidence interval for the ratio of variances is between 0.479 and 24.494. Therefore,  the probability for the ratio of variances (p = 0.202), as  the Levene test (p = 0.083) and Brown and Forsythe's test (p = 0.217) are greater than 0.05, so it is accepted the null hypothesis that there are no significant differences in the variances of the height of men between the cities 1 and 2, i.e., there is homogeneity of variances.

However, when comparing the weight of men between the cities 1 and 2, both the probability for the ratio of variances (p = 0.021) and of the Levene test (p = 0.007) are less than 0.05,  but not Brown & Forsythe's test (p = 0.112 ), therefore,  it is reasonable to reject the null hypothesis and, therefore, that there are significant differences between the variances of the height of men between the cities 1 and 2, i.e., there is no homogeneity of variances.

\tabular{clll}{
\figure{RIV4}{options: width=5.2in}
}
}
\examples{
\dontrun{

data(ZIV1)

IV4(data=ZIV1, variables=c("Height","Weight"), group=c("Country","Gender"),
alfa=0.05, varSel=list(c("City","1","2"),c("City","1","3")))

}
}
\keyword{IV4}
