\name{IX1}
\alias{IX1}
\encoding{latin1}
\title{\emph{t}-TEST FOR INDEPENDENT SAMPLES}
\description{It applies the test of the \emph{t} for independent samples and data can be shown by using a boxplot or a beanplot.} 
\usage{
IX1(data, variables, factor, pop1, pop2, trans=NULL, graph="Boxplot",
PAR=NULL, ResetPAR=TRUE, YLAB=NULL, XLAB=NULL, OrderCat=NULL, LabelCat=NULL,
COLOR=NULL, BOXPLOT=NULL, BEANPLOT=NULL, LEGEND=NULL, AXIS=NULL,
MTEXT= NULL, TEXT=NULL, file="Output.txt")
}
\arguments{
  \item{data}{Data file.}
  \item{variables}{Dependent variable.}
  \item{factor}{It defines which is the variable that acts as a factor.}
  \item{pop1}{First group of variable population to be compared.}
  \item{pop2}{Second group of vaiable population to be compared.}
  \item{trans}{Type of transformation that is applied to the data:

1. NULL (untransformed)

2. 1/x2

3. 1/x

4. LN

5. LOG

6. SQR (square root)

7. x2

8. x3

9. EXP (exponential)

10. ASN (arcsine)
}
  \item{graph}{If it is NULL, there is no graph
and the other options are "Boxplot" or "Beanplot".}
  \item{PAR}{Accessing the function \link{PAR} which allows to modify many different aspects of the chart.}
  \item{ResetPAR}{If FALSE, the conditions are not placed by default in the function \link{PAR} and those defined by the user on previous graphics are maintained.}
  \item{YLAB}{A legend for the Y axis in the boxplot and beanplot.}
  \item{XLAB}{A legend for the X axis in the boxplot and beanplot.}
  \item{OrderCat}{It allows to specify a vector with the order in which categories are displayed in the graph.}
  \item{LabelCat}{It allows to specify a vector with the names of the categories of the graph.}
  \item{COLOR}{Vector with the color of the categories of the chart.}
  \item{BOXPLOT}{It allows to specify the characteristics of the boxplot.}
  \item{BEANPLOT}{It allows to specify the characteristics of the beanplot.}
  \item{LEGEND}{It allows to include a legend.}
  \item{AXIS}{It allows to add axes.}
  \item{MTEXT}{It allows to add texts in the margins of the chart.}
  \item{TEXT}{It allows to add a text in any area of the inner part of the chart.}
  \item{file}{TXT FILE. Name of the output file with the results.}
}
\value{A TXT file is obtained with the results of the \emph{t}-test and it can render a boxplot or a beanplot.}
\details{
\strong{IX. CONTRASTS OF HOMOGENEITY IN QUANTITATIVE VARIABLES}

For the contrast of homogeneity, in the case of quantitative variables, there are two types of analysis, the \strong{parametrics}, which come from a model that requires them to meet certain assumptions about the parameters and the probability distribution of the population from which the sample was drawn, and the \strong{non-parametrics}, which are less restrictive to be applied. It should be borne in mind that the parametric statistics is more accurate, but the chance of being applied, as discussed below, are limited.

\strong{IX.1 PARAMETRIC TEST}

\strong{IX.1.1. Requirements}

Before using parametric tests, it is essential to check certain conditions (assumptions) for its application. The most important to consider are:

1. Normal Distribution of the populations.

2. Equality of variances.

For the verification of the hypothesis of normality, it is necessary to perform a goodness of fit test and the Kolmogorov-Smirnov or the Shapiro-Wilk test, explained in the \link{VI3} function, can be used. The normality test should be done on the residuals or differences between the observed values of the dependent variable and the values that predicts the model once estimated parameters. If the residuals are Normal, also the dependent variable will have Normal distribution at each level of each factor. The assumption of equal variances is verified commonly as detailed in the \link{IV4} function or as explained in the examples discussed below.

If our data do not meet the assumption of Normal distribution, the variable would be transformed to assume a Normal distribution as discussed in the following section. In general, the transformation that "normalizes" the data also achieves equal variances. In the event that this fails to reach the Normal distribution and/or the homogeneity of variances, even after transforming the data, the best alternative would be to use a non-parametric method, although sometimes some parametric tests apply not assuming equal variances, as for example the t-test as modified by Welch-Satterthwaite.

\strong{IX.1.2. Transformations}

If the variable is transformed, there will be various possibilities depending on the type of distribution (asymmetric positive or negative, see function \link{II1}).  The literature speaks of the so-called ladder of the transformations of Tukey, which shows the type of transformation recommended depending on the intensity of the asymmetry or the direction in which extreme cases go (Sanchez, 1999). Figure IX.1 is a modification of the chart made by Erickson & Nosanchuk (1977) and adapted by Guisande et al. (2011).
\tabular{c}{
\strong{Figure IX.1.} Ladder of transformations.\cr
\figure{FIX1}{options: width=5.0in}
}
To choose the appropriate transformation, the asymmetry and kurtosis should be taken into account. As the chart shows only the asymmetry,  the influence of kurtosis may give rise to values lower than the average require a square root transformation and values higher than the average require squaring. The transformation that makes closer to zero simultaneously both coefficients must be chosen. 

\strong{IX.1.3. \emph{t}-test}

\emph{IX.1.3.1. Independent samples}

The \emph{t}-test is the most common method to evaluate the differences between the means of two independent groups, for example, two groups of fish subjected to different diets. For this test, the subject should ideally be allocated randomly to two groups, so that any difference in response is due to the treatment (or lack of treatment) and not to other factors. To apply this analysis, it must be ensured that differences in other factors are not masking or enhancing a significant difference between the means. The null hypothesis (\eqn{H_0}) which is commonly used is that the means are equal. In general it is not required that the number of observations in both groups is equal. If the \eqn{H_0} is certain and equal variances are assumed, the statistical (\emph{t}-test) will follow a \emph{t} distribution of Student with \eqn{n_x} +  \eqn{n_y} - 2 degrees of freedom. There is also the option of using the statistical \emph{t} of Student not assuming equal variances, when working with the degrees of freedom of Welch-Sattherthwaite .

\strong{FUNCTIONS}

For the beanplot, the \link[beanplot]{beanplot} function of the beanplot package is used (Kampstra, 2008; Kampstra, 2013). The \link[stats]{shapiro.test} function of the base package stats to perform the Shapiro-Wilk test. Levene's test is performed with the \link[lawstat]{levene.test} function of the lawstat package(Gastwirth et al., 2013). The asymmetry and kurtosis are performed with the \link[e1071]{skewness} and \link[e1071]{kurtosis} functions, respectively, of the package e1071 (Meyer et al., 2014).

\strong{EXAMPLE}

Data on weight and height of boys and girls between 2 and 4 years in Italy and Spain. The aim of this work is to determine if there are significant differences in weight, jointly considering boys and girls in both countries. Figure IX.2 shows the median and distribution of the weight data of children in Italy and Spain.
\tabular{c}{
\strong{Figure IX.2.} Beanplot comparing the weight of children\cr
between Spain and Italy.\cr
\figure{FIX2}{options: width=2.7in}
}
The Shapiro-Wilk test shows that the two populations of children in Spain (p = 0.215) and Italy (p = 0.476) have normal distribution. It will also fulfill the requirement of homogeneity of variances, both considering the average (p = 0.644) as the median (p = 0.643).  Therefore, it is not necessary to perform the analysis again transforming the dependent variable. In the case of failure to fulfill any of the two requirements, there is also information on the asymmetry and the kurtosis of each of the populations, which would help to choose the best processing to perform.
\tabular{c}{
\figure{RIX1-1}{options: width=4.7in}
\cr
\figure{RIX1-2}{options: width=4.7in}
}
Finally, the test of the \emph{t} shows no significant difference in the weight of the boys and girls between Spain and Italy (t =-0.54, df = 117.8, p = 0.588), with mean values of 13.8 and 13.6 kg, respectively.
\tabular{c}{
\figure{RIX2}{options: width=4.7in}
}
}
\references{
Erikson, F.H. & Nosanchuk, T.A. (1977) \emph{Understandig data}. McGraw Hill. Toronto.

Gastwirth, J.L., Gel, Y.R., Hui, W.L.W., Lyubchich, V., Miao, W. & Noguchi, K. (2013).  An R package for biostatistics, public policy, and law. R package version 2.4.1. Available at: \url{http://CRAN.R-project.org/package=lawstat}.

Guisande, C., Vaamonde, A. & Barreiro, A. (2011) \emph{Tratamiento de datos con R, SPSS y STATISTICA}. Ediciones Daz de Santos, Madrid, 978 pp.

Kampstra, P (2008). Beanplot: A Boxplot Alternative for Visual Comparison of Distributions. \emph{Journal of Statistical Software, Code Snippets}, 28: 1-9.

Kampstra, P (2013) Visualization via Beanplots (like Boxplot/Stripchart/Violin Plot). R package version 1.1. Available at: \url{http://CRAN.R-project.org/package=beanplot}.

Meyer, D., Dimitriadou, E., Hornik, K., Weingessel, A., Leisch, F., Chang, C.C. & Lin, C.C (2014) Misc Functions of the Department of Statistics (e1071), TU Wien. R package version 1.6-3. Available at: \url{http://CRAN.R-project.org/package=e1071}.

Snchez, J.J. (1999) \emph{Manual de anlisis estadstico de los datos}. Alianza Editorial. Madrid.
}
\examples{
\dontrun{

data(ZIX1)

#Comparison of the weight of children between Italy and Spain

IX1(data = ZIX1, variables = "Weight", factor = "Country", pop1 = "Spain",
pop2 = "Italy", graph = "Beanplot", PAR = c("cex.lab=1.6", "font.lab=2",
"cex.axis=1.4","family = 'Andalus'", "omi=c(0,0.7,0,0)"),
BEANPLOT = c("col = list(c('red','white'), c('blue','white'))",
"ll = 0.04", "ylab = 'Weight (kg)'", "xlab='Country'"))

}
}
\keyword{IX1}
