\name{IX10}
\alias{IX10}
\encoding{latin1}
\title{CONTRASTS OF NON-PARAMETRIC HOMOGENEITY FOR K INDEPENDENT SAMPLES}
\description{The sum of ranks of Kruskal-Wallis test is applied. In addition, the data can be represented with a boxplot or a beanplot.} 
\usage{
IX10(data, variables, Factor, ResetPAR=TRUE, graph="Boxplot", PAR=NULL, YLAB=NULL,
XLAB=NULL, OrderCat=NULL, LabelCat=NULL, COLOR=NULL, BOXPLOT=NULL,
BEANPLOT=NULL, LEGEND=NULL, AXIS=NULL, MTEXT= NULL, TEXT=NULL, file="Output.txt")
}
\arguments{
  \item{data}{Data file.}
  \item{variables}{Dependent variable.}
  \item{Factor}{It defines which is the variable that acts as a factor.}
  \item{ResetPAR}{If FALSE, the default conditions of the function \link{PAR} are not placed and are those defined by the user in previous graphs.}
  \item{graph}{If NULL, there is no graph and the other options are "Boxplot" or "Beanplot".}
  \item{PAR}{It accesses the function \link{PAR} which allows to modify many different aspects of the graph.}
  \item{YLAB}{Legend of the Y axis in the Boxplot and beanplot.}
  \item{XLAB}{Legend of the X axis in the Boxplot and beanplot.}
  \item{OrderCat}{It allows to specify a vector with the order in which categories are displayed in the graph.}
  \item{LabelCat}{It allows to specify a vector with the names of the categories of the graph.}
  \item{COLOR}{Vector with the color of the categories of the graph.}
  \item{BOXPLOT}{It allows to specify the characteristics of the boxplot.}
  \item{BEANPLOT}{It allows to specify the characteristics of the beanplot.}
  \item{LEGEND}{It allows to include a legend.}
  \item{AXIS}{It allows to add axes.}
  \item{MTEXT}{It allows to add text in the margins of the graph.}
  \item{TEXT}{It allows to add text in any area of the inner part of the graph.}
  \item{file}{TXT FILE. Output file name with the results.}
}
\value{A TXT file is obtained with the results of the test and a boxplot or beanplot can be displayed.}
\details{
\strong{IX. CONTRASTS OF HOMOGENEITY IN QUANTITATIVE VARIABLES}

\strong{IX.2. NON-PARAMETRIC TESTS}

\strong{IX.2.2. Contrasts for \emph{K}-Independent samples}

The most used contrasts are the median and the Kruskal-Wallis test, which are briefly explained below.

\emph{IX.2.2.1. Median contrast}

This is to determine the median value of our observations including all the \emph{k} samples to analyze and characterize all the values as positive, if they are above the median and negative if they are below. If the samples were homogeneous, in each one of them, about half of the values should be above the median and the other half below. This will be the null hypothesis (that all the samples come from the same population).

A contingency table 2x\emph{k} with the number of positive and negative data from each sample is made. A contrast \eqn{\chi^2} of homogeneity is applied with the null hypothesis indicated, i.e., in each sample the expected frequency of positive is equal to the expected frequency of negative.

This contrast is not very sensitive, so it is more accurate using the Kruskal-Wallis test. However, in cases where the orders have artificial limits this contrast, in theory, this is the most suitable.

\emph{IX.2.2.2. ANOVA of Kruskal-Wallis}

The contrast is analogous to the non-parametric analysis of variance, this is why it is called ANOVA, although the statistic has Chi-square distribution. It is the most widely used test for more than two independent samples, being much more sensitive than the test of the median. On a theoretical level, it is an extension of the \emph{U} Mann-Whitney contrast for more than two samples. This means that it is a test that measures the central tendency of the samples, having as null hypothesis that the tested populations have the same median.

The complete development of the calculation of this statistic is at Sokal & Rohlf (1981), in which the steps are:

1. Sort the data in ranges (all samples combined).

2. Add the ranges of each sample and calculate the statistic of \emph{H} that compares with a tabulated value of contrast.

3. If \emph{H} is greater than the tabulated value the null hypothesis is rejected, indicating that the samples are different.

\strong{FUNCTIONS}

For the graph beanplot, the function \link[beanplot]{beanplot} of the beanplot package (Kampstra, 2008; Kampstra, 2013) is used. The Kruskal-Wallis ANOVA is performed with the function \link[stats]{kruskal.test} of the stats package.

\strong{EXAMPLE}

Data from the concentration of nitrite, nitrate and ammonium (\eqn{\mu ML}) in the lakes of the Colombian Amazon in two different months. The aim is to determine whether there are differences in the concentration of nitrate among all lakes.

The test result has a p = 0.131, so the null hypothesis of homogeneity (Figure IX.13) is accepted. 
\tabular{c}{
\figure{RIX21}{options: width=3.8in}
}
\tabular{c}{
\strong{Figure IX.13.} Nitrate concentration (\eqn{\mu ML}) in several lakes of the Amazon\cr
\figure{FIX13}{options: width=2.5in}
}
}
\references{
Kampstra, P. (2008). Beanplot: A Boxplot Alternative for Visual Comparison of Distributions. \emph{Journal of Statistical Software, Code Snippets}, 28: 1-9.

Kampstra, P (2013) Visualization via Beanplots (like Boxplot/Stripchart/Violin Plot). R package version 1.1. Available at: \url{http://CRAN.R-project.org/package=beanplot}.

Sokal, R.R. & Rohlf, F.J. (1981) \emph{Biometry}. WH Freeman and Company, New York.
}
\examples{
\dontrun{

data(ZIX7)

IX10(data=ZIX7, variables="Nitrate", Factor="Lake")

}
}
\keyword{IX10}
