\name{IX11}
\alias{IX11}
\encoding{latin1}
\title{CONTRASTS OF HOMOGENEITY FOR TWO NON-PARAMETRIC DEPENDENT SAMPLES}
\description{The Wilcoxon test is applied for related pairs. In addition, the data can be represented with a boxplot or a beanplot.} 
\usage{
IX11(data, varTime, graph="Boxplot", PAR=NULL, ResetPAR=TRUE, YLAB="Dependent variable",
XLAB="Time", LabelCat=NULL, COLOR=NULL, BOXPLOT=NULL, BEANPLOT=NULL,
LEGEND=NULL, AXIS=NULL, MTEXT=NULL, TEXT=NULL, file="Output.txt")
}
\arguments{
  \item{data}{Data File.}
  \item{varTime}{Columns in which the dependent variable has been measured over time.}
  \item{graph}{If NULL, there is no graph and the other options are "Boxplot" or "Beanplot".}
  \item{PAR}{It accesses the function \link{PAR} which allows to modify many different aspects of the graph.}
  \item{ResetPAR}{If FALSE, the default conditions of the function \link{PAR} are not placed and are those defined by the user in previous graphs.}
  \item{YLAB}{Legend of the Y axis in the boxplot and beanplot.}
  \item{XLAB}{Legend of the X axis in the boxplot and beanplot.}
  \item{LabelCat}{It allows to specify a vector with the names of the categories of the graph.}
  \item{COLOR}{Vector with the color of the categories of the graph.}
  \item{BOXPLOT}{It allows to specify the characteristics of the boxplot.}
  \item{BEANPLOT}{It allows to specify the characteristics of the beanplot.}
  \item{LEGEND}{It allows to include a legend.}
  \item{AXIS}{It allows to add axes.}
  \item{MTEXT}{It allows to add text in the margins of the graph.}
  \item{TEXT}{It allows to add text in any area of the inner part
of the graph.}
\item{file}{TXT FILE. Output file name with the results.}
}
\value{A TXT file is obtained with the results of the test of Wilcoxon for two dependent samples and a boxplot or beanplot can be displayed.}
\details{
\strong{IX. CONTRASTS OF HOMOGENEITY IN QUANTITATIVE VARIABLES}

\strong{IX.2. NON-PARAMETRIC TESTS}

\strong{IX.2.3. Contrasts for two dependent samples}

The tests most commonly used are the contrast of the signs, and the Wilcoxon test for related pairs.

\emph{IX.2.3.1. Contrast of the signs}

This contrast measures the direction of the differences between two paired samples, which is very useful when working with paired samples to which an increase or decrease in the measurement can be identified, but it is difficult to quantify this change. In other conditions, the Wilcoxon test is more sensitive.

The number of times that the differences of the values of the two samples are positive, negative or no difference is studied. With these premises the null hypothesis that the samples  arehomogeneous can be contrasted, since in that case there will be approximately as many positive as negative differences.
 
The full development of the test appears in Siegel & Castellan (1988), but the brief steps are: 

1. Determining differences (+ or -).

2. Adjustment of the differences observed to a binomial distribution. When the number of data is large (greater than 30), an approximation to the Normal distribution of the binomial distribution (statistical calculation of \emph{Z}) is used. 

3. Determination of the probability associated with the statistic of contrast to accept or reject the null hypothesis that the samples are homogeneous.

\emph{IX.2.3.2. Wilcoxon test for related pairs}

The test is similar to the \emph{t} of Student for related samples, being almost as powerful as this. In regard to the sensitivity, it is a contrast much more powerful than the previous one because, although it also uses the differences between the values for each case, the absolute value of the differences are sorted in ranges (not just positive and negative), having more information about the differences in the previous case.

If samples are homogeneous, the null hypothesis, the sum of the ranges of the positive differences must be similar to the sum of the ranges with a negative value (randomness of the differences).

A detailed description of this test is at Siegel & Castellan (1988), the main steps are:

1. Sort the values of the samples in ascending order and sort in ranges the difference in absolute value between both samples.

2. Calculate a test statistic \emph{T} and \eqn{T'}.

3. If \emph{T} or \eqn{T'} is less than or equal to the threshold quantities listed in the so-called Table of Wilcoxon, the null hypothesis that the variables are homogeneous is rejected. 

In the event that the sample size is high (greater than 100), an approximation to the Normal of the statistical \emph{T} can be performed. The value \emph{Z} of the Normal distribution that returns the probability of the contrast can be calculated.

\strong{FUNCTIONS}

For the beanplot, the function \link[beanplot]{beanplot} of the package beanplot (Kampstra, 2008; Kampstra, 2013) is used. The Wilcoxon test is done with the function \link[stats]{wilcox.test} of the stats package.

\strong{EXAMPLE}

Concentration data of erythrocytes (in millions per cubic millimeter), of several men and women who were undergoing a treatment to increase the concentration of red blood cells. The objective is to determine if the concentration is different between the beginning and at the end of a month.

Figure IX.14 shows that the concentration of erythrocytes is very similar to the beginning and at the end of a month, as well as demonstrates the Wilcoxon test (p = 0.57).
\tabular{c}{
\strong{Figure IX.14.} Erythrocyte concentration (in millions per cubic millimeter) in men\cr
and women at the beginning and after a month of treatment.\cr
\figure{FIX14}
}
\tabular{c}{
\figure{RIX22}{options: width=5.0in}
}
}
\references{
Kampstra, P. (2008). Beanplot: A Boxplot Alternative for Visual Comparison of Distributions. \emph{Journal of Statistical Software, Code Snippets}, 28: 1-9.

Kampstra, P (2013) Visualization via Beanplots (like Boxplot/Stripchart/Violin Plot). R package version 1.1. Available at: \url{http://CRAN.R-project.org/package=beanplot}.

Siegel, S. & Castellan, N.J. Jr. (1988) \emph{Nonparametric statistics for the behavioral sciences}. McGraw-Hill, New York.
}
\examples{

\dontrun{

data(ZIX9)

#Variation in the concentration of erythrocytes over time

IX11(data=ZIX9, varTime=c("Beginning", "Month1"),graph = "Beanplot",
XLAB="Time", YLAB="Concentration of erythrocytes")
}
}
\keyword{IX11}
