\name{IX12}
\alias{IX12}
\encoding{latin1}
\title{CONTRASTS OF HOMOGENEITY FOR NON-PARAMETRIC K INDEPENDENT SAMPLES}
\description{Friedman ANOVA is applied to k-related samples.
In addition, the data can be represented with a boxplot or a beanplot.} 
\usage{
IX12(data, varTime, Case, graph="Boxplot", PAR=NULL, ResetPAR=TRUE,
YLAB="Dependent variable", XLAB="Time", LabelCat=NULL, COLOR=NULL, BOXPLOT=NULL,
BEANPLOT=NULL, LEGEND=NULL, AXIS=NULL, MTEXT=NULL, TEXT=NULL, file="Output.txt")
}
\arguments{
  \item{data}{Data file.}
  \item{varTime}{Columns in which the dependent variable has been measured over time.}
  \item{Case}{Variable that identifies each case.}
  \item{graph}{If NULL, there is no graph and the other options are "Boxplot" or "Beanplot".}
  \item{PAR}{It accesses the function \link{PAR} which allows to modify many different aspects of the graph.}
  \item{ResetPAR}{If FALSE, the default conditions of the function \link{PAR} are not placed and are those defined by the user in previous graphs.}
  \item{YLAB}{Legend of the Y axis in the boxplot and beanplot.}
  \item{XLAB}{Legend of the X axis in the boxplot and beanplot.}
  \item{LabelCat}{It allows to specify a vector with the names of the categories of the graph.}
  \item{COLOR}{Vector with the color of the categories of the graph.}
  \item{BOXPLOT}{It allows to specify the characteristics of the boxplot.}
  \item{BEANPLOT}{It allows to specify the characteristics of the beanplot.}
  \item{LEGEND}{It allows to include a legend.}
  \item{AXIS}{It allows to add axes.}
  \item{MTEXT}{It allows to add text in the margins of the graph.}
  \item{TEXT}{It allows to add text in any area of the inner part
of the graph.}
\item{file}{TXT FILE. Output file name with the results.}
}
\value{A TXT file is obtained with the results of the ANOVA of Friedman and a boxplot or beanplot can be displayed.}
\details{
\strong{IX. CONTRASTS OF HOMOGENEITY IN QUANTITATIVE VARIABLES}

\strong{IX.2. NON-PARAMETRIC TESTS}

\strong{IX.2.4. Contrasts for \emph{K}-dependent samples}

The most commonly used test is the Friedman ANOVA. This test contrasts the hypothesis that measures come from the same populations, when data from each of the samples have been transformed into ranks in ascending order.

This test is analogous to ANOVA for repeated samples so, even thought it is a contrast \eqn{\chi^2}, it is called ANOVA.

The steps of this test are described by Siegel & Castellan (1988). Briefly they are: 

1. Assign ranges within each sample case.

2. Add the ranges of each variable for the entire sample.

3. Calculate a test statistic \eqn{\chi^2} and compare it with the tabulated value \eqn{ \chi^ 2} critical with \emph{a} - 1 degrees of freedom, being \emph{a} the number of measured values for each sample.

\strong{FUNCTIONS}

For the beanplot, the function \link[beanplot]{beanplot} of the package beanplot (Kampstra, 2008; Kampstra, 2013) is used. The ANOVA of Friedman is performed with the function  \link[stats]{friedman.test} of the stats package.

\strong{EXAMPLE}

Concentration data of erythrocytes (in millions per cubic millimeter), several men and women who were undergoing a treatment to increase the concentration of red blood cells. The objective is to determine if the concentration of red blood cells is different considering all times analyzed, and considering the set of men and women.

Figure IX.15 shows that the concentration of erythrocytes is very similar at the beginning and in the following months and indeed the results of the contrast of Friedman show that, in the set of men and women, the concentration of red blood cells does not change over time (p = 0.967).
\tabular{c}{
\strong{Figure IX.15.} Erythrocyte concentration (in millions per cubic millimeter) in men\cr
and women at the beginning and in the next three months.\cr
\figure{FIX15}
}
\tabular{c}{
\figure{RIX23}{options: width=5.0in}
}
}
\references{
Kampstra, P. (2008). Beanplot: A Boxplot Alternative for Visual Comparison of Distributions. \emph{Journal of Statistical Software, Code Snippets}, 28: 1-9.

Kampstra, P (2013) Visualization via Beanplots (like Boxplot/Stripchart/Violin Plot). R package version 1.1. Available at: \url{http://CRAN.R-project.org/package=beanplot}.

Siegel, S. & Castellan, N.J. Jr. (1988) \emph{Nonparametric statistics for the behavioral sciences}. McGraw-Hill, New York.
}
\examples{
\dontrun{

data(ZIX10)

#Variation in the concentration of erythrocytes over time

IX12(data=ZIX10, varTime=c("Beginning", "Month1", "Month2", "Month3"),
Case="Individual", XLAB="Time (months)", YLAB="Concentration of erythrocytes")
}
}
\keyword{IX12}
