\name{IX13}
\alias{IX13}
\encoding{latin1}
\title{ANALYSIS OF COVARIANCE (ANCOVA) NON-PARAMETRIC}
\description{An analysis of covariance using a statistical ANOVA type (Wang & Ye, 2010; Wang, 2013) is applied. In addition, the relationship between the dependent variable and the covariate can be plotted, differentiating between the groups of the factor.} 
\usage{
IX13(data, variables, Factor, Covariable, T.AOV=NULL, ResetPAR=TRUE,
graph=TRUE, PAR=NULL, YLAB=NULL, XLAB=NULL, MAIN=NULL, CEXPCH=1.3,
COLOR=NULL, PCH=NULL, LEGEND=NULL, AXIS=NULL, MTEXT= NULL, TEXT=NULL,
file="Output.txt")
}
\arguments{
  \item{data}{Data file.}
  \item{variables}{Dependent variable.}
  \item{Factor}{Factor.}
  \item{Covariable}{Covariate.}
  \item{T.AOV}{It accesses the funtion \link[fANCOVA]{T.aov}.}
  \item{ResetPAR}{If FALSE, the conditions are not placed by default in the \link{PAR} function and are those defined by the user in previous graphics.}
  \item{graph}{If NULL, the graph is not performed.}
  \item{PAR}{It accesses the function \link{PAR} that allows to modify many different aspects of the graph.}
  \item{YLAB}{Legend of the Y axis.}
  \item{XLAB}{Legend of the X axis.}
  \item{MAIN}{Graph title.}
  \item{CEXPCH}{Size of the graph symbols.}
  \item{COLOR}{This allows to change the colors of the graph,
but it must be as many different groups as the factor has.}
  \item{PCH}{Vector with the symbols on the graph, but they must be as many as different groups have the factor. If it is NULL, they are automatically calculated starting with the symbol 15.}
  \item{LEGEND}{It allows to include a legend to a graph.}
  \item{AXIS}{It allows to add axis to a graph.}
  \item{MTEXT}{It allows to add text in the margins of the graph.}
  \item{TEXT}{It allows to add text in any area of the inner part of the chart.}
  \item{file}{TXT FILE. Output file name with the results.}
}
\value{A TXT file is obtained with the results of non-parametric ANCOVA and a graph can be represented linking the dependent variable with the covariate, besides differentiating between factor groups.}
\details{
\strong{IX. CONTRASTS OF HOMOGENEITY IN QUANTITATIVE VARIABLES}

\strong{IX.2. NONPARAMETRIC TESTS}

\strong{IX.2.5. Non-parametric ANCOVA}

There are also non-parametric methods to perform an analysis of covariance. The package fANCOVA (Wang & Ye, 2010; Wang, 2013) contains some functions that perform this analysis based on the idea of comparing two curves to check their equality or parallelism, which is valid for regression curves or for density functions, and therefore can be considered equivalent to a parametric analysis of covariance.

\strong{FUNCTIONS}

It uses the function \link[fANCOVA]{T.aov} of package fANCOVA (Wang & Ye, 2010; Wang, 2013), which uses a statistical type (ANOVA) to perform the non-parametric ANCOVA.

\strong{EXAMPLE 1}

It compares the relationship between minimum and maximum temperature between the years 1990 and 2000, considering the daily records of three cities in Spain: Huelva, Palma de Mallorca and Vigo. The objective is to determine if there are differences in the maximum temperature between the two years, once eliminated the possible effect of the minimum temperature that is considered as a covariate.

It is important to mention that the variables must be numeric, i.e., it has been observed that if variables are used with text, the function can result in errors. If it is necessary to make the graph with variables of text(to better fit the legend), the parametric ANCOVA of the function \link{IX4} can be used.

The results show that there were no significant differences in the relationship between minimum and maximum temperature between the years 1990 and 2000 (p = 0.383). It is important to note that if the analysis is repeated, the probability value can be changed, i.e., it does not always give the same result.
\tabular{c}{
\figure{RIX24}{options: width=5.3in}
}
Figure IX.16 shows that there is a clear relationship between maximum and minimum temperature considering the three cities.\tabular{c}{
\strong{Figure IX.16.} Relationship between minimum and maximum temperature in 1990 and 2000,\cr
in three cities in Spain: Huelva, Palma de Mallorca and Vigo.\cr
\figure{FIX16}{options: width=4.2in}
}
\strong{EXAMPLE 2}

It compares the relationship between minimum and maximum temperature with daily records in 1990 and 2000, between three cities in Spain: Huelva, Palma de Mallorca and Vigo. The objective is to determine if there are differences in temperature between the three cities, removing the possible effect of the minimum temperature which is considered as a covariate.

Figure IX.17 shows that there are clear differences in the relationship between minimum and maximum temperature between the three cities, which is confirmed by contrast, since p = 0.005.
\tabular{c}{
\figure{RIX25}{options: width=5.2in}
}
\tabular{c}{
\strong{Figure IX.17.} Relationship between the minimum and maximum temperature, considering the years\cr
1990 and 2000, in three cities in Spain: Huelva, Palma de Mallorca and Vigo.\cr
\figure{FIX17}{options: width=4.2in}
}
}
\references{
Wang. X.F. & Ye, D. (2010). On nonparametric comparison of images and regression surfaces. \emph{Journal of Statistical Planning and Inference}, 140; 2875-2884.

Wang, X.F. (2013). Nonparametric Analysis of Covariance. R package version 0.5-1. Available at: \url{http://CRAN.R-project.org/package=fANCOVA}.
}
\examples{
\dontrun{

data(ZIX11)

#EXAMPLE 1
IX13(data=ZIX11, variables="T.Max", Factor="Year", Covariable="T.Min",
XLAB="Minimum temperature (degree C)", YLAB="Maximum temperature (degree C)",
MAIN="Factor Year", CEXPCH=0.8)

#EXAMPLE 2
IX13(data=ZIX11, variables="T.Max", Factor="City", Covariable="T.Min",
XLAB="Minimum temperature (degree C)", YLAB="Maximum temperature (degree C)", MAIN="Factor City",
CEXPCH=0.8, LEGEND=c("x = 'topleft'" , "legend=c('Huelva', 'Palma de Mallorca','Vigo')",
"bty = 'n'", "pch=c(15,16,17)", "col=rainbow(3)", "cex=1.2"))

}
}
\keyword{IX13}
