\name{IX2}
\alias{IX2}
\encoding{latin1}
\title{\emph{t}-TEST FOR DEPENDENT SAMPLES}
\description{It applies the test of the \emph{t} for dependent samples and data can be shown by using a boxplot or a beanplot.} 
\usage{
IX2(data, variables, factor, pop1, pop2, trans=NULL, graph="Boxplot", PAR=NULL,
ResetPAR=TRUE, YLAB=NULL, XLAB=NULL, OrderCat=NULL, LabelCat=NULL, COLOR=NULL,
BOXPLOT=NULL, BEANPLOT=NULL, LEGEND=NULL, AXIS=NULL, MTEXT= NULL, TEXT=NULL,
file="Output.txt")
}
\arguments{
  \item{data}{Data file.}
  \item{variables}{Dependent variable.}
  \item{factor}{It defines which is the variable that acts as a factor.}
  \item{pop1}{First group of variable population to be compared.}
  \item{pop2}{Second group of variable population to be compared.}
  \item{trans}{Type of transformation that is applied to the data:

1. NULL (untransformed)

2. 1/x2

3. 1/x

4. LN

5. LOG

6. SQR (square root)

7. x2

8. x3

9. EXP (exponential)

10. ASN (arcsine)
}
  \item{graph}{If it is NULL, there is no graph and the other options are "Boxplot" or "Beanplot".}
  \item{PAR}{Accessing the function \link{PAR} which allows to modify many different aspects of the chart.}
  \item{ResetPAR}{If FALSE, the conditions are not placed by default in the function \link{PAR} and those defined by the user on previous graphics are maintained.}
\item{YLAB}{A legend for the Y axis in the boxplot and beanplot.}
  \item{XLAB}{A legend for the X axis in the boxplot and beanplot.}
  \item{OrderCat}{It allows to specify a vector with the order in which categories are displayed in the graph.}
  \item{LabelCat}{It allows to specify a vector with the names of the categories of the graph.}
  \item{COLOR}{Vector with the color of the categories of the chart.}
  \item{BOXPLOT}{It allows to specify the characteristics of the Boxplot.}
  \item{BEANPLOT}{It allows to specify the characteristics of the beanplot.}
  \item{LEGEND}{It allows to include a legend.}
  \item{AXIS}{It allows to add axes.}
  \item{MTEXT}{It allows to add texts in the margins of the chart.}
  \item{TEXT}{It allows to add a text in any area of the inner part of the chart.}
  \item{file}{TXT FILE. Name of the output file with the results.}
}
\value{A TXT file is obtained with the results of the \emph{t}-test and it can render a boxplot or a beanplot.}
\details{
\strong{IX. CONTRASTS OF HOMOGENEITY IN QUANTITATIVE VARIABLES}

\strong{IX.1.3. \emph{t}-test}

\emph{IX.1.3.2. Dependent samples}

The \emph{t}-test for related samples compares the means of two variables for a single group. It calculates the differences between the values of each variable and verifies if the average difference is significantly different from zero (Sanchez, 1999).

This test assumes that the samples are dependent, paired or related, therefore, a fundamental requirement is to have an equal number of observations in both variables.

This \emph{t}-test for dependent samples requires no assumption about the variances, but requires that the differences in the values of each pair be normally distributed. If it is not, but the sample size is large, the central limit theorem guarantees that the probability distribution of the mean difference be approximately Normal, which allows to use the Normal distribution instead of the \emph{t} distribution. Given that both distributions are virtually identical when the number of degrees of freedom is very large, this means that with large samples, the test can be applied even if the distribution of the variable deviates from normal.

The dependent samples often appear when evaluating the same variable more than once in each subject in the sample (for example in different time ranges). The \emph{t}-test is not focused on the variability that can occur between individuals, but in the observed differences in a same subject from one moment to the next. This test is also applied in case-control studies where each case individually paired with a control.

\strong{FUNCTIONS}

For the beanplot, the \link[beanplot]{beanplot} function of the beanplot package is used (Kampstra, 2008; Kampstra, 2013). The \link[stats]{shapiro.test} function of the base package stats to perform the Shapiro-Wilk test. Levene's test is performed with the \link[lawstat]{levene.test} function of the lawstat package(Gastwirth et al., 2013). The asymmetry and kurtosis are performed with the \link[e1071]{skewness} and \link[e1071]{kurtosis} functions, respectively, of the package e1071 (Meyer et al., 2014).

\strong{EXAMPLE}

Data on weight and height of boys and girls between 2 and 3 years in Italy and Spain. The objective is to determine if there are significant differences in the height of girls between the ages of 2 and 3 in Italy. Boys and girls that are measured and weighted as they age are always the same.

Figure IX.3 shows clear differences in the height of Italian girls aged 2 and 3 years. 
\tabular{c}{
\strong{Figure IX.3.} Boxplot comparing the height of Italian girls\cr
between the ages of two and three.\cr
\figure{FIX3}{options: width=3.8in}
}
The Shapiro-Wilk test shows that the two populations of girls of 2 (p = 0.415) and 3 (p = 0.29) years have normal distribution. It also fulfills the requirement of homogeneity of variances,  considering both the mean (p = 0.831) and  median (p = 0.817).  Therefore, it is not necessary to perform the analysis again transforming the dependent variable. In the case of failure to fulfill any of the two requirements, there is also information on the asymmetry and the kurtosis of each of the populations, which would help to better choose on the transformation to be performed.
\tabular{c}{
\figure{RIX3-1}{options: width=4.9in}
\cr
\figure{RIX3-2}{options: width=4.9in}
}
Finally, the test of the \emph{t} shows that there are significant differences in the height of Italian girls between ages of 2 and 3 (t =-25.1 , df = 9, p < 0.001), with a difference of 8.2 cm.
\tabular{c}{
\figure{RIX4}{options: width=4.9in}
}
}
\references{
Gastwirth, J.L., Gel, Y.R., Hui, W.L.W., Lyubchich, V., Miao, W. & Noguchi, K. (2013).  An R package for biostatistics, public policy, and law. R package version 2.4.1. Available at: \url{http://CRAN.R-project.org/package=lawstat}.

Kampstra, P (2008). Beanplot: A Boxplot Alternative for Visual Comparison of Distributions. \emph{Journal of Statistical Software, Code Snippets}, 28: 1-9.

Kampstra, P (2013) Visualization via Beanplots (like Boxplot/Stripchart/Violin Plot). R package version 1.1. Available at: \url{http://CRAN.R-project.org/package=beanplot}.

Meyer, D., Dimitriadou, E., Hornik, K., Weingessel, A., Leisch, F., Chang, C.C. & Lin, C.C (2014) Misc Functions of the Department of Statistics (e1071), TU Wien. R package version 1.6-3. Available at: \url{http://CRAN.R-project.org/package=e1071}.

Snchez, J.J. (1999) \emph{Manual de anlisis estadstico de los datos}. Alianza Editorial. Madrid.
}
\examples{
\dontrun{

#Comparison of the height of Italian girls between 2 and 3 years.

data(ZIX1)

data1<-subset(ZIX1, Country=="Italy"  &  Gender=="Girl")

IX2(data=data1, variables="Height", factor="Age", pop1=2, pop2=3,
BOXPLOT= c("xlab='Age'", "ylab='Height (cm)'", "cex.lab=1.6", "col=c('red','green')",
"notch=TRUE", "cex.axis=1.4"), PAR=c("omi=c(0,0.2,0,0)", "font.lab=2"))

}
}
\keyword{IX2}
