\name{IX5}
\alias{IX5}
\encoding{latin1}
\title{ANOVA FOR FACTORS WITH REPEATED MEASURES}
\description{ANOVA was applied for dependent samples
and the data can be displayed with a boxplot or beanplot.} 
\usage{
IX5(data, varTime, graph="Boxplot", SS=2, PAR=NULL, ResetPAR=TRUE,
YLAB="Dependent variable", XLAB="Time", LabelCat=NULL, COLOR=NULL,
BOXPLOT=NULL, BEANPLOT=NULL, LEGEND=NULL, AXIS=NULL, MTEXT=NULL,
TEXT=NULL, file="Output.txt")
}
\arguments{
  \item{data}{Data file.}
  \item{varTime}{Columns in which the dependent variable has been measured over time.}
  \item{graph}{If it is NULL, there is no graph and the other options are "Boxplot" or "Beanplot".}
  \item{SS}{When there are several factors, the decomposition of the sum of squares in parts attributed to each one of the factors is not unique. Four types of sums of squares are commonly used: type I for nested models, type II for balanced models, type III for unbalanced models (also balanced), and type IV for models with empty boxes. As a model of repeated measures all the boxes of the model have equal number of data (balanced model), the type II will be used by default.
This description is very simplified; interested readers should consult supplementary bibliography for a correct use of the ANOVA with complex models.}
  \item{PAR}{Accessing the function \link{PAR} which allows to modify many different aspects of the chart.}
  \item{ResetPAR}{If FALSE, the conditions are not placed by default in the function \link{PAR} and those defined by the user on previous graphics are maintained.}
  \item{YLAB}{A legend for the Y axis in the boxplot and beanplot.}
  \item{XLAB}{A legend for the X axis in the boxplot and beanplot.}
  \item{LabelCat}{It allows to specify a vector with the order in which categories are displayed in the graph.}
  \item{COLOR}{Vector with the color of the categories of the chart.}
  \item{BOXPLOT}{It allows to specify the characteristics of the boxplot.}
  \item{BEANPLOT}{It allows to specify the characteristics of the beanplot.}
  \item{LEGEND}{It allows to include a legend.}
  \item{AXIS}{It allows to add axes.}
  \item{MTEXT}{It allows to add texts in the margins of the chart.}
  \item{TEXT}{It allows to add a text in any area of the inner part of the chart.}
\item{file}{TXT FILE. Name of the output file.}
}
\value{A TXT file with the results of the ANOVA is obtained  for dependent samples and a boxplot or beanplot can also be displayed.}
\details{
\strong{IX. CONTRASTS OF HOMOGENEITY IN QUANTITATIVE VARIABLES}

\strong{IX.1.6. ANOVA for factors with repeated measures}

The function \link{IX2} showed that there was a form of \emph{t}-test that was used in the case of wanting to make a contrast of homogeneity of related or matched data.
However, it may be the case that the factor has more than two levels or that has more than one factor. For example, several people were selected and asked to give a score from 0 to 10 on the quality of five different perfumes. In these cases the \emph{t}-test only allows to compare two perfumes together. To compare the five joint, an analysis of variance for repeated measures must be used.

The analysis with repeated measures is designed to more precisely determine the residual error, which will be less if we are able to control or delete the variability between subjects and leave only the variability intra subject.
The smaller is the residual error, the more precise determination of significant effects, as each effect is compared with the residual variability to know if it is significant.

This type of analysis of variance can be univariate or multifactorial, i.e., the fact of working with one or more factors with repeated measures in all factors or only in one of them. This also allows to include covariates, i.e., to run an ANCOVA (analysis of covariance, see function \link{IX7}). 

\strong{FUNCTIONS}

For the beanplot, the function \link[beanplot]{beanplot} of the package beanplot (Kampstra, 2008; Kampstra, 2013) is used. The linear model is performed with the function\link[stats]{lm} of the package stats. The ANOVA is performed with the \link[car]{Anova} of the package car (Fox et al., 2014).
 
\strong{EXAMPLE}

In an experiment conducted with expert tasters and people who had no experience of tasting, they were taught to identify 15 types of wines from different regions. The objective was to determine whether the ability to ascertain the provenance of the wine varied over time (after one hour, one day, one week and one month). To do this, each time each person evaluated a large number of samples and recorded the degree of success on a scale of 0 to 12.
 
Figure IX.6 clearly shows how the skill of the tasters decreases with time.
\tabular{c}{
\strong{Figure IX.6.} Degree of success of the tasters over time.\cr
\figure{FIX6}{options: width=3.5in}
}
The results indicate that the time is a significant factor (p < 0.001). The observed differences in the degree of success over time are not due to chance, but that the learned capacity to correctly identify the wines is lost with time.
\tabular{c}{
\figure{RIX11}{options: width=4.8in}
}
A requirement of the statistical \emph{F} in the ANOVA with repeated measures is that the variances of the differences between each two levels of the intra-subject factor, time, must be equal, and the levels independent of each other. This assumption is equivalent to stating that the variance-covariance matrix is proportional to the unit matrix (equal variances and null covariances), or that the joint dispersion is spherical. The table shows the results of the test of sphericity of Mauchley. As the value \emph{p} is greater than 0.05 (p = 0.073) the assumption of sphericity is accepted.
\tabular{c}{
\figure{RIX11-1}{options: width=4.9in}
}
If the requirement of sphericity might not be fulfilled (if the value \emph{p} is less than 0.05), one of the two modifications that are also shown should be used: Greenhouse-Geisser and Huynh-Feldt, to correct the degrees of freedom downward which allows to adjust (increase) the \emph{p} value of the ANOVA contrast. In this case both corrected \emph{p} values \eqn{2.282*10^{-14}} and \eqn{5.136*10^{-16}} are virtually zero, so it also shows a significant relationship between time and accuracy.

Once tested the significant relationship, it is necessary to know which of the levels are different (at least two are).  For this a \emph{t} test with the two levels to be compared must be used. The function automatically performs all the comparisons between each time. For example, the results of the comparison of the degree of coincidence after one hour and after one day are displayed. As the p-value < 0.001, one can conclude that the degree of success is significantly different between hour and day.
\tabular{c}{
\figure{RIX12}{options: width=4.5in}
}
When making multiple comparisons, such as the above-mentioned, it must be remembered that it is necessary to use some type of protection, especially when making many comparisons, to avoid the increase of the probability of error of type I. For example, one can divide the significance level by the number of comparisons (Bonferroni method).
}
\references{
Fox, J., Weisberg, S., Adler, D., Bates, D., Baud-Bovy, G., Ellison, S., Firth, D., Friendly, M., Gorjanc, G., Graves, S., Heiberger, R., Laboissiere, R., Monette, G., Murdoch, D., Nilsson, H., Ogle, D., Ripley, B., Venables, W. & Zeileis, A. (2014) Companion to Applied Regression. R package version 2.0-20. Available at: \url{http://CRAN.R-project.org/package=car}.

Kampstra, P. (2008). Beanplot: A Boxplot Alternative for Visual Comparison of Distributions. \emph{Journal of Statistical Software, Code Snippets}, 28: 1-9.

Kampstra, P (2013) Visualization via Beanplots (like Boxplot/Stripchart/Violin Plot). R package version 1.1. Available at: \url{http://CRAN.R-project.org/package=beanplot}.
}
\examples{
\dontrun{

data(ZIX5)

#Variation in the ability to ascertain the origin of a
#wine versus time

IX5(data = ZIX5 , varTime = c("Hour","Day","Week","Month") ,
YLAB = "Degree of success")

}
}
\keyword{IX5}
