\name{IX7}
\alias{IX7}
\encoding{latin1}
\title{ANCOVA FOR FACTORS WITH REPEATED AND NON-REPEATED MEASURES}
\description{An ANCOVA and a covariate in which there are factors with repeated measures (factors intra-subject) and factors without repeated measures (factors inter-subject) are applied. In addition to displaying the data with a boxplot or beanplot and an interaction graph of each of the factors along with the time factor.} 
\usage{
IX7(data, varTime, Factor1, Covariable, Error, Factor2=NULL, Factor3=NULL, SS=2,
ResetPAR=TRUE, mfrow=NULL, YLAB="Dependent variable",
XLAB="Time", graphT="Boxplot", PART=NULL, LabelCatT=NULL,
COLORT=NULL, BOXPLOTT=NULL, BEANPLOTT=NULL, LEGENDT=NULL, AXIST=NULL,
MTEXTT= NULL, TEXTT=NULL, graph1="Boxplot", PAR1=NULL, OrderCat1=NULL,
LabelCat1=NULL, COLOR1=NULL, BOXPLOT1=NULL, BEANPLOT1=NULL, LEGEND1=NULL,
AXIS1=NULL, MTEXT1= NULL, TEXT1=NULL, graph2="Boxplot",  PAR2=NULL,
OrderCat2=NULL, LabelCat2=NULL, COLOR2=NULL, BOXPLOT2=NULL, BEANPLOT2=NULL,
LEGEND2=NULL, AXIS2=NULL, MTEXT2= NULL, TEXT2=NULL, graph3="Boxplot",
PAR3=NULL, OrderCat3=NULL, LabelCat3=NULL, COLOR3=NULL, BOXPLOT3=NULL,
BEANPLOT3=NULL, LEGEND3=NULL, AXIS3=NULL, MTEXT3= NULL, TEXT3=NULL,
INTERPLOT1=NULL, INTERPLOT2=NULL, INTERPLOT3=NULL, file="Output.txt")
}
\arguments{
  \item{data}{Data file.}
  \item{varTime}{Columns in which the dependent variable has been measured over time.}
  \item{Factor1}{First factor.}
  \item{Covariable}{Covariate.}
  \item{Error}{It is the variable that encodes the subjects studied.}
  \item{Factor2}{Second factor.}
  \item{Factor3}{Third factor.}
  \item{SS}{When there are several factors, the decomposition of the sum of squares in parts attributed to each one of the factors is not unique. Four types of sums of squares are commonly used: type I for nested models, type II for balanced models, type III for unbalanced models (also balanced), and type IV for models with empty boxes. As a model of repeated measures all the boxes of the model have equal number of data (balanced model), the type II will be used by default. This description is very simplified; interested readers should consult supplementary bibliography for a correct use of the ANOVA with complex models.}
  \item{ResetPAR}{If FALSE, the conditions are not placed by default in the function \link{PAR} and those defined by the user on previous graphics are maintained.}
  \item{mfrow}{If it is NULL and there are various graphics, these appear in separate windows. If the graphics go into panels, this argument is a vector with the format c(nr, nc) indicating the number of figures per row (nr) and column (nc), by first filling the rows.}
  \item{YLAB}{A legend for the Y axis in the boxplot and beanplot.}
  \item{XLAB}{A legend for the X axis in the boxplot and beanplot.}
  \item{graphT}{If NULL, the graphic of factor time is not performed and the other options are "Boxplot" or "Beanplot".}
  \item{PART}{This accesses the function \link{PAR} which allows to modify many different aspects of the graph of the time factor.}
  \item{LabelCatT}{This allows to specify a vector with the names of the categories of the graph of the time factor.}
  \item{COLORT}{Vector with the color of the categories
of the graph of the time factor.}
  \item{BOXPLOTT}{It allows to specify the characteristics of the boxplot graph of the time factor.}
  \item{BEANPLOTT}{It allows to specify the characteristics of the beanplot graph of the time factor.}
  \item{LEGENDT}{It allows to include a legend to the graph of the time factor.}
  \item{AXIST}{It allows to add axes to the graph of the time factor.}
  \item{MTEXTT}{It allows to add text in the margins of the graph of the time factor.}
  \item{TEXTT}{It allows to add text in any area of the inner part of the graph of the time factor.}
  \item{graph1}{If NULL, the graphic of factor 1 is not performed and the other options are "Boxplot" or "Beanplot".}
  \item{PAR1}{This accesses the function \link{PAR} which allows to modify many different aspects of the graph of the factor 1.}
  \item{OrderCat1}{It allows to specify a vector with the order in which the categories are shown in graph 1.}
  \item{LabelCat1}{It allows to specify a vector with the names of the categories of graph 1.}
  \item{COLOR1}{Vector with the color of the categories of graph 1.}
  \item{BOXPLOT1}{It allows to specify the characteristics of the boxplot of factor 1.}
  \item{BEANPLOT1}{It allows to specify the characteristics of the beanplot of factor 1.}
  \item{LEGEND1}{It allows to include a legend to the graph of factor 1.}
  \item{AXIS1}{It allows to add axes to the graph of factor 1.}
  \item{MTEXT1}{It allows to add texts on the margins of the graph of factor 1.}
  \item{TEXT1}{It allows to add text in any area of the inner part of the graph of factor 1.}
  \item{graph2}{If NULL, the graphic of factor 2 is not performed and the other options are "Boxplot" or "Beanplot".}
  \item{PAR2}{This accesses the function \link{PAR} which allows to modify many different aspects of the graph of the factor 2.}
  \item{OrderCat2}{It allows to specify a vector with the order in which the categories are shown in graph 2.}
  \item{LabelCat2}{It allows to specify a vector with the names of the categories of graph 2.}
  \item{COLOR2}{Vector with the color of the categories of graph 2.}
  \item{BOXPLOT2}{It allows to specify the characteristics of the boxplot of factor 2.}
  \item{BEANPLOT2}{It allows to specify the characteristics of the beanplot of factor 2.}
  \item{LEGEND2}{It allows to include a legend to the graph of the factor 2.}
  \item{AXIS2}{It allows to add axes to the graph of the factor 2.}
  \item{MTEXT2}{It allows to add text in the margins of the graph of the factor 2.}
 \item{TEXT2}{It allows to add text in any area of the inner part of the graph of the factor 2.}
  \item{graph3}{If NULL, the graphic of factor 3 is not performed and the other options are "Boxplot" or "Beanplot".}
  \item{PAR3}{This accesses the function \link{PAR} which allows to modify many different aspects of the graph of the factor 3.}
  \item{OrderCat3}{It allows to specify a vector with the order in which the categories are shown in graph 3.}
  \item{LabelCat3}{It allows to specify a vector with the names of the categories of graph 3.}
  \item{COLOR3}{Vector with the color of the categories of graph 3.}
  \item{BOXPLOT3}{It allows to specify the characteristics of the boxplot of factor 3.}
  \item{BEANPLOT3}{It allows to specify the characteristics of the beanplot of factor 3.}
  \item{LEGEND3}{It allows to include a legend to the graph of the factor 3.}
  \item{AXIS3}{It allows to add axes to the graph of the factor 3.}
  \item{MTEXT3}{It allows to add text in the margins of the graph of the factor 3.}
  \item{TEXT3}{It allows to add text in any area of the inner part of the graph of the factor 3.}
  \item{INTERPLOT1}{It allows to specify the characteristics  of the graph of interaction of factor 1.}
  \item{INTERPLOT2}{It allows to specify the characteristics  of the graph of interaction of factor 2.}
  \item{INTERPLOT3}{It allows to specify the characteristics  of the graph of interaction of factor 3.}
  \item{file}{TXT FILE. Output file name.}
}
\value{A TXT file with the results of the ANOVA is obtained,  
and a boxplot or a beanplot can be displayed for each factor, in addition to showing an interaction graph of each of the factors with the time factor.}
\details{
\strong{IX. CONTRASTS OF HOMOGENEITY IN QUANTITATIVE VARIABLES}

\strong{IX.1.7. ANOVA for factors with repeated and non-repeated measures}

See section \emph{details} of the function \link{IX5} or Guisande et al. (2011) for an explanation on this type of ANOVA.

\strong{FUNCTIONS}

For the beanplot, the function \link[beanplot]{beanplot} of the package beanplot (Kampstra, 2008; Kampstra, 2013)is used. The linear model is performed with the function\link[stats]{lm}, the ANOVA with the function \link[stats]{aov} and the graph of interaction is performed with the function \link[stats]{interaction.plot}, all of the stats package.

\strong{EXAMPLE}

In an experiment conducted with expert tasters and people who had no experience of tasting, they were taught to identify 15 types of wines from different regions. The objective was to determine whether the ability to ascertain the provenance of the wine varied over time (after one hour, one day, one week and one month), and depending on the experience. To do this, every time each person assessed a large number of samples and the degree of success on a scale of 0 to 12 was recorded. In addition, the possible influence of the age of the tasters, which was considered as a covariate was taken into account.

Figure IX.8 clearly shows how the degree of accuracy of the tasters decreases over time (left panel), but experienced tasters have a greater degree of success than those who do not have (central panel) and finally the interaction graph seems to show that the degree of success, or intensity of memory, decreases over time from one hour to one month, similar in both groups (both lines are approximately parallel, especially between one day and one month). The intensity is smaller as time passes, and experts always maintain a degree of success two or three points higher than non-experts. However, it is necessary to check whether this difference is statistically significant.
\tabular{c}{
\strong{Figure IX.8.} Panel showing the degree of accuracy of the tasters along the time (left panel),\cr
the average value of the tasters with and without experience(central panel)\cr
and the interaction graph (right panel).\cr
\figure{FIX8}{options: width=5.5in}
}
The Experience factor is significant, with p < 0.001. The factor Time is also significant(p < 0.001), as we had already checked, and the interaction between them, with p = 0.044, which means that the evolution of the memory is different in both groups, and the curves are not really parallel as it had seemed before. Therefore, the ability to identify the origin of wine decreases with different intensity over time between experts and non-experts. Finally, the age also has a significant effect on the degree of success, with p < 0.001.
\tabular{c}{
\figure{RIX13-2}
}
A requirement of the statistical \emph{F} in the ANOVA with repeated measures is that the variances of the differences between each two levels of the intra-subject factor, time, must be equal, and the levels independent of each other. This assumption is equivalent to stating that the variance-covariance matrix is proportional to the unit matrix (equal variances and null covariances),or that the joint dispersion is spherical. The table shows the results of the test of sphericity of Mauchley. As the value \emph{p} is greater than 0.05 (p = 0.57) the assumption of sphericity is accepted.
\tabular{c}{
\figure{RIX13-3}
}
If the requirement of sphericity might not be fulfilled (if the value\emph{p} is less than 0.05), one of the two modifications that are also shown should be used: Greenhouse-Geisser and Huynh-Feldt, to correct the degrees of freedom downward which allows to adjust (increase) the \emph{p value} of the ANOVA contrast. In this case both corrected \emph{p} values \eqn{2.2*10^{-16}} and \eqn{4.1*10^{-23}} are virtually zero, so it also shows a significant relationship between time and accuracy.
}
\references{
Guisande, C., Vaamonde, A. & Barreiro, A. (2011) Tratamiento de datos con R, STATISTICA y SPSS. Ediciones Daz de Santos, Madrid, 978 pp.

Kampstra, P. (2008). Beanplot: A Boxplot Alternative for Visual Comparison of Distributions. \emph{Journal of Statistical Software, Code Snippets}, 28: 1-9.

Kampstra, P (2013) Visualization via Beanplots (like Boxplot/Stripchart/Violin Plot). R package version 1.1. Available at: \url{http://CRAN.R-project.org/package=beanplot}.
}
\examples{
\dontrun{

data(ZIX5)

#Variation in the ability to ascertain the origin of
#a wine versus time and, age and experience of the sommelier 

IX7(data = ZIX5, varTime = c("Hour","Day","Week","Month"), Factor1 = "Experience",
Covariable = "Age" , Error = "Sommelier", mfrow = c(1,3), YLAB = "Degree of success",
graphT = "Beanplot", graph1 = "Beanplot", PART = c("cex.axis = 1.5", "cex.lab = 1.8",
"font.lab = 2", "mar = c(5,5,3,2)"), PAR1 = c("cex.axis = 1.5", "cex.lab = 1.8",
"font.lab = 2", "mar = c(5,5,3,2)"), INTERPLOT1 = c("ylab=YLAB", "xlab=XLAB",
"legend=TRUE", "main='Factor Experience'","cex.main=2", "cex.lab=1.8",
"col=rainbow(length(unique(datos4[,Factor1])))", "trace.label=''"))
}
}
\keyword{IX7}
