\name{IX9}
\alias{IX9}
\encoding{latin1}
\title{CONTRASTS OF NON-PARAMETRIC HOMOGENEITY FOR TWO INDEPENDENT SAMPLES}
\description{The Kolmogorov-Smirnov test for two samples and the sum of ranks of Wilcoxon are applied. In addition, the data can be represented with a boxplot or a beanplot.} 
\usage{
IX9(data, variables, factor, pop1, pop2, graph="Boxplot", PAR=NULL,
ResetPAR=TRUE, YLAB=NULL, XLAB=NULL, OrderCat=NULL, LabelCat=NULL,
COLOR=NULL, BOXPLOT=NULL, BEANPLOT=NULL, LEGEND=NULL, AXIS=NULL, MTEXT= NULL,
TEXT=NULL, file="Output.txt")
}
\arguments{
  \item{data}{Data file.}
  \item{variables}{Dependent variable.}
  \item{factor}{It defines which is the variable that acts as a factor.}
  \item{pop1}{First group of the population variable to compare.}
  \item{pop2}{Second group of the population variable to compare.}
  \item{graph}{If NULL, there is no graph and the other options are "Boxplot" or "Beanplot".}
  \item{PAR}{It accesses the function \link{PAR} which allows to modify many different aspects of the graph.}
  \item{ResetPAR}{If FALSE, the conditions are not placed by default in the \link{PAR} function and are those defined by the user in previous graphics.}
  \item{YLAB}{Legend of the Y axis in the boxplot and beanplot.}
  \item{XLAB}{Legend of the X axis in the boxplot and beanplot.}
  \item{OrderCat}{It allows to specify a vector with the order in which categories are displayed in the graph.}
  \item{LabelCat}{It allows to specify a vector with the names of the categories of the graph.}
  \item{COLOR}{Vector with the color of the categories of the graph.}
  \item{BOXPLOT}{It allows to specify the characteristics of the boxplot.}
  \item{BEANPLOT}{It allows to specify the characteristics of the beanplot.}
  \item{LEGEND}{It allows to include a legend.}
  \item{AXIS}{It allows to add axes.}
  \item{MTEXT}{It allows to add text in the margins of the graph.}
  \item{TEXT}{It allows to add text in any area of the inner part
of the graph.}
  \item{file}{TXT FILE. Output file name with the results.}
}
\value{A TXT file is obtained with the results of the test and a boxplot or beanplot can be displayed.}
\details{

\strong{IX. CONTRASTS OF HOMOGENEITY IN QUANTITATIVE VARIABLES}

\strong{IX.2. NON-PARAMETRIC TESTS}

Often assumptions about normality and equality of variances in our data can not be assumed, therefore it is necessary to use the so-called non-parametric statistics or free distribution methods. Similarly, the non-parametric tests can be used when data of the population are in the form of range, when the procedure for obtaining the sample prevents assimilate it with a succession of quantitative values (Prez, 2004).

They have the advantage that they are more generally applicable than the parametric ones (these contrasts can also be applied to normally distributed variables) since they do not require any conditions on the type of distribution. However, they are less sensitive to the detection of differences than parametric tests, although it can be said  that the coincidence between the results obtained with the parametric and non-parametric tests is greater than 90\%.

Within non-parametric tests of homogeneity, two different types can be distinguished depending on the nature of the samples. Independent samples would be obtained when the elements were randomly selected from a separate or non-related way (for example, a measure of the level of sugar in both men and women), and dependent samples, when the measurements are related, usually because they correspond to the same individual (for example, a measure of the sugar level in diabetics, before and after a treatment).

\strong{IX.2.1. Contrasts for two independent samples}

The contrasts are similar to the parametric contrast \emph{t} of Student. There are three main tests trying to determine if the differences observed between two samples are due to random or if they belong to two different populations. In all of them, the data is sorted in ascending without considering its membership group and, depending on its position, they are assigned an order number or range.

\emph{IX.2.1.1. Mann-Whitney \emph{U} test}

It is a test that compares the central tendency of two samples, that is not necessary to have the same size, on the basis of the null hypothesis that in both samples the central measure is the same.

It is a widely used contrast, although in the event that not only differences are measured in the central tendency of the data but on other features such as, for example, asymmetry or dispersion of data, it is more appropriate to use the test of Wald-Wolfowitz.

A premise of this test is that the values of each of the samples are different, i.e., that there is no overlap of data (repeated values). In case of overlapping, the contrast becomes more conservative (it is more difficult to find differences between samples). If the number of overlaps is very large, especially in small samples and with continuous variables, the use of the Kolmogorov-Smirnov test for two samples is advisable, although there is a correction for overlaps of the own statistician.

A range in ascending order (1,2,3, ...), is assigned to the ordered samples from lowest to highest, having as many ranges as data. In case of overlapping or draw, the ranges involved in it are added and divided by the number of overlapping data.

The complete development of this test is displayed in Sokal and Rohlf (1981).  This is to calculate the statistic \emph{U} with which is possible to know whether the mean of the ranks is significantly different between the two samples.

If the total number of data is less than 20, a table for determining critical values of \emph{U} is used. However, if the total number of data is greater than 20, an approach to the Normal from statistical \emph{U} can be used, which indicates the value \emph{Z} of the Normal and its probability.

\emph{IX.2.1.2. Wald-Wolfowitz runs Test}

It is a test that compares the distribution of two samples that do not need to have the same size, based on the null hypothesis that the distribution of ranges is random, i.e., the samples are homogeneous.

The data from the two samples are sorted together in ascending order and each set of values is assigned a run value. The streaks are sequences of values of the same group when the samples have been ordered.

A full description of the statistical appears in section 25.6 of the book \emph{Biostatistical Analysis} (Zar, 1999).

If two samples have the same distribution it can be expected that in the sorting of data from least to greatest, both samples are very mixed (randomized), the number of runs is high.

With a contrast table is determined if the number of runs found is significantly large and the randomness of the ranges can be assumed and, therefore no differences between samples. If the number of data is large, as with the Mann-Whitney contrast, this statistic is set to Normal and the homogeneity of the samples can be analyzed by calculating the statistical \emph{Z}.

This statistic is less powerful than the contrast of Mann-Whitney, but it has the advantage that detects differences not only of central tendency but dispersion and asymmetry.

\emph{IX.2.1.3. Kolmogorov-Smirnov Test for two samples}

The advantage is that it measures the differences between the cumulative relative frequencies of the two samples, and that the differences are detected not only in the central tendency, but also in the dispersion and form (symmetry, pointing) of the samples.

When the sample size is large, the statistical \emph{U} of Mann-Whitney is better. This statistical test is used to test that the \eqn{H_0} of the two samples come from the same population, therefore this requires comparing two sampling distribution functions, observing the maximum difference between them.

The complete development of the calculation of this statistic is at Sokal & Rohlf (1981), in which the steps are:

1. Sorting the observations in each sample and distribute them in classes.

2. Determine the cumulative frequency of the classes in each sample.

3. Search for the maximum difference between the cumulative frequency of both samples.

4. Determine the critical values of \eqn{D_{max}} in a table.

5. If \eqn{D_{max}} is greater than the critical value, the null hypothesis that the samples come from the same population is rejected.

\strong{FUNCTIONS}

For the beanplot, the function \link[beanplot]{beanplot} of the beanplot package (Kampstra, 2008; Kampstra, 2013) is used.

The Mann-Whitney U test is performed with the function \link[stats]{wilcox.test} and the Kolmogorov-Smirnovof test is performed for two samples with the function \link[stats]{ks.test}, both from the stats package.

\strong{EXAMPLE}

Data from the concentration of nitrite, nitrate and ammonium (\eqn{\mu ML}) in the lakes of the Colombian Amazon in two different months. The aim is to determine whether there are differences in the concentration of nitrate among all lakes.
\tabular{c}{
\figure{RIX20}
}
Figure IX.12 shows that the concentration is very similar in both lakes. The Wilcoxon rank-sum test (also known as \emph{U} test of Mann-Whitney) with p = 0.794 accepts the hypothesis of equality, similar to the one of Kolmogorov-Smirnov test with p = 0.831. It is important to mention that when there are draws, that is to say, there are equal values in the groups to be compared, R does not calculate the exact value of probability, neither in the Wilcoxon sum of ranks nor in the Kolmogorov-Smirnov test and, therefore, small differences with other statistical programs can be observed.
\tabular{c}{
\strong{Figure IX.12.} Beanplot of the median and distribution of nitrite\cr
concentration (\eqn{\mu ML}) in two lakes of the Amazon.\cr
\figure{FIX12}
}
}
\references{
Kampstra, P. (2008). Beanplot: A Boxplot Alternative for Visual Comparison of Distributions. \emph{Journal of Statistical Software, Code Snippets}, 28: 1-9.

Kampstra, P (2013) Visualization via Beanplots (like Boxplot/Stripchart/Violin Plot). R package version 1.1. Available at: \url{http://CRAN.R-project.org/package=beanplot}.

Prez, C (2004) \emph{Tcnicas de anlisis multivariante de datos}. Aplicaciones con SPSS.  Pearson Educacin.  Madrid.

Sokal, R.R. & Rohlf, F.J. (1981) \emph{Biometry}. WH Freeman and Company, New York.

Zar, J.H. (1999) \emph{Biostatistical Analysis}. Prentice Hall, New Jersey.
}
\examples{
\dontrun{

data(ZIX7)

IX9(data=ZIX7, variables="Nitrite", factor="Lake", pop1="Correo", pop2="Tarapoto",
graph="Beanplot")

}
}
\keyword{IX9}
