\name{VI1}
\alias{VI1}
\encoding{latin1}
\title{CONTRAST OF GOODNESS OF FIT-POISSON}
\description{It is determined if a sample is adjusted to a Poisson distribution.} 
\usage{
VI1(data, variables, group=NULL, distribution="Normal", combine=TRUE,
graph=TRUE, ni=12, xlab="", col.bar="cyan", col.line="red", lty=2,
lwd=2, legend.pos="topleft", file="Output.csv", na="NA", dec=",",
row.names=FALSE)
}
\arguments{
  \item{data}{Data file.}
  \item{variables}{Variable or variables for which the contrast of goodness of fit can be performed.}
  \item{group}{Variables that gather data for calculations. In case of selecting NULL, there would be no grouping and it would be calculated considering all the data of the selected variables.}
  \item{distribution}{Type of theoretical distribution which contrasts the adjustment of the sample: "Binomial", "Poisson" or "Normal".}
  \item{combine}{It is advisable that if the number of expected cases within a class is less than 5, several categories can be combined in one until all have an expected frequency greater than or equal to 5. For this reason, it is convenient to leave the default value TRUE.}
  \item{graph}{GRAPHIC. Logical value which defines whether it represents the graph with the expected and actual distributions.}
  \item{ni}{GRAPHIC. Number of bars (intervals) in the graph of the Normal distribution.}
  \item{xlab}{GRAPHIC. Legend of the X-axis.}
  \item{col.bar}{GRAPHIC. Color of the bars.}
  \item{col.line}{GRAPHIC. Color of the line of the theoretical distribution.}
  \item{lty}{GRAPHIC. Type of the theoretical distribution line.}
  \item{lwd}{GRAPHIC. The line width of the theoretical distribution.}
  \item{legend.pos}{GRAPHIC. Position of the legend on the chart: "topleft", "topright", "bottomleft" o "bottomright"}
  \item{file}{CSV FILE. Output file name.}
  \item{na}{CSV FILE. Text used in cells without data.}
  \item{dec}{CSV FILE. Defines whether the comma "," or dot 
"."  is used as decimal separator.}
  \item{row.names}{CSV FILE. Logical value that defines if identifiers are put in rows or a vector with a text for each of the rows.} 
}
\value{A CSV file is obtained with the results of the contrasts and the graph with the expected and actual distributions if the option to show was selected.}

\details{
\strong{VI. CONTRAST OF GOODNESS OF FIT}

To determine if the variables are adjusted to a Normal distribution, Poisson, Binomial, etc., it is necessary to use statistical contrasts, which are called goodness-of-fit tests. There are different goodness-of-fit tests that are used depending on the type of data and the theoretical distribution expected. A classification of the settings used is:

1. Categorized sample (data are codes assigned to the values of a qualitative variable or class in which a quantitative variable values are grouped): Chi-square 

2. Samples not categorized (quantitative variables, continuous or discrete, not grouped into intervals or classes). 

a) For all distributions: Kolmogorov-Smirnov test (test K-S).

b) Normal Distribution: Test of normality Shapiro-Wilk.

\strong{VI.1. CHI-SQUARE}

This applies to continuous distributions (with data previously grouped in classes) as to discrete distributions or qualitative variables. It is based on quantifying the differences between the observed frequencies in each class and the expected ones, based on the null hypothesis that the data follow an \emph{F(x)} distribution (which can be Normal, Poisson, etc.). For its application in the \emph{n} existing classes, the number of observed cases (\eqn{O_i}) to be contrasted  and, through, the theoretical function, the number of expected cases (\eqn{E_i}) is calculated. From these frequencies, the statistical value of \eqn{\chi^2}, is calculated using the following formula:
\deqn{\chi^2=\displaystyle\sum_{i=1}^{n}\frac{(O_i-E_i)^2}{E_i}}

It is recommended that if the number of expected cases within a class is less than 5, various categories are combined in one, until all have an expected frequency greater than or equal to 5. It should not be used when there are few data. 
Then the degrees of freedom (\eqn{\upsilon}) of the sample should be calculated. If the expected values can be calculated prior to sampling, the number of \eqn{\upsilon} is \emph{n} - 1. However, if to calculate the expected values is necessary to estimate some statistics obtained in the sampling parameters (such as, \eqn{\mu} or \eqn{\sigma} for a Normal distribution), the number of \eqn{\upsilon} is \emph{n} - \emph{r} -1 where \emph{r} is the number of statistics necessary to calculate the expected value.

Once determined \eqn{\chi^2} and \eqn{\upsilon}, it is necessary to search in the table \eqn{\chi^2} (Table 3 Appendix I Guisande et al., 2011) the critical value for these \eqn{\upsilon} and to the chosen level of significance (usually \eqn{\alpha} = 0.05). If the \eqn{\chi^2} critical is greater than \eqn{\chi^2} calculated, the null hypothesis that the observed data are consistent with the expected distribution is accepted, while if \eqn{\chi^2} critical is less than \eqn{\chi^2} calculated, the hypothesis is rejected. Most of the statistical programs directly calculate the value \emph{p} of the contrast; if it is less than the chosen level of significance (usually 0.05 or 0.01), the hypothesis is rejected.


\strong{VI.2. KOLMOGOROV-SMIRNOV TEST}

This is the correct test to compare the normality of a sample if the number of data is large (\emph{n} > 30), although it can be used for both large and small samples. It can also be used to compare other distributions such as the Binomial or Poisson. It is a very conservative test that is applied to continuous variables. It is based on the determination of the maximum (\emph{D}) difference between the observed cumulative frequencies (\eqn{AO_i}) and the expected cumulative frequencies (\eqn{AE_i}), based on the null hypothesis that the data follow a certain distribution. The formula of the test is \eqn{D=max|AO_i-AE_i|}. This test was recalculated to a Normal distribution studying the expected frequencies based on the mean and variance of the sample (Lilliefors, 1967) and is known as test \emph{K-S-L}. However, its application is limited when there are few data (100 observations are necessary to distinguish between a Normal with \eqn{\mu} = 0 and \eqn{\sigma^2} = 1 and a uniform distribution between \eqn{-\sqrt{3}} and \eqn{\sqrt{3}}.
 
Once the statistical \emph{D} is calculated, it is compared with a \emph{D} critical value for the chosen level of significance that appears in Table 5 of Appendix I (Guisande et al. , 2011) and Table 6 of Appendix I (Guisande et al. , 2011, for the \emph{K-S-L} test). The null hypothesis is accepted when \emph{D}observed is lower than the value of \emph{D} tabulated or when the value \emph{p} of the contrast is greater that the level of significance (for example greater than 0.05).


\strong{VI.3. SHAPIRO-WILK TEST}

It is the recommended test to verify the normality of a sample, especially when working with a small number of data ( \emph{n} < 30). It is only used to verify the Normal distribution (Shapiro & Wilk, 1965). It is based on measuring the adjustment of data to a straight Normal probability (Figure VI.1). If the setting were perfect, the points would form a straight line of 45 (observed frequency equal to expected frequency). The statistic test is expressed by using the following equation:
\deqn{W=\frac{1}{\displaystyle\sum_{j=1}^{n}(x_j-\mu)^2}\left[\displaystyle\sum_{j=1}^{h}a_{j,n}(x_{(n-j+1)}-x_j)\right]^2}

where \emph{n} is the number of data, \eqn{x_j} is the sample data in ascending order which ranks \emph{j}, \eqn{\mu} is the mean, \emph{h} is \emph{n}/2 if \emph{n} is even or (\emph{n}-1)/2 if \emph{n} is odd and \eqn{a_{j,n}} is a tabulated value.
 
Once the statistical \emph{W} is calculated, this is contrasted with a critical value \emph{W} for the chosen level of significance.

As this statistic measures the adjustment to a straight line and not the distance to the normal distribution (as it was in previous cases),and can be interpreted in an approximate way as a correlation coefficient between the observed and expected values (a value close to 1 indicates a good fit, and next to 0 a bad fit), the null hypothesis is accepted when the value \emph{W} is higher than the tabulated value of contrast (very high adjusted value).

\tabular{clll}{
\strong{Figure VI.1.} Representation of expected and observed probabilities\cr
of a sample along with the line of best fit to a Normal distribution.\cr
\cr
\figure{FVI1}{options: width=2.5in}
}
\strong{EXAMPLE}

Data from the abundance of two herbivorous species of sea snails (\emph{Littorina littorea} and \emph{Littorina saxatilis}) and a carnivorous species (\emph{Nucella lapillus}), in two areas of sampling. It is necessary to know if the distribution is random in different areas, i.e., if this follows a Poisson distribution. 

To see all the charts, which are shown below (Figure VI.2), simply drag each of the windows, and thus see the graph below that.

\tabular{cccccc}{
\strong{Figure VI.2.} Frequency histograms for each of the species in the two areas.\cr
\figure{FVI2}{options: width=3.2in}
\cr
\figure{FVI3}{options: width=3.2in}
\cr
\figure{FVI4}{options: width=3.9in}\cr
\figure{FVI5}{options: width=3.9in}\cr
\figure{FVI6}{options: width=3.9in}\cr
\figure{FVI7}{options: width=3.9in}
}
The results are shown below:
\tabular{clll}{
\figure{RVI1}{options: width=4.5in}
}
In the case of the test \eqn{\chi^2}, the test set comprises the categories to achieve expected frequencies no less than five. When the results of the unadjusted and adjusted tests are different, this means that it has been necessary to group them and, therefore, the unadjusted test is invalid. The results show that in all cases the probability values for test \eqn{\chi^2} of the adjusted test are different from the unadjusted and therefore, in all cases the adjusted test must be considered as valid. 

For \emph{Littorina littorea} in zone 1, the value \emph{p} of the contrast \eqn{\chi^2} is less than 0.05 in the adjusted test (p = 0.011), therefore, the hypothesis that the distribution of this species is random in zone 1 is rejected, i.e. it does not follow a Poisson distribution. The Kolmogorov-Smirnov test (\emph{K-S}) corroborates the before mentioned since p = 0.002 (is less than 0.05).  On the contrary, for the same species in zone 2, the value \emph{p} of the contrast \eqn{\chi^2} is greater than 0.05 in the adjusted test (p = 0.162), indicating that there can be a Poisson distribution in this area. The test \emph{K-S} confirms what is already mentioned before that p = 0.454 (is greater than 0.05).
 
In the case of \emph{Littorina saxatilis}, the value \emph{p} of the contrast \eqn{\chi^2} is less than 0.05 in zone 1 (p = 0.007 adjusted), indicating that it does not follow a Poisson distribution, and can not be estimated in zone 2. 

With the test of \emph{K-S} the probability is also less than 0.05 in zone 1 (p = 0.007), indicating that the distribution is not Poisson. The test \emph{K-S} is more appropriate than the test \eqn{ \chi^2} for quantitative variables, so that we would give validity to the test \emph{K-S}.  In any case, if you decide to apply multiple valid evidence for the same purpose, as in this example where we use the \eqn{\chi^2} and \emph{K-S} tests, and some of them reject the null hypothesis and some not, the null hypothesis must be rejected. 

For \emph{Nucella lapillus}, in the two areas, both the \eqn{ \chi^2} of the adjusted tests as the \emph{K-S} test, the p-value < 0.05 , rejecting the hypothesis of random Poisson distribution.

}
\references{
Guisande, C., Vaamonde, A. & Barreiro, A. (2011) \emph{Tratamiento de datos con R, SPSS y STATISTICA}. Ediciones Daz de Santos, Madrid, 978 pp.

Lilliefors, H. (1967) On the Kolmogorov-Smirnov test for normality with mean and variance unknown. \emph{Journal of the American Statistical Association}, 62: 399-402.

Shapiro, S.S. & Wilk, M.B. (1965) An analysis of variance test for normality (complete samples). \emph{Biometrika}, 52: 591-611.
}
\examples{
\dontrun{

data(ZVI1)

#Poisson distribution
VI1(data=ZVI1, variables=c("Area1","Area2"), group =c("Species"),
distribution="Poisson", xlab="Abundance")

}
}
\keyword{VI1}
