\name{VI2}
\alias{VI2}
\encoding{latin1}
\title{CONTRAST OF GOODNESS OF FIT-BINOMIAL}
\description{It determines whether a sample is adjusted to a Binomial distribution.} 
\usage{
VI2(data, variables, group=NULL, distribution="Normal", combine=TRUE,
graph=TRUE, ni=12, xlab="", col.bar="cyan", col.line="red", lty=2, lwd=2,
legend.pos="topleft", file="Output.csv", na="NA", dec=",", row.names=FALSE)
}
\arguments{
  \item{data}{Data file.}
  \item{variables}{Variable or variables for which the contrast of goodness of fit can be performed.}
  \item{group}{Variables that gather data for calculations.
In case of selecting NULL, there would be no grouping and it would be calculated considering all the data of the selected variables.}
  \item{distribution}{Type of theoretical distribution which contrasts the adjustment of the sample: "Binomial", "Poisson" or "Normal".}
  \item{combine}{It is advisable that if the number of expected cases within a class is less than 5, several kinds can be combined in one until all have an expected frequency greater than or equal to 5. For this reason, it is convenient to leave the default value TRUE.}
  \item{graph}{GRAPHIC. Logical value which defines whether it represents the graph with the expected and actual distributions.}
  \item{ni}{GRAPHIC. Number of bars (intervals) in the graph of the Normal distribution.}
  \item{xlab}{GRAPHIC. Legend of the X-axis.}
  \item{col.bar}{GRAPHIC. Color of the bars.}
  \item{col.line}{GRAPHIC. Color of the line of the theoretical distribution.}
  \item{lty}{GRAPHIC. Type of the theoretical distribution line.}
  \item{lwd}{GRAPHIC. Line-width of the theoretical distribution.}
  \item{legend.pos}{GRAPHIC. Position of the legend on the chart: "topleft", "topright", "bottomleft" o "bottomright"}
  \item{file}{CSV FILE. Output file name.}
  \item{na}{CSV FILE. Text used in the cells without data.}
  \item{dec}{CSV FILE. It defines whether the comma "," or dot "."  is used as decimal separator.}
  \item{row.names}{CSV FILE. Logical value that defines if identifiers are placed in rows or a vector with a text for each of the rows.}
}
\value{A CSV file is obtained with the results of the contrasts and the graph with the expected and actual distributions if the option to show was selected.}
\details{
\strong{VI. CONTRAST OF GOODNESS OF FIT}

See section \emph{details} of the function \link{VI1}.

\strong{EXAMPLE}

Data from the abundance of two herbivorous species of sea snails (\emph{Littorina littorea} and \emph{Littorina saxatilis}) and a carnivorous species (\emph{Nucella lapillus}), in two sampling areas. It is necessary to know if the distribution is Binomial in both areas and for each species.

To view all the charts, which are shown below (Figure VI.3), simply drag each of the windows, and thus, the chart below can be seen. 
\tabular{cccccc}{
\strong{Figure VI.3.} Frequency histograms for each of the species\cr
in the two areas.\cr
\figure{FVI8}{options: width=3.3in}
\cr
\figure{FVI9}{options: width=3.85in}
\cr
\figure{FVI10}{options: width=3.85in}
\cr
\figure{FVI11}{options: width=3.85in}
\cr
\figure{FVI12}{options: width=3.85in}
\cr
\figure{FVI13}{options: width=3.85in}
}
The results are shown below:
\tabular{c}{
\figure{RVI2}{options: width=5.4in}
}
In the case of the test \eqn{\chi^2}, the test set comprises the categories to achieve expected frequencies no less than five. When the results of the unadjusted and adjusted tests are different, this means that it has been necessary to group them and, therefore, the unadjusted test is invalid. The results show that in all cases the probability values for test \eqn{\chi^2} of the adjusted test are different from the unadjusted and therefore, in all cases the adjusted test must be considered as valid. 

When p < 0.05 the null hypothesis is rejected and, therefore, the distribution of the species does not follow a Binomial one. On the contrary, in the case of \emph{L. littorea} in zone 2  (p = 0.083) and \emph{L. saxatilis} in zone 1 (p = 0.254) species show a Binomial distribution.}
\examples{
\dontrun{

data(ZVI1)

#Binomial distribution
VI2(data=ZVI1, variables=c("Area1","Area2"), group=c("Species"),
distribution="Binomial", xlab="Abundance")
}
}
\keyword{VI2}
