\name{VI3}
\alias{VI3}
\encoding{latin1}
\title{CONTRAST OF GOODNESS OF FIT-NORMAL}
\description{It determines if a sample is adjusted to a Normal distribution.} 
\usage{
VI3(data, variables, group=NULL, distribution="Normal", combine=TRUE,
graph=TRUE, ni=12, xlab="", col.bar="cyan", col.line="red", lty=2, lwd=2,
legend.pos="topleft", file="Output.csv", na="NA", dec=",", row.names=FALSE)
}
\arguments{
  \item{data}{Data file.}
  \item{variables}{Variable or variables for which the contrast of goodness of fit can be performed.}
  \item{group}{Variables that gather data for calculations.
In case of selecting NULL, there would be no grouping and it would be calculated considering all the data of the selected variables.}
  \item{distribution}{Type of theoretical distribution which contrasts the adjustment of the sample: "Binomial", "Poisson" or "Normal".}
  \item{combine}{It is advisable that if the number of expected cases within a class is less than 5, several kinds can be combined in one until all have an expected frequency greater than or equal to 5. For this reason, it is convenient to leave the default value TRUE.}
  \item{graph}{GRAPHIC. Logical value which defines whether it represents the graph with the expected and actual distributions.}
  \item{ni}{GRAPHIC. Number of bars (intervals) in the graph of the Normal distribution.}
  \item{xlab}{GRAPHIC. Legend of the X-axis.}
  \item{col.bar}{GRAPHIC. Color of the bars.}
  \item{col.line}{GRAPHIC. Color of the line of the theoretical distribution.}
  \item{lty}{GRAPHIC. Type of the theoretical distribution.}
  \item{lwd}{GRAPHIC. Line-width of the theoretical distribution.}
  \item{legend.pos}{GRAPHIC. Position of the legend on the chart: "topleft", "topright", "bottomleft" o "bottomright"}
  \item{file}{CSV FILE. Output file name.}
  \item{na}{CSV FILE. Text used in the cells without data.}
  \item{dec}{CSV FILE. It defines whether the comma "," or dot "."  is used as decimal separator.}
  \item{row.names}{CSV FILE. Logical value that defines if identifiers are placed in rows or a vector with a text for each of the rows.}
}
\value{A CSV file is obtained with the results of the contrasts and the graph with the expected and actual distributions if the option to show it was selected.}
\details{
\strong{VI. CONTRAST OF GOODNESS OF FIT}

See section \emph{details} of the function \link{VI1}.

\strong{EXAMPLE}

Data from the abundance of two herbivorous species of sea snails (\emph{Littorina littorea} and \emph{Littorina saxatilis}) and a carnivorous species (\emph{Nucella lapillus}), in two sampling areas. It is necessary to know if the distribution is Normal in both areas and for each species.

To view all graphs, which are shown below (Figure VI.4), simply drag each of the windows, and thus, the chart below can be seen. 
\tabular{cccccc}{
\strong{Figure VI.4.} Frequency histograms for each of the species\cr
in the two areas.\cr
\figure{FVI14}{options: width=3.7in}
\cr
\figure{FVI15}{options: width=3.7in}
\cr
\figure{FVI16}{options: width=3.9in}
\cr
\figure{FVI17}{options: width=3.9in}
\cr
\figure{FVI18}{options: width=3.9in}
\cr
\figure{FVI19}{options: width=3.9in}
}
The results are shown below:
\tabular{c}{
\figure{RVI3}{options: width=5.2in}
}
The results also show the asymmetry of each of the data sets since under the assumption that the population does not have a Normal distribution, it is possible to transform data and the asymmetry indicates the type of transformation to be performed (see section \emph{details} of the function \link{IX1}).

There is only a discrepancy when comparing the test \emph{K-S} with the Shapiro-Wilk test. The species \emph{L. saxatilis} in zone 1 does not have a Normal distribution as the test \emph{K-S} (p = 0.001), while the Shapiro-Wilk test shows a normal distribution (p = 0.065). 

As mentioned before, if there is a discrepancy between two tests, a conservative decision must be made, that is to say,   rejecting the null hypothesis. In this example the Normal distribution is rejected.
}
\examples{
\dontrun{

data(ZVI1)

#Normal distribution
VI3(data=ZVI1, variables=c("Area1","Area2"), group=c("Species"),
xlab="Abundance", col.bar="blue", col.line="green", lty=3, lwd=3,
legend.pos="topright")

}
}
\keyword{VI3}
