\name{VII1}
\alias{VII1}
\encoding{latin1}
\title{CONTRASTS OF HOMOGENEITY IN QUALITATIVE VARIABLES - INDEPENDENT SAMPLES AND POLYTOMOUS VARIABLES}
\description{It determines if multiple samples taken from the same population or from different populations, differ in a certain qualitative variable.} 
\usage{
VII1(data, variables, group=NULL, test=c(1,2,3), graph=TRUE, compress=TRUE,
xlim=NULL, ylim=NULL, spacing=spacing_conditional(sp=0),
keep_aspect_ratio=FALSE, xscale=0.9, yspace=unit(0.5, "lines"), main=NULL,
sub=NULL, residuals_type="Pearson", shade=TRUE, gp_axis=gpar(lty = 3, lwd=2,
col="black"), grid.edit=FALSE, text.grid="rect:", gp.grid = gpar(fill="red"),
labeling=labeling_border,  labeling_args=list(), margins=unit(3, "lines"),
legend_width=unit(5, "lines"), gp_varnames=gpar(fontsize=12, fontface=1),
gp_labels=gpar(fontsize=12, fontface=1), main_gp=gpar(fontsize=20, fontface=2),
sub_gp=gpar(fontsize=15, fontface=1), legend = legend_resbased(fontsize=12,
fontfamily="Arial", x= unit(1, "lines"), y=unit(0.1,"npc"), height=unit(0.8, "npc"),
width=unit(0.7, "lines"), digits=2, check_overlap=TRUE, text=NULL, steps=200,
ticks=10, pvalue=TRUE), gp= shading_hcl, file="Output.txt")
}
\arguments{
  \item{data}{Data file.}
  \item{variables}{Variable or variables to which the contrast of homogeneity is to be performed.}
  \item{group}{Variables together with the data are grouped for calculations. In case of selecting NULL, no grouping would be done, and this would be calculated considering all data of the selected variables.}
  \item{test}{TYPE OF CONTRAST OF HOMOGENEITY.

1. Chi-square test.

2. G-test without the Williams' correction.

3. G-test with the Williams' correction.

4. Chi-square test with Yates correction (Only for 2x2 tables).

5. Fisher's exact test (Only for 2x2 tables), bilateral.

6. Fisher's exact test (Only for 2x2 tables), unilateral:  less than.

7. Fisher's exact test (Only for 2x2 tables), unilateral:  greater than.

8. Friedman ANOVA test.

9. McNemar's test without the continuity correction.

10. McNemar's test with the continuity correction (Only for 2x2 tables).

11. Cochran test.}
  \item{graph}{GRAPH. If TRUE, the graph of the contingency table is shown. This chart does not allow accents and the categories are sorted by alphabetical order. The example of the function \link{VIII1} shows how to sort the categories.}
  \item{compress}{GRAPH. Logical value, if FALSE the space between rows and columns is chosen so that the total of heights and widths of the rows and columns are equal. If TRUE, the space between rows and columns is fixed and, therefore, the graph is more compressed.}
  \item{xlim}{GRAPH. Vector with the X axis limits.}
  \item{ylim}{GRAPH. Vector with the Y axis limits.}
  \item{spacing}{GRAPH. Space between the bars, both horizontal and vertical, which can be extended by changing the value "sp=0" to a larger number. See the function \link[vcd]{spacings} for more options.}
  \item{keep_aspect_ratio}{GRAPH. Logical value, if TRUE the height and width of the graph are the same.}
  \item{xscale}{GRAPH. The categories bar width.}
  \item{yspace}{GRAPH. Vertical spacing between bars that can be expressed in different units as "lines", "cm", "mm", "inches", etc. See funtion \link[grid]{unit} for more details.}
  \item{main}{GRAPH. Main title of the graph.}
  \item{sub}{GRAPH. Subtitle of the graph.}
  \item{residuals_type}{GRAPH. It specifies the type of residuals but, for the moment, this only allows the Pearson residuals.}
  \item{shade}{GRAPH. Logical value that if TRUE are the results of the statistical Chi square of Pearson and, in addition, the categories that are significantly different are shaded.}
  \item{gp_axis}{GRAPH. It defines the line type, thickness, color, etc., of the line of the bars of the categories.}
  \item{grid.edit}{GRAPH. Logical value that if TRUE allows to highlight a category with a different color.}
  \item{text.grid}{GRAPH. Text that allows to identify the variables and categories of variables to highlight, for example "rect:Parents=Yes,Sex=Male". If text.grid is FALSE, it is not used. See one of the examples for more details.}
  \item{gp.grid}{GRAPH. Object of the class \link[grid]{gpar} which allows to define the transparency and the color of the category to highlight.}
  \item{labeling}{GRAPH. It allows to set the labels for the categories on the left with "labeling_left", a framework with "labeling_cboxed", change from left to right and from top to bottom and put a framework with "labeling_lboxed", etc. See function \link[vcd]{labeling_border} for more details.}
  \item{labeling_args}{GRAPH. It allows to specify the distance at which the category labels, legends, etc., are placed. See one of the examples for more details.}
  \item{margins}{GRAPH. Object of type \link[grid]{unit} with four components that delimit the margins from the top, right, down and left on the chart. See one of the examples for more details.}
  \item{legend_width}{GRAPH. Margin of the legend to the right edge.}
  \item{gp_varnames}{GRAPH. Size, format and font type letter of the legends of variables.}
  \item{gp_labels}{GRAPH. Size, format and font type letter of each of the categories of variables.}
  \item{main_gp}{GRAPH. Size, format, and font type letter of the main title.}
  \item{sub_gp}{GRAPH. Size, format, and font type letter of the subtitle.}
  \item{legend}{GRAPH. It allows to modify many aspects of the legend as the font size, font type, number of decimal places, change the text, etc.}
  \item{gp}{GRAPH. It allows to change the scale of color in the legend and also has different palettes: "shading_hcl", "shading_hsv", "shading_Friendly", "shading_max",
"shading_sieve" and "shading_binary".}
  \item{file}{TXT FILE. Output file name.}
}
\value{A TXT file with the results of the contrast is obtained and the graph that shows the contingency table, if the option to display it was selected.}
\details{
\strong{VII. CONTRASTS OF HOMOGENEITY IN QUALITATIVE VARIABLES}

In this function, the statistical treatments are performed for the contrasts of homogeneity that serve to work with qualitative variables, which are variables that are not expressed numerically and may be dichotomous (the variable can only take two values, such as women or man) or polytomous (the variable can have three or more values), being within these last two types: nominal and ordinal.

In a contrast of homogeneity, the aim is to check if two or more samples belong to the same population or that two samples belonging to the same population have not been altered. In other words, it would be interesting to know if the data from the measurements of a variable in several groups or times have the same distribution, or whether each measurement is different. Two types of contrasts depending on the nature of the variables can be distinguished, since it can work with independent measurements (for example, two selected samples in different areas) or paired (for example, the same variable can be measured twice).

\strong{VII.1. INDEPENDENT SAMPLES}

\strong{VII.1.1. Polytomous variables}

The tests are the Chi-square and the likelihood ratio (G-test).

\emph{VII.1.1.1. Chi-square}

The null hypothesis of this test assumes that the samples belong to the same population and, therefore, the proportion of expected frequencies is the same in all samples. That can be used to calculate the expected frequency values for each cell, by multiplying the two marginal frequencies and dividing by the sample size, and are compared with the observed frequencies. In the event that the differences are small and, in consequence, the statistic of contrast lower than a critical value, the hypothesis that the samples are homogeneous (they have the same distribution) is accepted. 

The formula for calculating the expected values is::

\deqn{E_{ij}=\frac{n_{mi}n_{cj}}{n}}
Once obtained the expected values, the statistic of contrast \eqn{\chi^2} is calculated with the following formula:
\deqn{\chi^2=\displaystyle\sum_{i=1}^{h}\displaystyle\sum_{j=1}^{k}\frac{(O_{ij}-E_{ij})^2}{E_{ij}}}
The critical value for (\emph{h-1})*(\emph{k-1}) degrees of freedom and for the chosen level of significance (usually 0.05) is searched in Table \eqn{\chi^2} (Table 3 of Appendix I in Guisande et al., 2011).
If \eqn{\chi^2} critical is greater than \eqn{\chi^2} calculated, the null hypothesis that are homogeneous is accepted, while if \eqn{\chi^2} critical is less than \eqn{\chi^2} calculated, (or p < significance level), the hypothesis is rejected. For the implementation of this test it is required that the expected frequencies do not take values lower than 5.

\emph{VII.1.1.2 Likelihood ratio (test G)}

This contrast is very similar to test \eqn{\chi^2}, since it also quantifies differences between observed and expected values. In addition, the degrees of freedom are calculated in the same way as in the test \eqn{\chi^2} of homogeneity of samples and the critical value of the test is obtained from the Table \eqn{\chi^2} (Table 3 of Appendix I in Guisande et al., 2011).

The contingency table and the calculation of the expected values are the same as those used in the \eqn{\chi^2} test of homogeneity.

The formula for the test statistic is:
\deqn{G=2\displaystyle\sum_{m=1}^{h}\displaystyle\sum_{c=1}^{k}O_{mc}ln\frac{O_{mc}}{E_{mc}}}
Same as in the previous contrast, the critical value with the degrees of freedom and the level of certain significance is searched in Table \eqn{\chi^2} (Table 3 of Appendix I in Guisande et al., 2011).
If \eqn{\chi^2} critical is greater than G, the null hypothesis that the samples are homogeneous is accepted.

The statistical G has a \eqn{\chi^2} distribution approximately. There are some corrections that improve the approximation, such as Williams (1976), which are applicable when the different categories have similar frequencies.

\strong{FUNCTIONS}

The function \link[vcd]{assoc} to make the graph (Meyer et al., 2006; 2013) was used. For more details on how to use this function, refer to the function help reference and/or Guisande & Vaamonde (2012).

\strong{EXAMPLE 1}

Data on the extent to which men and women smoke in different work centers. The categories used were: 1 (non-smoker), 2 (1 to 10 cigarettes a day), 3 (11 to 20 cigarettes a day), 4 (1 to 2 packs a day) and 5 (more than 2 packs a day).
 
There is also information about whether any of the parents of these workers are smokers and the categories are: workers in which either of their parents is smoker (category with value YES) and the other group are those in which none of their parents is smoker (category with value NO). It is a question of determining, in men and women, if there are differences between the group of people with any of the smoking parents and the group that their parents do not smoke, in the proportion of different types of degrees of smoker. For this, the variables to compare with the argument \emph{variables = c("Parents", "Smoker")} are defined in the script and as it is intended that the analysis is done by separating sex, the argument is defined \emph{group="Sex"}.

Figure VII1.1 shows the graphical representation of the contingency table. This chart also shows the results of the test \eqn{\chi^2} with a p < 0.001. Therefore, the null hypothesis that the samples are homogeneous is rejected, that is to say, there are significant differences between the group with one of their smoking parents and the group without smoking parents, in the percentage of the different types of smokers. The chart also gives a very important additional information, the categories where the differences are significant and which are contributing to that, as a whole, the test \eqn{\chi^2} is significant. 

The gray color categories are not significantly different, while the categories with color are significantly different. In particular, it notes that under the category of non-smoking parents, for both men and women, there is a significantly higher proportion of people who do not smoke (the bars are above the dotted line). On the contrary, the number of people who do not smoke is significantly lower in the group of smoking parents (the bar is below the dotted line). Therefore, the fact that the parents do not smoke appears to foster their children not to smoke. However, once a person smokes, the degree to which smoke does not vary depending on whether the parents smoke or not smoke, as it could be observed that in all the categories of smokers, the color of the bars is gray.
\tabular{c}{
\strong{Figure VII1.1} Graphical representation of the contingency table of variables\cr
sex, if the parents smoke or not and the level of smoking dependence.\cr
\cr
\figure{FVII1}{options: width=5in}
}
\tabular{c}{
\figure{RVII1}{options: width=4in}
}
\tabular{c}{
\figure{RVII2}{options: width=4in}
}
In the script  the argument was defined \emph{group="Sex"} and, therefore, the test for men and women were carried out separately. In the case of men, both the test \eqn{\chi^2} (p = 0.039) as the test of the \emph{G} with Williams' correction (p = 0.0457) showed significant differences. Therefore, there are significant differences between the group with one of their smoking parents and the group without parental smoking in the percentage of different types of smoking in men, which as shown in Figure VII1.1, were due to a more non-smoking men in the group of non-smoking parents.

In the case of women, the differences were even more significant, both in the test \eqn{\chi^2} (p < 0.001 ) as in the test of the \emph{G} with the Williams' correction (p < 0.001 ). As well as men, the figure VII1.1 showed that these differences were due to a greater number of non-smoking women in the group of non-smoking parents. 

\strong{EXAMPLE 2}

In this second example the objective, using the same data for the previous example, is to compare whether the proportion of men and women sampled in the study was different in the group of smokers compared with non-smokers.
\tabular{c}{
\strong{Figure VII1.2} Graphical representation of the contingency table of variables\cr
sex and if the parents smoke or not.\cr
\figure{FVII2}{options: width=3.5in}
}
Figure VII1.2 shows no significant differences(\eqn{\chi^2}, p = 0.818). Therefore, the proportion men and women was equal in the group of smoking and non-smoking parents. The example also shows how to highlight in  a different color a category with the argument \emph{text.grid="rect:Parents=Yes,Sex=Male"} (Figure VII1.2).

}
\references{
Guisande, C., Vaamonde, A. & Barreiro, A. (2011) \emph{Tratamiento de datos con R, SPSS y STATISTICA}. Ediciones Daz de Santos, Madrid, 978 pp.

Guisande, C. & Vaamonde, A. (2012) \emph{Grficos estadsticos y mapas con R}. Ediciones Daz de Santos, Madrid, 367 pp.

Meyer, D., Zeileis, A. & Hornik, K. (2006) The strucplot framework: Visualizing multiway contingency tables with vcd. \emph{Journal of Statistical Software}, 17: 1-48.

Meyer, D., Zeileis, A. & Hornik, K. (2013) Visualizing Categorical Data. R package version 1.3-1. Available at: \url{http://CRAN.R-project.org/package=vcd}.

Williams, D.A. (1976) Improved llikelihood ratio test for complete contingency tables. \emph{Biometrika}, 63: 33-37.
}
\examples{
\dontrun{

data(ZVII1)

#Example 1

#Differences in the degree of smoking depending on whether
#parents are smokers, and separating them by sex

VII1(data=ZVII1, variables=c("Parents","Smoker"), group="Sex",
test=c(1,2,3), labeling_args= list(offset_varnames = c(left =-0.5, top=-0.5),
offset_labels=c(top=-0.3), rot_labels=c(left=0)), main="STUDY ABOUT SMOKERS", 
main_gp=gpar(fontsize=20, fontface=2, fontfamily="Aharoni"),
gp_varnames = gpar(fontsize=16,fontface=2),
gp_labels=gpar(fontsize = 12, fontface = 2))

#Example 2

#Shows how to highlight a category

VII1(data=ZVII1, variables=c("Parents","Sex"), test=c(1,2),
grid.edit=TRUE,
text.grid="rect:Parents=Yes,Sex=Male", gp.grid = gpar(fill = "red"),
margins=unit(c(4,2,2,4), "lines"), main="STUDY ABOUT SMOKERS", main_gp=gpar(fontsize=20,
fontface=2, fontfamily="Aharoni"), gp_varnames = gpar(fontsize=20, fontface=2),
gp_labels=gpar(fontsize = 14, fontface = 2))

}
}
\keyword{VII1}
