\name{VII2}
\alias{VII2}
\encoding{latin1}
\title{CONTRASTS OF HOMOGENEITY IN QUALITATIVE VARIABLES - INDEPENDENT SAMPLES AND DICHOTOMOUS VARIABLES}
\description{It determines if multiple samples, taken from the same population or of different populations, differ in a certain qualitative variable.}
\usage{
VII2(data, variables, group=NULL, test=c(1,4,5,6,7), graph=TRUE,
compress=TRUE, xlim=NULL, ylim=NULL, spacing=spacing_conditional(sp=0), 
keep_aspect_ratio=FALSE, xscale=0.9, yspace=unit(0.5, "lines"), main=NULL,
sub=NULL, residuals_type="Pearson", shade=TRUE, gp_axis=gpar(lty = 3, lwd=2,
col="black"), grid.edit=FALSE, text.grid="rect:", gp.grid = gpar(fill="red"),
labeling=labeling_border,  labeling_args=list(), margins=unit(3, "lines"),
legend_width=unit(5, "lines"), gp_varnames=gpar(fontsize=12, fontface=1),
gp_labels=gpar(fontsize=12, fontface=1), main_gp=gpar(fontsize=20, fontface=2),
sub_gp=gpar(fontsize=15, fontface=1), legend = legend_resbased(fontsize=12,
fontfamily="Arial", x= unit(1, "lines"), y=unit(0.1,"npc"), height=unit(0.8, "npc"),
width=unit(0.7, "lines"), digits=2, check_overlap=TRUE, text=NULL, steps=200,
ticks=10, pvalue=TRUE), gp= shading_hcl, file="Output.txt")
}
\arguments{
  \item{data}{Data file.}
  \item{variables}{Variable or variables to which the contrast of homogeneity is to be performed.}
  \item{group}{Variables together with the data are grouped for calculations. In case of selecting NULL, no grouping would be done, and this would be calculated considering all data of the selected variables.}
  \item{test}{TYPE OF CONTRAST OF HOMOGENEITY.

1. Chi-square test.

2. G-test without the Williams' correction.

3. G-test with the Williams' correction.

4. Chi-square test with Yates correction (Only for 2x2 tables).

5. Fisher's exact test (Only for 2x2 tables), bilateral.

6. Fisher's exact test (Only for 2x2 tables), unilateral:  less than.

7. Fisher's exact test (Only for 2x2 tables), unilateral:  greater than.

8. Friedman ANOVA test.

9. McNemar's test without the continuity correction.

10. McNemar's test with the continuity correction (Only for 2x2 tables).

11. Cochran test.}
  \item{graph}{GRAPH. If TRUE, the graph of the contingency table is shown. This chart does not allow accents and the categories are sorted by alphabetical order. The example of the function \link{VIII1} shows how to sort the categories.}
  \item{compress}{GRAPH. Logical value, if FALSE the space between rows and columns is chosen so that the total of heights and widths of the rows and columns are equal. If TRUE, the space between rows and columns is fixed and, therefore, the graph is more compressed.}
  \item{xlim}{GRAPH. Vector with the X axis limits.}
  \item{ylim}{GRAPH. Vector with the Y axis limits.}
  \item{spacing}{GRAPH. Space between the bars, both horizontal and vertical, which can be extended by changing the value "sp=0" to a larger number. See the function \link[vcd]{spacings} for more options.}
  \item{keep_aspect_ratio}{GRAPH. Logical value, if TRUE the height and width of the graph are the same.}
  \item{xscale}{GRAPH. The categories bar width.}
  \item{yspace}{GRAPH. Vertical spacing between bars that can be expressed in different units as "lines", "cm", "mm", "inches", etc. See funtion \link[grid]{unit} for more details.}
  \item{main}{GRAPH. Main title of the graph.}
  \item{sub}{GRAPH. Subtitle of the graph.}
  \item{residuals_type}{GRAPH. It specifies the type of residuals but, for the moment, this only allows the Pearson residuals.}
  \item{shade}{GRAPH. Logical value that if TRUE are the results of the statistical Chi square of Pearson and, in addition, the categories that are significantly different are shaded.}
  \item{gp_axis}{GRAPH. It defines the line type, thickness, color, etc., of the line of the bars of the categories.}
  \item{grid.edit}{GRAPH. Logical value that if TRUE allows to highlight a category with a different color.}
  \item{text.grid}{GRAPH. Text that allows to identify the variables and categories of variables to highlight, for example "rect:Parents=Yes,Sex=Male". If text.grid is FALSE, it is not used. See one of the examples for more details.}
  \item{gp.grid}{GRAPH. Object of the class \link[grid]{gpar} which allows to define the transparency and the color of the category to highlight.}
  \item{labeling}{GRAPH. It allows to set the labels for the categories on the left with "labeling_left", a framework with "labeling_cboxed", change from left to right and from top to bottom and put a framework with "labeling_lboxed", etc. See function \link[vcd]{labeling_border} for more details.}
  \item{labeling_args}{GRAPH. It allows to specify the distance at which the category labels, legends, etc., are placed. See one of the examples for more details.}
  \item{margins}{GRAPH. Object of type \link[grid]{unit} with four components that delimit the margins from the top, right, down and left on the chart. See one of the examples for more details.}
  \item{legend_width}{GRAPH. Margin of the legend to the right edge.}
  \item{gp_varnames}{GRAPH. Size, format and font type letter of the legends of variables.}
  \item{gp_labels}{GRAPH. Size, format and font type letter of each of the categories of variables.}
  \item{main_gp}{GRAPH. Size, format, and font type letter of the main title.}
  \item{sub_gp}{GRAPH. Size, format, and font type letter of the subtitle.}
  \item{legend}{GRAPH. It allows to modify many aspects of the legend as the font size, font type, number of decimal places, change the text, etc.}
  \item{gp}{GRAPH. It allows to change the scale of color in the legend and also has different palettes: "shading_hcl", "shading_hsv", "shading_Friendly", "shading_max",
"shading_sieve" and "shading_binary".}
  \item{file}{TXT FILE. Output file name.}
}
\value{A TXT file is obtained with the results of the contrasts and the graph that shows the contingency table, if the option of displaying it is selected.}
\details{
\strong{VII. CONTRASTS OF HOMOGENEITY IN QUALITATIVE VARIABLES}

\strong{VII.1. INDEPENDENT SAMPLES}

\strong{VII.1.2. Dichotomous variables}

When both variables are dichotomous, i.e. that have only two categories such as, for example, presence/absence or woman/man, then a contingency table of 2x2 is obtained and a correction of the test \eqn{\chi^2} is used, the Yates' correction (1934) or the Fisher's exact test (1922).

\emph{VII.1.2.1. The Yates' correction}

The Yates' correction is applied when a contingency table is 2x2, i.e., two rows and two columns, and the sample has a small number of cases since it is not possible to group categories.

In this situation, the value of \eqn{\chi^2} is overestimated and, to correct it, the so-called Yates correction that modifies the calculation of the statistical is applied as follows:

\deqn{\chi^2=\displaystyle\sum_{m=1}^{j}\displaystyle\sum_{c=1}^{i}\frac{|O_{mc}-E_{mcj}|-\frac{1}{2})^2}{E_{mc}}}
In this case the critical value of contrast would be the \eqn{\chi^2} for a degree of freedom. If the value obtained is less than the tabulated value of contrast, the null hypothesis that the samples are homogeneous is accepted.

However, it is worth mentioning that the use of the Yates' correction does not exempt from certain requirements about the sample size necessary for the use of statistical \eqn{\chi^2}.  As a general rule, it will be required that 80\% of the cells in a contingency table have expected values greater than 5. Thus, in a 2x2 table all of the cells will have to verify this condition, although in practice is allowed one of them to display expected frequencies slightly below this value.

\emph{VII.1.2.2. Fisher's test}

Fisher's exact test is used with contingency tables 2x2 and is the most advisable when there is one or more cells with expected frequencies lower than 5.

The test is based on the determination of the probability of obtaining the observed frequencies, from a hypergeometric distribution, when the total of rows and columns are constant, taking as null hypothesis that the variables are independent.

\strong{FUNCTIONS}

The function \link[vcd]{assoc} to make the graph (Meyer et al., 2006; 2013) was used. For more details on how to use this function, refer to the function help reference and/or Guisande & Vaamonde (2012).

\strong{EXAMPLE}

Data for the presence of the virus of herpes labialis in men and women. The aim is to determine if the number of carriers of the virus is different between men and women. This specifies the variables to compare in the argument \emph{variables = c("Sex", "Presence")}.
\tabular{c}{
\strong{Figure VII2.1} Graphical representation of the contingency table\cr
of the variables sex and presence of the virus of herpes labialis.\cr
\cr
\figure{FVII3}{options: width=4.5in}
}
Figure VII2.1 shows that there are no significant differences with p = 0.694. Therefore, the presence of the virus of herpes labialis is equal in men and women.

The results of all tests are shown below:

\strong{Chi-Square}

The value \eqn{\chi^2} is 0.15 with p = 0.694. It is therefore concluded that there was no relationship between gender and the presence of the virus of herpes labialis.

\strong{Fisher's exact test.}

It returns the calculated statistical both with a unilateral alternative hypothesis (that tells whether the number of females who are carriers of the virus is greater than the number of men carriers) as a two-sided alternative hypothesis (which simply reports whether the virus is different).

The odds would be unilateral p = 0.425 and p = 0.838 for bilateral. In both cases, the assumption of homogeneity of variables is accepted, although with these data (it is not an a priori assumption that there will be more women with virus than men), the bilateral probability should be applied.
\tabular{c}{
\figure{RVII4}{options: width=3.5in}
}
\strong{Yates' correction.}

In this case, and given that the frequencies of each category are greater than 5, this correction would not be necessary. Assuming that it would need, a contrast value of 0.035 and p = 0.851, so the assumption that the presence of the virus is the same in both sexes is accepted.
\tabular{c}{
\figure{RVII3}{options: width=4.2in}
}
}
\references{
Fisher, L.D. & van Belle, G. (1993) \emph{Biostatistics. A methodology for the health sciences}. John Wiley y Sons, New York.

Guisande, C., Vaamonde, A. & Barreiro, A. (2011) \emph{Tratamiento de datos con R, SPSS y STATISTICA}. Ediciones Daz de Santos, Madrid, 978 pp.

Guisande, C. & Vaamonde, A. (2012) \emph{Grficos estadsticos y mapas con R}. Ediciones Daz de Santos, Madrid, 367 pp.

Meyer, D., Zeileis, A. & Hornik, K. (2006) The strucplot framework: Visualizing multiway contingency tables with vcd. \emph{Journal of Statistical Software}, 17: 1-48.

Meyer, D., Zeileis, A. & Hornik, K. (2013) Visualizing Categorical Data. R package version 1.3-1. Available at: \url{http://CRAN.R-project.org/package=vcd}.

Yates, F. (1934) Contingency table involving small numbers and the \eqn{\chi^2} test. \emph{Supplement to the Journal of the Royal Statistical Society}, 1: 217-235.
}
\examples{

\dontrun{

data(ZVII2)

#Presence of the herpes virus

VII2(data = ZVII2, variables = c("Sex","Presence"), gp_varnames = gpar(fontsize=15,
fontface=2), gp_labels=gpar(fontsize = 13, fontface = 2))

}

}\keyword{VII2}
