\name{VII3}
\alias{VII3}
\encoding{latin1}
\title{
CONTRASTS OF HOMOGENEITY IN QUALITATIVE VARIABLES-RELATED SAMPLES AND POLYTOMOUS VARIABLES}
\description{It determines if multiple samples, taken from the same population or of different populations, differ in a certain qualitative variable.}
\usage{
VII3(data, variables, group=NULL, test=c(8), graph=TRUE,
compress=TRUE,
xlim=NULL, ylim=NULL, spacing=spacing_conditional(sp=0),
keep_aspect_ratio=FALSE, xscale=0.9, yspace=unit(0.5, "lines"), main=NULL,
sub=NULL, residuals_type="Pearson", shade=TRUE, gp_axis=gpar(lty = 3, lwd=2,
col="black"), grid.edit=FALSE, text.grid="rect:", gp.grid = gpar(fill="red"),
labeling=labeling_border,  labeling_args=list(), margins=unit(3, "lines"),
legend_width=unit(5, "lines"), gp_varnames=gpar(fontsize=12, fontface=1),
gp_labels=gpar(fontsize=12, fontface=1), main_gp=gpar(fontsize=20, fontface=2),
sub_gp=gpar(fontsize=15, fontface=1), legend = legend_resbased(fontsize=12,
fontfamily="Arial", x= unit(1, "lines"), y=unit(0.1,"npc"), height=unit(0.8, "npc"),
width=unit(0.7, "lines"), digits=2, check_overlap=TRUE, text=NULL, steps=200,
ticks=10, pvalue=TRUE), gp= shading_hcl, file="Output.txt")
}
\arguments{
  \item{data}{Data file.}
  \item{variables}{Variable or variables to which the contrast of homogeneity is to be performed.}
  \item{group}{Variables together with the data are grouped for calculations. In case of selecting NULL, no grouping would be done, and this would be calculated considering all data of the selected variables.}
  \item{test}{TYPE OF CONTRAST OF HOMOGENEITY.

1. Chi-square test.

2. G-test without the Williams' correction.

3. G-test with the Williams' correction.

4. Chi-square test with Yates correction (Only for 2x2 tables).

5. Fisher's exact test (Only for 2x2 tables), bilateral.

6. Fisher's exact test (Only for 2x2 tables), unilateral:  less than.

7. Fisher's exact test (Only for 2x2 tables), unilateral:  greater than.

8. Friedman ANOVA test.

9. McNemar's test without the continuity correction.

10. McNemar's test with the continuity correction (Only for 2x2 tables).

11. Cochran test.}
  \item{graph}{GRAPH. If TRUE, the graph of the contingency table is shown. This chart does not allow accents and the categories are sorted by alphabetical order. The example of the function \link{VIII1} shows how to sort the categories.}
  \item{compress}{GRAPH. Logical value, if FALSE the space between rows and columns is chosen so that the total of heights and widths of the rows and columns are equal. If TRUE, the space between rows and columns is fixed and, therefore, the graph is more compressed.}
  \item{xlim}{GRAPH. Vector with the X axis limits.}
  \item{ylim}{GRAPH. Vector with the Y axis limits.}
  \item{spacing}{GRAPH. Space between the bars, both horizontal and vertical, which can be extended by changing the value "sp=0" to a larger number. See the function \link[vcd]{spacings} for more options.}
  \item{keep_aspect_ratio}{GRAPH. Logical value, if TRUE the height and width of the graph are the same.}
  \item{xscale}{GRAPH. The categories bar width.}
  \item{yspace}{GRAPH. Vertical spacing between bars that can be expressed in different units as "lines", "cm", "mm", "inches", etc. See funtion \link[grid]{unit} for more details.}
  \item{main}{GRAPH. Main title of the graph.}
  \item{sub}{GRAPH. Subtitle of the graph.}
  \item{residuals_type}{GRAPH. It specifies the type of residuals but, for the moment, this only allows the Pearson residuals.}
  \item{shade}{GRAPH. Logical value that if TRUE are the results of the statistical Chi square of Pearson and, in addition, the categories that are significantly different are shaded.}
  \item{gp_axis}{GRAPH. It defines the line type, thickness, color, etc., of the line of the bars of the categories.}
  \item{grid.edit}{GRAPH. Logical value that if TRUE allows to highlight a category with a different color.}
  \item{text.grid}{GRAPH. Text that allows to identify the variables and categories of variables to highlight, for example "rect:Parents=Yes,Sex=Male". If text.grid is FALSE, it is not used. See one of the examples for more details.}
  \item{gp.grid}{GRAPH. Object of the class \link[grid]{gpar} which allows to define the transparency and the color of the category to highlight.}
  \item{labeling}{GRAPH. It allows to set the labels for the categories on the left with "labeling_left", a framework with "labeling_cboxed", change from left to right and from top to bottom and put a framework with "labeling_lboxed", etc. See function \link[vcd]{labeling_border} for more details.}
  \item{labeling_args}{GRAPH. It allows to specify the distance at which the category labels, legends, etc., are placed. See one of the examples for more details.}
  \item{margins}{GRAPH. Object of type \link[grid]{unit} with four components that delimit the margins from the top, right, down and left on the chart. See one of the examples for more details.}
  \item{legend_width}{GRAPH. Margin of the legend to the right edge.}
  \item{gp_varnames}{GRAPH. Size, format and font type letter of the legends of variables.}
  \item{gp_labels}{GRAPH. Size, format and font type letter of each of the categories of variables.}
  \item{main_gp}{GRAPH. Size, format, and font type letter of the main title.}
  \item{sub_gp}{GRAPH. Size, format, and font type letter of the subtitle.}
  \item{legend}{GRAPH. It allows to modify many aspects of the legend as the font size, font type, number of decimal places, change the text, etc.}
  \item{gp}{GRAPH. It allows to change the scale of color in the legend and also has different palettes: "shading_hcl", "shading_hsv", "shading_Friendly", "shading_max",
"shading_sieve" and "shading_binary".}
  \item{file}{TXT FILE. Output file name.}
}
\value{A TXT file is obtained with the results of the contrasts and the graph that shows the contingency table, if the option of displaying it is selected.}
\details{
\strong{VII. CONTRASTS OF HOMOGENEITY IN QUALITATIVE VARIABLES}

\strong{VII.2. RELATED SAMPLES}

It may be the case that the variables to be compared are related, i.e., they are paired data. For example, when a treatment is given to a group of people and it is studied whether this drug causes some type of allergy, allergy is quantified by means of any qualitative variable as presence or absence of spots on the skin. In this case, the variables to compare are not independent, since they are the same individuals that are compared over time.

As in the case of the independent samples, there is evidence for polytomous and dichotomous variables.

\strong{VII.2.1. Polytomous variables}

\emph{VII.2.1.1. The Friedman ANOVA}

The test developed by Friedman (1937), is the similar test to analysis of variance (ANOVA) for repeated samples, despite the fact that it is a \eqn{\chi^2} contrast, it is called ANOVA.

The steps in this statistical are described by Siegel & Castellan (1988). They are as follows:

1. Assign ranges within each element in the sample. 

2. Add the ranges of each element in the sample.

3. Calculate the statistic \eqn{\chi^2} to contrast and compare it with the tabulated value \eqn{\chi^2} critical with \emph{a} - 1 degrees of freedom, being \emph{a} the number of variables.

\strong{EXAMPLE}

Data on how 15 enologists evaluated 4 different types of wines. Category 1 is Very bad, 2 Poor, 3 Good and 4 Very good. The objective is to determine if there are differences between the quality of the wines. As the evaluation, of each of the enologists of different wines, is compared, the data are not independent, they are related. In addition each of the variables has more than 2 values, so they are polytomous.

In the case of the Friedman ANOVA, the following order is necessary: the variable that has the data from the response, the factor, and, finally, the variable that has the information about the individuals to which each response belongs, in this case would be \emph{variables=c("Quality","Wine","Oenologist")}.

Since the probability is less than 0.05, the null hypothesis of homogeneity is rejected and therefore, there are significant differences between the quality of wines according to the enologists (ANOVA  \eqn{\chi^2} = 10.1, df = 3, p = 0.018).
\tabular{c}{
\figure{RVII5}
}
}
\references{
Friedman, M. (1937) The use of ranks to avoid the assumption of normality implicit in the analysis of variance. \emph{Journal of the American Statistical Association}, 32: 675-701.

Siegel, S. & Castellan, N.J. Jr. (1988) \emph{Nonparametric statistics for the behavioral sciences}. McGraw-Hill, New York.
}
\examples{
\dontrun{

data(ZVII3)

#Wine-tasting

VII3(data=ZVII3, variables=c("Quality","Wine","Oenologist"),
graph=FALSE)

}
}
\keyword{VII3}
