\name{VII4}
\alias{VII4}
\encoding{latin1}
\title{CONTRASTS OF HOMOGENEITY IN QUALITATIVE VARIABLES-RELATED SAMPLES AND DICHOTOMOUS VARIABLES WITHOUT REPETITION}
\description{It determines if multiple samples, taken from the same population or from different populations, differ in a certain qualitative variable.} 
\usage{
VII4(data, variables, group=NULL, test=c(9,10), graph=TRUE, compress=TRUE,
xlim=NULL, ylim=NULL, spacing=spacing_conditional(sp=0),
keep_aspect_ratio=FALSE, xscale=0.9, yspace=unit(0.5, "lines"), main=NULL,
sub=NULL, residuals_type="Pearson", shade=TRUE, gp_axis=gpar(lty = 3, lwd=2,
col="black"), grid.edit=FALSE, text.grid="rect:", gp.grid = gpar(fill="red"),
labeling=labeling_border,  labeling_args=list(), margins=unit(3, "lines"),
legend_width=unit(5, "lines"), gp_varnames=gpar(fontsize=12, fontface=1),
gp_labels=gpar(fontsize=12, fontface=1), main_gp=gpar(fontsize=20, fontface=2),
sub_gp=gpar(fontsize=15, fontface=1), legend = legend_resbased(fontsize=12,
fontfamily="Arial", x= unit(1, "lines"), y=unit(0.1,"npc"), height=unit(0.8, "npc"),
width=unit(0.7, "lines"), digits=2, check_overlap=TRUE, text=NULL, steps=200,
ticks=10, pvalue=TRUE), gp= shading_hcl, file="Output.txt")

}
\arguments{
  \item{data}{Data file.}
  \item{variables}{Variable or variables to which the contrast of homogeneity is to be performed.}
  \item{group}{Variables together with the data are grouped for calculations. In case of selecting NULL, no grouping would be done, and this would be calculated considering all data of the selected variables.}
  \item{test}{TYPE OF CONTRAST OF HOMOGENEITY.

1. Chi-square test.

2. G-test without the Williams' correction.

3. G-test with the Williams' correction.

4. Chi-square test with Yates correction (Only for 2x2 tables).

5. Fisher's exact test (Only for 2x2 tables), bilateral.

6. Fisher's exact test (Only for 2x2 tables), unilateral:  less than.

7. Fisher's exact test (Only for 2x2 tables), unilateral:  greater than.

8. Friedman ANOVA test.

9. McNemar's test without the continuity correction.

10. McNemar's test with the continuity correction (Only for 2x2 tables).

11. Cochran test.}
  \item{graph}{GRAPH. If TRUE, the graph of the contingency table is shown. This chart does not allow accents and the categories are sorted by alphabetical order. The example of the function \link{VIII1} shows how to sort the categories.}
  \item{compress}{GRAPH. Logical value, if FALSE the space between rows and columns is chosen so that the total of heights and widths of the rows and columns are equal. If TRUE, the space between rows and columns is fixed and, therefore, the graph is more compressed.}
  \item{xlim}{GRAPH. Vector with the X axis limits.}
  \item{ylim}{GRAPH. Vector with the Y axis limits.}
  \item{spacing}{GRAPH. Space between the bars, both horizontal and vertical, which can be extended by changing the value "sp=0" to a larger number. See the function \link[vcd]{spacings} for more options.}
  \item{keep_aspect_ratio}{GRAPH. Logical value, if TRUE the height and width of the graph are the same.}
  \item{xscale}{GRAPH. The categories bar width.}
  \item{yspace}{GRAPH. Vertical spacing between bars that can be expressed in different units as "lines", "cm", "mm", "inches", etc. See funtion \link[grid]{unit} for more details.}
  \item{main}{GRAPH. Main title of the graph.}
  \item{sub}{GRAPH. Subtitle of the graph.}
  \item{residuals_type}{GRAPH. It specifies the type of residuals but, for the moment, this only allows the Pearson residuals.}
  \item{shade}{GRAPH. Logical value that if TRUE are the results of the statistical Chi square of Pearson and, in addition, the categories that are significantly different are shaded.}
  \item{gp_axis}{GRAPH. It defines the line type, thickness, color, etc., of the line of the bars of the categories.}
  \item{grid.edit}{GRAPH. Logical value that if TRUE allows to highlight a category with a different color.}
  \item{text.grid}{GRAPH. Text that allows to identify the variables and categories of variables to highlight, for example "rect:Parents=Yes,Sex=Male". If text.grid is FALSE, it is not used. See one of the examples for more details.}
  \item{gp.grid}{GRAPH. Object of the class \link[grid]{gpar} which allows to define the transparency and the color of the category to highlight.}
  \item{labeling}{GRAPH. It allows to set the labels for the categories on the left with "labeling_left", a framework with "labeling_cboxed", change from left to right and from top to bottom and put a framework with "labeling_lboxed", etc. See function \link[vcd]{labeling_border} for more details.}
  \item{labeling_args}{GRAPH. It allows to specify the distance at which the category labels, legends, etc., are placed. See one of the examples for more details.}
  \item{margins}{GRAPH. Object of type \link[grid]{unit} with four components that delimit the margins from the top, right, down and left on the chart. See one of the examples for more details.}
  \item{legend_width}{GRAPH. Margin of the legend to the right edge.}
  \item{gp_varnames}{GRAPH. Size, format and font type letter of the legends of variables.}
  \item{gp_labels}{GRAPH. Size, format and font type letter of each of the categories of variables.}
  \item{main_gp}{GRAPH. Size, format, and font type letter of the main title.}
  \item{sub_gp}{GRAPH. Size, format, and font type letter of the subtitle.}
  \item{legend}{GRAPH. It allows to modify many aspects of the legend as the font size, font type, number of decimal places, change the text, etc.}
  \item{gp}{GRAPH. It allows to change the scale of color in the legend and also has different palettes: "shading_hcl", "shading_hsv", "shading_Friendly", "shading_max",
"shading_sieve" and "shading_binary".}
  \item{file}{TXT FILE. Output file name.}
}
\value{A TXT file is obtained with the results of the contrasts and the graph that shows the contingency table, if the option of displaying it is selected.}

\details{
\strong{VII. CONTRASTS OF HOMOGENEITY IN QUALITATIVE VARIABLES}

\strong{VII.2. RELATED SAMPLES}

\strong{VII.2.2. Dichotomous variable without repetition}

\emph{VII.2.2.1. McNemar's test}

It is used with samples that measured the same dichotomous variable twice, i.e., they are paired data (McNemar, 1947). It is widely used in medicine to see if a treatment has effect, being able to represent data in a 2x2 contingency table.

It performs the following contrast, which assumes as null hypothesis that the expected frequencies b and c are the same:
\deqn{\chi^2=\frac{(b-c)^2}{(b+c)}}
The critical value of contrast corresponds to the distribution \eqn{\chi^2} to 1 degree of freedom.

\strong{EXAMPLE}

The objective of this study is to determine if an antibiotic causes an allergic response in the skin. For this reason the antibiotic was administered to 50 people and 50 others were given a placebo. The results compare positive response (allergy) or negative (no allergy) in 100 people between days 5 and 10 after treatment. What is tested is whether there are differences in each of the groups, that is, if they are homogeneous in terms of the allergic response, in the two periods considered, 5 and 10 days. Assuming that 5 days is before and 10 days is after and allergy necessarily appear in this interval, the allergic effect of the antibiotic can be tested if homogeneity was found in the placebo group and non-homogeneity in the group that was provided antibiotic, although in the latter case should also be checked that the allergy is higher after than before and not the other way around (in both cases, the contrast may be significant).
\tabular{c}{
\figure{RVII6}{options: width=4.5in}
}
In the case of people who were not provided with the antibiotic,  such as p = 0.248 in the test with continuity correction (which is the test that must be used when there are frequencies lower than 5), it is accepted the null hypothesis that there are no significant differences in the allergic response to the antibiotic between day 5 and day 10.

In the case of people who were provided with the antibiotic such as p = 0.134, to be greater than 0.05, it is also accepted the null hypothesis that there are no significant differences in the allergic response to the antibiotic between day 5 and day 10. 
\tabular{c}{
\figure{RVII7}{options: width=3.6in}
}
Figure VII4.1 shows the results. Not the scale is shown with the significance because the test \eqn{\chi^2} is not used.
\tabular{c}{
\strong{Figure VII4.1} Contingency table of the variables antibiotic\cr
and the days 5 and 10.\cr
\figure{FVII4}{options: width=3.1in}
}
}
\references{
McNemar Q. (1947) Note on the sampling error of the difference between correlated proportions or percentages. \emph{Psychometrika}, 12: 153-157.
}
\examples{
\dontrun{

data(ZVII4)

VII4(data=ZVII4, variables=c("Day.5", "Day.10"), group="Antibiotic",
shade=FALSE, labeling_args =list(set_varnames= c(Day.5="Day 5", Day.10="Day 10")),
gp_varnames = gpar(fontsize=15,fontface=2), gp_labels=gpar(fontsize=13, fontface=2))

}
}
\keyword{VII4}
