\name{VIII1}
\alias{VIII1}
\encoding{latin1}
\title{CONTRAST OF INDEPENDENCE IN QUALITATIVE VARIABLES ASSOCIATION - POLYTOMOUS VARIABLES}
\description{It determines if several samples taken from the same population or different populations, are independent and in case of dependency, the degree of association in polytomous variables.} 
\usage{
VIII1(data, variables, group=NULL, strata=NULL, test=c(1,2,3),
graph=TRUE, compress=TRUE, xlim=NULL, ylim=NULL, spacing=spacing_conditional(sp=0), 
keep_aspect_ratio=FALSE, xscale=0.9, yspace=unit(0.5, "lines"), main=NULL,
sub=NULL, residuals_type="Pearson", shade=TRUE, gp_axis=gpar(lty = 3, lwd=2,
col="black"), grid.edit=FALSE, text.grid="rect:", gp.grid = gpar(fill="red"),
labeling=labeling_border,  labeling_args=list(), margins=unit(3, "lines"),
legend_width=unit(5, "lines"), gp_varnames=gpar(fontsize=12, fontface=1),
gp_labels=gpar(fontsize=12, fontface=1), main_gp=gpar(fontsize=20, fontface=2),
sub_gp=gpar(fontsize=15, fontface=1), legend = legend_resbased(fontsize=12,
fontfamily="Arial", x= unit(1, "lines"), y=unit(0.1,"npc"), height=unit(0.8, "npc"),
width=unit(0.7, "lines"), digits=2, check_overlap=TRUE, text=NULL, steps=200,
ticks=10, pvalue=TRUE), gp= shading_hcl, file="Output.txt")

}
\arguments{
  \item{data}{Data file.}
  \item{variables}{Variable or variables to which the contrast of homogeneity is to be performed.}
  \item{group}{Variables together with the data are grouped for calculations. In case of selecting NULL, no grouping would be done, and this would be calculated considering all data of the selected variables.}
  \item{strata}{Variable defining the strata.}
  \item{test}{TYPE OF CONTRAST OF HOMOGENEITY.

1. Chi-square test.

2. G-test without the Williams' correction.

3. G-test with the Williams' correction.

4. Chi-square test with Yates correction (Only for 2x2 tables).

12. Measures of association.

13. Coefficient of uncertainty.

14. Cochran tests (without correction) (only tables 2x2xk).

15. Cochran-Mantel-Haenszel test (with correction) (only tables 2x2xk).

16. Calculating risk ratios per stratum (only 2x2xk.

17. Breslow & Day Test with Tarone correction. (Only 2x2xk).}
  \item{graph}{GRAPH. If TRUE, the graph of the contingency table is shown. This chart does not allow accents and the categories are sorted by alphabetical order. The example of the function \link{VIII1} shows how to sort the categories.}
  \item{compress}{GRAPH. Logical value, if FALSE the space between rows and columns is chosen so that the total of heights and widths of the rows and columns are equal. If TRUE, the space between rows and columns is fixed and, therefore, the graph is more compressed.}
  \item{xlim}{GRAPH. Vector with the X axis limits.}
  \item{ylim}{GRAPH. Vector with the Y axis limits.}
  \item{spacing}{GRAPH. Space between the bars, both horizontal and vertical, which can be extended by changing the value "sp=0" to a larger number. See the function \link[vcd]{spacings} for more options.}
  \item{keep_aspect_ratio}{GRAPH. Logical value, if TRUE the height and width of the graph are the same.}
  \item{xscale}{GRAPH. The categories bar width.}
  \item{yspace}{GRAPH. Vertical spacing between bars that can be expressed in different units as "lines", "cm", "mm", "inches", etc. See funtion \link[grid]{unit} for more details.}
  \item{main}{GRAPH. Main title of the graph.}
  \item{sub}{GRAPH. Subtitle of the graph.}
  \item{residuals_type}{GRAPH. It specifies the type of residuals but, for the moment, this only allows the Pearson residuals.}
  \item{shade}{GRAPH. Logical value that if TRUE are the results of the statistical Chi square of Pearson and, in addition, the categories that are significantly different are shaded.}
  \item{gp_axis}{GRAPH. It defines the line type, thickness, color, etc., of the line of the bars of the categories.}
  \item{grid.edit}{GRAPH. Logical value that if TRUE allows to highlight a category with a different color.}
  \item{text.grid}{GRAPH. Text that allows to identify the variables and categories of variables to highlight, for example "rect:Parents=Yes,Sex=Male". If text.grid is FALSE, it is not used. See one of the examples for more details.}
  \item{gp.grid}{GRAPH. Object of the class \link[grid]{gpar} which allows to define the transparency and the color of the category to highlight.}
  \item{labeling}{GRAPH. It allows to set the labels for the categories on the left with "labeling_left", a framework with "labeling_cboxed", change from left to right and from top to bottom and put a framework with "labeling_lboxed", etc. See function \link[vcd]{labeling_border} for more details.}
  \item{labeling_args}{GRAPH. It allows to specify the distance at which the category labels, legends, etc., are placed. See one of the examples for more details.}
  \item{margins}{GRAPH. Object of type \link[grid]{unit} with four components that delimit the margins from the top, right, down and left on the chart. See one of the examples for more details.}
  \item{legend_width}{GRAPH. Margin of the legend to the right edge.}
  \item{gp_varnames}{GRAPH. Size, format and font type letter of the legends of variables.}
  \item{gp_labels}{GRAPH. Size, format and font type letter of each of the categories of variables.}
  \item{main_gp}{GRAPH. Size, format, and font type letter of the main title.}
  \item{sub_gp}{GRAPH. Size, format, and font type letter of the subtitle.}
  \item{legend}{GRAPH. It allows to modify many aspects of the legend as the font size, font type, number of decimal places, change the text, etc.}
  \item{gp}{GRAPH. It allows to change the scale of color in the legend and also has different palettes: "shading_hcl", "shading_hsv", "shading_Friendly", "shading_max",
"shading_sieve" and "shading_binary".}
  \item{file}{TXT FILE. Output file name.}
}
\value{A TXT file is obtained with the results of the contrasts and the graph that shows the contingency table, if the option of displaying it is selected.}

\details{

 \strong{VIII. CONTRAST OF INDEPENDENCE AND QUALITATIVE VARIABLES ASSOCIATION}

One of the main purposes of the statistics is to determine if there is an association between two or more characters or variables of the same sample. In addition to know whether two or more variables are independent or dependent, it is also interesting to know what is the strength of this association.

In general, it should be said that the formula of approximation for the study of independence is the measurement of the differences between the observed frequencies and the frequencies that are expect to find if the variables were independent.  

\strong{VIII.1. POLYTOMOUS VARIABLES}

\strong{VIII.1.1. Tests of independence}

\emph{VIII.1.1.1. Pearson's chi-squared test and Likelihood Ratio G-test}

They are the most commonly used contrasts, although they tend not to be used for dichotomous variables, since there are specific tests for them.

Operationally the calculation of both statistical is equal to the contrast of homogeneity of samples (see paragraphs VII.1.1.1 and VII.1.1.2 in the section \emph{details} of the function \link{VII1}), except that in this case, rows and columns relate to different variables of the same sample.

\strong{VIII.1.2. Measures of association}

Measuring the strength of this association may be based on the calculation of distances between variables or in the amount of variability explained if the frequencies of a variable are calculated in function of the other variable.

\emph{VIII.1.2.1. V de Cramer}

The coefficient \emph{V} of Cramer is the following:
\deqn{V= \sqrt{\frac{\chi^2} {n(min(f,c)-1)}}}
being \emph{f} and \emph{c} the number of categories in rows and columns respectively and \emph{n} the number of cases.

A value of 0 indicates total independence of the two variables, while a value of 1 indicates perfect association. It has the advantage to analyze contingency tables of any size. 

\emph{VIII.1.2.2. Contingency Coefficient}

It is also a measure associated to \eqn{\chi^2}. The formula is: \deqn{C=\sqrt{\frac{\chi^2}{n+\chi^2}}}
where \emph{n} is the number of elements in the sample.

This coefficient takes values between 0 and 1. A value near zero indicates independence, and next to one indicates strong dependence. It can never take the limit value 1, even when there is total dependence. 

\emph{VIII.1.2.3. Coefficient of Uncertainty}

It is a measure of association based on the proportional  error reduction, with a range between 0 and 1, from the measurement of a variable based on the knowledge of the other. That is, it indicates the percentage of the variability explained by the association of variables.

There are two different methods for performing this test:

1. Whereas an independent variable and one dependent. In this case two different statistical would be calculated as the dependent variable can consider both rows and columns. The measures of association are assuming the variable Y in columns and X in rows:

Dependent variable columns
\deqn{I_{y|x}=\frac{(I_x+I_y-I_{xy})}{I_y}}
Dependent variable rows
\deqn{I_{x|y}=\frac{(I_x+I_y-I_{xy})}{I_x}}
where
\deqn{I_y=-\displaystyle\sum_{j=1}^{k}\frac{n_j}{n}ln\frac{n_j}{n}}
\deqn{I_x=-\displaystyle\sum_{i=1}^{h}\frac{n_i}{n}ln\frac{n_i}{n}}
\deqn{I_{xy}=-\displaystyle\sum_{i=1}^{h}\displaystyle\sum_{j=1}^{k}\frac{n_{ij}}{n}ln\frac{n_{ij}}{n}}
being \emph{h} and \emph{k} the number of rows and columns, \emph{n} the sample size, \eqn{n_i} and \eqn{n_j} the marginal frequencies of row and column, and \eqn{n_{ij}} joint frequencies.

2. Without considering dependence among variables
\deqn{I_{ind}=2\frac{(I_x+I_y-I_{xy})}{I_x+I_y}}

\strong{FUNCTIONS}

The function \link[vcd]{assoc} to make the graph (Meyer et al., 2006; 2013) was used. For more details on how to use this function, refer to the function help reference and/or Guisande & Vaamonde (2012).

\strong{EXAMPLE}

In the example of the function \link{VII5} a study was conducted to determine if an antibiotic causes an allergic response in the skin.
\tabular{c}{
\strong{Figure VIII1} Contingency table of the antibiotic and response variables, along the time.\cr
\figure{FVIII1}{options: width=3.5in}
}
The contrast of homogeneity showed that, both in the case of people treated with the antibiotic and those who were not provided, there were significant differences in the symptoms of allergy detected in the skin over the study period. It will be determined if there is indeed a relationship between time and the symptoms of allergy. The response variable is dichotomous to the antibiotic (positive or negative response), but the variable time is not dichotomized since there is data response at days 5, 10, 15 and 20 of the study.

This chart does not allow accents and orderly categories in alphabetical order. The names of the columns are sorted with some sort of code in the input data file, to then leave these categories in the graph in the desired order. To change the labels, in order to include the accents, the argument \emph{labeling_args} is used and then \emph{set_varnames} is specified for the legends and \emph{set_labels} for the labels of the categories, as shown in the script.
\tabular{c}{
\figure{RVIII1}{options: width=3.2in}
}
The joint analysis of the data shows that significant differences exist in the allergic response over time depending on whether an antibiotic is provided (Figure VIII1, p < 0.001).  These differences were significant mainly in the day 20 where, to the people who were given the antibiotic, the positive responses were significantly higher and the negative responses were significantly lower (Figure VIII1).

The separate analysis shows that the group that was not given antibiotic, whose results are shown below, the null hypothesis of independence (\eqn{\chi^2_3} = 1.59 , p = 0.661) is accepted.  Therefore, in spite of that the contrast of homogeneity showed significant differences in the allergic response observed in the skin over time, these observed differences are not sufficient to establish a significant dependency between time and the allergic response in those patients who were given a placebo instead of the antibiotic.
\tabular{c}{
\figure{RVIII2}{options: width=3.3in}
}
On the contrary, in the group of people who received antibiotic, the null hypothesis of independence (\eqn{\chi^2_3} = 29.9, p < 0.001) is rejected, that is to say, there is a significant relationship between time and the allergic response observed in the skin. 

Among the association coefficients the \emph{V} of Cramer, the coefficient of uncertainty and the contingency coefficient are considered. The \emph{phi} is not considered because the table is not 2x2. 

The coefficient \emph{V} of Cramer is 0.39 and the contingency of 0.36, which indicates weak association. The coefficient of uncertainty y-dependent is 0.1186, that is to say, the variable X (time) reduced by 11.86\% uncertainty on the prediction of the variable Y (allergy). Of course, it is considered that the variable allergy is time-dependent, and not vice versa. 

With these results it is concluded that the variables are significantly related to value of 0.39 and, therefore, as allergy (variable Y) depends on the time (variable X), it can be concluded that the time explains a 12\% of allergy observed in skin in people who were given the antibiotic.}
\references{
Meyer, D., Zeileis, A. & Hornik, K. (2006) The strucplot framework: Visualizing multiway contingency tables with vcd. \emph{Journal of Statistical Software}, 17: 1-48.
}
\examples{
\dontrun{

data(ZVIII1)

#Allergic response of an antibiotic over time

VIII1(data=ZVIII1, variables=c("Response", "Day"), group="Antibiotic",
test=c(1,12,13), labeling_args =list(set_labels = list(Day= c("Day 5", "Day 10",
"Day 15", "Day 20"))), gp_varnames = gpar(fontsize=15,fontface=2),
gp_labels=gpar(fontsize = 13, fontface = 2))

}
}
\keyword{VIII1}
