\name{VIII2}
\alias{VIII2}
\encoding{latin1}
\title{CONTRAST OF INDEPENDENCE AND QUALITATIVE VARIABLES ASSOCIATION - DICHOTOMOUS VARIABLES}
\description{It determines if several samples taken from the same population or from different populations are independent and in case of dependency, the degree of association in dichotomous variables.} 
\usage{
VIII2(data, variables, group=NULL, strata=NULL, test=c(1,2,3), graph=TRUE,
compress=TRUE, xlim=NULL, ylim=NULL, spacing=spacing_conditional(sp=0), 
keep_aspect_ratio=FALSE, xscale=0.9, yspace=unit(0.5, "lines"), main=NULL,
sub=NULL, residuals_type="Pearson", shade=TRUE, gp_axis=gpar(lty = 3, lwd=2,
col="black"), grid.edit=FALSE, text.grid="rect:", gp.grid = gpar(fill="red"),
labeling=labeling_border,  labeling_args=list(), margins=unit(3, "lines"),
legend_width=unit(5, "lines"), gp_varnames=gpar(fontsize=12, fontface=1),
gp_labels=gpar(fontsize=12, fontface=1), main_gp=gpar(fontsize=20, fontface=2),
sub_gp=gpar(fontsize=15, fontface=1), legend = legend_resbased(fontsize=12,
fontfamily="Arial", x= unit(1, "lines"), y=unit(0.1,"npc"), height=unit(0.8, "npc"),
width=unit(0.7, "lines"), digits=2, check_overlap=TRUE, text=NULL, steps=200,
ticks=10, pvalue=TRUE), gp= shading_hcl, file="Output.txt")
}
\arguments{
  \item{data}{Data file.}
  \item{variables}{Variables whose association is to be determined.}
  \item{group}{Variables together with the data are grouped to do the calculations. In the case of selecting NULL, there would be no grouping and this would be calculated considering all the data of the selected variables.}
  \item{strata}{Variable defining the strata.}
  \item{test}{TYPE OF CONTRAST OF HOMOGENEITY.

1. Chi-square test.

2. G-test without the Williams' correction.

3. G-test with the Williams' correction.

4. Chi-square test with Yates correction (Only for 2x2 tables).

12. Measures of association.

13. Coefficient of uncertainty.

14. Cochran tests (without correction) (only tables 2x2xk).

15. Cochran-Mantel-Haenszel test (with correction) (only tables 2x2xk).

16. Calculating risk ratios per stratum (only 2x2xk.

17. Breslow & Day Test with Tarone correction. (Only 2x2xk).}

\item{graph}{GRAPH. If TRUE, the graph of the contingency table is shown. This chart does not allow accents and the categories sorted by alphabetical order. In the example, the function \link{VIII1} shows how to sort the categories and include the accents.}
  \item{compress}{GRAPH. Logical value, if FALSE the space between rows and columns is chosen so that the total of heights and widths of the rows and columns are equal. If TRUE, the space between rows and columns is fixed and, therefore, the graph is more compressed.}
  \item{xlim}{GRAPH. Vector with the X axis limits.}
  \item{ylim}{GRAPH. Vector with the Y axis limits.}
  \item{spacing}{GRAPH. Space between the bars, both horizontal and vertical, which can be extended by changing the value "sp=0" to a larger number. See the function \link[vcd]{spacings} for more options.}
  \item{keep_aspect_ratio}{GRAPH. Logical value, if TRUE the height and width of the graph are the same.}
  \item{xscale}{GRAPH. The categories bar width.}
  \item{yspace}{GRAPH. Vertical spacing between bars that can be expressed in different units as "lines", "cm", "mm", "inches", etc. See funtion \link[grid]{unit} for more details.}
  \item{main}{GRAPH. Main title of the graph.}
  \item{sub}{GRAPH. Subtitle of the graph.}
  \item{residuals_type}{GRAPH. It specifies the type of residuals but, for the moment, this only allows the Pearson residuals.}
  \item{shade}{GRAPH. Logical value that if TRUE are the results of the statistical Chi square of Pearson and, in addition, the categories that are significantly different are shaded.}
  \item{gp_axis}{GRAPH. It defines the line type, thickness, color, etc., of the line of the bars of the categories.}
  \item{grid.edit}{GRAPH. Logical value that if TRUE allows to highlight a category with a different color.}
  \item{text.grid}{GRAPH. Text that allows to identify the variables and categories of variables to highlight, for example "rect:Parents=Yes,Sex=Male". If text.grid is FALSE, it is not used. See one of the examples for more details.}
  \item{gp.grid}{GRAPH. Object of the class \link[grid]{gpar} which allows to define the transparency and the color of the category to highlight.}
  \item{labeling}{GRAPH. It allows to set the labels for the categories on the left with "labeling_left", a framework with "labeling_cboxed", change from left to right and from top to bottom and put a framework with "labeling_lboxed", etc. See function \link[vcd]{labeling_border} for more details.}
  \item{labeling_args}{GRAPH. It allows to specify the distance at which the category labels, legends, etc., are placed. See one of the examples for more details.}
  \item{margins}{GRAPH. Object of type \link[grid]{unit} with four components that delimit the margins from the top, right, down and left on the chart. See one of the examples for more details.}
  \item{legend_width}{GRAPH. Margin of the legend to the right edge.}
  \item{gp_varnames}{GRAPH. Size, format and font type letter of the legends of variables.}
  \item{gp_labels}{GRAPH. Size, format and font type letter of each of the categories of variables.}
  \item{main_gp}{GRAPH. Size, format, and font type letter of the main title.}
  \item{sub_gp}{GRAPH. Size, format, and font type letter of the subtitle.}
  \item{legend}{GRAPH. It allows to modify many aspects of the legend as the font size, font type, number of decimal places, change the text, etc.}
  \item{gp}{GRAPH. It allows to change the scale of color in the legend and also has different palettes: "shading_hcl", "shading_hsv", "shading_Friendly", "shading_max",
"shading_sieve" and "shading_binary".}
  \item{file}{TXT FILE. Output file name.}
}
\value{A TXT file is obtained with the results of the contrasts and the graph that shows the contingency table, if the option of displaying it is selected.}
\details{
\strong{VIII. CONTRAST OF INDEPENDENCE AND QUALITATIVE VARIABLES ASSOCIATION}

\strong{VIII.2. DICHOTOMOUS VARIABLE}
 
\strong{VIII.2.1. Tests of independence}

\emph{VIII.2.1.1. Yates'correction and Fisher's test}

To contrast independence in dichotomous variables, when there is only one table 2x2, the test \eqn{\chi^2} with Yates' correction can be used, which has already been explained in paragraph VII.1.2.1 of the function \link{VII2}. 

Fisher's exact test, which is briefly explained in the paragraph VII.1.2.2 function \link{VII2}, is also used when the contingency table is 2x2 and should be used instead of the test \eqn{\chi^2} when the contingency table contains any cell with expected frequencies under 5. 

\emph{VIII.2.1.2. The Cochran-Mantel-Haenszel test}

As with the Fisher's test, the evidence of Cochran (1954) and Mantel-Haenszel (1959) also serve to contrast the independence in a 2x2 Contingency Table.

However, they have the advantage over Fisher's test that can also be used when there are several 2x2 tables. These contingency tables are of the type \emph{K}x2x2, that is to say, there are so many 2x2 tables such as \emph{K} strata.

In these tables, the aim is to study whether or not there is association between two dichotomous variables, when there is information on several strata. For example, to determine if the presence of cervical cancer is related to the presence of human papilloma virus in women of different ages or on the contrary are independent.

Therefore, multiple 2x2 tables (presence or non-presence of cancer and presence or non-presence of the virus, both dichotomous variables) would be obtained in several layers that would be the different classes of age at which the group of women studied was divided. In this example, analyze each 
2x2 table separately with Fisher's test would not give information about the effect of age. The statistic of Cochran is as follows:
\deqn{\chi^2_{Cochran}=\frac{\left(\displaystyle\sum_{k}n_k-\displaystyle\sum_{k}m_k\right)^2}{\displaystyle\sum_{k}\sigma^2_{n_k}}}

where:

\emph{k} = each of the strata

\eqn{n_k} = frequency observed in any of the boxes of the stratum \emph{k} (only one and is always the same in all strata)

\eqn{m_k} = expected frequency corresponding to\eqn{n_k}
\deqn{\sigma^2_{n_k}=\frac{n_{f1k}n_{f2k}n_{c1k}n_{c2k}}{n^3}}
\eqn{n_{f1k}}, \eqn{n_{f2k}}, \eqn{n_{c1k}} y \eqn{n_{c2k}} they are the four marginal frequencies associated with the 2 X 2 tables of each stratum \emph{k}.

The Mantel-Haenszel statistical is very similar to the Cochran, except for two things:

1) It uses the correction for continuity (midpoint is subtracted from the numerator before squaring).

2) It slightly changes the denominator of the variance, using \eqn{n^2(n-1)} instead of \eqn{n^3}.

In both statistics, the Cochran's and Mantel-Haenszel, if the value of \emph{p} is greater than 0.05, the hypothesis of independence is accepted and it is concluded that, after taking into account the effect of the strata, the two dichotomous variables are not associated. 

\strong{VIII.2.2. Measures of association}

In the case of 2x2 contingency tables, any of the three factors discussed above in section VIII.1.2 of the \link{VIII1} function can be used: \emph{V} Cramer, Contingency Coefficient and Coefficient of Uncertainty. Besides these three coefficients, the coefficient Phi (\eqn{\phi}) can be used.

\emph{VIII.2.2.1. Phi}

The range of this ratio is only between 0 and 1 in 2x2 contingency tables and therefore should only be used when the variables to compare are both dichotomous.
 
Phi (\eqn{\phi}) is a measure based on the statistical \eqn{\chi^2}. The formula is:
\deqn{\phi=\sqrt{\frac{\chi^2}{n}}}
where \emph{n} is the number of elements in the sample.

\emph{VIII.2.2.2. Relative risk, odds ratio and Breslow-Day test and Tarone}

When there are contingency tables \emph{K}x2x2, mentioned above, the importance of association will be better estimated using the relative risk and odds ratio.  These measures can also be used in tables 2x2, as well as the coefficients described above (\emph{V} of Cramer, contingency coefficient, Coefficient of uncertainty and Phi), but in the case of the tables \emph{K}x2x2 these measures have the advantage that they can be compared between the layers or strata. 

Relative risk indicates how much more likely is the success of a first group against the second. In a 2 x 2 table as shown in the table, the risk or probability of the event considered in Group A and Group B would be:
\tabular{cccc}{
\tab \strong{Group A} \tab \strong{Group B} \tab \strong{Total}\cr
Event \tab a \tab c \tab a+c\cr
No event \tab b \tab d \tab b+d\cr
Total \tab a+b \tab c+d \tab \emph{n}
}
\tabular{ll}{
\eqn{Risk(A)=\frac{a}{(a+b)}} \tab \eqn{Risk(B)=\frac{c}{(c+d)}}
}
the ratio of these two quantities is the relative risk of the event (\eqn{RR_{event}}) and likewise it could be calculated the relative risk of the event or otherwise "no event" (\eqn{RR_{no-event}})
\tabular{ll}{
\eqn{RR_{event}=\frac{\frac{a}{(a+b)}}{\frac{c}{(c+d)}}} \tab \eqn{RR_{no-event}=\frac{\frac{b}{(a+b)}}{\frac{d}{(c+d)}}}
}
The ratio of both relative risks is equal to the odds ratio or Reason of predominances (\emph{OR}, \emph{Odds Ratio}):
\deqn{OR=\frac{RR_{event}}{RR_{no-event}}=\frac{(a*d)}{(b*c)}}
The interpretation of the relative risk is more intuitive than the reason of predominances. However the odds ratio is widely used, mainly because of its connection with the Logistic Regression, which will be reflected in another chapter, with important applications in epidemiology and other areas.

Breslow & Day test (1980) and the modification of this test of Tarone (1985) are homogeneity tests that compare odds ratios between different strata, in \emph{K}x2x2 contingency tables. With this information it is possible to determine whether the degree of association between two dichotomous variables varies according to the different strata. In the example mentioned above, this would inform about if the possible association between human papillomavirus and cervical cancer increases or becomes less intense with the age of the women.

\strong{EXAMPLE}

The number of children who died after a year regarding his birth weight was analyzed in two different hospitals. The group I were newborns weighing less than 1.5 kg, group II between 1.5 and 2.5 kg, group III between 2.5 and 4.2 kg
and group IV over 4.2 kg. The objective was to determine whether there were differences in mortality between hospitals and tried to eliminate the possible effect of any birthweight infant mortality.
\tabular{c}{
\strong{Figure VIII2} Graphical representation of the contingency table in the proportion of live babies\cr
and dead after a year, in the two hospitals and for each group of birth weight.\cr
\figure{FVIII2}{options: width=4.2in}
}
The joint analysis of the data shows that there are significant differences in mortality of babies (Figure VIII2, p < 0.001). In both hospitals the percentage of dead babies after one year is significantly higher in groups I and II 
(babies with less weight at birth, blue bars above the dotted line) and also the group IV (babies with a weight much higher than normal). On the contrary, the percentage of dead babies was significantly lower (bars below the dotted line) in the group III.

The first thing that one can observe when a TXT file with the results is opened are a series of double entry tables with summarized data.
\tabular{c}{
\figure{RVIII3}{options: width=1.1in}
}
Then a series of different analyses results can be observed.
The \eqn{\chi^2} without (\eqn{\chi^2_1} = 1.9, p = 0.168) and with Yates' correction (\eqn{\chi^2_1} = 1.6, p = 0.196) 
are not significant, so it was concluded that there is no association between the two variables, which means that without considering the birthweight - there is no difference in the percentage of live and dead babies between hospitals.
\tabular{c}{
\figure{RVIII4}{options: width=4in}
}
Cochran tests (without continuity correction, \eqn{\chi^2_1} = 7.9 , p = 0.004 ) and Mantel-Haenszel (with continuity correction, \eqn{\chi^ 2_1} = 7.39 , p = 0.006) were significant, indicating that if it is considered the birth weight, mortality depends on the hospital, it ceases to be independent. They also show the values of the odds ratio, that explain this relationship: in level 1 of the stratification factor (babies with birth weight < 1.5 kg) predominance of deaths on not dead at hospital A is 0.046 times the predominance at hospital B (22 times smaller); in the remaining levels of weight the differences are much smaller.
\tabular{c}{
\figure{RVIII5}{options: width=3.1in}
}
Breslow's test (HBD = 9.2) and the correction of Tarone (HBDT = 9.2) are used to check if there are significant differences between strata. In this case, the p-value associated with these statistics is 0.026, which reject the null hypothesis that there are no differences between strata. This means that birth weight influences the mortality of babies during their first year of life.
\tabular{c}{
\figure{RVIII6}{options: width=1.4in}
}

}
\references{
Breslow, N.E. & Day, N.E. (1980) \emph{Statistical methods in cancer research}. Volume 1. The analysis or case-control studies. Lyon: International Agency for Research on Cancer.

Cochran, W.G. (1954) Some methods for strengthening the common \eqn{\chi^2} tests. \emph{Biometrics}, 10: 417-451.

Mantel, N. & Haenszel, W. (1959) Statistical aspects of the analysis of data from retrospective studies of disease. \emph{Journal of the National Cancer Institute}, 22: 719-748.

Meyer, D., Zeileis, A. & Hornik, K. (2006) The strucplot framework: Visualizing multiway contingency tables with vcd. \emph{Journal of Statistical Software}, 17: 1-48.

Tarone, R.E. (1985) On heterogeneity tests based on efficient scores. \emph{Biometrika}, 72: 91-95.
}
\examples{
\dontrun{

data(ZVIII2)

#Mortality at birth

VIII2(data=ZVIII2, variables=c("Mortality","Hospital"), strata="Birth.Weight",
test=c(1,4,14,15,16,17), gp_labels=gpar(fontsize = 14, fontface = 2),
gp_varnames=gpar(fontsize = 16, fontface = 2),
labeling_args =list(set_varnames=c(Birth.Weight="Birth weight" )))

}
}
\keyword{VIII2}
