\name{X1}
\alias{X1}
\encoding{latin1}
\title{SIMPLE BIVARIATE CORRELATIONS}
\description{An analysis of correlation between two variables is applied using the coefficients of Pearson, Spearman and Kendall. In addition, the relationship between the dependent variable and the independent can be plotted, and also be distinguished between groups.} 
\usage{
X1(data, varX,  varY, test=c("Pearson","Spearman", "Kendall"),
group=NULL, ResetPAR=TRUE, PAR=NULL, YLAB=NULL, XLAB=NULL,
CEXPCH=1.3, COLOR=NULL, PCH=NULL, LEGEND=NULL, AXIS=NULL, MTEXT= NULL,
TEXT=NULL, file="Output.txt")
}
\arguments{
  \item{data}{Data file.}
  \item{varX}{Independent variable.}
  \item{varY}{Dependent variable.}
  \item{test}{One, two or three correlation coefficients may be chosen: Pearson, Spearman and/or Kendall.}
  \item{group}{Variable in the case of wanting to estimate the correlations by groups.}
  \item{ResetPAR}{If FALSE, the default conditions of the function \link{PAR} are not placed and are those defined by the user in previous graphs.}
  \item{PAR}{It accesses the function \link{PAR} which allows to modify many different aspects of the graph.}
  \item{YLAB}{Legend of the Y axis.}
  \item{XLAB}{Legend of the X axis.}
  \item{CEXPCH}{Size of the symbols on the chart.}
  \item{COLOR}{It allows to modify the colors of the symbols, but in the event that \emph{group} is not NULL, should be as many different groups as the \emph{group} variable has.}
  \item{PCH}{Vector with graphic symbols. If NULL, these are automatically calculated starting with the symbol 15.}
  \item{LEGEND}{It allows to add a legend to the graph.}
  \item{AXIS}{It allows to add axes to the graph.}
  \item{MTEXT}{It allows to add text in the margins of the graph.}
  \item{TEXT}{It allows to add text in any area of the inner part
graphic.}
  \item{file}{TXT FILE. Output file name.}
}
\value{A TXT file is obtained with the results of the correlations and can represent a graph relating the dependent variable with the independent, differentiating between the groups of the grouping variable.}
\details{
\strong{X. CONTRASTS OF INDEPENDENCE AND ASSOCIATION IN QUANTITATIVE VARIABLES}

     One of the most frequent objectives when analizing data is to study the degree of dependence or association between variables. The correlation is the overarching theoretical framework within which we can study these aspects.

     It is said that a variable \emph{y} depends on another variable \emph{x} when the value of \emph{x} determines to some extent the value of \emph{y}. It may be the case that the value of \emph{y} is completely determined by the value of \emph{x}.  Then, if the value of the variable \emph{x} is known, there is a functional relationship that defines the perfect form of value that \emph{y} would take. In this case it seems that between the two variables there is a relationship of functional dependence. In this case it would seem that there is a relationship between the two variables of functional dependence.  But in practice, most often will be the situations in which the value of the variable and it is not perfectly defined by the value of \emph{x}, but there is a certain degree of relationship between the two that allows an approximation to the value of \emph{y}.  In this case, a relation of dependence between the two random variables.
 
A series of statistics that are called correlation coefficients are used to analyze the degree of dependence or association between variables. The correlation coefficients indicate if the variables are associated or not (if independent) and also, in what sense that association or correlation between variables (positive or negative) is given. They also report on the intensity of the correlation. Through various statistics, it is also possible to know whether the correlation between variables is significant or not.

\strong{X.1. SIMPLE BIVARIATE CORRELATIONS}

\strong{X.1.1. Pearson's correlation coefficient (\emph{r})}

The Pearson correlation coefficient (\emph{r}) indicates the strength of the linear relationship between the two variables. It is necessary to assume, therefore, that any dependency relationship that exists between the two variables is linear. That only serves to quantitative variables.

The coefficient \emph{r} of Pearson is calculated according to the following formula, which is based on the covariance between the two variables:
\deqn{r_{y_1,y_2}=\frac{\displaystyle\sum_{i=1}^{n}\left[(y_{i1}-\bar{y}_1)(y_{i2}-\bar{y}_2))\right]}{\sqrt{\displaystyle\sum_{i=1}^{n}(y_{i1}-\bar{y}_1)^2\displaystyle\sum_{i=1}^{n}(y_{i2}-\bar{y}_2)^2}}}
or what is the same
\deqn{\frac{S_{xy}}{S_xS_y}}
that is, the covariance divided by the product of the standard deviations.

     The values of this ratio are spread in a range between -1 and 1. The closer to -1 or 1, the stronger is the correlation between the variables. Values close to 0 indicate the absence of correlation and, therefore, of dependence. 

     For the significance test of the Pearson's coefficient, it is usually set as \eqn{H_0} that \emph{R} = 0, using the correlation coefficient \emph{r} obtained from the sample as estimator of the true correlation coefficient population \emph{R}. In addition, it is necessary that the joint probability distribution of both variables is Normal.
\deqn{t=\frac{r}{s_r}}
where \eqn{s_r} is the standard error of the estimator
\emph{r}:
\deqn{s_r=\sqrt{\frac{(1-r^2)}{(n-2)}}}
\strong{X.1.2. Spearman's correlation coefficient (\eqn{\rho})}

Among the non-parametric methods, the Spearman coefficient (\eqn{\rho}) is the most commonly used.  As in all the non-parametric methods, it is not necessary to make any assumptions about the distribution that follows the data. This is a statistic that is calculated in a similar way to the Pearson's coefficient, but allocating ranges to the data. When there are several data with the same value, the average of the corresponding ranges is assigned to all of them.

This ratio works for any type of association between variables that follow a monotonic function type. Obviously, this is due to the fact that an ordinal scale is used, so this property is useful for any other coefficient that uses ranges to be calculated. This is an important difference compared to the Pearson's coefficient, which only responds well if the relationship between two variables is linear. In addition, it serves both quantitative as qualitative ordinal variables.

It is calculated by using the following formula:
\deqn{\rho=1-\frac{6\sum_{}^{}d_i^2}{n(n^2-1)}}
where \eqn{d_i} is the difference, for each data or observation, between the ranges that take the values of the two variables.

     The range of values that takes this coefficient ranges from - 1 to 1. The closer of these ends, the stronger is the degree of association, and the sign indicates whether the functional relationship between two variables is ascending or descending, in the same way as the Pearson's coefficient. 

   To determine the significance of this coefficient the following statistic, whose distribution approaches the \emph{t} Student, is used and when the sample size is greater than 20 units: 
\deqn{t=\frac{\rho\sqrt{n-2}}{\sqrt{1-\rho^2}}}
In the same way as Pearson's coefficient, it is usually set as \eqn{H_0} that \eqn{\rho} = 0. 

\strong{X.1.3. Coefficient \eqn{tau} of Kendall}

This coefficient is particularly suitable for variables expressed in ordinal form. Therefore it can also be used after assigning ranges to the values of the variables.

There is a formula for its calculation that does not take into account "ties" between ranges of data, it is denoted by \eqn{ \tau_A}, and is calculated as follows: 
\deqn{\tau_A=\frac{n_c-n_d}{\frac{1}{2}n(n-1)}}
where \eqn{n_c} is the number of concordant pairs of ranges and \eqn{n_d} is the number of discordant pairs of ranges.

In the event that there is data in which there are "ties" between ranges, this new formula would be used:
\deqn{\tau_B=\frac{n_p-n_q}{\sqrt{(n_p+n_q+n_{E(X)})(n_p+n_q+n_{E(Y)})}}}
where \emph{p} indicates concordance or not investment, \emph{q} discordance or investment, and \emph{E} tie considering all pairs of cases.

The values of this coefficient are between -1 and 1, and its properties and interpretation are similar to the coefficients of Pearson and Spearman. 

The significance is contrasted by means of statistical that are distributed according to a Normal. In the case of \eqn{\tau_A} the following formula is applied:

\deqn{z=\frac{3(n_c-n_d)}{\sqrt{\frac{n(n-1)(2n+5)}{2}}}}
In the case of \eqn{\tau_B} the following formula would be used:
\deqn{z=\frac{n_c-n_d}{\sqrt{\upsilon}}}
where:
\deqn{\upsilon=\frac{\upsilon_0-\upsilon_t-\upsilon_u}{18+\upsilon_1+\upsilon_2}}
which in turn:
\deqn{\upsilon_0=n(n-1)(2n+5)}\cr
\deqn{\upsilon_t=\sum_{}^{}t_i(t_i-1)(2t_i+5)}\cr
\deqn{\upsilon_u=\displaystyle\sum\nolimits_{j}u_j(u_j-1)(2u_j+5)}\cr
\deqn{\upsilon_1=\displaystyle\sum\nolimits_{i}t_i(t_i-1)\displaystyle\sum\nolimits_{j}\frac{u_j(u_j-1)}{2n(n-1)}}\cr
\deqn{\upsilon_2=\displaystyle\sum\nolimits_{i}t_i(t_i-1)(t_i-2)\displaystyle\sum\nolimits_{j}\frac{u_j(u_j-1)(u_j-2)}{9n(n-1)(n-2)}}\cr
The \eqn{H_0} for the significance of this coefficient is that its value is 0 and therefore no association between variables. 

\strong{X.1.4. Gamma coefficient \eqn{\gamma}}

The most appropriate coefficient when the data present a high overlap of ranges. Again, the range of values that this coefficient can take is between -1 and 1, with -1 perfect negative association, 1 perfect positive association and 0 no association. 
The formula is as follows: 
\deqn{\gamma=\frac{n_c-n_d}{n_c+n_d}}
where \eqn{n_c} is the number of concordant pairs of ranges and \eqn{n_d} is the number of discordant pairs.

The significance is checked by using the following statistical value which is distributed by following a Normal\deqn{z=\gamma\sqrt{\frac{n_c-d_d}{N(1-\gamma^2)}}}

As with the rest of coefficients, the \eqn{H_0} is that the value of the coefficient is equal to 0, and therefore there is no association between the variables. 

\strong{FUNCTIONS}

To estimate the correlations, the function used is as follows  \link[ltm]{rcor.test} (Rizopoulos 2006; 2013).

\strong{EXAMPLE}

Data from a sampling in nests of a small bird species, the common quail. In this sample, the number of eggs per female, posts during a breeding season is counted in 50 females marked whose age was known. At the same time the average temperature during the same breeding season and the availability of food for females (whose values are percentages are given for the maximum measured) were recorded. The same sampling was repeated in the next breeding season with a different sample of females in the same population. The objective of the research is to discover if there is a relationship between the age of the female and the number of eggs per clutch. Estimates are made for each of the Provinces sampled.

Figure X.1 shows that there is a clear positive relationship between the age of the female and the number of eggs per clutch in the two provinces.
\tabular{c}{
\strong{Figure X.1} Relationship between the age of the female quail and the number\cr
of eggs per clutch, for each of the provinces.\cr
\figure{FX1}{options: width=3.7in}
}
The results table shows each of the correlation coefficients in the upper-right half of the table, and in the lower half left the probability. It is noted that, in all cases, the assumption of independence is rejected, because the probability is always less than 0.05. Therefore, in both provinces and considering the three coefficients, it is concluded that there is a relationship of dependency between the age of the female and the number of eggs. This association seems to be stronger in the province of Soria where, for example, Pearson's correlation coefficient is 0.78 , while in Palencia is 0.45. The coefficients of Spearman and Kendall also show this greater association between both variables in one province than in the other.
\tabular{c}{
\figure{RX1}
}
}
\references{
Rizopoulos, D. (2006) ltm: An R package for latent variable modelling and item response theory analyses. \emph{Journal of Statistical Software}, \strong{17}, 1-25.

Rizopoulos, D. (2013) Latent Trait Models under IRT. R package version 1.0-0. Available at: \url{http://CRAN.R-project.org/package=ltm}.
}
\examples{
\dontrun{

data(ZX1)

X1(data=ZX1,varX="Age", varY="Eggs", group="Province")

}
}
\keyword{X1}
