\name{X2}
\alias{X2}
\encoding{latin1}
\title{PARTIAL CORRELATIONS}
\description{A partial correlation analysis is applied between two variables using the coefficients of Pearson and Kendall, and taking into account the effect of another variable. In addition the relationship between the dependent variable and the independent can be plotted, and also distinguished between groups.} 
\usage{
X2(data, varX, varY, varZ, test=c("Pearson","Kendall"),
group=NULL,
ResetPAR=TRUE, PAR=NULL, YLAB=NULL, XLAB=NULL, CEXPCH=1.3, COLOR=NULL,
PCH=NULL, LEGEND=NULL, AXIS=NULL, MTEXT= NULL, TEXT=NULL, file="Output.txt")
}
\arguments{
  \item{data}{Data file.}
  \item{varX}{Independent variable.}
  \item{varY}{Dependent variable.}
  \item{varZ}{Variable that the effects on the correlation wants to be tested.}
  \item{test}{One, or two correlation coefficients may be chosen: Pearson and/or Kendall.}
  \item{group}{Variable in the case of wanting to estimate the correlations by groups.}
  \item{ResetPAR}{If FALSE, the default conditions of the function \link{PAR} are not placed and are those defined by the user in previous graphs.}
  \item{PAR}{It accesses the function \link{PAR} which allows to modify many different aspects of the graph.}
  \item{YLAB}{Legend of the Y axis.}
  \item{XLAB}{Legend of the X axis.}
  \item{CEXPCH}{Size of the symbols on the chart.}
  \item{COLOR}{It allows to modify the colors of the symbols, but in the event that \emph{group} is not NULL, should be as many different groups as the \emph{group} variable has.}
  \item{PCH}{Vector with graphic symbols. If NULL, these are automatically calculated starting with the symbol 15.}
  \item{LEGEND}{It allows to add a legend to the graph.}
  \item{AXIS}{It allows to add axes to the graph.}
  \item{MTEXT}{It allows to add text in the margins of the graph.}
  \item{TEXT}{It allows to add text in any area of the inner part
graphic.}
  \item{file}{TXT FILE. Output file name.}
}
\value{A TXT file is obtained with the results of the correlations and can represent a graph relating the dependent variable with the independent, differentiating between the groups of the grouping variable.
}
\details{
\strong{X. CONTRASTS OF INDEPENDENCE AND ASSOCIATION IN QUANTITATIVE VARIABLES}

\strong{X.2. PARTIAL CORRELATIONS}

\strong{X.2.1. Pearson correlation coefficient}

Sometimes a bivariate linear correlation can be masked by the effect of other variables beyond our control. For example, there may be a strong relationship between the size of the clutch of a certain bird species and the age of the female and, however, this correlation is masked by the influence of other variables in our data such as the average temperature during the breeding season. To study a simple correlation between two variables of interest, at the same time that the effect of other variables is controlled, the partial correlations are used.
 
If there are two variables \emph{X} and \emph{Y} on which the partial correlation is calculated controlling \emph{k} variables \emph{Z}, the method is based on calculating the Pearson correlation coefficient between two derived variables \eqn{d_x} and \eqn{d_y} such that:

\tabular{c}{
\eqn{d_x} = residues of the linear regression of \emph{x} with \eqn{z_1}, ..., \eqn{z_k}\cr
\eqn{d_y} = residues of the linear regression of \emph{y} with\eqn{z_1}, ..., \eqn{z_k}
}
It is possible to control, at the same time, the effect of one or more variables \emph{Z}. If only one is controlled, it would be partial correlation of first order. If two are controlled, it would be partial correlation of second order, and so on.

The calculation of the partial correlations of first order is by using the following formula: 
\deqn{r_{xy,z}=\frac{r_{xy}-r_{xz}r_{yz}}{\sqrt{(1-r_{xz}^2)(1-r_{yz}^2)}}}
where \emph{r} is the Pearson correlation coefficient between the indicated variables.

As an example of greater order, the formula of the coefficient is shown in the case that they are controlling two variables (\eqn{z_i} and \eqn{z_j}) whereby is a partial correlation of second order. The higher-order is obtained following the same logic:
\deqn{r_{xy,z_iz_j}=\frac{r_{xy,z_i}-r_{xz_j,z_i}r_{yz_j,z_i}}{\sqrt{(1-r_{xz_j,z_i}^2)(1-r_{yz_j,z_i}^2)}}}
The test of significance of this coefficient, with the null hypothesis that the population value is zero, is performed by calculating the statistical \emph{t} by means of the following formula:
\deqn{T=r_{xy,k}\frac{\sqrt{m-k-2}}{\sqrt{(1-r_{xy,k}^2)}}}
where \emph{m} it is the number of cases (if it is not equal for all pairs of variables, the less of them must be taken) and \emph{k} is the number of controlled variables that has been used.

\strong{X.2.2. Partial Kendall correlation coefficient 
(\eqn{T_{xy,z}})}

The basis of the partial correlations is the same as in the case of parametric statistics but a different statistic is needed which allows working without making any assumption about the distribution that our data follow. The main statistical that performs this function is the \emph{T} of Kendall, which is essentially the same as the \eqn{\tau} described in paragraph X.1.3 of the critical role \link{X1}, but adapted to the calculation of partial correlations.

The formula to compute it is as follows:
\deqn{T_{xy,z}=\frac{T_{xy}-T_{xz}T_{yz}}{\sqrt{(1-T_{xz}^2)(1-T_{yz}^2)}}}
where each bivariate correlation T is calculated in the same way that the \eqn{\tau} as described in section X.1.3 function \link{X1}.

For the calculation of its significance, the following statistical which follows a Normal distribution is used:
\deqn{z=\frac{3T_{xy,z}\sqrt{N(N-1)}}{\sqrt{2(2N+5)}}}
The \eqn{H_0} set, as usual for these statistics, is that the value of the population coefficient is 0.

\strong{FUNCTIONS}

To estimate the correlations the following function \link[ltm]{rcor.test} is used (Rizopoulos 2006; 2013).

\strong{EXAMPLE}

Data from a sampling in nests of a small bird species, the common quail. In this sample the number of eggs laid per female during the breeding season is counted in 50 tagged females whose age was known. At the same time the average temperature during the same breeding season and the availability of food for females (whose values are percentages are given for the maximum measured) were recorded. The same sampling was repeated in the next breeding season with a different sample of females in the same population. The objective of the research is to determine if temperature affects the possible relationship between the age of the female and the number of eggs per clutch. The calculations are performed without differentiating between provinces.

Figure X.2 shows that there is a clear positive relationship between female age and the number of eggs per clutch, considering the set of all provinces. 
\tabular{c}{
\strong{Figure X.2} Relationship between the age of the female quail and the number\cr
of eggs per clutch, considering all provinces.\cr
\figure{FX2}{options: width=2.7in}
}
In the Pearson coefficient, the upper right matrix shows that there is a correlation between the two variables of 0.637, and the lower left is the probability matrix. It is observed that the hypothesis of independence is rejected, since p < 0.001. Therefore, there is a significant correlation between female age and the number of eggs per female. The Kendall coefficient is 0.498 and p < 0.001.
\tabular{c}{
\figure{RX2}{options: width=4.5in}
}
\tabular{c}{
\figure{RX3}
}
Then the results including the variable temperature during the breeding season are shown. Again, only it should be noted in the ratio between the dependent variable and the independent, that for Pearson is 0.842 and 0.622 for Kendall. In both cases the probability, which is shown in the matrix \emph{pvalue}, is significant for the two tests with p < 0.001. Therefore, as the two correlation coefficients increase when the control variable is not considered, temperature in this example, 0.637 to Pearson and 0.498 for Kendall, it was concluded that the relationship between the age of the female and the number of eggs per female varies depending on the temperature during the breeding season.

\tabular{c}{
\figure{RX4}
}
}
\references{
Kim, S. (2013) Partial and Semi-partial (Part) correlation. R package version 1.0. Available at: \url{http://CRAN.R-project.org/package=ppcor}.

Rizopoulos, D. (2006) ltm: An R package for latent variable modelling and item response theory analyses. \emph{Journal of Statistical Software}, \strong{17}, 1-25.

Rizopoulos, D. (2013) Latent Trait Models under IRT. R package version 1.0-0. Available at: \url{http://CRAN.R-project.org/package=ltm}.
}
\examples{
\dontrun{

data(ZX1)

X2(data=ZX1,varX="Age", varY="Eggs", varZ="Temperature")

}
}
\keyword{X2}
