\name{X3}
\alias{X3}
\encoding{latin1}
\title{MULTIPLE CORRELATION}
\description{A correlation analysis between all the variables selected by the user is applied and the probability values are also calculated. In addition, two graphics matrix of correlations are performed.} 
\usage{
X3(data, variables, ResetPAR=TRUE, PAR=NULL, CORRPLOT=NULL, PAIRS=NULL,
colhist="#00FFFFFF", file="Output.txt")
}
\arguments{
  \item{data}{Data file.}
  \item{variables}{Variables for which the correlations are calculated.}
  \item{ResetPAR}{If FALSE, the default conditions of the function \link{PAR} are not placed and are those defined by the user in previous graphs.}
  \item{PAR}{It accesses the function \link{PAR} which allows to modify many different aspects of both charts.}
  \item{CORRPLOT}{It accesses the function \link[corrplot]{corrplot} which allows to specify the arguments of the first matrix chart.}
  \item{PAIRS}{It accesses the function \link[graphics]{pairs} which allows to specify the arguments of the second matrix chart.}
  \item{colhist}{Colour of the bars of the histogram in the second graph matrix.}
  \item{file}{TXT FILE. Output file name with the results.}
}
\value{A TXT file with the results of the correlations and probability values is obtained, in addition to performing two correlation matrix graphs.}
\details{
\strong{X. CONTRASTS OF INDEPENDENCE AND ASSOCIATION IN QUANTITATIVE VARIABLES}

\strong{X.3. MULTIPLE CORRELATION}

\strong{X.3.1. Pearson's correlation coefficient}

It is an extension of the method of simple Pearson correlation to cases where there is more than one independent variable. This coefficient indicates the degree of association between several independent variables \eqn{x_i} and a dependent variable \emph{y}.  This coefficient is often expressed as \emph{R}, and its square \eqn{R^2} is the "coefficient of determination", which is interpreted as the proportion of variance explained by the multiple linear regression:
\deqn{R^2=c'R_{xx}^{-1}c}
where \emph{c} it is a column vector or matrix with all possible correlations between the independent variables and the dependent variable. \emph{c'} is the transposed in this array or row vector. \eqn{R_{xx}} is a matrix of correlations between all the independent variables, and the superscript -1 indicates that the inverse of this matrix is used in the formula. It can also be calculated as the correlation coefficient simple -bivariate- between the dependent variable and the estimate of \emph{y} obtained using the multiple linear regression model, \emph{y'}.

The significance can be obtained through the statistical \emph{F}, calculated using the following formula:
\deqn{F=\frac{\frac{R_{yx_{1...k}}^2}{k}}{\frac{(1-R_{yx_{1...k}}^2)}{(n-k-1)}}}
where the term \eqn{R_{yx_{1...k}}^2} is the value of the coefficient of multiple correlation, \emph{k} is the number of independent variables, and \emph{n} the number of data. The degrees of freedom of the \emph{F} are \emph{k} and (\emph{n} - \emph{k} - 1).

\strong{X.3.2. Kendall's coefficient of concordance (W)}

All the non-parametric coefficients to measure association between variables we have seen so far were applicable for bivariate data and are based on the comparison of two groups of ranges or ordinal variables. The Kendall's coefficient of concordance (\emph{W}), however, will allow us to work with more than two groups of ranges or ordinal variables. It is therefore, to some extent, similar to the multiple correlation coefficient of Pearson, although in this case there is no a single dependent variable. Suppose that we have scores of \emph{m} judges (for example tasters) on \emph{n} objects (for example wines) and we want to measure the degree of agreement between judges. The formula to compute it is as follows  
\deqn{W=\frac{12S}{m^2(n^3-n)}}
where:
\deqn{S=\displaystyle\sum_{i=1}^{n}(R_i-\bar{R})^2}
\eqn{R_i} is the average range for the object \emph{i} and \eqn{\bar{R}} is the average of the ranges:
\tabular{ll}{
\eqn{R_i=\displaystyle\sum_{j=1}^{m}r_{i,j}} \tab \eqn{\bar{R}=\frac{1}{2}m(n+1)}
}
If "draws" between various data, each data is assigned to the mean of the ranks (if the third and fourth are equal, the range will be 3.5 for both).

To test the significance of this statistic, there would be two possible cases:

- If \eqn{3\leq N\leq 7}, a distribution generated from all the possible combinations of ranges, which is tabulated for different number of variables or groups (\eqn{3\leq k\leq 20}), and large number of ranges (Siegel & Castellan, 1988) is used. 

- If \emph{N}>7, another statistical distribution that follows an approximately \eqn{\chi^2} with \eqn{n} - 1 degrees of freedom will be used:
\deqn{\chi^2=k(n-1)W}

In any case, the \eqn{H_0} that set, will be the value of \emph{W} is equal to zero.

\strong{X.3.3. Squared coefficient of multiple linear correlation}

Another method of calculation is the square of the coefficient of multiple linear correlation. That square is interpreted as the coefficient of determination or proportion of variance explained by the linear regression on the set of all of the explanatory variables.

The correlation matrix is calculated for the whole set, that array is reversed, and finally are subtracted from the unit the reciprocals of the elements of the diagonal, thus obtaining, simultaneously, all the coefficients of the squared multiple correlation. This is the method that will be used to estimate the correlation of one variable with multiple variables.

The square of the coefficient of multiple linear correlation is equal to the coefficient of determination \eqn{r^2} which is obtained in the regressions.
  
\strong{FUNCTIONS}

The function \link[ltm]{rcor.test} of the package ltm (Rizopoulos 2006; 2013) for the calculation of the correlation and odds between the variables is used and the function \link[psych]{smc} of the package psych (Revelle, 2014) to calculate the multiple correlations. For the first graph the function \link[corrplot]{corrplot} of the package corrplot (Wei, 2013) is used. For the second graph functions \link[SciViews]{panel.hist}, \link[SciViews]{panel.cor} and \link[SciViews]{panel.reg} of SciViews package (Grosjean, 2014) and \link[graphics]{pairs} of the base package graphics are used.

\strong{EXAMPLE}

Morphometric data from various species of the order Characiformes, such as the length of the base of the dorsal fin (M12), height of the body (M11), and so on for more details see Guisande et al. (2010).  The purpose is to estimate the correlation between several variables.

In Figures X.3 and X.4, the correlations between morphometric measurements of the fish in two different formats are represented. In the case of Figure X.3 variables are sorted by default using a Principal Components Analysis, although there are other methods available.
\tabular{cc}{
\strong{Figures X.3 y X.4} Correlation between morphometric measures of several\cr
fish species of the order Characiformes.\cr 
\figure{FX3}{options: width=3.3in}
\cr
\figure{FX4}{options: width=4.7in}
}
The results are shown in the following table, where the matrix above right are the correlations between variables, and the lower left the odds.
\tabular{c}{
\figure{RX5}{options: width=4.5in}
}
Finally, in the following table, the multiple correlations of each variable with all the remaining ones are shown. For example, a value of 0.975 for the variable M11 means that the rest of variables explain 97.5\% of the variability observed in M11.
\tabular{c}{
\figure{RX6}{options: width=5in}
}
}
\references{
Guisande, C., Manjarrs-Hernndez, A., Pelayo-Villamil, P., Granado-Lorencio, C., Riveiro, I., Acua, A., Prieto-Piraquive, E., Janeiro, E., Matas, J.M., Patti, C., Patti, B., Mazzola, S., Jimnez, S., Duque, V. & Salmern, F. (2010) IPez: An expert system for the taxonomic identification of fishes based on machine learning techniques. \emph{Fisheries Research}, 102, 240-247.

Grosjean, P. (2014) SciViews GUI API - Main package. R package version 0.9-5. Available at: \url{http://CRAN.R-project.org/package=SciViews}.

Rizopoulos, D. (2006) ltm: An R package for latent variable modelling and item response theory analyses. \emph{Journal of Statistical Software}, \strong{17(5)}, 1-25.

Rizopoulos, D. (2013) Latent Trait Models under IRT. R package version 1.0-0. Available at: \url{http://CRAN.R-project.org/package=ltm}.

Revelle, W. (2014) Procedures for Psychological, Psychometric, and Personality Research. R package version 1.4.5. Available at: \url{http://CRAN.R-project.org/package=psych}.

Siegel, S. & Castellan, N.J. Jr. (1988) \emph{Nonparametric statistics for the behavioral sciences}. McGraw-Hill, New York.

Wei, T. (2013) Visualization of a correlation matrix). R package version 0.73. Available at: \url{http://CRAN.R-project.org/package=corrplot}.
}
\examples{
\dontrun{

data(ZX3)

#Correlation between morphometric variables of fish species #of order Characiformes

X3(data=ZX3, variables=c("M11","M12","M13","M15","M24","M2","M3","M4","M5"))

}
}
\keyword{X3}
