\name{XI1}
\alias{XI1}
\encoding{latin1}
\title{SIMPLE REGRESSION}
\description{Different regression models are applied to describe the type of function that best fits the possible relationship between two variables.} 
\usage{
XI1(data, varY, varX, model=c("Linear", "Log", "S-curve",
"Power", "Exp",
"Quadratic", "Cubic", "Inverse"), outliers=NULL, quant1=0.05, quant2 = 0.95,
ResetPAR=TRUE, mfrow=c(2,4), PAR=NULL, PLOT=NULL, PLOTR=NULL, YLAB=NULL,
XLAB=NULL, CEXPCH=1.3, COLABLINE="#48D1CCFF", COLOR="#C0FF3EFF",
PCH=15, resPlot=TRUE, LEGEND=NULL, AXIS=NULL, MTEXT= NULL, TEXT=NULL,
file1="Output.txt", file2="Coefficients.csv", file3="Residuals.csv",
na="NA", dec=",", row.names=FALSE)
}
\arguments{
  \item{data}{Data file.}
  \item{varY}{Dependent variable.}
  \item{varX}{Independent variable.}
  \item{model}{One, or multiple regression models can be selected: "Linear" , "Log", "S-curve", "Power", "Exp", "Quadratic", "Cubic", "Inverse".  It is not considered the model in those cases in which there is the logarithm that apply to any of the variables, if any value of the variable, which applies the logarithm, is zero or negative. The inverse model is not calculated if any value of the independent variable is zero.}
  \item{outliers}{If it is NULL, the outliers are not deleted. If any regression model, "Linear" , "Log", "S-curve", "Power", "Exp", "Quadratic", "Cubic" or "Inverse" is chosen, then the outliers are removed using the selected regression model.}
  \item{quant1}{Quantile of the lower end to the elimination of outliers.}
  \item{quant2}{Quantile of the upper end to the elimination of outliers.}
  \item{ResetPAR}{If it is FALSE, the default condition of the function \link{PAR} is not placed and maintained those defined by the user in previous graphics.}
  \item{mfrow}{If it is NULL and there are several regression models selected, these come in separate windows. If it is required that the graphs are displayed in panels, this argument is a vector with the format c(nr, nc) that indicates the number of figures per row (nr) and column (nc), by filling the first rows.}
  \item{PAR}{It accesses the function \link{PAR} which allows to modify many different aspects of the graph.}
  \item{PLOT}{It accesses the function  \link{plot.default} which allows to modify the graph of the regression.}
  \item{PLOTR}{It accesses the function \link{plot.default} which allows to modify the graph of the residuals.}
  \item{YLAB}{Legend of the axis Y.}
  \item{XLAB}{Legend of the axis X.}
  \item{CEXPCH}{Size of the graphic symbols.}
  \item{COLABLINE}{Color of the line of the regression model.}
  \item{COLOR}{Colour of symbols.}
  \item{PCH}{Type of symbol.}
  \item{resPlot}{If TRUE, the graphs showing the relationship between the predicted value and the typified residual are shown.}
  \item{LEGEND}{It allows to add a legend to the chart. It only makes sense if a single graph, since a single regression model is selected.}
  \item{AXIS}{It allows to add axes to the graph. It only makes sense if a single graph, since a single regression model is selected.}
  \item{MTEXT}{It allows to add text in the margins of the graph. It only makes sense if a single graph, since a single regression model is selected.}
  \item{TEXT}{It allows to add text in any area of the inner part of the graph. It only makes sense if a single graph, since a single regression model is selected.}
  \item{file1}{TXT FILE. Name of the output file with the results of the analysis.}
  \item{file2}{CSV FILES. Filename with the coefficients of the regression models.}
  \item{file3}{CSV FILES. Filename with residuals of the regression models.}
  \item{na}{CSV FILES. Text that is used in the cells without data.}
  \item{dec}{CSV FILES. It defines if the comma "," is used as decimal separator or the dot ".".}
  \item{row.names}{CSV FILES. Logical value that defines if identifiers are put in rows or a vector with a text for each of the rows.}
}
\value{A TXT file is obtained with the results of the regressions and the normality test, homogeneity of variances and homoscedasticity for each of the regression models, as well as graphics with the relationship between the dependent and independent variable for each of the regression models, in addition to graphics with the relationship between the predicted value and the typified residual.}
\details{
\strong{XI. REGRESSIONS}

Regression is defined as the theory that seeks to express, through a mathematical function, the relationship between a dependent variable and a (simple regression) or multiple (multiple regression) independent variables. Obtaining this feature allows to predict what will be the value of the dependent variable depending on the value that the independent variable or variables take.

Regression differs from correlation in which the latter examines the degree of association between the variables, and determines whether the relationship is or is not significant, whereas the regression, as mentioned above, sought to define the role that best explains the relationship between the variables.

\strong{XI.1. REGRESSION MODELS FOR QUANTITATIVE DEPENDENT VARIABLES}

\strong{XI.1.1. Requirements}

To implement a regression model between variables is not required that the data submitted a Normal distribution or that there is homogeneity of variances; however, in order to be able to determine if the function obtained with the regression model is significant it is necessary to apply contrasts, and this will have to fulfill the following requirements, which are largely related to the residuals (difference between the observed value of the dependent variable and the value set by the function):

1. The residuals obtained from the regression model must present a Normal distribution. 

2. Homoscedasticity must exist in the residuals, that is to say, the variance of the residuals must be constant. The graphs shown below (Figure XI1.1) are examples where homoscedasticity of residuals is not satisfied, because its variability is not constant but changes depending on the predicted values. The first graph, obtained in the setting of a straight line, also shows that the relationship is not linear, since failure to maintain the horizontal trend.
\tabular{c}{
\strong{Figure XI1.1.} Examples without homoscedasticity.\cr
\figure{FXI1}{options: width=4.3in}
}
3. There should be no autocorrelation in the series of residuals (must be independent). If this requirement is not met, it is not possible to know the exact degree of relationship between the independent variable and the dependent, because that part of the forecast is due to the own values of the dependent variable.

4. In the case of the multiple regression model, there must be no relationship between the independent variables, i.e. there should be no multicollinearity. 

\strong{XI.1.2. Simple regression}

The most common models, and that are calculated in this function, are the following, which are shown as they are expressed in the output file TXT file with the results of the models and the CSV where the coefficients of the models are displayed:
\tabular{lll}{
\strong{Model} \tab \strong{CSV} \tab \strong{TXT}\cr
Linear \tab \eqn{y=a+bx} \tab Same\cr
Logarithm \tab \eqn{y=e^{a+\frac{b}{x}}} \tab Same\cr
S-Curve \tab \eqn{y=e^{a+\frac{b}{x}}} \tab Same\cr
Potential \tab \eqn{y=ax^b} \tab \eqn{y=e^{ln(a)+bln(x)}}\cr
Exponential \tab \eqn{y=ae^{bx}} \tab \eqn{y=e^{ln(a)+bx}}\cr
Quadratic \tab \eqn{y=a+bx+cx^2} \tab Same\cr
Cubic \tab \eqn{y=a+bx+cx^2+dx^3} \tab Same\cr
Inverse \tab \eqn{y=a+\frac{b}{x}} \tab Same\cr
}
\strong{FUNCTIONS}

The function \link[nortest]{lillie.test} of the package nortest (Gross, 2013) is used to perform the test of Normality Kolmogorov-Smirnov with Lilliefors'correction, the function \link[lmtest]{dwtest} of the package lmtest (Hothorn et al., 2013) to analyze the autocorrelation with the test and the Durbin-Watson statistic function \link[lmtest]{bptest} of the package lmtest (Hothorn et al., 2013) to perform the Breusch-Pagan test of homoscedasticity.

\strong{EXAMPLE}

The data correspond to a study that aims to find the best regression model that exists between the weight and width of the shell for a set of three species of molluscs.

\strong{Step 1.}

In the first place the relationship between the weight and width of the shell is analyzed considering the three species of molluscs and all of the regression models.

The residuals of the models, which are in one of the CSV files generated by this function are shown partially in the following table. These are useful to identify outliers, to see if it meets the homoscedasticity, as shown in the Figure XI1.1 and to analyze data for Normality.
\tabular{c}{
\figure{RXI1}{options: width=5.1in}
}
The following table shows the coefficients of the equations of regression models and \eqn{r^2}.
\tabular{c}{
\figure{RXI2}{options: width=4.5in}
}
Figure XI1.2, which generates the function, shows the eight regression models in a single panel and in Figure XI1.3 the residuals (the black line indicates a residual of zero).\tabular{cc}{
\strong{Figures XI1.2 and XI1.3.} Relationship between shell width and weight in three\cr
species of molluscs and residuals of the regressions.\cr
\figure{FXI2}{options: width=5.2in}
\cr
\figure{FXI3}{options: width=5.2in}
}
Although the values of \eqn{r^2} are higher in the quadratic and cubic models, it is observed that the potential model residuals are equally small, have a linear behavior and are very similar throughout the entire range of predicted values of the dependent variable, to those obtained with quadratic and cubic models (Figure XI1.3). Therefore, the potential model was chosen because it is preferable to choose a simpler model, provided that the residuals are similar to those obtained in the quadratic and cubic models.

\strong{Step 2.}

In the figure XI1.2 it was noted that there were some outliers, which can be removed easily using the argument \emph{outliers}.  As mentioned before that the best model was the potential, it is now defined with the argument \emph{model= "Power"}. In addition, it specifies that data is removed using the same model \emph{outliers= "Power"} and as only a graph is removed, the panel is canceled with \emph{mfrow=NULL}. 

The new model that is obtained (figure XI1.4) shows that the outliers have disappeared and due to this the \eqn{r^2 =0.97}, is greater than in Figure XI 1.2 (\eqn{r^2} = 0.89) where the atypical data had not been deleted. Figure XI1.5  shows the residuals, which then will be whether they are homogeneous throughout the range of predicted values of the dependent variable.
\tabular{clll}{
\strong{Figures XI1.4 and XI1.5} Potential relationship between shell width and weight\cr
and between the predicted values and residuals.\cr
\figure{FXI4}{options: width=3.3in}
\cr
\figure{FXI5}{options: width=3.3in}
}
In the TXT file that generates the function, the regression model power is shown, where the variable shell width is significant (p < 0.001, see \emph{Pr(>|t|)}) and, therefore, the model as a whole was also significant (p < 0.001, see \emph{p-value} at the end of the results).

The \eqn{r^2} (see \emph{Multiple R-squared}) shows that the width of the shell explains a 97\% of the observed variance in the weight of the individuals. The \eqn{r^2} adjusted (see \emph{Ajusted R-squared}) takes into account the size of the sample to determine the proportion above and, in this case, it shows the same value. The \eqn{r^2} adjusted should be used to compare models with different numbers of observations or independent variables. The equation of the potential regression model could be expressed in either of these two ways:
\tabular{lll}{
\eqn{Weight=0.436*Width^{3.547}} \tab or \tab \eqn{Weight=e^{ln(-0.829)+3.547*ln(Width)}}
}
\tabular{clll}{
\figure{RXI3}{options: width=3.3in}
}
\tabular{clll}{
\figure{RXI4}{options: width=3.3in}
}
In the above table, the results of the test of Kolmogorov-Smirnov normality with Lilliefors' correction are shown, the test for autocorrelation of Durbin-Watson statistic and the Breusch-Pagan test of homoscedasticity.

\strong{Normality} The residuals do not have a Normal distribution with p < 0.001. Although is not complied with the assumption of normality, this does not invalidate the model as it is very predictive with a \eqn{r^2} very high. The problem resulting from these residuals are not Normal is that there can be no assurance that the degree of significance, probability value that shows the model, is the correct one.

\strong{Autocorrelation} The requirement that there should be no autocorrelation is no longer met the test of Durbin-Watson statistic p = 0.012. This means that the value of \eqn{r^ 2} of the 97\% is not all due to the independent variable, the width of the shell, but it is also in part due to the own dependent variable that is auto explained and, therefore, it is not possible to know exactly how much is the variance explained by the independent variable. Anyway it is necessary to mention that the probability value of the test of Durbin-Watson statistic can be less than 0.05 easily when there are many data, as in this example. The statistical DW, whose value is 1.81 in this example, is a better indicator of the autocorrelation when the number of data is very large. According to Durbin & Watson (1951), a DW less than 1 means a strong positive autocorrelation, a DW greater than 4 a strong negative autocorrelation, values between 1 and 3 a moderate autocorrelation, and a value close to 2 means that there is no autocorrelation. Therefore, it can be concluded that the autocorrelation in this example is very small and the variance explained by the independent variable may be close to 97\%.

\strong{Homoscedasticity} Finally, the requirement of homoscedasticity of the residuals is not satisfied, because the likelihood of the Breusch-Pagan test is p < 0.001. The fact of not fulfilled this requirement means that the model is not as predictive for the entire range of values of the dependent variable. In the residuals of the model (Figure XI1.5) it is noted that as the width is greater, the residuals are larger. Therefore, the model predicts well the weight in smaller individuals, and a little worse in the mollusks of greater size.
}
\references{
Durbin, J. & Watson G.S. (1951) Testing for serial correlation in least squares regression. \emph{Biometrika}, \strong{38}, 159-171.

Gross, J. (2013) Tests for Normality. R package version 1.0-2. Available at: \url{http://CRAN.R-project.org/package=nortest}.

Hothorn, T. et al., (2013) Testing Linear Regression Models R package version 0.9-33. Available at: \url{http://CRAN.R-project.org/package=lmtest}.
}
\examples{
\dontrun{

data(ZXI1)

#Step 1. Regression between shell width (independent variable) and
#weight (dependent variable) considering several species of molluscs

XI1(data=ZXI1, varX="Width",varY="Weight", XLAB= "Width (cm)", YLAB="Weight (gr)")

#Step 2. Same regression but removing outliers and performing
#only potential model

XI1(data=ZXI1, varX="Width",varY="Weight", model="Power", outliers="Power",
mfrow=NULL, XLAB= "Width (cm)", YLAB="Weight (gr)")

}
}
\keyword{XI1}
