\name{XI10}
\alias{XI10}
\encoding{latin1}
\title{POISSON REGRESSION-ESTIMATION}
\description{A Poisson regression is applied which allows to find the model that best fits the possible relationship between the number of times it occurs when regarding some random phenomenon (dependent variable) and several independent variables.}
\usage{
XI10(data, varY, varX, varplot=NULL, offset=NULL, offsetlog=TRUE, stepwise=TRUE,
ResetPAR=TRUE, PAR=NULL,  YLAB=NULL, XLAB=NULL, PLOT.TS=NULL, OrderCat=NULL,
LabelCat=NULL, COLOR=NULL, PCH=NULL, LEGEND=NULL, AXIS=NULL, MTEXT=NULL,
TEXT=NULL, file1="Coefficients.csv", file2="Predictions.csv", na="NA", dec=",",
row.names=FALSE, file3="Output.txt")
}
\arguments{
  \item{data}{Data file.}
  \item{varY}{Dependent variable.}
  \item{varX}{Independent variables.}
  \item{varplot}{Vector with three variables. The first variable is the Y axis, the second the X axis and the third is like a factor, in such a way that the relationship between the first and the second variable is displayed on each of the different categories coming from the third variable of this vector \emph{varplot}.}
  \item{offset}{A weight variable can be specified.}
  \item{offsetlog}{If it is TRUE, the variable \emph{offset} is logarithmically transformed.}
  \item{stepwise}{If it is TRUE, regression is applied according to steps in order to eliminate those variables that are not significant. It uses the Akaike Information Criterion (\emph{AIC})}.
  \item{ResetPAR}{If FALSE, the conditions are not placed by default in the function \link{PAR} and those defined by the user on previous graphics are maintained.}
  \item{PAR}{It accesses the function \link{PAR} that allows to modify many different aspects of the graph.}
  \item{YLAB}{Legend of the Y axis.}
  \item{XLAB}{Legend of the X axis.}
  \item{PLOT.TS}{It accesses the function \link[stats]{plot.ts} from the stats package.}
  \item{OrderCat}{It allows to specify a vector with the order in which the categories from the X axis are shown.}
  \item{LabelCat}{It allows to specify a vector with the names of the categories from the X axis.}
  \item{COLOR}{Colors that are used in the graph time series, to identify the categories of the third variable which is specified in the argument of the vector \emph{varplot}.}
  \item{PCH}{Symbols that are used in the time series graph, to identify the categories of the third variable which is specified in the argument vector \emph{varplot}.}
  \item{LEGEND}{It allows to include a legend.}
  \item{AXIS}{It allows to add axes.}
  \item{MTEXT}{It allows to add text in the margins of the graph.}
  \item{TEXT}{It allows to add text in any area of the inside part of the graph.}
 \item{file1}{CSV FILES. Filename with the coefficients of the Poisson regression.}
  \item{file2}{CSV FILES. Filename with the predictions of the Poisson regression.}
  \item{na}{CSV FILES. Text used in the cells without data.}
  \item{dec}{CSV FILES. It defines if the comma "," is used as decimal separator or the dot ".".}
  \item{row.names}{CSV FILES. Logical value that specifies whether identifiers are being placed in rows or either a vector with a text for each one of the rows.}
  \item{file3}{TXT FILE. Output file name with the results of the analysis.}
}
\value{A TXT file is obtained with the regression results, two CSV files with the coefficients and regression predictions, and a time series chart if selected.}  
\details{
\strong{XI. REGRESSIONS}

\strong{XI.1. REGRESSION MODELS FOR QUANTITATIVE DEPENDENT VARIABLES}

\strong{XI.1.6. Poisson regression}

\emph{XI.1.6.1. Model estimation}

It is used to model the number of times that a true random phenomenon occurs. For example, the number of new cases of a particular disease during a given time period in fairly general terms it can be adequately modeled by a Poisson distribution. It suffices to do with the assumption that cases occur randomly over time and independently. This is true for many other series of events, like the calls to a telephone switchboard machine breakdowns, or traffic accidents, but in the epidemiological field the number of new cases is used to measure the incidence rate, so the Poisson distribution turns out to be important in the study of the incidence and its causes.

When using one or more explanatory factors, that divide the population into strata (smokers and nonsmokers, groups receiving different medication, age groups, etc), a model is usually built to try to explain the differences between groups, admitting that within each group variability occurs randomly.

The Poisson distribution is simple: it has only one parameter, generally represented by \eqn{\lambda}. This value is both the mean and variance of the variable at the same time, so their estimate is very simple: it is enough to just take a representative sample and calculate the average. If in a particular area 7.2 of the cases annually appear as an average disease (average value, for example, in the last 10 years), that is the estimated value of the lambda parameter.

If in the sample we observe the variance being very different from the average, that will indicate us that the Poisson distribution is not adequate to model that situation, but overall the Poisson regression is appropriate for variables that measure recounts, in which case the linear regression is not appropriate, since the estimate could produce negative recounts, residuals does not have a normal distribution, and the variance of the response tends to increase with the average.

In the Poisson regression model it is assumed that the dependent variable, given the values of the explanatory variables, has a Poisson distribution (conditional distribution by those values) whose parameter \eqn{\lambda} has the value:
\deqn{\lambda=e^{P(X_i)}}
being \eqn{P(X_i)} of a linear function of the explanatory variables.  

\strong{FUNCTIONS}

To estimate the Poisson regression, the function used is the one \link[stats]{glm} from the stats package.

To estimate the model by steps the function used \link[MASS]{stepAIC} was from the MASS package (Venables & Ripley, 2002; Ripley et al., 2014).

The time series graph is done with the function \link[stats]{plot.ts} from the stats package.

The contrast to determine if it is a Poisson distribution is being performed with the old function \emph{epicalc}.

\strong{EXAMPLE}

Data refer to a study of cohorts, about the exposure of arsenic in the industry and the deaths from respiratory diseases, available in the database Montana from the old emph{epicalc} package (Chongsuvivatwong, 2012).

The data is the number of deaths in each group (\emph{respdeath}), number of persons by years of exposure (\emph{personyrs}), dividing the number of deaths and the number of persons per years of exposure * 10.000 (\emph{respdeath.personyrs}), age groups (\emph{agegr}), period of employment (\emph{period}), start of employment (\emph{start}) and time of exposure to arsenic throughout the years (\emph{arsenic}).
	
The primary endpoint of this study is (\emph{respdeath}), number of deaths from respiratory causes, and we try to find the relationship that may exist between this variable and the others remaining. Since the target variable is a recount, the Poisson model may be suitable. For the regression model the dependent variable is the number of deaths in each group (\emph{varY=respdeath}).

The independents are age group (\emph{agegr}), period of employment (\emph{period}), start of the employment (\emph{start}) and time of exposure to the arsenic throughout the years (\emph{arsenic}), which are defined on the argument \emph{varX=c("agegr", "period", "start", "arsenic")}.

The argument \emph{offset} allows to include a constant or a variable in the function. As we know a priori that the number of deaths should be proportional in each group to the number of people exposed, in the example the variable \emph{personyrs}, we include this variable in the model, being necessary to transform the variable logarithmically so it can correspond with the overall transformation performed with the remaining variables, for which we leave the default argument \emph{offsetlog=TRUE}.

With the argument \emph{varplot=c("respdeath.personyrs","period","agegr")} variables are defined to represent the time series graph.
\tabular{c}{
\strong{Figure XI11.1.} Evolution of the incidence rate (deaths divided by number\cr
of exposed people) for different periods of work and different age groups.\cr
\figure{FXI27}{options: width=2.7in}
}
In the graph (Figure XI11.1) it is observed that in the incidence, number of deaths divided by the number of people who were exposed, is higher in the two older age groups.

The following results show the model obtained, whose \eqn{r^2=0.8} and the contrast, whose null hypothesis is that the variable follows a Poisson distribution, has a p = 0.26. Therefore, we conclude that the distribution is of Poisson.\tabular{c}{
\figure{RXI18}
}
The following table shows the predictions for each case that allow to analyze the relative risk.
\tabular{c}{
\figure{RXI19}
}
}
\references{
Chongsuvivatwong, V. (2012) Epidemiological calculator. R package version 2.15.1.0.

Ripley, B., Venables, B., Bates, D.M., Hornik, K., Gebhardt, A. & Firth, D. (2014) Support Functions and Datasets for Venables and Ripley's MASS. R package version 7.3-33. Available at: \url{http://CRAN.R-project.org/package=MASS}.

Venables, W.N. & Ripley, B.D. 2002. \emph{Modern Applied Statistics with S}. Springer, fourth edition, New York. \url{http://www.stats.ox.ac.uk/pub/MASS4}.
}
\examples{
\dontrun{

data(ZXI11)

XI10(data = ZXI11, varY = "respdeath", varX = c("agegr", "period",
"start", "arsenic"), offset = "personyrs", varplot = c("respdeath.personyrs",
"period", "agegr"), YLAB = "Deaths per year*10.000", XLAB = "Period",
MTEXT = c("text = 'Incidence rate per age and period'", "line = 1", "cex = 2",
"font = 2"))

}
}
\keyword{XI10}
