\name{XI11}
\alias{XI11}
\encoding{latin1}
\title{POISSON REGRESSION-PREDICTION}
\description{A Poisson regression model previously calculated with \link{XI10} function is applied.}
\usage{
XI11(data, varY,  varX, offset=NULL,  offsetlog=TRUE, file="Model predictions.csv",
na="NA", dec=",", row.names=FALSE)
}
\arguments{
  \item{data}{Data file.}
  \item{varY}{Dependent variable.}
  \item{varX}{Independent variables.}
  \item{offset}{A weight variable may be specified.}
  \item{offsetlog}{If it is TRUE the variable \emph{offset} is then logarithmically transformed.}
  \item{file}{CSV FILES. Filename with the predictions of the Poisson regression.}
  \item{na}{CSV FILES. Text used in the cells without data.}
  \item{dec}{CSV FILES. Defines if a decimal separator like a comma "," or period "." is being used.}
  \item{row.names}{CSV FILES. Logical value that specifies whether identifiers are put in rows or in a vector with a text for each of the rows set.}
}
\value{A CSV file is obtained with the model predictions.}
\details{
\strong{XI. REGRESSIONS}

\strong{XI.1. REGRESSION MODELS FOR QUANTITATIVE DEPENDENT VARIABLES}

\strong{XI.1.6. Poisson Regression}

\emph{XI.1.6.2. Model prediction}

The best method to assess the quality of the regression model is to check the degree of accuracy using data that was not included in the original matrix and which was used to estimate the model.
This function allows to easily apply a Poisson regression model already estimated which, besides serving to evaluate the quality of the model, it also serves to be able to use the model, i.e., predict values predicted for a given case.

To use this feature, it will be necessary to have the Poisson regression model calculated with the function \link{XI10}.

\strong{EXAMPLE}

The data must have the same format, i.e., the same variables and the same position, that the data matrix which was used when the model was estimated with the function \link{XI10}. In addition, the working directory must be the same that was used just like when the model was estimated using the function \link{XI10}.

Data refer to a study of cohorts, about the exposure of arsenic in the industry and the deaths from respiratory diseases, available in the database of the old package \emph{epicalc} from the epicalc package (Chongsuvivatwong, 2012). The data is the number of deaths in each group (\emph{respdeath}), number of persons by years of exposure (\emph{personyrs}), dividing the number of deaths and the number of persons per years of exposure * 10.000 (\emph{respdeath.personyrs}), age groups (\emph{agegr}), period of employment (\emph{period}), start of employment (\emph{start}) and time of exposure to arsenic throughout the years (\emph{arsenic}).

However, these data were not included when the original model was estimated with the \link{XI10} function. The primary endpoint of this study is (\emph{respdeath}), number of deaths from respiratory causes, we try to find the relationship that may exist between this variable and the others remaining. Since the target variable is a recount, the Poisson model may be suitable.

For the regression model the dependent variable is the number of deaths in each group (\emph{varInteresY=respdeath}). The independents are age groups (\emph{agegr}), period of employment (\emph{period}), start of employment (\emph{start}) and time of exposure to arsenic in years (\emph{arsenic}), which are defined on the argument \emph{varInteresX=c("agegr", "period", "start", "arsenic")}.

The argument \emph{offset} allows to include a constant or a variable in the function. As we know a priori, the number of deaths should be proportional in each group as the number of people exposed, in the example, the variable \emph{personyrs}, we include this variable in the model, being necessary for the variable logarithmically transformed to correspond with the overall transformation performed with the remaining variables, for which leave the default argument intact \emph{offsetlog=TRUE}.

The results show that \eqn{r^2=0.84}. Therefore, it seems to be that the model is very trustworthy and reliable.
}
\examples{
\dontrun{

data(ZXI12)

XI11(data=ZXI12, varY="respdeath", varX=c("agegr", "period", "start",
"arsenic"), offset="personyrs")

}
}
\keyword{XI11}
