\name{XI2}
\alias{XI2}
\encoding{latin1}
\title{NON-LINEAR FUNCTIONS}
\description{Different regression models are applied to describe the type of non-linear function that best fits the possible relationship between two variables.} 
\usage{
XI2(data, varY, varX, model=c("Clench", "Nexponential", "Saturation",
"Rational", "Bertalanffy", "Gompertz", "Logistic"), outliers=NULL,
quant1=0.05, quant2 = 0.95, ResetPAR=TRUE, mfrow=c(2,4), PAR=NULL,
PLOT=NULL, YLAB=NULL, XLAB=NULL, CEXPCH=1.3, COLABLINE="#48D1CCFF",
COLOR="#C0FF3EFF", PCH=15, resPlot=TRUE, LEGEND=NULL, AXIS=NULL, MTEXT= NULL,
TEXT=NULL, file1="Output.txt", file2="Coefficients.csv", file3="Residuals.csv",
na="NA", dec=",", row.names=FALSE)
}
\arguments{
  \item{data}{Data file.}
  \item{varY}{Dependent variable.}
  \item{varX}{Independent variable.}
  \item{model}{One or multiple regression models can be selected: "Clench", "Nexponential", "Saturation", "Rational", "Bertalanffy", "Gompertz" and/or "Logistic".}
  \item{outliers}{If NULL, outliers are not removed. When choosing a regression model, "Clench", "Nexponential", "Saturation", "Rational", "Bertalanffy", "Gompertz" or "Logistic", then the outliers are removed using the selected regression model (for further information see section \emph{details}).}
  \item{quant1}{Quantile of the lower end to the elimination of outliers.}
  \item{quant2}{Quantile of the upper end to the elimination of outliers.}
\item{ResetPAR}{If it is FALSE, the default condition of the function \link{PAR} is not placed and maintained those defined by the user in previous graphics.}
  \item{mfrow}{If it is NULL and there are several regression models selected, these come in separate windows. If it is required that the graphs are displayed in panels, this argument is a vector with the format c(nr, nc) that indicates the number of figures per row (nr) and column (nc), by filling the first rows.}
  \item{PAR}{It accesses the function \link{PAR} which allows to modify many different aspects of the graph.}
  \item{PLOT}{It accesses the function \link{plot.default} which allows to modify the graph of the regression.}
  \item{YLAB}{Legend of the axis Y.}
  \item{XLAB}{Legend of the axis X.}
  \item{CEXPCH}{Size of the graphic symbols.}
  \item{COLABLINE}{Color of the line of the regression model.}
  \item{COLOR}{Colour symbols.}
  \item{PCH}{Type of symbol.}
  \item{resPlot}{If TRUE, the graphs showing the relationship between the predicted value and the typified residual are shown.}
  \item{LEGEND}{It allows to add a legend to the chart. It only makes sense if a single graph, since a single regression model is selected.}
  \item{AXIS}{It allows to add axes to the graph. It only makes sense if a single graph, since a single regression model is selected.}
  \item{MTEXT}{It allows to add text in the margins of the graph. It only makes sense if a single graph, since a single regression model is selected.}
  \item{TEXT}{It allows to add text in any area of the inner part of the graph. It only makes sense if a single graph, since a single regression model is selected.}
  \item{file1}{TXT FILE. Name of the output file with the results of the analysis.}
  \item{file2}{CSV FILES. Filename with the coefficients of the regression models.}
  \item{file3}{CSV FILES. Filename with residual of the regression models.}
  \item{na}{CSV FILES. Text that is used in the cells without data.}
  \item{dec}{CSV FILES. It defines if the comma "," is used as decimal separator or the dot ".".}
  \item{row.names}{CSV FILES. Logical value that defines if identifiers are put in rows or a vector with a text for each of the rows.}
}
\value{A TXT file is obtained with the results of the functions and the test of Normality for each of them, as well as graphics with the relationship between the dependent and independent variable in addition to graphics with the relationship between the predicted value and the residuals defined for each function.}
\details{
\strong{XI. REGRESSIONS}

\strong{XI.1. REGRESSION MODELS FOR QUANTITATIVE DEPENDENT VARIABLES}

\strong{XI.1.3. Non-linear functions}

Many times variables are adjusted to a type of non-linear function that is none of the common which are described in most statistical programs as were observed in the function \link{XI1}. Below are some of these non-linear functions and how to calculate them.

\emph{XI.1.3.1. Accumulation functions}

The growth rate of a bacterial population, of yeast or phytoplankton at different concentrations of nutrients or temperature, the photosynthetic rate of plants at different light intensities, the accumulated richness in function of the number of samplings, among many other examples, are adjusted to the so-called functions of accumulation (Figure XI2.1). There are different types but they can be divided between those in which the zero of Y and the zero of X always coincide and those that allow a non-zero value for Y when X is zero (Figure XI2.1).
\tabular{c}{
\strong{Figure XI2.1.} Accumulation curves in which zero of Y and zero of X always coincide (black\cr
circles) and curves that allow a different value of zero for X when Y is zero (white circles).\cr
\figure{FXI6}{options: width=2.1in}
}
In this \emph{script} is calculated: 1) the curve of Clench (Clench, 1979), which is a modification of the function of Monod (Monod, 1950), and was proposed to butterflies; 2) the negative exponential (Miller & Wiegert, 1989) that was proposed for rare plant species; 3) the saturation curve that was used to show the relationship between growth of phytoplankton, a toxic algae of the genus \emph{Alexandrium} and the concentration of phosphate (Frangpulos et al., 2004), which is similar to von Bertalanffy growth curve that we will see below but adapting the coefficients to better explain the pattern of accumulation function and, finally; 4) the rational function (Ratkowski, 1990) that can be used when there is no clear criterion which model to use (Falther, 1996).
\tabular{lll}{
\strong{Name} \tab \strong{Function} \tab \strong{Reference}\cr
Clench \tab \eqn{y=\frac{ax}{1+bx}} \tab (Clench, 1979)\cr
Negative exponential \tab \eqn{y=a\left(1-e^{-bx}\right)} \tab (Miller & Wiegert, 1989)\cr
Saturation \tab \eqn{y=a\left(1-e^{-b(x-c)}\right)} \tab (Frangpulos et al., 2004)\cr
Rational \tab \eqn{y=\frac{(a+bx)}{(1+cx)}} \tab (Ratkowski, 1990)\cr
}
\emph{XI.1.3.2. Growth functions}

The growth curves are generally applied to the growth of individuals while the von Bertalanffy curve can also be set to the growth of populations. That is why previously showed the saturation curve, whose formula is identical to the von Bertalanffy, but with their coefficients modified. 

XI.1.3.2.1. Growth curve of von Bertalanffy 

The growth curve of many organisms fits well with the von Bertalanffy equation (Figure XI2.2):
\deqn{L_t=L_{\infty}\left(1-e^{-k(t-t_0)}\right)}
where \eqn{L_t} is the length of the individual to the age \emph{t}, \eqn{L_{\infty}} is the maximum length that reaches the individual when the growth ceases, \emph{k} is the constant growth expressed in \eqn{time^{-1}} and \eqn{t_0} is the hypothetical age that would have an individual who had a zero size. Therefore, the dependent variable is \eqn{L_t}, the independent variable is the age of the individual (\emph{t}) and the constants in this equation are \emph{k}, \eqn{L_{\infty}} and \eqn{t_0}.
\tabular{c}{
\strong{Figure XI2.2.} Growth curve of von Bertalanffy \cr
\cr
\figure{FXI7}{options: width=2.4in}
}
XI.1.3.2.2. Growth curve of Gompertz 

In some species, such as fish, crustaceans and molluscs, in the early stages of the life cycle (larval stage) the growth can be better adjusted to the Gompertz equation (Hernandez-Llamas & Ratkowsky, 2004) (Figure XI2.3):
\deqn{L_t=ae^{-be^{-ct}}}
where \eqn{L_t} is the length of the individual to the age \emph{t}, \emph{a} is a constant that represents the maximum value of the asymptotic curve, \emph{t} is the age of the individual and, \emph{b} and \emph{c} are the other two constants in the equation.
\tabular{c}{
\cr
\strong{Figure XI2.3.} Growth curve of Gompertz\cr
\figure{FXI8}{options: width=2.2in}
}
\emph{XI.1.3.2. Logistics function}

Many phenomena in nature are adjusted to a logistic curve (Figure XI2.4), as for example the changes in the abundance of a population over time (Smith & Smith, 2000), the scientific progress over time within a particular line of research (Solla Price, Little Science, Big Science, 1963 -cited in Callon et al., 1995), etc. 
\tabular{c}{
\strong{Figure XI2.4.} Logistics function with a negative slope (white circles)\cr
and positive (black circles).\cr
\figure{FXI9}{options: width=2.2in}
}
The logistic curve is defined by the following equation:
\deqn{Y=\frac{a}{1+e^{(b-cX)}}}
where the constant \emph{a} sets the upper limit of the curve, and is equal to \emph{K} or load capacity of the population (maximum number of individuals of that population), in the case of that model a population. The constant \emph{c} determines the slope, and in the case of populations is equal to \emph{r} or rate of population growth. The constant \emph{b} defines the size of the so-called phase of latency in the case of populations, the phase with smaller values before starting the slope to reach the maximum value.

\strong{FUNCTIONS}

It uses the function \link[nortest]{lillie.test} of the package (Gross, 2013) to perform the test Kolmogorov-Smirnov normality with Lilliefors' correction and the function \link[stats]{nls} of the base package stats for the estimation of the models.

\strong{EXAMPLE 1}

Samplings were conducted at several sites and the number of species present was recorded. It was a relationship between the number of sites sampled and accumulated richness considering all sites surveyed above. The goal is to determine the theoretical total number of species that exists in the area. 

Figure XI2.5 shows the functions obtained, where it is observed that the functions of Clench and Rational are those that have the higher \eqn{r^2}.
\tabular{c}{
\strong{Figure XI2.5.} Relationship between the number of sites sampled and richness of\cr
accumulated species considering all sites surveyed so far.\cr
\figure{FXI10}{options: width=4.0in}
}
Figure XI2.6 shows that Clench and Rational functions also have the smallest residuals, have a nearly linear behavior and are the same throughout the entire range of predicted values for the dependent variable. Therefore, both functions are those that best fit.
\tabular{c}{
\strong{Figure XI2.6.} Relationship between the predicted values and the residuals\cr
typified from all accumulation functions.\cr
\figure{FXI11}{options: width=3.6in}
}
The function of Clench's test and the Kolmogorov-Smirnov normality with Lilliefors correction is displayed below. The residuals have a Normal distribution with p = 0.26. 
\tabular{c}{
\figure{RXI6}{options: width=3.2in}
}
The equation would be as shown below, in such a way that considering 500 sampled sites the theoretical total richness of the area would be of 31 species.
\deqn{Richness=\frac{1.05*Sites}{1+0.032*Sites}}

\strong{EXAMPLE 2}

\strong{Step 1.}

The study consisted of cultivate species of the genus \emph{Alexandrium} at different concentrations of phosphate. The objective was to determine the minimum concentration of phosphate necessary to ensure growth and the maximum rate of growth of the population.

Figure XI2.7 shows the functions obtained, where it is noted that the saturation curve is the one that has a greater \eqn{r^2}. It is also noted that it was not possible to find an adjustment for the Rational function, which can happen for any function depending on the type of data.
\tabular{c}{
\strong{Figure XI2.7.} Relationship between the concentration of phosphate and the rate of\cr
daily growth of population of a species of the genus \emph{Alexandrium}\cr
\figure{FXI12}{options: width=5.0in}
}
Figure XI2.8 shows that for the three functions, the residuals are small, have an almost linear behavior and are the same throughout the range of predicted values of the dependent variable. However, there appear to be outliers.
\tabular{clll}{
\strong{Figure XI2.8.} Relationship between the predicted values and the residuals\cr
typified from all accumulation functions.\cr
\cr
\figure{FXI13}{options: width=5.0in}
}

\strong{Step 2.}

Figure XI2.8 it is noted that there were some outliers, which can be easily removed using the argument \emph{outliers}. As it was previously observed the best model was the function of Saturation, specifying that outliers must be removed by using the argument \emph{outliers="Saturacin"}. Moreover, as it was not possible to adjust the Rational function, this was removed from the argument \emph{model=c("Clench","Nexponential", "Saturation")}. Finally, as there are only three graphs, the argument \emph{mfrow=c(1,3)} is used to represent them in one row and three columns.

Figure XI2.9 shows the obtained functions, where it is observed that the function of saturation is that which continues to have a greater \eqn{r^2}.
\tabular{c}{
\strong{Figure XI2.9.} Relationship between the concentration of phosphate and the rate of\cr
daily population growth of a species of the genus \emph{Alexandrium}\cr
\figure{FXI14}{options: width=5.5in}
}
Figure XI2.10 shows that for the three functions, the residuals are homogeneous and, moreover, outliers were eliminated.
\tabular{c}{
\strong{Figure XI2.10.} Relationship between the predicted values and the residuals\cr
typified from all accumulation functions.\cr
\figure{FXI15}{options: width=5.5in}
}
The function of Saturation, and the Normality test with the Kolmogorov-Smirnov Lilliefors' correction is shown below. The residuals have a Normal distribution with p = 0.801. 
\tabular{c}{
\figure{RXI7}{options: width=5.2in}
}
The equation would be as shown below, so that the maximum growth rate is 0.222 \eqn{d^{-1}} and 0.468 \eqn{\mu M} is the minimum threshold of phosphate concentration required by the species to grow, as at this concentration of phosphate growth is zero.
\deqn{y=0.222\left(1-e^{-2.553(Phosphate-0.468)}\right)} 

\strong{EXAMPLE 3}

A study carried out with the anchovy (\emph{Engraulis encrasicolus}), in the Alboran Sea and the Strait of Sicily, was to analyze the relationship between the length of the individuals and their age, which was quantified by counting otolith rings (Basilone et al., 2004). The aim was to compare the growth in both areas and determine the maximum length. For this reason, attempts had been made to find the growth function to best fit the data. 

\strong{Step. 1}

First the two growth functions with the argument are selected \emph{model=c("Bertalanffy", "Gompertz")}. Figure XI2.11 shows that it could only find a setting with the Gompertz function.
\tabular{c}{
\strong{Figure XI2.11.} Relationship between the length and age in the anchovy\cr
(\emph{Engraulis encrasicolus}), in the Alboran Sea and the Strait of Sicily.\cr
\figure{FXI16}{options: width=3.2in}
}
\strong{Step. 2}

Then the model was made with only \emph{model="Gompertz"} and to eliminate possible outliers using the argument \emph{outliers="Gompertz"}. Figure XI2.12 displays the Gompertz function.
\tabular{c}{
\strong{Figure XI2.12.} Relationship between the length and age in the anchovy\cr
(\emph{Engraulis encrasicolus}), in the Alboran Sea and the Strait of Sicily.\cr
\figure{FXI17}{options: width=3.2in}
}
\strong{Step. 3}

Finally, there was a script in order to show the trend in both areas. With the function \emph{subset} the data of the Alboran Sea is first selected and the first graph is done, and with the second \emph{subset} the data of Sicily is selected. With the function \emph{seq}, a sequence of 10 to 32 with 100 divisions is generated, that allows then to obtain the values of \emph{Length} by applying the Gompertz function corresponding to the data within each of the areas. With the function \emph{lines} the trend line is represented. In order to have the coefficients of the functions of each of the areas, in step 2 there would be the script, but doing separately the Alborn Sea and the Strait of Sicily. Finally, with the function \emph{legend} the legends are set. The resulting graph is shown in Figure XI2.13.
\tabular{c}{
\strong{Figure XI2.13.} Relationship between the length and age in the anchovy\cr
(\emph{Engraulis encrasicolus}), in the Alboran Sea and the Strait of Sicily.\cr
\figure{FXI19}{options: width=4in}
}
The equations obtained for each of the areas are as follows:
\tabular{lc}{
\strong{Area} \tab \strong{Function}\cr
Alborn sea \tab \eqn{Length=28.994*e^{-1.8457*e^{(-0.044718*Age)}}}\cr
Sicily \tab \eqn{Length=57.613*e^{-2.8974*e^{(-0.038967*Age)}}}\cr
}

\strong{EXAMPLE 4}

The growth of a population of phytoplankton normally follows a logistic growth curve. The purpose is to estimate the logistic curve of growth, to determine the maximum abundance that the species can reach under such growing conditions.

Figure XI2.14 shows that the adjustment to the logistics function is good, with a \eqn{r^2=0.98}, and residuals are homogeneous throughout the range of predicted values (Figure XI2.15).
\tabular{c}{
\strong{Figure XI2.14.} Evolution of the abundance of a species\cr
of phytoplankton over time\cr
\figure{FXI20}{options: width=3.2in}
}
\tabular{c}{
\strong{Figure XI2.15.} Relationship between the predicted values and residuals\cr
typified in the function shown in Figure XI2.14.\cr
\figure{FXI21}{options: width=3.2in}
}
The results show that the residuals are normal with p = 0.734 and logistic curve is defined by the following function, where it is observed that the  maximum abundance is \eqn{3.422*10^5} cells per ml:
\deqn{Abundance=\frac{3,422*10^5}{1+e^{(6,152-1,391*Time)}}}
\tabular{clll}{
\figure{RXI8}{options: width=4.2in}
}
}
\references{
Basilone, G., Guisande, C., Patti, B., Mazzola, S., Cuttitta, A., Bonanno, A. & Kallianiotis, A. (2004). Linking habitat conditions and growth in the European anchovy (\emph{Engraulis encrasicolus}). \emph{Fisheries Research}, 68: 9-19.

Callon, M., Courtial, J.P. & Penan, H. (1995) \emph{Cienciometra: La medicin de la actividad cientfica, de la bibliometra a la vigilancia tecnolgica}. Trea, D.L., Gijn.

Clench, H.K. (1979) How to make regional lists of butterflies: some invoking empirically based criteria in selecting among thoughts. \emph{The Journal of the Lepidopterists' Society}, 33: 216-231.

Flather, C.H. (1996) Fitting species-accumulation functions and assessing regional land use impacts on avian diversity. \emph{Journal of Biogeography}, 23: 155-168.

Frangpulos, M., Guisande, C., deBlas, E. y Maneiro, I. (2004) Toxin production and competitive abilities under phosphorus limitation of \emph{Alexandrium} species. \emph{Harmful Algae}, 3: 131-139.

Gross, J. (2013) Tests for Normality. R package version 1.0-2. Available at: \url{http://CRAN.R-project.org/package=nortest}.

Hernndez-Llamas, A. & Ratkowsky, D.A. (2004) Growth of fishes, crustaceans and molluscs: estimation of the von Bertalanffy, Logistic, Gompertz and Richards curves and a new growth model. \emph{Marine Ecology Progress Series} 282: 237-244.

Miller, R.I. & Wiegert, R.G. (1989) Documenting completeness species-area relations, and the species-abundance distribution of a regional flora. \emph{Ecology}, 70: 16-22.

Monod, J. (1950) La technique de culture continue, thorie et applications. \emph{ Annales de l'Institut Pasteur (Paris)},  79: 390-410.

Ratkowski, D.A. (1990) \emph{Handbook of nonlinear regression models}. Marcel Dekker, New York, 241 pp.

Smith, R.L. & Smith, T.M. (2000) \emph{Ecologa}. Pearson Educacin, S.A., Madrid.
}
\examples{
\dontrun{

data(ZXI2)

#EXAMPLE 1. Accumulated richness and sampling sites

XI2(data=ZXI2, varX="Sampling.sites",varY="Richness", model=c("Clench",
"Nexponential", "Saturation","Rational"), mfrow=c(2,2), XLAB="Sampling sites")

#EXAMPLE 2. Growth rate of a toxic algae as a function 
#of the concentration of phosphate

data(ZXI3)

#Step 1.
XI2(data=ZXI3, varX="Phosphate",varY="Growth", model=c("Clench", "Nexponential", "Saturation",
"Rational"), mfrow=c(2,2), YLAB=expression(paste("Growth rate (d "^"-1",")")),
XLAB=expression(paste("Phosphate (",mu,"M)")))

#Step 2.
XI2(data=ZXI3, varX="Phosphate",varY="Growth", model=c("Clench","Nexponential",
"Saturation"), outliers="Saturation",  mfrow=c(1,3),
YLAB=expression(paste("Growth rate (d "^"-1",")")),
XLAB=expression(paste("Phosphate (",mu,"M)")))

#EXAMPLE 3. Relationship between age and length in the anchovy

data(ZXI4)

#Step 1.
XI2(data=ZXI4, varX="Age",varY="Length",
model=c("Bertalanffy", "Gompertz"), mfrow=c(1,2))

#Step 2.

XI2(data=ZXI4, varX="Age",varY="Length",model="Gompertz",
outliers=c("Gompertz"), mfrow=NULL)

#Step 3

data(ZXI4)

#Alboran is selected
data1<-subset(ZXI4,ZXI4[,"Area"] %in% "Alboran")
plot( formula = Length~Age, xlim = c(0,50), ylim = c(0,25),
xlab="Age (days)",
ylab="Length (cm)", font.lab=2, cex.lab=1.5, col = "#FF8C00FF" , pch = 15,
cex = 1.2, data = data1)

#Line of the function
cx<-seq(10,32, length.out = 100)
cy<-28.994*exp(-1.8457*exp(-0.044718*cx))
lines(cx,cy, col="#FF8C00FF",lwd=3 )

#Sicilia is selected
data2<-subset(ZXI4,ZXI4[,"Area"] %in% "Sicily")
points(formula=Length~Age , col="#00FF00FF" , data=data2,
pch=17 , cex=1.2)

#Line of the function
cx<-seq(10,32, length.out = 100)
cy<-57.613*exp(-2.8974*exp(-0.038967*cx))
lines(cx,cy,  col="#00FF00FF",   lwd=3 )

#Legends
legend(x=0, y= 26, legend=expression(paste("Alboran ",
italic("r")^"2"," = 0.82")),pch=c(15), bty="n", cex=1.3,
col="#FF8C00FF")
legend(x=0, y= 24, legend=expression(paste("Sicily ",
italic("r")^"2"," = 0.75")),pch=c(17), bty="n", cex=1.3,
col="#00FF00FF")

#EXAMPLE 4. Evolution of the abundance of a population
#of phytoplankton species over time

data(ZXI5)

XI2(data=ZXI5, varX="Day",var="Abundance", model=c("Logistic"), mfrow=NULL,
YLAB=expression(paste("Abundance (cells ml"^"-1",")")),
XLAB="Time (days)")

}
}
\keyword{XI2}
