\name{XI3}
\alias{XI3}
\encoding{latin1}
\title{SELECTION OF NON-CORRELATED VARIABLES USING THE VIF}
\description{The inflation factor of the variance (VIF) is used to select uncorrelated variables, from an initial matrix with multiple variables.}
\usage{
XI3(data, variables, method="vifstep", threshold=10, varCode=NULL, file1="VIF.csv",
file2="Variables.csv", na="NA", dec=",", row.names=FALSE)
}
\arguments{
  \item{data}{Data file.}
  \item{variables}{Variables from which those non-correlated will be selected.}
  \item{method}{There are three methods to select non-correlated variables: "vif", "vifcor" and "vifstep" (see section \emph{details} for further information). "vif" method is not registered by default, despite being the recommended option, since it only works with RWizard and therefore does not work on other platforms, such as for example RGUI.}
  \item{threshold}{Cut-off value for VIF.}
  \item{varCode}{Optionally, variables of the original matrix can be selected, which are exported in the output file with non-correlated variables. For example, this allows to choose variables which are codes of rows.}
  \item{file1}{CSV FILES. Name of the file with the VIF values for all variables.}
  \item{file2}{CSV FILES. Name of the file where the non-correlated variables are exported.}
  \item{na}{CSV FILES. Text that is used in the cells without data.}
  \item{dec}{CSV FILES. Defines whether as decimal separator is used the comma "," or the dot ".".}
  \item{row.names}{CSV FILES. Logical value which defines whether there are identifiers on the rows or a vector with a text for each of the rows.}
}
\value{Two CSV files are exported: one with VIF values of the variables that have been selected and are not correlated, and the other with the variables included in the \emph{varCode} argument and those selected which are not correlated.}
\details{
\strong{XI. REGRESSIONS}

\strong{XI.1. REGRESSION MODELS FOR QUANTITATIVE DEPENDENT VARIABLES}

\strong{XI.1.4. Variable selection using the inflation factor of variance (VIF)}

\emph{XI.1.4.1. Selection of uncorrelated variables}

In many multivariate statistical models is necessary to use variables that are not correlated. With this function, it is easy to generate a file with uncorrelated variables from a set of initial variables. The selection method is based on the inflation factor of variance (VIF).

A variable is redundant if is highly correlated with another or others, in which case it contains essentially the same information and should be excluded. The redundant variables in a model produced the effect of increasing the variance of the estimates of the coefficients (the coefficients are more unstable), thereby distorting the confidence intervals for these ratios and the contrasts of significance (may appear as a non-significant coefficient that it actually is). The problem is known as "multicollinearity," the regressors are interrelated and are not independent. 

In general a certain degree of multicollinearity is inevitable, and should be accepted as such. Only when the multicollinearity is serious, action must be taken by removing from the model the variables that cause it. 

The most widely used method to detect multicollinearity and redundant variables is the one that uses the so-called "inflation factor of variance" VIF: \eqn{VIF(x)=\frac{1}{(1-R^2)}} being \eqn{R^2} the coefficient of determination of the regression of the variable \emph{x} with the remaining (square of the multiple correlation coefficient).

As \eqn{ 1-R^2} represents the fraction of variance of \emph{x} not explained by the other variables, its inverse indicates the degree of redundant information: a VIF = 40 means that the information in this variable already contained in other variables is 40 times greater than the different information or new that this brings. The minimum value of VIF is 1, and has no maximum (can be arbitrarily large).

The following values are often used as reference values of VIF: VIF < 10 mild; 10 < VIF < 30 moderate; VIF > 30 serious. It is advisable to delete redundant by the variables with VIF > 30. 

Delete variables can make the model biased or incomplete, it is generally recommended caution in doing so: it is preferable to maintain a variable that provides supporting information (at the expense of increasing the variability or instability) to supress it, because the effect could be more serious, especially if the sample is large, since the sample size corrects the problem making to reduce the variability of the estimates.

In this function between three different methods can be chosen to select the non-correlated variables.

If "vif" is selected, there is a pop-up window where it will report on the variables with VIF above the threshold indicated by the user in the argument \emph{threshold}, and the user is the one who decides which variables will be eliminated. The advantage of the manual method is that the user decides which variable to delete from the correlated pairs.

In the other two options "vifcor" and "vifstep", an automatic selection of the variables to exclude is carried out, which is logically much faster and more convenient, but it is always preferable to use the manual option, so that the user always has control over when choosing which variable is selected between two correlated.

If "vifcor" is selected, it first looks for the pair of variables that has the maximum linear correlation, and eliminates the one which has the larger VIF, repeating the process until there is no variable with a high coefficient of correlation with another variable.

If "vifstep" is selected, it calculates the VIF for all the variables, and excludes that which has a greater VIF, always considering the threshold defined by the user in the argument \emph{threshold}, repeating the process until no variable is correlated with another.

\strong{FUNCTIONS}

The functions \link[usdm]{vif}, \link[usdm]{vifcor} and \link[usdm]{vifstep} of the usdm package (Naimi, 2013; Naimi et al., 2014) were used.

\strong{EXAMPLE}

Data are for morphometric measurements of fishes. The objective is to select those which are not correlated to a set of variables. The selection method chosen is "vif", which means it will get a menu which is shown below (Figure XI3.1), where the user is deciding which variables eliminate. Furthermore, the argument \emph{varCode} indicates that the variables "Order", "Family", "Genus" and "Species" in the export file are included with the selection of uncorrelated variables
\tabular{c}{
\strong{Figure XI3.1.} Menu that allows to select which variables to eliminate,\cr
from those which are correlated.\cr
\cr
\figure{FXI28}{options: width=5in}
}
}
\references{
Naimi, B. (2013) Uncertainty analysis for species distribution models. R package version 3.5-0. Available at: \url{http://CRAN.R-project.org/package=usdm}.

Naimi, B., Hamm, N.A.S., Groen, T.A., Skidmore, A.K., & Toxopeus, A.G. 2014. Where is positional uncertainty a problem for species distribution modelling? \emph{Ecography}, 37: 191-203.
}
\examples{
\dontrun{

data(ZX3)
XI3(data=ZX3, variables = c("M2", "M3", "M4", "M5", "M6", "M7", "M8",
"M9", "M10", "M11", "M12", "M13", "M14", "M15", "M16", "M17", "M18",
"M19", "M20", "M21", "M22", "M23", "M24", "M25", "M26", "M27", "M28"),
method="vif",varCode=c("Order","Family","Genus","Species"))

}
}
\keyword{XI3}
