\name{XI4}
\alias{XI4}
\encoding{latin1}
\title{SELECTION OF CORRELATED VARIABLES USING VIF}
\description{The inflation factor of variance (VIF) is used to select highly correlated variables, from an initial array with multiple variables.}
\usage{
XI4(data, variables, threshold=10, varCode=NULL, file1="VIF.csv",
file2="Variables.csv", na="NA", dec=",", row.names=FALSE)
}
\arguments{
  \item{data}{Data file.}
  \item{variables}{Variables from which those correlated will be selected.}
  \item{threshold}{Cut-off value for VIF.}
  \item{varCode}{Optionally, variables of the original matrix can be selected, which are exported in the output file with correlated variables. For example, this allows to choose variables which are codes of rows.}
  \item{file1}{CSV FILES. Name of the file with the VIF values for all variables.}
  \item{file2}{CSV FILES. Name of the file where the correlated variables are exported.}
  \item{na}{CSV FILES. Text that is used in the cells without data.}
  \item{dec}{CSV FILES. Defines whether as decimal separator is used the comma "," or the dot ".".} 
  \item{row.names}{CSV FILES. Logical value which defines whether there are identifiers on the rows or a vector with a text for each of the rows.}
}
\value{Two CSV files are exported: one with VIF values of the variables that have been selected and are correlated, and the other with the variables included in the \emph{varCode} argument and those selected which are correlated.}
\details{
\strong{XI. REGRESSIONS}

\strong{XI.1. REGRESSION MODELS FOR QUANTITATIVE DEPENDENT VARIABLES}

\strong{XI.1.4. Variable selection using the inflation factor of variance (VIF)}

\emph{XI.1.4.2. Selection of correlated variables}

It is not frequent, but there are statistical multivariate models where it is useful to note that the variables are correlated, for example, the Principal Components Analysis (PCA).  With this function it is easy to generate a file with the correlated variables from a set of initial variables. The method of selection is based on the inflation factor of the variance (VIF) that is explained in the section \emph{details} of the function \link{XI3}. 

\strong{FUNCTIONS}

The function \link[usdm]{vif} of the usdm package (Naimi, 2013; Naimi et al., 2014) was used.

\strong{EXAMPLE}

Data correspond to morphometric measures of fishes. The goal is to select those variables that are highly correlated to a set of variables. In addition, it indicates that the variables "Family" and "Gender" be included in the export file with the selection of correlated variables.}

\references{
Naimi, B. (2013) Uncertainty analysis for species distribution models. R package version 3.5-0. Available at: \url{http://CRAN.R-project.org/package=usdm}.

Naimi, B., Hamm, N.A.S., Groen, T.A., Skidmore, A.K., & Toxopeus, A.G. (2014) Where is positional uncertainty a problem for species distribution modelling? \emph{Ecography}, 37: 191-203.
}
\examples{
\dontrun{

data(ZX3)

XI4(data=ZX3, variables=c("M11","M12","M13","M15","M24","M2", "M3", "M4", "M5"),
varCode=c("Family","Genus"))

}
}
\keyword{XI4}
