\name{XI5}
\alias{XI5}
\encoding{latin1}
\title{MULTIPLE REGRESSION}
\description{Different statistical techniques are applied to obtain the type of function that best fits the relationship that exists between a quantitative dependent variable and multiple quantitative independent variables.}
\usage{
XI5(data, varY, varX, outliers=FALSE, quant1=0.05, quant2 = 0.95,
stepwise=FALSE,
direction="both", deplog=FALSE, indlog=FALSE, method="hier.part",
threshold=10,
CoVa=FALSE, typeV="lmg", rela=TRUE, b=1000, names.abbrev=15, ylimV=NULL,
mainV=NULL, cex.title=1.5, PAIRS=TRUE, lower.panel=panel.smooth,
upper.panel=panel.reg,
diag.panel=panel.hist, main=NULL, cex.main=2, cex=1.2, pch=24, colhist="#00FFFFFF",
bg="#B2DFEEFF", cex.labels=1, font.labels=2, file1="Output.txt", file2="Residuals.csv",
na="NA", dec=",", row.names=FALSE)
}
\arguments{
  \item{data}{Data file.}
  \item{varY}{Dependent variable.}
  \item{varX}{Independent variables.}
  \item{outliers}{If it is TRUE, the outliers are removed using the selected regression model (for more details see section \emph{details} of function \link{XI1}).}
  \item{quant1}{Quantile of the lower end for the elimination of the atypical data.}
  \item{quant2}{Quantile of the top end for the elimination of atypical data.}
  \item{stepwise}{If TRUE, a regression to eliminate those variables that are not significant is therefore applied by steps. It uses Akaike Information Criterion (AIC) to define which are the variables that are excluded (see section \emph{details} for more information).}
  \item{direction}{The mode of stepwise search, can be one of the following: "both" (default), "backward", or "forward"}
  \item{deplog}{If TRUE, the logarithm is applied to the dependent variable by using the equation \eqn{ln(variable-(min(variable)-1 equation))}.}
  \item{indlog}{If TRUE, the logarithm of all independent variables is calculated and added to the rest of variables,
to perform the regression model with transformed and untransformed independent variables, in order to get the best model. The same equation used in the argument \emph{deplog} is applied.}
  \item{method}{There are four methods to select the non-correlated variables: "vif", "vifcor" "vifstep" and "hier.part" (default). The "vif" method is not selected by default, because it can only work with RWizard and, therefore, it does not work in other platforms such as RGUI. If this argument is NULL, the variables that show collinearity are not deleted. For more information, see section \emph{details}.}
  \item{threshold}{Cut-off value for the VIF (for more information, see section \emph{details} of the function \link{XI3}).}
  \item{CoVa}{If it is TRUE, the graph is shown with the contribution of independent variables to the regression model, provided that the number of independent variables is greater than two.}
  \item{typeV}{GRAPHIC CONTRIBUTION OF VARIABLES OF ARGUMENT \emph{CoVa}. It can be one or a vector with the following methods:"lmg", "pmvd" (only version outside the United States), "last", "first", "betasq", "pratt", "genizi" or "car". For more details see section \emph{details} of the function \link[relaimpo]{calc.relimp}.} 
  \item{rela}{GRAPHIC CONTRIBUTION OF VARIABLES OF ARGUMENT \emph{CoVa}. If TRUE the relative importance of all variables add up to 100\%.}
  \item{b}{GRAPHIC CONTRIBUTION OF VARIABLES OF ARGUMENT \emph{CoVa}. It is the number of boot cycles requested at boot.relimp. Be sure to adjust to a lower number, if you are simply testing code.}
  \item{names.abbrev}{GRAPHIC CONTRIBUTION OF VARIABLES OF ARGUMENT \emph{CoVa}. An integer which defines the number of letters in the labels.}
  \item{ylimV}{GRAPHIC CONTRIBUTION OF VARIABLES OF ARGUMENT \emph{CoVa}. A vector with Y axis limits.}
  \item{mainV}{GRAPHIC CONTRIBUTION OF VARIABLES OF ARGUMENT \emph{CoVa}. Title of the graph.}
  \item{cex.title}{GRAPHIC CONTRIBUTION OF VARIABLES OF ARGUMENT \emph{CoVa}. Text size title.}
  \item{PAIRS}{If TRUE, the matrix chart is displayed. If the number of variables is greater than 10, it is better to define the argument as FALSE, because the utility is lost when the relationships among the variables are not well observed.}
  \item{lower.panel}{MATRIX CHART. Graph type of the upper left panel.}
  \item{upper.panel}{MATRIX CHART. Graph type of the upper right panel.}
  \item{diag.panel}{MATRIX CHART. The diagonal graph type.}
  \item{main}{MATRIX CHART. Graph title.}
  \item{cex.main}{MATRIX CHART. Size of the letter of the title.}
  \item{cex}{MATRIX CHART. Size of the symbols.}
  \item{pch}{MATRIX CHART. Type of symbol.}
  \item{colhist}{MATRIX CHART. Color of the bars of the histogram.}
  \item{bg}{MATRIX CHART. Color of symbols.}
  \item{cex.labels}{MATRIX CHART. Size of the labels.}
  \item{font.labels}{MATRIX CHART. Label font type.}
  \item{file1}{TXT FILE. Name of the output file with the results of the analysis.}
  \item{file2}{CSV FILE. Name of the file with the residuals  of the regression models.}
  \item{na}{CSV FILES. Text used in cells without data.}
  \item{dec}{CSV FILES. It defines if a comma "," or a dot "." is used as decimal separator.}
  \item{row.names}{CSV FILES. Logical value which defines whether there are identifiers on the rows or a vector with a text for each of the rows.}
}
\value{A TXT file is obtained with the VIF values of all variables, the VIF of the selected variables after removing those with colinearity, the VIF of the variables that are finally in the regression model, the normality test, homogeneity of variances and homoscedasticity and the regression model. A matrix of scatterplots, a plot with the relative contribution of the independent variables estimated by using hierarchical partitioning and a plot with the relative contribution of the independent variables in the multiple regression if the argument \emph{CoVa=TRUE}. A CSV file is also obtained with the standardized residuals.}  
\details{
\strong{XI. REGRESSIONS}

\strong{XI.1. REGRESSION MODELS FOR QUANTITATIVE DEPENDENT VARIABLES}

\strong{XI.1.5. Multiple regression}

So far we have seen regressions in which there was a single independent variable. However, it is often necessary to consider whether our dependent variable is related to more than one variable. In this case, the multiple regression
should be used.

In addition to normal and homoscedasticity of the residuals, and that there should be no autocorrelation, requirements of simple regressions (see function \link{XI1}), another requirement of the multiple regressions is that there should be no correlation between independent variables, i.e., there should be no multicollinearity.

In the function four different methods for selecting uncorrelated variables can be chosen. If "vif" is selected, a pop-up window comes out where variables with VIF above threshold indicated by the user in the argument \emph{threshold} are reported, and the user decides which variables are removed. The advantage of the manual method is that the user decides which variables to delete from the correlated pairs.

In the "vifcor" and "vifstep" options, an automatic selection of the variables to exclude is made, which is obviously much faster and comfortable. If "vifcor" is selected, you must first find the pair of variables that has the maximum linear correlation, and eliminate those having the greater VIF, and the process should be repeated until there is no variable with a high correlation coefficient with another variable. If "vifstep" is selected, the VIF must be calculated for all variables, and exclude which has the greater VIF, always considering the threshold defined by the user in the argument  \emph{threshold}, the process should be repeated until no variable is correlated with another. The problem of "vifcor" and "vifstep" methods is that these are not taken into account when eliminating variables, which is the one that has a greater contribution to explain the observed variability in the dependent variable and, therefore, are not the best methods for obtaining the best regression model.

The default is "hier.part" in which the contribution of all independent variables to the regression model is calculated by the hierarchical partitioning method (Chevan & Sutherland, 1991) and subsequently between the variables that are above VIF threshold, eliminating those that contribute less to the regression model. Therefore, among the auto-correlated variables, those that best explain the observed variability in the dependent variable are selected. The problem is that one can only use this method if the number of dependent variables, including those log-transformed and untransformed, is not greater than 12. If the number is greater, then the "vifstep" method is automatically applied.

The default option of the argument \emph{outliers=TRUE},
means that outliers are eliminated as explained in function \link{XI1}.

If the argument \emph{stepwise=TRUE} is selected, it means that a regression is performed by steps using Akaike Information Criterion (\emph{AIC}) to define which are the variables that are excluded from the regression model, since they do not contribute to explain the dependent variable. The criterion of Akaike (\emph{AIC}) is used to decide how many explanatory variables are chosen, and what they should be. The method of Akaike values the goodness of the model by setting a penalty because of their complexity, so a simpler model is preferable to another with more independent variables that only explains a small additional portion of the variability of the dependent variable. In general \eqn{AIC=2k-2ln(L)}, where \emph{k} is the number of explanatory variables or parameters of the model and \emph{L} the likelihood or probability associated with the sample used in accordance with model, so that \emph{AIC} is smaller than the lower the number of variables and the greater the likelihood; between alternative models the one with the lowest value of \emph{AIC} must be chosen. At each step the variable that, when it is incorporated into the model, makes smaller the value \emph{AIC} is chosen, until any unused variables allows to reduce it.

If the argument \emph{indlog = TRUE}, the logarithm of all independent variables were calculated using the following equation \eqn{LnVariable = ln (variable-(min (variable) -1))}, and all these variables are added to the non-transformed ones. The aim is to perform a regression model in which the transformed and non-transformed variables are included, to find the best model, because sometimes the transformed variable shows a better relationship with the dependent variable that the not transformed logarithmically.

\strong{FUNCTIONS}

The hierarchical partitioning is performed with the function \link[hier.part]{hier.part} of the hier.part package (Walsh & Mac Nally, 2014)). The \link[nortest]{lillie.test} function of the nortest package (Gross, 2013) is used to perform the Normality test of Kolmogorov-Smirnov with Lilliefors' correction, the function \link[lmtest]{dwtest} of the lmtest package (Hothorn et al., 2013) to analyze the autocorrelation with the test of Durbin-Watson statistic, the function \link[lmtest]{bptest} of  package lmtest (Hothorn et al. , 2013) to perform the Breusch-Pagan test of homoscedasticity, functions \link[usdm]{vif}, \link[usdm]{vifcor} and \link[usdm]{vifstep} of the package usdm (Naimi, 2013; Naimi et al., 2014) for the analysis of the VIF, the function \link[relaimpo]{calc.relimp} for the graph of the contribution of the independent variables (Grmping, 2006; 2013) and the functions \link[SciViews]{panels} and \link[SciViews]{panels.diag} for the matrix chart (Grosjean, 2013).

\strong{EXAMPLE}

The data correspond to a study in areas of upwelling where information on the concentration of chlorophyll (\eqn{mg^{-3 }}) was obtained, percentage of continental shelf in the cell, transport of Ekman (\eqn{m^3 km^{-1}s^{-1}}), which is a measure of upwelling, temperature, turbulence (\eqn{m^3 s^{-1}}), stability of the water column (\eqn{cycles s^{-1}}) and concentrations of phosphate, nitrate and silicate in \eqn{\mu M l^{-1}}. The objective is to determine which are the variables that best explain the observed variations in the concentration of chlorophyll.

\strong{Step 1.}

First working with non-transformed dependent variable, and therefore leaving the option that comes by default in the argument \emph{deplog=FALSE}. However, the argument \emph{outliers=TRUE} to remove atypical data, \emph{stepwise=TRUE} to perform regression by steps and delete non-significant variables model, \emph{indlog=TRUE} to apply the logarithm of the independent variables and add them to the other variables to estimate the model, and leave the default option \emph{method="hier.part"} to remove the correlated independent variables using the hierarchical partitioning methods.

The first table shows high values of VIF, which means that there is multicollinearity between the independent variables, which is logical since they are the same transformed and non-transformed variable, for example <<LNTemperature>> and <<Temperature>>.

The second table shows the contribution of each of the variables to the regression model estimated by the hierarchical partitioning method. As in the script, the default option \emph{method="hier.part"} is used, the auto-correlated variables (variables with VIF values greater than the threshold) are removed following the criteria to eliminate those with less contribution to the model between the auto-correlated. The third table shows the variables that have been selected, once eliminated the auto-correlated of minor contribution.
\tabular{c}{
\figure{RXI9}{options: width=2.1in}
}
\tabular{c}{
\figure{RXI10}{options: width=3.3in}
}
Figure XI5.1 shows the contribution of each of the selected variables, estimated by the hierarchical partitioning method. The percentage of continental shelf in the cell was the variable that most contributes to explain the observed variability in the concentration of chlorophyll and secondly the intensity of upwelling.
\tabular{c}{
\strong{Figure XI5.1.} Relative contribution of independent variables\cr
in the regression model.\cr
\figure{FXI23}{options: width=5in}
}
The variables selected and shown in Figure XI5.1, not all were significant and in the stepwise regression model only the percentage of continental shelf that exists in the cell, the intensity of upwelling and temperature were selected. These three variables explained 60.7\% of the observed variance in chlorophyll concentration (\eqn{r^2= 0.61}).
\tabular{c}{
\figure{RXI13}{options: width=4.5in}
}
The three selected variables have VIF values smaller than 10 and, therefore, there is no problem with the collinearity.   
\tabular{c}{
\figure{RXI11}{options: width=5.3in}
}
It is also noted, that the assumptions of normality (p = 0.134) are fulfilled, there is no autocorrelation (p = 0.115) and there are homoscedasticity in residuals (p = 0.549). In case of non compliance with some of these assumptions see section \emph{details} of the function \link{XI1}, for more information.
\tabular{c}{
\figure{RXI12}{options: width=5.3in}
}
Figure XI5.2 shows the relationship that exists between all the selected variables, including the chlorophyll and the independent variables. 
\tabular{c}{
\cr
\strong{Figure XI5.2.} Matrix graph that shows the relationship between\cr
theindependent variables and chlorophyll concentration.\cr
\figure{FXI22}{options: width=3.9in}
}
\strong{Step 2.}

We then repeat the process but changing the dependent variable and, to this end, we modify the argument \emph{deplog=TRUE}. The regression model obtained shows that the same variables are chosen as they were previously selected: the percentage of shelf and upwelling are positively related and temperature negatively with the chlorophyll concentration. 
\tabular{c}{
\figure{RXI16}
}
The selected variables explain a 66\% of the variability observed in the concentration of chlorophyll (\eqn{r^2= 0.66}). Therefore, this model is better than the last, in which chlorophyll variable was not transformed. It is possible that explanatory variables are included in the model with p > 0.05.  With the Akaike criterion used, this means that the greater complexity of the model by adding this variable is compensated by the increase in likelihood (the observed sample is most likely or credible with the new model). However, it should be noted, that other methods of selection step by step discarded all the non-significant variables, so that the researcher's decision to exclude a variable with p > 0.05 could also be considered reasonable.

It is also noted, that the normality assumptions are fulfilled (p = 0.894), there is a certain autocorrelation (p = 0.007, see section \emph{details} function \link{XI1} for details) and there are homoscedasticity in residuals (p = 0.995).
\tabular{c}{
\figure{RXI15}
}
The regression model is defined by the following formula:\deqn{ln(Chlorophyll-(min(Chlorohyll)-1))=1.2+0.007*Percentage.shelf+}
\deqn{0.0004*Upwelling-0.069*Temperature}
}
\references{
Chevan, A. & Sutherland, M. (1991) Hierarchical Partitioning. \emph{The American Statistician} 45, 90-96.

Durbin, J. & Watson G.S. (1951) Testing for serial correlation in least squares regression. \emph{Biometrika}, 38: 159-171.

Grmping, U. (2006) Relative importance for linear regression in R: The package relaimpo. \emph{Journal of Statistical Software}, 17: 1-27.

Grmping, U. (2013)Relative importance of regressors in linear models. R package version 2.2-2. Available at: \url{http://CRAN.R-project.org/package=relaimpo}.

Grosjean, P. (2013) SciViews GUI API - Main package. R package version 0.9-5. Available at: \url{http://CRAN.R-project.org/package=SciViews}.

Gross, J. (2013) Tests for Normality. R package version 1.0-2. Available at: \url{http://CRAN.R-project.org/package=nortest}.

Hothorn, T. et al., (2013) Testing Linear Regression Models R package version 0.9-33. Available at: \url{http://CRAN.R-project.org/package=lmtest}.

Naimi, B. (2013) Uncertainty analysis for species distribution models. R package version 3.5-0. Available at: \url{http://CRAN.R-project.org/package=usdm}.

Naimi, B., Hamm, N.A.S., Groen, T.A., Skidmore, A.K., & Toxopeus, A.G. (2014) Where is positional uncertainty a problem for species distribution modelling? \emph{Ecography}, 37: 191-203.

Walsh, C. & Mac Nally, R. (2014) Hierarchical Partitioning. R package version 1.0-4. Available at: \url{http://CRAN.R-project.org/package=hier.part}.
}
\examples{
\dontrun{
data(ZXI6)

#Step 1

XI5(data=ZXI6, varY="Chlorophyll", varX = c("Percentage.shelf",
"Upwelling", "Temperature", "Turbulence", "Stability", "Silicate"),
outliers=TRUE, stepwise=TRUE, indlog=TRUE, main="Areas of upwelling")

#Step 2

XI5(data=ZXI6, varY="Chlorophyll",varX = c("Percentage.shelf",
"Upwelling",
"Temperature", "Turbulence", "Stability", "Silicate"), outliers=TRUE,
stepwise=TRUE, deplog=TRUE, indlog=TRUE, main="Areas of upwelling")
}
}
\keyword{XI5}
