\name{XI6}
\alias{XI6}
\encoding{latin1}
\title{BINOMIAL LOGISTIC REGRESSION-ESTIMATION}
\description{Apply various statistical techniques to obtain the type of function that best fits the possible relationship between a qualitative dependent variable with two categories and several independent qualitative or quantitative.}
\usage{
XI6(data, cat, var, resp, stepwise=TRUE, cart=TRUE, minsplit=2, minbucket=2,
cp=0.0001, surrogatestyle=0, type=0, extra=2, varlen=0, ycompress= TRUE,
main=NULL, cex.main=2, cex=1.2, model="Model.rda", file1="Coefficients.csv",
file2="Predictions.csv",  na="NA", dec=",", row.names=FALSE, file="Output.txt")
}
\arguments{
  \item{data}{Data file.}
  \item{cat}{Dependent variable.}
  \item{var}{Independent variables.}
  \item{resp}{Category that will be the reference for the dependent variable.}
  \item{stepwise}{If TRUE, a logistic regression is applied by steps, in order to eliminate those variables that are not significant. The Akaike information criterion (\emph{AIC}) is used to define what are the variables that are excluded (see section \emph{details} of the function \link{XI5} for more details).}
  \item{cart}{If TRUE, a graph of classification and regression tree (\emph{CART}) is created.}
  \item{minsplit}{CART. It specifies the minimum number of observations that must exist in a node for the partition, that is to say, as smaller is the tree, it will have more nodes.}
  \item{minbucket}{CART. It defines the minimum number of observations in a terminal node and, therefore, like the previous argument, as it is smaller, it goes more deeply into the tree, that is to say, this has more nodes and becomes more complex.}
  \item{cp}{CART. It controls the complexity and saves time in the pruning process. It is (default 0.0001) fraction that should improve the adjustment indicator to continue the construction of the tree. If the improvement is less than \emph{cp} the process stops. The user decides to delve deeper and make the tree very complex (\emph{cp} small), or have a more simple tree (\emph{cp} bigger).}
  \item{surrogatestyle}{CART. It controls the criterion for choosing the best substitute variable for the partition on each node. If it is 0, the variable with the greatest number of items correctly classified is used, and if it is 1, the variable which has the highest percentage of elements correctly classified on the number of valid cases of that variable; the first option penalises the variables that have missing values.}
  \item{type}{CART. Format of the graph: 0 shows the variables that have been selected in each partition and in the end, the predominant categories in the end-nodes, 1 is the same as the previous one but it also shows the predominant category in each partition, 2 is equal to 1 but it puts the node above and below the variable responsible for the partition, 3 the variable responsible for the partition is placed in both branches and, finally, 4 is the same as 3 but the nodes are labelled, not the branches.}
  \item{extra}{CART. It allows to show additional information on nodes: 0 only shows the majority group on the node, 1 shows the number of cases of all categories, 2 shows the number of correct cases against the total, 3 shows the number of incorrect cases against the total, 4 shows the probability of all categories, 5 is the same as 4 but does not display the category that predominates in the node, 6 shows the probability of the second type that is dominant in the node, 7 is the same as 6 but does not display the category that predominates in the node, 8 shows the probability of the type that predominates in the node, and finally, 9 shows the relative probability considering observations. }
  \item{varlen}{CART. It defines the number of characters of the texts: 0 uses the full text, >0 abbreviates them taking into account the number that is indicated, and <0 cuts the text of the variables taking into account, as much as possible, the indicated number to adjust the size.}
  \item{ycompress}{CART. If it is TRUE, when the nodes are overlapping they move vertically to avoid this overlap.}
  \item{main}{CART. Graph title.}
  \item{cex.main}{CART. Font size title.}
  \item{cex}{CART. Font size of the labels of the nodes.}
  \item{model}{Filename with model.}
  \item{file1}{CSV FILES. Filename with regression coefficients.}
  \item{file2}{CSV FILES. Filename with the predictions of the logistic model.}
  \item{na}{CSV FILES. Text used in the cells without data.}
  \item{dec}{CSV FILES. It defines whether the comma "," or the dot "." are used as decimal separators.}
  \item{row.names}{CSV FILES. Logical value which defines whether there are identifiers on the rows or a vector with a text for each of the rows.}
  \item{file}{TXT FILE. Name of the output file with the results of the logistic regression.}
}
\value{A TXT file with the coefficients of the logistic regression and the percentage of cases correctly identified is obtained. Two CSV files are obtained: (1) the predictions of the logistic model and 2) the regression coefficients. Finally, the classification and regression tree is shown, if it has been selected.}  
\details{
\strong{XI. REGRESSIONS}

\strong{XI.2. REGRESSION MODELS FOR QUALITATIVE DEPENDENT VARIABLES}

\strong{XI.2.1. Logistic regression}

In the event that the dependent variable is qualitative, a suitable model is the logistic regression. It is used widely in clinical research since it allows to estimate the probability of occurrence of a process based on certain variables, allowing to evaluate the influence of the independent variables on the dependent variable, resulting in probability. The dependent variable is always qualitative but the independent variables can be continuous, discrete, categorical, dichotomous or a mixture of them all. As was the case with the regression for quantitative dependent variables there must be multicollinearity between the different independent variables and the sample observations should be independent of each other.

However, it is not required that the residuals presents a Normal distribution or the assumption of homoscedasticity (constant variance in the residuals).

The dependent variable may be dichotomous (0 if the fact does not occur and 1 if it happens) or polynomial (there are several categories), giving rise to two different types of logistic regression, the binomial or multinomial, respectively.


\emph{XI.2.1.1. Binomial logistic regression}

XI.2.1.1.1. Estimation of the model 

The dependent variable is:
\deqn{Y_i=log\left(\frac{\Pi_i}{1-\Pi_i}\right)}
where \eqn{\Pi_i} is the probability that in the case \emph{i} the studied event occurs and \eqn{Y_i=\alpha+\beta X_i} is the value of the dependent variable in the case \emph{i}.

Expressed as regression:
\deqn{\Pi_i=\frac{1}{1+e^{-(\alpha+\beta X_i)}}}
where \eqn{\alpha} and \eqn{\beta} are the coefficients of the equation.

In case of several predictor variables (independent) regression becomes:
\deqn{\Pi_i=\frac{1}{1+e^{\left[-(\alpha+\displaystyle\sum_{j=1}^{k}\beta_jX_{ji})\right]}}}
where \eqn{\Pi_i} is the probability that the studied event occurs in the case \emph{i}, \emph{k} is the number of predictors, \eqn{\alpha} is a coefficient, \eqn{\beta_j} is the coefficient of the predictor variable \emph{j} and \eqn{X_{ji}} is the value of the predictor variable \emph{j} in the case \emph{i}.

In the case of \eqn{\Pi_i} is greater than 0.5, it is assumed (for the purposes of prediction) that the event occurs and if this is less than 0.5, that it does not occur.

As a complement to the logistic regression, with this function the trees of classification and regression (CARTs) are used. This is a non-parametric procedure of predicting a dependent variable based on a set of independent variables (Breiman's algorithm et al., 1984). Its non-parametric character makes no assumptions regarding the distribution of the dependent and independent variables is required, nor to the relationship between them and their possible interactions.

The dependent variable can be categorical (Classification Trees), different species such as, rejection treatment, presence/absence of cancer, etc. The dependent variable may also be continuous (Regression Trees), as for example the body mass index, blood sugar, etc. In both cases, Classification and Regression Trees (CARTs),the aim is to identify the variables that best identify the dependent variable. In this function the CARTs are used to determine the variables that best discriminate the two categories of the dependent variable. They are, therefore, an excellent tool to choose the best model to help define which are the independent variables with the greatest power of discrimination. For more details see the operating manual of the function \link[rpart]{rpart} and/or Guisande et al. (2012).

\strong{FUNTIONS}

To estimate binomial logistic regression the \link[stats]{glm} function of the package stats is used. To estimate the model by steps, the \link[MASS]{stepAIC} function of the package MASS (Venables & Ripley, 2002; Ripley et al., 2014) was used. To estimate the CART, the \link[rpart]{rpart} function (Therneau et al., 2014) and for its representation, the \link[rpart.plot]{rpart.plot} function (Milborrow, 2014).

\strong{EXAMPLE}

The study was to examine patients who have been diagnosed with a type of cancer, as well as a sample of people who do not. The objective is to determine if variables such as gender, age, marital status (unmarried, married and separated) and presence/absence of blood in the urine, can be an indicator of the presence of cancer. 

The options were left by default and, therefore, the regression is performed by steps. A \emph{minbucket= 10} was selected to do a more simplified CART, since it is only interesting to get information about what are the variables that best discriminate between the different families. 

The results show the regression coefficients, which are also obtained in a CSV file. The model correctly predicts the 74.1\% of the people who do not have cancer. However, what is important is that it is able to correctly predict the 95.1\% of the people who have cancer. Therefore, it is a relatively good model to be able to predict when a person could potentially have such cancer. 
\tabular{c}{
\figure{RXI17}{options: width=4.4in}
}
The CART shows that the presence of blood in urine is the most important variable (Figure XI8.1).  As the coefficient for the category is positive (3.64) and this coefficient refers to the category of blood in urine (presence), this indicates that people with cancer often have blood in the urine. The second variable in importance is the age. The positive coefficient (0.067) indicates that the occurrence of cancer is more frequent at higher age. 
Finally, the marital status of the person is incorporated in the CART (Figure XI8.1). In the event that the categorical variables are not dichotomous (only marital status), it creates a coefficient \emph{B} for each different category of reference (which has a value of 0). The negative value of the coefficient \emph{B} indicates that among single people (-0.927) the presence of cancer is less common. The fact that they were a man or a woman, does not influence significantly in the presence of cancer (p = 0.11), and although it is included in the model, possibly their exclusion would not mean changes in the predictive capacity of the model.
\tabular{c}{
\strong{Figure XI8.1.} Classification and Regression Tree that shows the importance of the\cr
variables analyzed in the study to predict the presence of cancer.\cr
\figure{FXI26}{options: width=3.8in}
}
The model would be defined by the following equation: 
\deqn{Pi_{Cancer.Yes}=\frac{1}{1+e^{-(-4.5+0.067*Age+0.333*Gender.Male+1.151*Separated-0.928*Unmarried+3.643*Blood.Presence)}}}
For example, suppose the first case of the data table, the probability that a married man, 59, and the presence of blood in the urine, has this type of cancer would be of 0.96 and, therefore, as it is greater than 0.5, predicted that the person might have cancer: \deqn{Pi_{Cancer.Yes}=\frac{1}{1+e^{-(-4.5+0.067*59+0.333*1+1.151*0-0.928*0+3.643*1)}}=0.96}
The probability that a single man of 23 years, and without blood in the urine, has this kind of cancer it would be 0.027 and, therefore, as it is less than 0.5, it is predicted that the individual did not have cancer: \deqn{Pi_{Cancer.Yes}=\frac{1}{1+e^{-(-4.5+0.067*23+0.333*1+1.151*0-0.928*1+3.643*0)}}=0.027}
}
\references{
Breiman, L., Friedman, J., Olshen, R. & Stone, C. (1984) \emph{Classification and Regression Trees}. Wadsworth.

Guisande, C., Vaamonde, A. & Barreiro, A. (2011) \emph{Tratamiento de datos con R, STATISTICA y SPSS}. Ediciones Daz de Santos, Madrid, 978 pp.

Guisande, C. & Vaamonde, A. (2012) \emph{Grficos estadsticos y mapas con R}. Ediciones Daz de Santos, Madrid, 367 pp.

Milborrow, S. (2014) Plot rpart models. An enhanced version of plot.rpart. R package version 1.4-4. Available at: \url{http://CRAN.R-project.org/package=rpart.plot}.

Ripley, B., Venables, B., Bates, D.M., Hornik, K., Gebhardt, A. & Firth, D. (2014) Support Functions and Datasets for Venables and Ripley's MASS. R package version 7.3-33. Available at: \url{http://CRAN.R-project.org/package=MASS}.

Therneau, T., Atkinson, B. & Ripley B (2014) Recursive Partitioning and Regression Trees. R package version 4.1-8. Available at: \url{http://CRAN.R-project.org/package=rpart}.

Venables, W.N. & Ripley, B.D. 2002. \emph{Modern Applied Statistics with S}. Springer, fourth edition, New York. \url{http://www.stats.ox.ac.uk/pub/MASS4}.
}
\examples{
\dontrun{

data(ZXI7)

XI6(data=ZXI7, cat="Cancer", var=c("Age","Gender", "Status","Blood"),
resp="Yes", minbucket=10)

}
}
\keyword{XI6}
