\name{XI8}
\alias{XI8}
\encoding{latin1}
\title{MULTINOMIAL LOGISTIC REGRESSION-ESTIMATION}
\description{Different statistical techniques are applied to obtain the type of function that best fits the possible relationship between a qualitative dependent variable with multiple categories and several qualitative or quantitative independent variables.}
\usage{
XI8(data, cat, var, optimize=TRUE, methop="cart", stepwise=FALSE, order=TRUE,
cart=TRUE, minsplit=2, minbucket=2, cp=0.0001, surrogatestyle=0, type=0,
extra=2, varlen=0, ycompress= TRUE, main=NULL, cex.main=2, cex=1.2,
file1="Predictions.csv", file2="Coefficients.csv", file3="Table.csv",
na="NA", dec=",", row.names=FALSE, model= "Model.rda", file="Output.txt")
}
\arguments{
  \item{data}{Data file.}
  \item{cat}{Dependent variable.}
  \item{var}{Independent variables.}
  \item{optimize}{If TRUE, two different algorithms can be used, which are defined in the argument \emph{methop}, whose goal is to look for a model that correctly identifies the 
100\% of the cases. If it is TRUE, the first variable argument of the \emph{var} should be quantitative. If it is TRUE, the model saved, which can then be used for prediction in the function \link{XI9}, is the optimized and not the logistical nor by steps, although both are calculated.}
  \item{methop}{It defines the algorithm that is used to optimize the model. If "cart", this is calculated with the variables that contribute to differentiating the categories using the trees of regression and classification (CARTs), which is explained in the function \link{XIV1}, and then those variables are introduced into the regression model in order of importance. If it is "stepwise", a stepwise logistic regression is applied to eliminate those variables that are not significant, using the information criteria of Akaike (\emph{AIC}) to define which are the variables that are excluded (see section \emph{details} of function \link{XI5} for more details). After the stepwise regression, more variables are added to the model if they help increase the percentage of cases correctly identified. Therefore, it is estimated a model with all variables, the stepwise logistic regression model and the optimized model, which is the latest model that is saved.}
  \item{stepwise}{If it is TRUE, a logistic regression is applied by steps, in addition to the model without steps, in order to eliminate those variables that are not significant using the AIC criterion mentioned above in the argument \emph{methop}. The difference with the optimize method \emph{optimize=TRUE} is that subsequently more variables are not added to the model using the approach to increase the percentage of cases correctly identified. This argument is placed automatically in TRUE if the argument \emph{optimize=TRUE} and the \emph{methop= "stepwise"}.}
  \item{order}{If it is TRUE, the regression coefficients are ordered in the file \emph{Coefficients.CSV} from A to Z for characters and from lesser to greater for numbers.}
  \item{cart}{If TRUE, a graph of classification and regression tree (\emph{CART}) is created.}
  \item{minsplit}{CART. It specifies the minimum number of observations that must exist in a node for which the partition is made, that is to say, as smaller the tree will have more nodes.}
  \item{minbucket}{CART. It defines the minimum number of observations in a terminal node and, therefore, like the previous argument, as it is smaller, it goes more deeply into the tree, i.e. has more nodes and is more complex.}
\item{cp}{CART. Controls the complexity and allows you to save time in the process of pruning. It it is the fraction (by default 0.0001) in which this should improve the adjustment indicator to continue the construction of the tree. If the improvement is less than \emph{cp} the process stops. The user decides whether to delve deeper and make the tree very complex (\emph{cp} small), or have a more simple tree (\emph{cp} bigger).}
\item{surrogatestyle}{CART. It controls the criterion for choosing the best surrogate variable for the partition on each node. If it is 0, the variable with the largest number of items correctly classified is used, and if it is 1, the one that has the highest percentage of elements correctly classified on the number of valid cases of that variable; the first option penalises the variables that have missing values.}
\item{type}{CART. Format of the chart: 0 shows the variables that have been selected in each partition and in the end, the predominant categories in the end-nodes, 1 is the same as the previous one but it also shows the predominant category in each partition, 2 equal to 1 but it puts the node above and below the variable responsible for the partition, 3 the variable responsible for the partition is placed in both branches and, 4 is the same as 3 but the nodes are labelled, not the branches.}
  \item{extra}{CART. It allows to display additional information in the nodes: 0 shows only the majority group in the node, 1 shows the number of cases of all categories, 2 shows the number of correct cases compared to the total, 3 shows the number of incorrect cases compared with the total, 4 shows the probability of all the categories, 5 is equal to 4 but it does not display the category that predominates in the node, 6 shows the probability of the second class that is dominant in the node, 7 is the same as 6 but it does not display the category which is dominant in the node, 8 shows the probability of the class that predominates in the node, and finally, 9 shows the relative likelihood considering all the observations.}
  \item{varlen}{CART. It defines the number of characters of the texts: 0 uses the full text, >0 uses the abbreviated one taking into account the number that is indicated, and <0 clips the text from the variables taking into account, as much as possible, the indicated number to adjust the size.}
  \item{ycompress}{CART. If TRUE, when the nodes are overlapping these move vertically to avoid this overlap.} 
  \item{main}{CART. Graph title.}
  \item{cex.main}{CART. Font size title.}
  \item{cex}{CART. Font size of the labels of the nodes.}
  \item{file1}{CSV FILE. Filename with predictions for each case of the logistic model, stepwise model and the optimized model, if that was selected to perform the last two.}
  \item{file2}{CSV FILES. Filename with regression coefficients. If \emph{optimize=TRUE} are the coefficients of the model optimized, if \emph{optimize=FALSE} and \emph{stepwise=TRUE} are the coefficients of the model by steps and, finally, if \emph{optimize=FALSE} and \emph{stepwise=FALSE} are the coefficients of the model in which all the variables are included.}
  \item{file3}{CSV FILES. Filename with the percentage of cases identified for each category of the dependent variable.}
  \item{na}{CSV FILES. Text that is used in the cells without data.}
  \item{dec}{CSV FILES. It defines whether the comma "," or dot "." are used as decimal separators.}
  \item{row.names}{CSV FILES. Logical value which defines whether there are identifiers on the rows or a vector with a text for each of the rows.}
  \item{model}{Filename with model.}
  \item{file}{TXT FILE. Output file name with the results.}
}
\value{A TXT file is obtained with the coefficients of the logistic regression that it is not by steps, the percentage of cases correctly identified, and the coefficients of the logistic regression by steps and the percentage of cases correctly identified, in the case that the regression by steps is selected. Five CSV files are obtained: (1) the predictions of the logistic model for each case and the model by steps, in the case of selecting it; (2) the regression coefficients; 3) the regression coefficients by steps, if this is chosen; 4) a table with the percentage of cases identified for each group and 5) a table with the percentage of cases identified for each group using the logistic model by steps, if this was selected. It also generates a file with the logistic model without steps and another for the model by steps, if this was selected, which are used later in the \link{XI9} function to predict to what categories the individuals belong. Finally, it shows the classification and regression tree, if this has been selected.}  
\details{
\strong{XI.2.1. Logistic regression}

\emph{XI.2.1.2. Multinomial Logistic Regression}

XI.2.1.2.1. Estimation Model

The main difference with respect to the binomial logistic regression is that qualitative dependent variable is not dichotomous, but may have more than 2 categories (for details see Guisande et al., 2011). Assuming \emph{k} classes or categories, and \emph{j} independent variables, this model can be summarized in the following functions, which provide the probability of belonging to the first \emph{k} - 1 classes:
\deqn{Z_{in}=\beta_{n0}+\beta_{n1}X_{i1}+\beta_{n2}X_{i2}+...+\beta_{nj}X_{ij}}
\deqn{\Pi_{in}=\frac{e^{Z_{in}}}{1+e^{Z_{i1}}+e^{Z_{i2}}+e^{Z_{i3}}+...+e^{Z_{ik-1}}}}
where \eqn{\Pi_{in}} is the belonging probability of the case \emph{i} to the class \emph{n}; \eqn{Z_{in}} is the value of the dependent variable \emph{Z} corresponding to the \emph{n} class in the case \emph{i}; \eqn{\beta_{nj}} is the coefficient of the independent variable \emph{j} for the  \emph{n} class; \eqn{x_{ij}} is the value of the predictor or independent variable \emph{j} for the case \emph{i}. The probability for the last class \emph{k} is obtained from the difference to 1.

As in the case of binomial logistic regression, classification and regression tree (CART) is an excellent tool to identify which are the variables that have the greatest differences between the categories of the dependent variable (based on Breiman's Algorithm et al., 1984) and, therefore, this makes it easier to choose the variables that going to get a greater number of cases correctly identified with the regression model. Therefore, this is helpful for obtaining the most predictive model of logistic regression. For more details, see the manual of the \link[rpart]{rpart} function and/or Guisande et al. (2012).

\strong{FUNCTIONS}

For the estimation of multinomial logistic regression the  \link[nnet]{multinom} function is used (Ripley, 2014).  To estimate the model by steps the \link[MASS]{stepAIC} function of the MASS package was used (Venables & Ripley 2002; Ripley et al. , 2014).  For the estimation of the CART, the \link[rpart]{rpart} function was used (Therneau et al. , 2014) and for their representation the \link[rpart.plot]{rpart.plot} function was used (Milborrow, 2014).

\strong{EXAMPLE}

The data are body measures of several species of fish (continuous variables), as well as the type of mouth they have (categorical variable).  The objective is to determine, if it is possible to identify, which family an individual belongs in function of biometrics. 

\strong{Step 1.}

First the dependent variable \emph{cat="Family"} and all morphometric as independent variables are selected. Default conditions are not neglected, since the argument \emph{optimize=FALSE} and, therefore, not optimized model is made. Conversely the argument \emph{stepwise=TRUE} and, therefore, the regression is performed by steps. A \emph{minbucket=10} 
was chosen for a more simplified CART, since only matter which are the variables that best discriminate between different families.
\tabular{c}{
\strong{Figure XI8.2.} Classification and Regression Tree of measures of freshwater fishes.\cr
\figure{FXI25}{options: width=4.7in}
}
The CART obtained (Figure XI8.2) shows the most important variables that best discriminate against families and this is even a better method for selecting variables than stepwise regression. The variables that are higher up the tree and are responsible for the first nodes are those which have a greater capacity for discrimination.

In the logistic model without steps, which includes all the variables, a 100\% of cases correctly identified is achieved, while in the model by steps a 97.6\% success is achieved. In the CSV file that is generated to save the estimated coefficients, whose default name is \emph{Coefficients.CSV}, it is noted that the selected variables in the model by steps are M12, M16, M17 and M22. There are no coefficients for the first category, which is calculated by default from the other categories. In the \emph{Predictions.CSV} file, the actual  and predicted categories for each case are shown by the models without and by steps.

\strong{Step 2.}

Then, a model in which it is the default otions is made, i.e., the \emph{optimize=TRUE} argument. On the other hand, the CART \emph{cart=FALSE} is not performed. The results show that the model correctly identifies the 100\% of the cases. 

Once developed the model it is possible to use it to predict which category an individual belongs. The \link{XI9} function allows to calculate the category to which an individual belongs, being able to carry out the calculation for many individuals at once, using the regression model without steps, by steps or optimized, which are estimated with this function.
}
\references{
Breiman, L., Friedman, J., Olshen, R. & Stone, C. (1984) \emph{Classification and Regression Trees}. Wadsworth.

Guisande, C., Vaamonde, A. & Barreiro, A. (2011) \emph{Tratamiento de datos con R, STATISTICA y SPSS}. Ediciones Daz de Santos, Madrid, 978 pp.

Guisande, C. & Vaamonde, A. (2012) \emph{Grficos estadsticos y mapas con R}. Ediciones Daz de Santos, Madrid, 367 pp.

Milborrow, S. (2014) Plot rpart models. An enhanced version of plot.rpart. R package version 1.4-4. Available at: \url{http://CRAN.R-project.org/package=rpart.plot}.

Ripley, B., Venables, B., Bates, D.M., Hornik, K., Gebhardt, A. & Firth, D. (2014) Support Functions and Datasets for Venables and Ripley's MASS. R package version 7.3-33. Available at: \url{http://CRAN.R-project.org/package=MASS}.

Ripley, B. (2014) Software for feed-forward neural networks with a single hidden layer, and for multinomial log-linear models. R package version 7.3-8. Available at: \url{http://CRAN.R-project.org/package=nnet}.

Therneau, T., Atkinson, B. & Ripley B (2014) Recursive Partitioning and Regression Trees. R package version 4.1-8. Available at: \url{http://CRAN.R-project.org/package=rpart}.

Venables, W.N. & Ripley, B.D. 2002. \emph{Modern Applied Statistics with S}. Springer, fourth edition, New York. \url{http://www.stats.ox.ac.uk/pub/MASS4}.
}
\examples{
\dontrun{

data(ZXI9)

#Step 1

windows(26,14)

XI8(data = ZXI9, cat="Family", var=c("M2","M6","M8","M9", "M12","M13",
"M15","M16","M17","M21","M22","Mouth"), optimize=FALSE, stepwise=TRUE,
minbucket=10, main="Fish morphology", cex=1)

#Step 2

XI8(data=ZXI9, cat="Family", var=c("M2","M6","M8","M9", "M12","M13",
"M15","M16","M17","M21","M22","Mouth"), cart=FALSE)

}
}
\keyword{XI8}
