\name{XII1}
\alias{XII1}
\encoding{latin1}
\title{META-ANALYSIS/FOREST PLOT}
\description{A meta-analysis is applied and shown in a forest plot.}
\usage{
XII1(data, event.e, n.e, event.c, n.c, studlab, META=NULL,
FOREST=NULL, file="Output.txt")
}
\arguments{
\item{data}{Data file.}
\item{event.e}{Variable with the number of events in the experimental group.}
\item{n.e}{Variable with the total number of observations in the experimental group.}
\item{event.c}{Variable with the number of events in the control group.}
\item{n.c}{Variable with the total number of observations in the control group.}
\item{studlab}{Variable with the code of the scientific studies.}
\item{META}{It accesses the \link[meta]{metabin} function which allows to modify the arguments of the meta-analysis.}
\item{FOREST}{It accesses the function \link[meta]{forest.meta} which allows to modify the arguments of the graph of the meta-analysis.}
\item{file}{TXT FILE. Name of the output file with the results.} 
}
\value{A TXT file is obtained with the results of the meta-analysis, in addition to the diagram of forest.}
\details{
\strong{XII. META-ANALYSIS}

\strong{XII.1. FOREST PLOT}

The meta-analysis is a statistical technique that allows to combine several statistical studies in only one. With this, statistical summaries are constructed so that they can take advantage of the increased power provided by the sample size, necessarily larger, resulting from the aggregation of the different samples of all the studies. This analysis is of special interest in medicine, where it is important to determine if a particular medication, a compound, a therapy, etc., can be beneficial or detrimental to health, especially in those cases in which there is a discrepancy between the different studies. As previously mentioned, the advantage of the meta-analysis is that it allows to combine the information from all the work done. The representations that are most frequently used are the forest plot, and the diagram of funnel.

\strong{FUNCTIONS}

The meta-analysis will use the \link[meta]{metabin} function and to the forest plot \link[meta]{forest.meta}, both from the meta package (Schwarzer, 2013).  For more details on how to use the arguments to these functions, which gives access to the arguments \emph{META} and \emph{FOREST}, consult the help of the function and/or Guisande & Vaamonde (2012).

\strong{EXAMPLE}

These data correspond to a study of Silagy & Ketteridge (1997) on the effect that the medical recommendation has to quit smoking. In the data file, the variable \emph{event.e} refers to the number of people who stopped smoking based on the recommendation of the doctor, \emph{n.e} the total number of people in the group to which the doctor recommended stop smoking, and \emph{event.c} and \emph{n.c} are the people who had stopped smoking and the total number of people who were in the control group, to which the doctor, did not recommend quitting tobacco, respectively.

In the function \link[meta]{metabin}, the argument \emph{method} specifies the method of grouping cases: "MH" Mantel-Haenszel , "Inverse" inverse variance, or "Peto" Peto method. Mantel-Haenszel (default option) calculates the aggregate OR 
weighting the data from each study by the total number of items that it contains considering its distribution into classes, and is the most widely used. Peto is an alternative method for the calculation of the odds that does not require correction for cells with zero cases, so it can be used when investigating rare events and the sample size is small.

The first results observed in the output TXT file are shown below: 
\tabular{clll}{
\figure{RXII1}{options: width=3.6in}
}
The value of \emph{OR} (\emph{Odds Ratio}), which measures the effect of the doctor's advice to quit smoking is calculated as follows, for example, in the case of the second study of Russell in 1979: 
\deqn{OR=\frac{34/(1031-34)}{8/(1107-8)}=4.68}

This value indicates that among those patients who received the medical advice, the relationship between those who stopped smoking and those who did not (predominance or advantage) is 4.68 times higher than among those who did not receive medical advice. The medical advice allowed, therefore, multiply by something more than four the success reached in smoking cessation. If the OR is significantly less than one, this indicates that the studied event has a lower predominance in the experimental group than in the control group: for example, if the studied event is the death of the patient, an odds ratio less than one corresponds to a factor of protection, and one or greater than the unit to a risk factor. It is noted that not all studies have an OR as high as that of the second study calculated above; some show values next to the unit (for example the McDowell 1985 and Slama 1990), indicating a null effect of medical advice. The confidence interval of 95\% that is shown in the two columns below helps us to understand better the OR: if the interval contains the value 1 the effect is not significant (i.e., it indicates that the medical advice does not appear to be effective), it occurs in 10 of the 16 studies.

The following results that appear in the TXT file, shown below, are the weight or weighting of each study, depending on the sample sizes used in each one. The fixed effects model assumes that the studies analyzed are all that are going to be considered, and the random effects that the data used are a random sample of studies obtained from a larger set, which adds an additional source of variability. The aggregated results show: OR = 1.76; although some studies do not seem to show a real effect of the medical recommendation, this set as a whole indicates a significant effect (the interval does not contain the value 1 and the p-value of the contrast of invalidity (null hypothesis: OR = 1) is very small, less than 0.0001.

In the test of Cochran-Mantel-Haenszel (see Guisande et al. 2011, for more details on this test), the value of p < 0.001 and, therefore the number of patients who stop smoking, is different in the experimental group (advised by the doctor) in comparison with the control (not advised by the doctor). Medical advice multiplies the predominance of quitting smoking by 1.76  (ratio between those quitting and those who do not).
\tabular{c}{
\figure{RXII2}{options: width=3.6in}
}
The latest results show some measures of heterogeneity. When studies are very heterogeneous, that is to say very different from each other, it is questionable whether they can be aggregated into one.  For this reason different measures of heterogeneity are used. These include Tau square, variability among studies, or the statistical I-squared, which measures the proportion of the total variability that is attributable to heterogeneity between studies, i.e., the variability among studies divided by the total variability = variability among studies + variability between patients. The authors of the statistical I-squared (Higgins et al., 2003) proposed the cut-off values 25 and 75 to interpret that heterogeneity is low (less than 25\%), moderate (25\% - 75\%) or high (more than 75\%). In the example, 27.6\% is moderate-low and, therefore, it is not a problem. Finally, it shows the P-value of the contrast of invalidity. A value, such as p = 0.1451 observed in the example, greater than the usual level of significance 0.05 allows to accept that there is no significant heterogeneity.
\tabular{c}{
\figure{RXII3}{options: width=3.6in}
}
The forest plot (Figure XII.1) shows all the results mentioned above. The estimated value is represented by a square, and the confidence limits are the ends of each horizontal line. It can also be observed as many lines exceed the value 1 to the right, indicating that the proportion of people who quit smoking is greater in the experimental group who received medical advice, than in the control group who was not influenced by the doctor's advice. The size of the square indicates the sample used: the bigger the square more representative is the study and, therefore, more reliable their conclusions.

\emph{W} is the weight or weighting that corresponds to each study on the obtaining of the \emph{OR} average or summary. Its value depends on the aggregation method used, the sample sizes and the number of events in each study. If the studies used in the meta-analysis are all existing studies, the fixed effects model should be used and, if this is a sample of studies chosen at random, the random model should be used.

The \emph{OR} summary calculated with the meta-analysis is represented by a diamond at the bottom, the ends of the diamond the confidence limits. It is observed as the confidence interval is much smaller than any of the individual studies, which is due to the larger size of the aggregate sample, and the fact that it is greater than 1, in particular 1.76 for both the fixed-effects and for the random, meaning that the doctor's advice positively influences at the time of quitting tobacco and, in addition, as shown in the test of Cochran-Mantel-Haenszel, this difference is significant. The graph allows, therefore, to see the results and conclusions of each of the individual studies and the aggregate results achieved with the meta-analysis.
\tabular{clll}{
\strong{Figure XII.1.} Forest plot from a study conducted on\cr
the effect of the doctor's advice to quit smoking.\cr
\figure{FXII1}{options: width=5.5in}
}
}
\references{
Guisande, C., Vaamonde, A. & Barreiro, A. (2011) Tratamiento de datos con R, STATISTICA y SPSS. Ediciones Daz de Santos, Madrid, 978 pp.

Guisande, C. & Vaamonde, A. (2012) Grficos estadsticos y mapas con R. Ediciones Daz de Santos, Madrid, 367 pp.

Higgins JPT, Thompson SG, Deeks JJ y Altman DG (2003) Measuring inconsistency in meta-analyses. \emph{BMJ}: 327-557.

Schwarzer, G. (2013) Fixed and random effects meta-analysis. Functions for tests of bias, forest and funnel plot. R package version 3.5-0. Available at: \url{http://CRAN.R-project.org/package=meta}.

Silagy, C. & Ketteridge, S. (1977) Physician advice for smoking cessation. En: Lancaster T, Silagy C, Fullerton D. Editores. Tobacco Addiction Module of the Cochrane Database of Systematic Reviews 4.
}
\examples{
\dontrun{

data(ZXII1)

#Influence of the medical advice to quit smoking.

XII1(data=ZXII1, event.e="event.e", n.e="n.e", event.c="event.c", n.c="n.c",
studlab="Research")

}
}
\keyword{XII1}
