\name{XII2}
\alias{XII2}
\encoding{latin1}
\title{META-ANALYSIS/CUMULATIVE FOREST PLOT}
\description{A meta-analysis is applied and shown in a  cumulative forest plot.}
\usage{
XII2(data, event.e, n.e, event.c, n.c, studlab, META=NULL,
FOREST=NULL, file="Output.txt")
}
\arguments{
\item{data}{Data file.}
\item{event.e}{Variable with the number of events in the experimental group.}
\item{n.e}{Variable with the total number of observations in the experimental group.}
\item{event.c}{Variable with the number of events in the control group.}
\item{n.c}{Variable with the total number of observations in the control group.}
\item{studlab}{Variable with the code of the scientific studies.}
\item{META}{It accesses the \link[meta]{metabin} function which allows to modify the arguments of the meta-analysis.}
\item{FOREST}{It accesses the function \link[meta]{forest.meta} which allows to modify the arguments of the graph of the meta-analysis.}
\item{file}{TXT FILE. Name of the output file with the results.} 
}
\value{a TXT file is obtained with the results of the meta-analysis, in addition to the diagram of forest.}
\details{
\strong{XII. META-ANALYSIS}

\strong{XII.2. CUMULATIVE FOREST PLOT}

Another way to represent the forest plot (see section of \emph{details} of the function \link{XII1}) is through the cumulative forest plot. The difference with the forest plot is that studies are being added as these began to appear, which allows to see if there is strength in the information and determine if it was a balance in the result.

\strong{FUNCTIONS}

For the meta-analysis the function \link[meta]{metabin} was used, for the cumulative forest plot \link[meta]{metacum} and \link[meta]{forest.meta}, were used all of the meta package (Schwarzer, 2013). For more details on how to use these functions, which provides access from the arguments in META and FOREST, refer to the help section of the function and/or Guisande & Vaamonde (2012).

\strong{EXAMPLE}

The example is the same as shown in the section of \emph{details} of the \link{XII1} function.
\tabular{clll}{
\figure{RXII4}{options: width=2.5in}
}
The first results showing the TXT file have already been explained in the section \emph{details} of the function \link{XII1}. The following table shows the values of I^2, which has already been explained in the section \emph{details} of the function \link{XII1}. The authors of the statistical I-squared (Higgins et al., 2003) proposed a heterogeneity moderate if the values are between the 25\% -75\%.  In our example this is stabilized at the end with a value of 27.7\%, which is moderate-low and, therefore, is not a problem.

The odds and confidence intervals for the different studies are displayed in the cumulative forest plot that is obtained (Figure XII.2). The estimated value is represented by a square, and the confidence limits are the ends of each horizontal line. It is observed as many lines exceed the value 1 to the right, indicating that the proportion of people who quit smoking is greater in the experimental group who was advised by the physician, than in the control group who was not influenced by the recommendations of the doctor. The size of the square indicates the sample used: the bigger the square more representative is the study and, therefore, more reliable their conclusions.

In this representation the studies are added as they were appearing, which allows to see if there is strength in the information and, if there was a balance in the result, when this balance was reached. Although the chronological order is the method most often used when studies are added to the meta-analysis, it is possible to use any other order.

The graph shows how aggregate estimation is stabilized, after an initial period with remarkable fluctuation, so that from 1990, the successive studies do not provide significant changes, and the result of the meta-analysis is virtually the same. 
\tabular{clll}{
\strong{Figure XII.2.} Cumulative forest plot from a study conducted on\cr
the effect of the doctor's advice to quit smoking.\cr
\figure{FXII2}
}
}
\references{
Guisande, C., Vaamonde, A. & Barreiro, A. (2011) \emph{Tratamiento de datos con R, STATISTICA y SPSS}. Ediciones Daz de Santos, Madrid, 978 pp.

Guisande, C. & Vaamonde, A. (2012) \emph{Grficos estadsticos y mapas con R}. Ediciones Daz de Santos, Madrid, 367 pp.

Higgins JPT, Thompson SG, Deeks JJ y Altman DG (2003) Measuring inconsistency in meta-analyses. \emph{BMJ}: 327-557.

Schwarzer, G. (2013) Fixed and random effects meta-analysis. Functions for tests of bias, forest and funnel plot. R package version 3.5-0. Available at: \url{http://CRAN.R-project.org/package=meta}.

Silagy, C. & Ketteridge, S. (1977) Physician advice for smoking cessation. En: Lancaster T, Silagy C, Fullerton D. Editors. Tobacco Addiction Module of the Cochrane Database of Systematic Reviews 4.
}
\examples{
\dontrun{

data(ZXII1)

#Influence of the medical advice to quit smoking.

XII2(data=ZXII1, event.e="event.e", n.e="n.e", event.c="event.c", n.c="n.c",
studlab="Research")

}
}
\keyword{XII2}
