\name{XII3}
\alias{XII3}
\encoding{latin1}
\title{META-ANALYSIS/L'ABBE PLOT}
\description{A meta-analysis is applied and displayed in a graph of L'Abb.}
\usage{
XII3(data, event.e, n.e, event.c, n.c, studlab, META=NULL, LABBE=NULL,
file="Output.txt")
}
\arguments{
\item{data}{Data file.}
\item{event.e}{Variable with the number of events in the experimental group.}
\item{n.e}{Variable with the total number of observations in the experimental group.}
\item{event.c}{Variable with the number of events in the control group.}
\item{n.c}{Variable with the total number of observations in the control group.}
\item{studlab}{Variable with the code of the scientific studies.}
\item{META}{It accesses the \link[meta]{metabin} function which allows to modify the arguments of the meta-analysis.}
\item{LABBE}{It accesses the function \link[meta]{labbe.metabin} which allows to modify the arguments of the L'Abb graph.}
\item{file}{TXT FILE. Name of the output file with the results.} 
}
\value{A TXT file is obtained with the results of the meta-analysis, in addition to the L'Abb graph.}
\details{
\strong{XII. META-ANALYSIS}

\strong{XII.3. L'ABB GRAPH}

In the event that the heterogeneity is present in the studies of a meta-analysis (see section of \emph{details} of the \link{XII1} function), the graph of L'Abb allows to identify which are the studies responsible for this heterogeneity.

The graph of L'Abb helps deepen the analysis of the presence and causes of heterogeneity in meta-analysis. The outcome in the treatment group (\emph{axis y}) compared to results in the control group (\emph{axis x}), with a diagonal line to 
45 that divides the graphic into two parts: on one side are studies in which the experimental group was favorable, and in the other studies in which the control group was favorable.

\strong{FUNCTIONS}

For the meta-analysis the function \link[meta]{metabin} is used for the graph of L'Abb \link[meta]{labbe.metabin}, both from meta package (Schwarzer, 2013). For more details on how to use these functions, which provides access from the arguments META and LABBE, refer to the help of the function and/or Guisande & Vaamonde (2012).

\strong{EXAMPLE}

The example is the same as it was explained in detail in the section of \emph{details} of the function \link{XII1}.

All the results of the TXT file were also explained in the section of \emph{details} of the function \link{XII1}.
\tabular{c}{
\strong{Figure XII.3.} L'Abb plot from a study conducted on\cr
the effect of the doctor's advice to quit smoking.\cr
\figure{FXII3}{options: width=4in}
}
In the graph of L'Abb of the example (Figure XII.3) above the diagonal are studies in which the proportion of patients who stopped smoking thanks to medical advice is greater than in the control group. The points are plotted in varying sizes depending on the sample size and precision of each estimate, so that larger dots are the most representative studies.

If the points are grouped in a narrow zone, next to a straight line, this means that the results are homogeneous, and if they are dispersed, they show heterogeneity. It also represents the line of fit to the point cloud (dotted line), whose slope is related to a joint \emph{OR}. It is easy to identify studies that are farthest from the majority pattern, i.e., the line of fit, which would be responsible for the observed heterogeneity, when it exists.

}
\references{
Guisande, C., Vaamonde, A. & Barreiro, A. (2011) \emph{Tratamiento de datos con R, STATISTICA y SPSS}. Ediciones Daz de Santos, Madrid, 978 pp.

Guisande, C. & Vaamonde, A. (2012) \emph{Grficos estadsticos y mapas con R}. Ediciones Daz de Santos, Madrid, 367 pp.

Higgins JPT, Thompson SG, Deeks JJ y Altman DG (2003) Measuring inconsistency in meta-analyses. \emph{BMJ}: 327-557.

Schwarzer, G. (2013) Fixed and random effects meta-analysis. Functions for tests of bias, forest and funnel plot. R package version 1.1-12. Available at: \url{http://CRAN.R-project.org/package=meta}.

Silagy, C. & Ketteridge, S. (1977) Physician advice for smoking cessation. En: Lancaster T, Silagy C, Fullerton D. Editors. Tobacco Addiction Module of the Cochrane Database of Systematic Reviews 4.
}
\examples{
\dontrun{

data(ZXII1)

#Influence of the medical advice to quit smoking.

XII3(data=ZXII1, event.e="event.e", n.e="n.e", event.c="event.c", n.c="n.c",
studlab="Research")

}
}
\keyword{XII3}
