\name{XII4}
\alias{XII4}
\encoding{latin1}
\title{META-ANALYSIS/FUNNEL PLOT}
\description{A meta-analysis is applied and shown in a funnel plot.}
\usage{
XII4(data, event.e, n.e, event.c, n.c, studlab, META=NULL, FUNNEL=NULL,
LEGEND=NULL, COLOR=c("#FFF68FFF", "#FFA54FFF", "#FF6347FF"),
file="Output.txt")
}
\arguments{
\item{data}{Data file.}
\item{event.e}{Variable with the number of events in the experimental group.}
\item{n.e}{Variable with the total number of observations in the experimental group.}
\item{event.c}{Variable with the number of events in the control group.}
\item{n.c}{Variable with the total number of observations in the control group.}
\item{studlab}{Variable with the code of the studies.}
\item{META}{It accesses the \link[meta]{metabin} function which allows to modify the arguments of the meta-analysis.}
\item{FUNNEL}{It accesses the function \link[meta]{funnel.meta} which allows to modify the arguments of the funnel plot.}
\item{LEGEND}{It allows to modify the graph legend.}
\item{COLOR}{It allows to modify the colors of the graph.}
\item{file}{TXT FILE. Name of the output file with the results.}
}
\value{A TXT file is obtained with the results of the meta-analysis, in addition to the funnel plot}
\details{
\strong{XII. META-ANALYSIS}

\strong{XII.4. FUNNEL PLOT}

Another problem that can have the meta-analysis (see section of \emph{details} of the function \link{XII1}) is the bias in the publication, i.e. the selective publication of the studies on the basis of their results. In other words, that the results that have a specific conclusion be more published and less the studies in which the results give rise to different conclusions.

It has been observed in some studies that if the results are negative, that is to say, that there was no effect, these are typically not published, since it is based on the mistaken idea that a no-effect is not news. It could also be the case that non-publication of the results that were unfavorable to the therapy used with a particular drug. The funnel plot allows to view and assess the bias in the publication on a given topic.

The analysis for the funnel graph comes from the idea that negative studies, which show no effect, are less likely to be published. If there is publication bias, which can occur preferably in small studies in which there is greater likelihood that altering the results by chance, this will tend to publish those that show differences.

In the funnel plot of the differences calculated estimator in the meta-analysis (odds ratio, relative risk, etc.) is represented for each study, along with its standard error. In the case there is no bias, points should be grouped around a central estimator, and would show much greater dispersion around this value smaller outside its size, so that the cloud of points is distributed as an inverted funnel shape.

If it had publication bias in the sense described above, the cloud of points become distorted and the funnel would lose its symmetry. The previous graph shows that the distribution has a funnel shape, confirming the absence of bias that also showed asymmetry test.


\strong{FUNCTIONS}

For the meta-analysis the \link[meta]{metabin} function was used and also for the funnel plot \link[meta]{funnel.meta}, both from meta package (Schwarzer, 2013). For more details on how to use these functions, from which gives access in META and FUNNEL arguments, consult the help of the function and/or Guisande & Vaamonde (2012).

\strong{EXAMPLE}

The example is the same as it was explained in detail in the section of \emph{details} of the function \link{XII1}.

All the results of the TXT file were also explained in the section of \emph{details} of the function \link{XII1}.
\tabular{c}{
\strong{Figure XII.4.} Funnel plot of a study on\cr
the effect of the doctor's advice to quit smoking.\cr
\figure{FXII4}
}
The graph (Figure XII.4) shown with dotted lines, the funnel to which the data are adjusted, centered on the \emph{OR} estimated. If the points fit reasonably into the funnel, without significant asymmetries, means that there is no evidence of bias (as in the example).

It is also shown, in different shades of colors, the confidence limits (in this example 90\%, 95\% and 99\%), based on the null hypothesis that there is no effect (\emph{OR} = 1)  i.e. the funnels-centric value of 1. 

The points that are outside of the confidence limits show the studies with significant effects for the corresponding level 
}
\references{
Guisande, C., Vaamonde, A. & Barreiro, A. (2011) \emph{Tratamiento de datos con R, STATISTICA y SPSS}. Ediciones Daz de Santos, Madrid, 978 pp.

Guisande, C. & Vaamonde, A. (2012) \emph{Grficos estadsticos y mapas con R}. Ediciones Daz de Santos, Madrid, 367 pp.

Higgins JPT, Thompson SG, Deeks JJ y Altman DG (2003) Measuring inconsistency in meta-analyses. \emph{BMJ}: 327-557.

Schwarzer, G. (2013) Fixed and random effects meta-analysis. Functions for tests of bias, forest and funnel plot. R package version 3.5-0. Available at: \url{http://CRAN.R-project.org/package=meta}.

Silagy, C. & Ketteridge, S. (1977) Physician advice for smoking cessation. En: Lancaster T, Silagy C, Fullerton D. Editors. Tobacco Addiction Module of the Cochrane Database of Systematic Reviews 4.
}
\examples{
\dontrun{

data(ZXII1)

#Influence of the medical advice to quit smoking.

XII4(data=ZXII1, event.e="event.e", n.e="n.e", event.c="event.c", n.c="n.c",
studlab="Research")

}
}
\keyword{XII4}
