\name{XII5}
\alias{XII5}
\encoding{latin1}
\title{META-ANALYSIS/SENSITIVITY ANALYSIS GRAPH}
\description{A meta-analysis is applied and it is shown in a plot of sensitivity analysis.}
\usage{
XII5(data, event.e, n.e, event.c, n.c, studlab, META=NULL,
FOREST=NULL, file="Output.txt")
}
\arguments{
  \item{data}{Data file.}
  \item{event.e}{Variable with the number of events in the experimental group.}
  \item{n.e}{Variable with the total number of observations in the experimental group.}
  \item{event.c}{Variable with the number of events in the control group.}
  \item{n.c}{Variable with the total number of observations in the control group.}
  \item{studlab}{Variable with the code of the studies.}
  \item{META}{It accesses the \link[meta]{metabin} function which allows to modify the arguments of the meta-analysis.}
  \item{FOREST}{It accesses the function \link[meta]{forest.meta} which allows to modify the arguments of the meta-analysis.}
  \item{file}{TXT FILE. Name of the output file with the results.}
}
\value{A TXT file is obtained with the results of the meta-analysis, in addition to the sensitivity analysis plot.}
\details{
\strong{XII. META-ANALYSIS}

\strong{XII.5. SENSITIVITY ANALYSIS PLOT}

In this diagram a sensitivity analysis is performed to determine the influence of each of the studies in the overall estimate of the effect and, therefore, the ruggedness or stability of the final measurement obtained in the meta-analysis.

It is therefore an important complement to the forest plot explained in the section of \emph{details} of the function \link{XII1}, within a study of meta-analysis. The method consists in the repetition of the meta-analysis as many times as selected studies, so that every time a study is omitted. If the results of the different meta-analysis are similar, i.e., the effect has the same direction, magnitude and statistical significance, it can be concluded that the result of the meta-analysis is sound.

Sensitivity analysis can also be used to see what happens when the studies which have not been published are eliminated, there are doubts about the quality of the study, etc.

\strong{FUNCTIONS}

For the meta-analysis the function \link[meta]{metabin} was used and also for the plot of sensitivity analysis \link[meta]{metainf} and \link[meta]{forest.meta}, all from the meta package (Schwarzer, 2013). For more details on how to use these functions, from which gives access in META and FOREST arguments, consult the help of the function and/or Guisande & Vaamonde (2012).

\strong{EXAMPLE}

The example is the same as it was explained in detail in the section of \emph{details} of the function \link{XII1}.

The results -similar to those explained in the previous functions- show the joint OR with its confidence interval obtained by omitting successively each of the studies, the value \emph{P} of the contrast of the aggregate effect, the variance between studies \emph{tau^2}, and the statistical heterogeneity of \emph{I^2}. In this example, the aggregate OR slightly change, major changes occur with the elimination of the studies Russell (1979) and Slama (1995) and in all cases maintaining the heterogeneity in low values, so that none of the studies has a distorting effect on the overall result.
\tabular{clll}{
\figure{RXII5}{options: width=4in}
}
\tabular{c}{
\strong{Figure XII.5.} Plot of sensitivity analysis of a study conducted on\cr
the effect of the doctor's advice to stop smoking.\cr
\figure{FXII5}{options: width=3.7in}
}
The plot of sensitivity analysis (Figure XII.5) shows that only the work of Russell (1979) has some influence in the analysis, since when it is removed, the overall estimate of the effect changes more than with the other studies.
}
\references{
Guisande, C., Vaamonde, A. & Barreiro, A. (2011) \emph{Tratamiento de datos con R, STATISTICA y SPSS}. Ediciones Daz de Santos, Madrid, 978 pp.

Guisande, C. & Vaamonde, A. (2012) \emph{Grficos estadsticos y mapas con R}. Ediciones Daz de Santos, Madrid, 367 pp.

Higgins JPT, Thompson SG, Deeks JJ y Altman DG (2003) Measuring inconsistency in meta-analyses. \emph{BMJ}: 327-557.

Schwarzer, G. (2013) Fixed and random effects meta-analysis. Functions for tests of bias, forest and funnel plot. R package version 3.5-0. Available at: \url{http://CRAN.R-project.org/package=meta}.

Silagy, C. & Ketteridge, S. (1977) Physician advice for smoking cessation. En: Lancaster T, Silagy C, Fullerton D. Editors. Tobacco Addiction Module of the Cochrane Database of Systematic Reviews 4.
}
\examples{
\dontrun{

data(ZXII1)

#Influence of the medical advice to quit smoking.

XII5(data=ZXII1, event.e="event.e", n.e="n.e", event.c="event.c", n.c="n.c",
studlab="Research")

}
}
\keyword{XII5}
