\name{XIII1}
\alias{XIII1}
\encoding{latin1}
\title{CORRESPONDENCE ANALYSIS}
\description{An Analysis of Correspondence is applied.} 
\usage{
XIII1(data, var, cat=NULL, plot3d=TRUE, ResetPAR=TRUE, PAR=NULL,  xlim=NULL,
ylim=NULL, main=NULL, cex.main=1.7, font.main=2, dim1 = c(1,2), dim2 = c(1,2,3),
map = "symmetric", what = c("all", "all"), mass = c("FALSE", "FALSE"),
contrib = c("none", "none"), col = c("#0000FF", "#FF0000"),
labcol=c("#0000FF", "#FF0000"), pch = c(16, 1, 17, 24), labels = c(2, 2),
arrows = c("FALSE", "FALSE"), LEGEND=NULL, AXIS=NULL, MTEXT= NULL, TEXT=NULL,
file="Output.txt")
}
\arguments{
  \item{data}{Data file.}
  \item{var}{Categorical variables that are included in the analysis.}
  \item{cat}{Column with the labels of the cases.}
  \item{plot3d}{If it is TRUE, the 3D graph is shown with the three axes selected by the user. This chart does not support accents in the categories of the variable \emph{cat}.}
  \item{ResetPAR}{If FALSE, the conditions are not placed by default in the function \link{PAR} and those defined by the user on previous graphics are maintained.}
  \item{PAR}{It accesses the \link{PAR} function which allows to modify many different aspects of the graphic.}
  \item{xlim}{Limits of the axis X.}
  \item{ylim}{Limits of the axis Y.}
  \item{main}{Graph title.}
  \item{cex.main}{Font size of the graph title.}
  \item{font.main}{Type of font for the title.}
  \item{dim1}{Vector with two values indicating the axis that are represented in the two dimensional graph.}
  \item{dim2}{Vector with three values indicating shafts that are represented in the 3D graph.}
  \item{map}{It defines the type of map and this can be any of the following options: "symmetric", "rowprincipal", "colprincipal", "symbiplot", "rowgab",  "Colgab", "rowgreen" or "colgreen".}
  \item{what}{Vector with two characters that may be "all" or "none", which indicates if the codes are displayed in the cases (first character of the vector) and/or columns (second character of the vector).}
  \item{mass}{Vector with two logical values TRUE or FALSE, indicating whether the mass is represented by the area of the symbols, for the cases (first logical value) and/or columns (second logical value).}
  \item{contrib}{Vector of two strings of characters that specify if contributions (relative or absolute) should be represented by different color intensities. The available options are "none" (contributions are not listed in the diagram), "absolute" (the absolute contributions are indicated with color intensities) or "relative" (the relative contributions are indicated with color intensities). If "absolute" or "relative" are set, the zero contributions are shown in white. The greater the contribution of a point, the closest to the color defined in the argument \emph{col}.}
  \item{col}{Vector with colors for the cases (first color) and columns (second color).}
  \item{labcol}{Vector with two colors for the cases and the columns in the 3D graph.}
  \item{pch}{Vector with 4 numbers that indicate the symbols, although they are only used the first (for the cases) and the third (for columns).}
  \item{labels}{Vector with two values indicating whether the graph should include only symbols (0), only labels (1) or both, symbols and labels (2).}
  \item{arrows}{Vector of two logical values that specify if the graph must contain points (FALSE by default) or arrows (TRUE). The first value sets the rows and the second value sets the columns.}
  \item{LEGEND}{It allows to embed a legend.}
  \item{AXIS}{It allows to add axis.}
  \item{MTEXT}{It allows to add text in the margins of the graph.}
  \item{TEXT}{It allows to add text in any area of the inner part of the graph.}
  \item{file}{TXT FILE. Name of the output file with the results.}
}
\value{A TXT file is obtained with the results of the Correspondence Analysis, a graph with scores and the 3D graph if this is selected.}
\details{
\strong{XIII. FACTORIAL MULTIVARIATE ANALYSES}

\strong{XIII.1. ANALYSIS OF CORRESPONDENCE}

It is a technique used to represent the rows and columns of a contingency table of two qualitative variables as points in a space of two dimensions, so that they overlap the rows and columns to get a joint representation. In general it is useful in large contingency tables. For example, if we have twenty species of trees and 15 forests and we have done a sample count, we will have a contingency table with the species in rows and columns in the forests. Each box of the table will give us the relative frequency for each dimensional species and forest. The correspondence analysis allows us to represent the species and forests on the same chart, so that it can be associated species with similar distribution profile, forest related, and identify the characteristic species of each forest. 

\strong{1. Profile of rows and columns}

Each row of the table provides a profile row, defined by their frequencies. 

1.1. Profile of the \emph{i}-nth row is the proportion of each category of the variable \emph{j} in the row \emph{i}:
\deqn{a_{ij}=\frac{no{ij}}{n_i}}
The profile of the column totals, i.e., the marginal frequencies of all the columns, define the average profile of the rows.

1.2. Profile of the column \emph{j} -nth is the proportion of each category of the variable \emph{i} in the column \emph{j}:
\deqn{c_{ij}=\frac{no{ij}}{n_j}}
The profile of the row totals, frequencies of marginal row, is the average profile of the columns.

\strong{2. Mass of each element or profile}

The mass associated with each row element (\eqn{r_i}) or column (\eqn{c_j}) measures the relative importance of that element in the set, and is equal to its marginal frequency divided by the overall total or sample size \emph{n}, i.e., the corresponding element of the average column profile, while the mass profile of each column will be the corresponding element of the row profile.
\tabular{ll}{
\eqn{r_i=\frac{n_i}{n}=f_{i.}} \tab \eqn{c_j=\frac{n_j}{n}=f_{.j}}
}
Representing the row/column profiles, more importance should be given to those with greater mass. 

The best measure of distance between profiles (which are defined by the frequency) is not the usual euclidean distance, but the Chi-square distance, since this distance is an important property of distributional equivalence, whereby if two equal profiles are added, the profile added that replaces both maintains the distance of the previous one with any another profile, and will not change any other distance. As the aggregation of rows and columns is usual in the construction of contingency tables, and often subjective criteria are used to decide the number and the limits of the categories or profiles, this property is of special interest. For this reason some simple transformations on the data are carried out to obtain this Chi-square distance.

Chi square distance between row profiles: 
\deqn{d_{\chi^2}^2(r_i,r_{i'})=\displaystyle\sum_{j=1}^{J}\frac{(r_{ij}-r_{i'j})^2}{c_j}}
Chi square distance between column profiles: 
\deqn{d_{\chi^2}^2(c_j,c_{j'})=\displaystyle\sum_{i=1}^{I}\frac{(c_{ij}-c_{ij'})^2}{r_i}}
To construct the graph Principal Components method is used, with which generally two dimensions are obtained. 

\strong{3. Absolute and relative contributions}

3.1. Absolute contributions: Part of the variability of each axis or dimension (main component) that is explained by each profile. These serve to interpret the axis according to the profiles, observing which are the profiles that have more weight -or absolute contribution- in the construction of each dimension.  

3.2. Part of the variability of each profile explained by each axis or component. They indicate to what extent each profile is adequately explained or represented by the two axes or dimensions. The row or column profiles with small contributions on both axes do not respond to the model, and are poorly represented in the graph, which should be taken into account in its interpretation.

\strong{FUNCTIONS}

Correspondence analysis is done with the \link[ca]{ca} function and the graph with the \link[ca]{plot.ca} function, both from the ca package (Greenacre & Pardo, 2006; Greenacre, 2007; Nenadic & Greenacre, 2007; Greenacre, 2013).

\strong{EXAMPLE}

Data assessment criteria, on a scale of 0 to 10 of 48 candidates who opt for a job. The objective is to determine if, with a Correspondence Analysis, it is possible to identify which are the qualities that allow to better distinguish between the candidates, in order to facilitate the selection process.

\strong{Step 1.}

Figures XIII.1 and XIII.2 show that in the right end of the first axis the variables are experience, the suitability for the job and letter of motivation. In the left end of the first axis motivation and confidence are associated. The second axis is associated with the business sense in the upper end, while at the lower end are honesty and level of studies.

\tabular{c}{
\strong{Figure XIII.1.} 2D Correspondence Analysis showing the variability observed\cr
in the qualities of candidates who opt for a job.\cr
\figure{FXIII1}{options: width=3.4in}
}
\tabular{c}{
\strong{Figure XIII.2.} 3D Correspondence Analysis showing the variability observed\cr
in the qualities of candidates who opt for a job.\cr
\cr
\figure{FXIII2}
}
The eigenvalues show the percentage of variance of the axes: 32.9\% first axis, 25.7\% the second, etc.
\tabular{c}{
\figure{RXIII1}{options: width=4.6in}
}
Inertia indicates the relative weight or importance of each variable. The highest values are those of the experience (0.0271), educational level (0.0168), honesty (0.0155), letter of motivation (0.015), adequacy (0.0149), commercial sense (0.012, \emph{Ability.to.sell}), etc. The results also show the coordinates of the variables on the axes I (Dim. 1) and II (Dim. 2), which allows to locate each variable in the graph shown above in order to dispose the coordinates to perform any other type of representation.
\tabular{c}{
\figure{RXIII3}{options: width=5.2in}
}
The most important instrument in the correspondence analysis is a graph in which the row and column objects related by distances and vicinity which can be interpreted. Among the results the (\emph{ChiDist}) distances are shown to average profile.

The mass associated with each row or column element -similar and alternative to the concept of inertia- measures the importance of that element in the set, and is equal to its marginal relative frequency. Representing the row-column profiles greater importance should be given in interpretation to those with greater mass.

The inertia of the candidates, which will choose the best candidate based on the quality to which priority is also shown, as well as the coordinate at the axes I (Dim. 1) and II (Dim. 2).
\tabular{c}{
\figure{RXIII2}{options: width=4.5in}
}
\strong{Step 2.}

It performs the Correspondence Analysis showing only the candidates (cases), which is shown in Figure XIII.3.
\tabular{c}{
\cr
\strong{Figure XIII.3.} Correspondence Analysis showing the variability observed\cr
in the qualities of candidates who opt for a job.\cr
\figure{FXIII3}{options: width=3.3in}
}
\strong{Step 3.}

It performs the Correspondence Analysis showing only the qualities of the candidates (columns), which is shown in the Figure XIII.4.
\tabular{c}{
\strong{Figure XIII.4.} Correspondence Analysis showing the variability observed\cr
in the qualities.\cr
\figure{FXIII4}{options: width=3.5in}
}
If to select the candidate we rely on the variables that most influenced the first axis in its rightmost (experience and adequacy), candidates who have the most positive coordinates on the first axis are AST and AAR. If on the other hand for the selection we rely on the variables that best discriminated against the second axis, as for example business sense which was located in the upper end of the positive axis, so the selected candidate should be ACC.
If we chose the honesty, the selected candidate should be PPA or AIU.
}
\references{
Nenadic, O. & Greenacre, M. (2007) Correspondence analysis in R, with two- and three-dimensional graphics: The ca package. \emph{Journal of Statistical Software}, 20: 1-13

Greenacre, M. (2013).  Simple, Multiple and Joint Correspondence Analysis. R package version 0.53. Available at: \url{http://CRAN.R-project.org/package=ca}.

Greenacre, M. (2007) \emph{Correspondence Analysis in Practice}. Second Edition. London: Chapman & Hall / CRC.

Greenacre, M.J. & Pardo, R. (2006) Subset correspondence analysis: visualizing relationships among a selected set of response categories from a questionnaire survey. \emph{Sociological Methods and Research}, 35: 193-218.
}
\examples{
\dontrun{
data(ZXIII1)

#Step 1
XIII1(data=ZXIII1, cat="Candidate", var=c("Motivation.letter","Presentation","Studies",
"Sympathy","Self.confidence", "Lucidity","Honesty","Ability.to.sell","Experience",
"Charisma","Ambition","Comprehension.capacity","Potential","Job.motivation",
"Suitableness"), xlim=c(-0.5,1.7))

#Step 2
XIII1(data=ZXIII1, cat="Candidate", var=c("Motivation.letter","Presentation","Studies",
"Sympathy","Self.confidence", "Lucidity","Honesty","Ability.to.sell","Experience",
"Charisma","Ambition", "Comprehension.capacity","Potential","Job.motivation",
"Suitableness"), what = c("all", "none"), mass = c("TRUE","FALSE"), contrib = "relative",
arrows = c("TRUE", "FALSE") , xlim=c(-0.5,1.7))

#Step 3
XIII1(data=ZXIII1, cat="Candidate", var=c("Motivation.letter","Presentation","Studies",
"Sympathy", "Self.confidence", "Lucidity","Honesty","Ability.to.sell", "Experience",
"Charisma","Ambition","Comprehension.capacity","Potential","Job.motivation",
"Suitableness"), xlim=c(-0.2, 1), what = c("none", "all"), mass = c("FALSE","TRUE"),
contrib = "relative",  arrows = c("FALSE", "TRUE"))
}
}
\keyword{XIII1}
