\name{XIII3}
\alias{XIII3}
\encoding{latin1}
\title{MULTIDIMENSIONAL SCALING}
\description{A multidimensional scaling is applied.} 
\usage{
XIII3(data, var, cat=NULL, ellipse=FALSE, convex=FALSE, dim=c(1,2), ResetPAR=TRUE,
PAR=NULL, METAMDS=NULL, SCATTERPLOT=NULL, COLOR=NULL, PCH=NULL, XLIM=NULL,
YLIM=NULL, XLAB=NULL, YLAB=NULL, TEXT=NULL, LEGEND=NULL, AXIS=NULL, MTEXT=NULL,
arrows=TRUE, larrow=0.95, colArrows="black", file1="Var loadings.csv",
file2="Cat loadings.csv", na="NA", dec=",", row.names=TRUE)
}
\arguments{
  \item{data}{Data file.}
  \item{var}{Variables included in the analysis.}
  \item{cat}{Categories of the cases.}
  \item{ellipse}{If it is TRUE, the ellipses with the levels of significance to the 0.5 (inner ellipse) and 0.95 (outer ellipse) of each category of the variable \emph{cat} are depicted. These levels of significance can be modified by entering the function \link[car]{scatterplot} using the argument \emph{SCATTERPLOT} and modifying the argument \emph{levels=c(0.5,0.95)}.}
  \item{convex}{If it is TRUE the convex hull is depicted for each category.}
  \item{dim}{Dimensions that are represented on the graph.}
  \item{ResetPAR}{If it is FALSE, the default condition of the function \link{PAR} are not placed and those defined by the user on previous graphics are maintained.}
  \item{PAR}{It accesses the function \link{PAR} that allows to modify different aspects of the graph.}
  \item{METAMDS}{It accesses the function \link[vegan]{metaMDS} from the vegan package.}
  \item{SCATTERPLOT}{It accesses the function \link[car]{scatterplot} from the car package.}
  \item{COLOR}{It allows to modify the colors of the graph, but must be as many different groups as the variable has \emph{cat}.}
  \item{PCH}{Vector with the graph symbols, which must be as many different groups as the variable has \emph{cat}. If it is NULL, this is automatically calculated starting with the symbol 15.}
  \item{XLIM, YLIM}{Vectors with the limits of the axes \emph{X} and \emph{Y}.}
  \item{XLAB, YLAB}{Legends of the axes \emph{X} and \emph{Y}.}
  \item{TEXT}{It accesses the function which allows to change the labels of cases in the graph \emph{biplot}.}
  \item{LEGEND}{It includes a legend.}
  \item{AXIS}{It adds axes.}
  \item{MTEXT}{It allows to add text in the margins of the graph.}
\item{arrows}{If it is TRUE the arrows are shown in the scatterplot.}
  \item{larrow}{It modifies the length of the arrows.}
  \item{colArrows}{Color of the arrows.}
  \item{file1}{CSV FILE. Name of the output file with the coordinates of the variables in the graph.}
  \item{file2}{CSV FILE. Name of the output file with the coordinates of the rows or cases, adding categories in the graph.}
  \item{na}{CSV FILE. Text used in the cells without data.}
  \item{dec}{CSV FILE. It defines if a comma"," o a dot "." can be used as decimal separator.}
  \item{row.names}{CSV FILES. Logical value that defines if identifiers are put in rows or a vector with a text for each of the rows.}
}
\value{A biplot graph is obtained with the dimensions I and II of the multidimensional scaling.}
\details{
\strong{XIII. FACTORIAL MULTIVARIATE ANALYSIS}

\strong{XIII.3. MULTIDIMENSIONAL SCALING}

It's about finding the underlying structure of a set of measures of proximity/distance between objects. Objects can be of any type: Countries, trademarks, kinship relationships, businesses, descriptors of quality, etc., the measures that allow to set proximity or distances between objects may also be of different types, quantitative or qualitative, real or supposed, objective or subjective. This technique is typically applied to the study of perceptions, of great interest in psychology, marketing, quality control, and other areas.

If we have a map, it is relatively simple to build a table of distances between towns. The multidimensional scaling is trying to solve the inverse problem: from a table of distances, a map is constructed, which allows to place objects and graphically interpret the relationships between them.

Each observation is assigned to a specific position in a space of small size, usually two, in such a way that the distances between the points correspond the best possible way with the distances between objects. The main result of this technique is therefore a graph.

The criterion or extent of most important adjustment used in the multidimensional scaling is the Stress (Kruskal), which is an average of deviations between end distances on the map and the distances or initial dissimilarities, normalized to take values between 0 and 1.
\deqn{S=\frac{\displaystyle\sum{}{}\displaystyle\sum{}{}\left(d_{ij}-\bar{d}_{ij}\right)^2}{\displaystyle\sum{}{}\displaystyle\sum{}{}d_{ij}^2}}
The greater the stress, the worse the fit. It is generally recommended not to use this technique when a value is greater than 0.2. It is often expressed as a percentage: the fit is good when the stress is less than 5\% (0.05). For its interpretation the following indicative scale can be used:
\tabular{ll}{
\strong{Stress} \tab \strong{Adjustment}\cr
0,1-0,2 \tab Poor\cr
0,05-0,1 \tab Regular\cr
0,025-0,05 \tab Good\cr
<0,025 \tab Excellent\cr
0 \tab Perfect
}
The squared multiple correlation coefficient RSQ between gaps and disparities, which can be interpreted as the proportion of variance of the transformed data -or percentage of variability- collected by the obtained representation is also used as a setting. It varies between 0 and 1, and the closer to 1 the better the fit; 0.6 is generally considered a minimum acceptable value. There are numerous variants and algorithms for the realization of the multidimensional scaling.

\strong{FUNCTIONS}

The Multidimensional Scaling was performed with the \link[vegan]{metaMDS} of the vegan package (Oksanen et al., 2013). To make the \emph{biplot}graph, the \link[car]{scatterplot} function of the car package (Fox et al., 2014) was used. The arrows are depicted with the function \link[IDPmisc]{Arrows} of the package IDPmisc (Locher & Ruckstuhl, 2014). The convex hull is estimated with the function \link[grDevices]{chull} of the package grDevices.

\strong{EXAMPLE}

The study consisted of performing different morphometric measures of shark species, belonging to different families of the order Carcharhiniformes. The aim is to determine if  species of the same family have similar morphometrics and, therefore, the Multidimensional Scaling shows that there is a morphometric pattern compared to each of the families.

In the results window the value of the measure of adjustment is shown, with a stress of 0.009 (0.9\%), which according to the classification presented in the introduction is considered good. It is noted that there is a relatively good clustering between families (Figure XIII.8).  Therefore, it is concluded that it is possible to differentiate the different families of sharks in function of its morphometry. The \emph{graph} biplot also allows to see which are the morphometric variables responsible for this differentiation between families. The ellipses show the levels of significance to the 0.5 (inner ellipse) and 0.95 (outer ellipse) of each of the families. It is an indicator of the degree of overlap between the families of sharks. These levels can be modified by entering the function \link[car]{scatterplot} using the argument \emph{SCATTERPLOT} and modifying the argument \emph{levels=c(0.5,0.95)}.
\tabular{c}{
\strong{Figure XIII.8.} Multidimensional scaling using morphometric measures\cr
from different families of sharks.\cr
\figure{FXIII8}{options: width=2.9in}
}
It is important to mention that the argument \emph{cat} is only used for the grah biplot and not in the multidimensional scaling. That is to say, any prior information is giving to perform the analysis of the potential groups that there are in the data, as for example in the logistic regressions, Discriminant Analysis, carts, etc., Therefore, in the case of obtaining a low value of stress and a chart that clearly shows a separation of groups, such as in this example, this would indicate that there is an underlying structure -some clearly differentiated groups- based on the set of measures used.

If access the function \link[vegan]{metaMDS} with \emph{argument METAMDS}, it is possible to change the index of dissimilarity which is used in the Multidimensional Scaling, with the argument \emph{distance}.  Experiment with different types of index of dissimilarity is advisable, as it can get a value of less stress and a graph where the groups are more clearly separated. In case of obtaining this error \emph{some dissimilarities are negative}, this may be due to the fact that there are rows or columns in which all values are zero.
}
\references{
Fox, J., Weisberg, S., Adler, D., Bates, D., Baud-Bovy, G., Ellison, S., Firth, D., Friendly, M., Gorjanc, G., Graves, S., Heiberger, R., Laboissiere, R., Monette, G., Murdoch, D., Nilsson, H., Ogle, D., Ripley, B., Venables, W. & Zeileis, A. (2014) Companion to Applied Regression. R package version 2.0-20. Available at: \url{http://CRAN.R-project.org/package=car}.

Locher, R. & Ruckstuhl, A. (2014) Utilities of Institute of Data Analyses and Process Design. R package version 1.1.17. Available at: \url{http://CRAN.R-project.org/package=IDPmisc}.

Oksanen, J., Blanchet, F.G., Kindt, R., Legendre, P., Minchin, P.R., O'Hara, R.B., Simpson, G.L., Solymos, P., Henry, M., Stevens, H. & Wagner, H. (2013) Community Ecology Package. R package version 2.0-10. Available at: \url{http://CRAN.R-project.org/package=vegan}.
}
\examples{
\dontrun{
data(ZXIII3)
XIII3(data=ZXIII3, var=c("M2", "M3", "M4", "M5", "M6", "M7",
"M10", "M11",
"M12", "M13", "M14", "M15", "M16", "M17", "M19", "M20", "M21",
"M23", "M24",
"M25", "M26", "M27", "M30"), cat="Family", ellipse=TRUE)
}
}
\keyword{XIII3}
