\name{XIII4}
\alias{XIII4}
\encoding{latin1}
\title{CANONICAL CORRELATION}
\description{A canonical correlation is applied.} 
\usage{
XIII4(data, varX,  varY, labels=NULL, labelsvar="varX", log=FALSE, dim=c(1,2),
expand=TRUE, ellipse=FALSE, convex=FALSE, ResetPAR=TRUE, PAR=NULL, CANCOR=NULL,
SCATTERPLOT=NULL, COLOR=NULL, PCH=NULL, XLIM=NULL, YLIM=NULL, XLAB=NULL, YLAB=NULL,
TEXTX=NULL, TEXTY=NULL, LEGEND=NULL, AXIS=NULL, MTEXT= NULL, arrows=TRUE, larrow=0.95,
colAX="black", colAY="blue", file1="Output.txt", file2="xcoef.csv", file3="ycoef.csv",
file4="xscores.csv", file5="yscores.csv", na="NA", dec=",", row.names=TRUE)
}
\arguments{
  \item{data}{Data file.}
  \item{varX}{Independent variables.}
  \item{varY}{Dependent variables.}
  \item{labels}{Variable that allow to tag cases.}
  \item{labelsvar}{The cases are represented using scores of the independent (\emph{X}) or dependent (\emph{Y}) variables.}
  \item{log}{If TRUE, the logarithm is applied to the dependent and independent variables.}
  \item{dim}{Dimensions that are represented on the graph.}
  \item{expand}{If TRUE, the coefficients of the variables \emph{X} and \emph{Y} and scores of the cases of the independent (\emph{X}) or dependent (\emph{Y}) variables are adjusted to the same scale, when plotted on the graph. This allows a better view of the adjustment of the coefficients and scores on the canonical space, i.e., to see which variables and scores coincide in space generated by the canonical variables, which were created as a linear combination of dependent and independent variables.}
  \item{ellipse}{If it is TRUE the ellipses with the levels of significance to the 0.5 (inner ellipse) and 0.95 (outer ellipse) of each category of the variable \emph{labels} are depicted. These levels of significance can be modified by entering the function \link[car]{scatterplot} using the argument \emph{SCATTERPLOT} and modifying the argument \emph{levels=c(0.5,0.95)}.}
  \item{convex}{If it is TRUE the convex hull is depicted for each category.}
  \item{ResetPAR}{If it is FALSE, the default condition of the function \link{PAR} are not placed and those defined by the user on previous graphics are maintained.}
  \item{PAR}{It accesses the function \link{PAR} which allows to modify many different aspects of the graph.}
  \item{CANCOR}{It accesses the function \link[candisc]{cancor} of the candisc package.}
  \item{SCATTERPLOT}{It accesses the function \link[car]{scatterplot} of the car package.}
  \item{COLOR}{It allows to modify the colors of the graph, but they must be as many as different groups the variable \emph{labels} has.}
  \item{PCH}{Vector with the symbols on the chart, which must be as many as different groups the variable \emph{labels} has. If it is NULL, they are automatically calculated starting with the symbol 15.}
  \item{XLIM, YLIM}{Vectors with the limits of the axes \emph{X} and \emph{Y}.}
  \item{XLAB, YLAB}{Legends of the axes \emph{X} and \emph{Y}.}
  \item{TEXTX}{It accesses the function to change the labels of cases in graph \emph{biplot}.}
  \item{TEXTY}{It accesses the function to change the labels of the coefficients of the dependent variables (\emph{Y}) in the graph \emph{biplot}.}
  \item{LEGEND}{It allows to include a legend.}
  \item{AXIS}{It allows to add axes.}
  \item{MTEXT}{It allows to add texts in the margins of the graph.}
  \item{arrows}{If it is TRUE the arrows are shown in the scatterplot.}
  \item{larrow}{It modifies the length of the arrows.}
  \item{colAX, colAY}{Colors of emph{X} and \emph{Y} arrows.}
  \item{file1}{TXT FILE. Name of output file with test results.}
  \item{file2}{CSV FILE. Output file name with the coefficients of the variables \emph{X}, shown in the graph, but without the correction applied in the case of the argument \emph{expand=TRUE}.}
  \item{file3}{CSV FILE. Output file name with the coefficients of the variables \emph{Y}, shown in the graph, but without the correction applied in the case of the argument \emph{expand=TRUE}.}
  \item{file4}{CSV FILE. Name of the output file with the coordinates of the cases considering the variables \emph{X}, shown in the graph, but without the correction applied in the case of the argument \emph{expand=TRUE}.}
  \item{file5}{CSV FILEs. Name of the output file with the coordinates of the cases considering the variables \emph{Y}, shown in the graph, but without the correction applied in the case of the argument \emph{expand=TRUE}.}
  \item{na}{CSV FILES. Text used in the cells without data.}
  \item{dec}{CSV FILES. It defines if a comma"," o a dot "." can be used as decimal separator.}
  \item{row.names}{CSV FILES. Logical value that defines if identifiers are put in rows or a vector with a text for each of the rows.}
}
\value{A graph \emph{biplot} with the Canonical Correlation, a TXT file with the test results and four CSV files are obtained: the coefficients of the variables \emph{X} and \emph{Y} and the coordinates of the cases considering the variables \emph{X} and \emph{Y}.}
\details{
\strong{XIII. FACTORIAL MULTIVARIATE ANALYSIS}

\strong{XIII.4. CANONICAL CORRELATION}

The canonical correlation analysis is a generalization of the regressions. A simple regression correlates an independent variable with another dependent. 

A multiple regression does the same thing with more than one independent variable and a dependent. The canonical correlation maps a group of variables \eqn{x_1,...,x_m} with other group \eqn{y_1,....,y_n}. The method is to find two variables \eqn{A=a_1x_1+...+a_mx_m}, \eqn{B=b_1y_1+...+b_ny_n} among which the correlation is maximum. These variables are called composite canonical variables. The analysis calculates several canonical correlations, each with a pair of canonical variables \emph{A} and \emph{B}. In particular, this will calculate many canonical variables as the number of variables the smallest group has (the \emph{x} or \emph{y}), although only the first has practical interest. Often a few pairs of canonical variables make  possible to analyze the relationship between the two groups, facilitating the study of our data by reducing the dimension.

     This type of multivariate analysis shares aspects with the Principal Component Analysis and factor analysis. But unlike these, seeking internal relationships among the variables of a group, the canonical correlation is looking for a relationship between two sets of variables.

     The general requirements of this type of analysis are the same as for a factorial analysis: 

1. Qualitative variables are excluded.

2. Relationships between variables must be linear.

However, it is important to point out some characteristics that, although they are not prior hypotheses, it is desirable that these be fulfilled particularly in this analysis: 

1. The method works better when the correlation between variables within each group is small, and is large between variables of different group.

2. The variables within a group, although different, must be homogeneous with respect to the type of information, or the topic, to which they relate (remember that in the factorial analysis there is also this requirement, but there are no two groups); otherwise, if the information they contain is not related, the construction of new variables (canonical) as a linear combination of old variables loses meaning.

     In short, this type of analysis will be particularly useful when there are two groups of variables, each of which would provide information about a topic, as measured by different variables. Then, it intends to find a correlation between these two groups, or items of information. This method may be more appropriate to compare the two variables to two, and in addition, the correlation found between the canonical variables calculated is always higher than the existing one in any of these two to two comparisons.

\strong{FUNCTIONS}

The Canonical Correlation was performed with the \link[candisc]{cancor} function of the candisc package (Friendly, 2007; Firendly and Fox, 2013). To perform the \emph{biplot} graph the \link[car]{scatterplot} function of the car package was used (Fox et al., 2014). The arrows are depicted with the function \link[IDPmisc]{Arrows} of the package IDPmisc (Locher & Ruckstuhl, 2014). The convex hull is estimated with the function \link[grDevices]{chull} of the package grDevices.

\strong{EXAMPLE}

This analysis will be used to check if a number of variables, which generally relate to the quality of a soil for the growth of plants, predict the best or worst condition in which the plants that have grown on that soil can be. There is a group of variables that provide information on soil quality. These are as follows: water content (in \% of the weight of the soil), nitrogen, phosphate, and a number of trace minerals (in micro moles per gram of soil). The other group of variables provides an idea of condition of the plants, and these are a series of independent parameters related to the growth and reproduction: leaf coverage (in \eqn{m^2}), the average length of internodes (in cm) and the \% of the total viable seeds produced. In this case there are data from a set of trees of the same age which have grown in different soils. We want to know if both groups of variables are correlated.

It is very important to keep in mind the advisability of including variables that have low variability, i.e., that all values are equal except a few cases. These variables with little variability can have a great weight in the canonical axes and it should be assessed whether its inclusion is necessary. For example, in the case of working with an abundance of species, it may be that those which are not present in the majority of the samples and appear once or twice have an important weight in the canonical axes and it is necessary to assess whether it is proper to include them.

In the script, the group of independent variables with the argument \emph{varX} and dependent with \emph{varY} are selected.
It is s specified by the argument \emph{labels= "Area"} that the scores of cases display differenciating by the sampling areas.

The following table shows the results of the analysis. Three pairs of canonical variables are calculated, because the group of the dependent variables has the fewest number of variables, which are three. The first pair of canonical variables explain the greater portion of the variance (94.72\%), and the remaining pairs explain, successively, as much as possible of the remaining variance. To explain different aspects of the variance, the pairs of canonical variables are never correlated with each other.The first canon R (\emph{Canr 1= 0.94}) is equivalent to R's global analysis. The second R canon (\emph{Canr 2 = 0.48}) is independent of the first, the third R canon (\emph{Canr 3 = 0.33}) is independent of the first and the second, and so on in the event that there are more canonical pairs. It is noted that the low value of R, and in fact, by deleting the first pair of canonical variables calculated, R is no longer significant (p = 0.136 ).  Therefore, the correlation is only meaningful in the first calculated couple of canonical variables, that is to say, for the first canonical shaft (p < 0.001).  Overall it may be said that the quality of the soil is significantly connected with the condition of the plants with the variables used.
\tabular{c}{
\figure{RXIII6}{options: width=3in}
}
In Figure III. 9 the coefficients of the dependent and independent variables are shown, as well as scores of  differentiated cases in function of the sampling area. The higher the absolute value of the coefficient, the greater the contribution of that variable to the canonical variable. In this example is of special interest to see what are the variables that have more weight in the first canonical correlation (\emph{CC1}), because as it was seen, this is the only significant one. It is noted that the independent variables of more weight are the phosphate and nitrogen. In what refers to the dependent variables, it will also be noted, for the first canonical correlation, that the variable of more weight is the percentage of viable seeds, which is greater in soils with more concentration of phosphate and nitrogen.
\tabular{c}{
\strong{Figure XIII.9.} I and II canonical axes of the Canonical Correlation applied to the data\cr
of growth and reproduction of plants and variablesthat measure soil quality.\cr
\figure{FXIII9}{options: width=2.9in}
}
The ellipses show the levels of significance to the 0.5 (inner ellipse) and 0.95 (outer ellipse) of each of the sampling sites. It is an indicator of the degree of overlap between the sampling sites.

These levels can be modified by entering in the scatterplot function using the argument \emph{SCATTERPLOT} and modifying the argument \emph{levels=c(0.5,0.95)}. With some examples it is observed that it is not possible to estimate the ellipses and this error \emph{Error in svd(sqrt(w/sum(w)) * X, nu = 0):} is obtained or this other \emph{Error in cov.trob(cbind(x[use], y[use]), wt = weights[use]): no positive weights}. In case of obtaining these errors or simply not wanting to show the ellipses, again using the argument emph{ellipse=FALSE}. 

The figure shows that the sample areas can be differentiated in terms of the characteristics of the soil and the condition of the plants. Site 1 is where there are higher concentrations of phosphate and nitrogen in the soil and, as a result, a greater percentage of viable seeds. Site 4, on the contrary, it is where the percentage of viable seed is smaller, in principle caused by a soil of a lesser quality, that is to say, the lowest concentrations of phosphate and nitrogen.

It is possible to obtain a greater percentage of explanation in the first axes, and they are even more significant, if those variables that contribute little to the canonical axes are not included in the analysis that is to say, they are in the center of the graph. Therefore, it is advisable to carry out various tests by eliminating variables that have little weight in the analysis and see if this increases the percentage of explanation and/or degree of significance of the canonical axes.
}
\references{
Friendly, M. (2007). HE plots for Multivariate General Linear Models. \emph{Journal of Computational and Graphical Statistics}, 16: 421-444.

Friendly, M. & Fox, J. (2013) Visualizing Generalized Canonical Discriminant and Canonical Correlation
Analysis. R package version 0.6-5. Available at: \url{http://CRAN.R-project.org/package=candisc}.

Fox, J., Weisberg, S., Adler, D., Bates, D., Baud-Bovy, G., Ellison, S., Firth, D., Friendly, M., Gorjanc, G., Graves, S., Heiberger, R., Laboissiere, R., Monette, G., Murdoch, D., Nilsson, H., Ogle, D., Ripley, B., Venables, W. & Zeileis, A. (2014) Companion to Applied Regression. R package version 2.0-20. Available at: \url{http://CRAN.R-project.org/package=car}.

Locher, R. & Ruckstuhl, A. (2014) Utilities of Institute of Data Analyses and Process Design. R package version 1.1.17. Available at: \url{http://CRAN.R-project.org/package=IDPmisc}.
}
\examples{
\dontrun{

data(ZXIII4)

XIII4(data=ZXIII4, varX=c("H2O","N","P","Fe","Mn"), varY=c("Coverage",
"Internodes","Seeds"), labels="Area", ellipse=TRUE)

}
}
\keyword{XIII4}
