\name{XIV1}
\alias{XIV1}
\encoding{latin1}
\title{CLASSIFICATION AND REGRESSION TREES (CARTs)}
\description{A Classification and Regression Tree is performed (CART).}
\usage{
XIV1(data, cat, var, ResetPAR=TRUE, PAR=NULL, CART=NULL, RPART=NULL,
file="Output.txt")
}
\arguments{
  \item{data}{Data file.}
  \item{cat}{Dependent variable.}
  \item{var}{Independent variables.}
  \item{ResetPAR}{If it is FALSE, the default condition of the function \link{PAR} are not placed and those defined by the user on previous graphics are maintained.}
  \item{PAR}{It accesses the function \link{PAR} that allows to modify many different aspects of the graph.}
  \item{CART}{It accesses the function \link[rpart]{rpart}.}
  \item{RPART}{It accesses the function \link[rpart.plot]{rpart.plot}.}
  \item{file}{TXT FILE. Output file name with the results.}
}
\value{A graph with the Classification and Regression Tree and a TXT file with the results of the CART are obtained.}  
\details{
\strong{XIV. MULTIVARIATE ANALYSIS OF CLASSIFICATION}

It is the set of multivariate analysis methods whose main objective is to group or classify the elements of a sample of objects described by several variables. Compared to the factorial methods, classification techniques generally have an algorithmic approach (not algebraic), and most of them are not based on the linear model. Historically these arise with the computer and informatics, and benefit from the extraordinary power of calculation that these tools provide. There are hundreds of methods of classification or cluster analysis, of which only the most important will be seen.

In general it is to get homogeneous groups (classes, clusters), i.e., constructed in such a way that the elements in each group are similar among them, the classes must be separated or different, so that the elements of different groups are quite different. It is to find a structure in the data that will help to better understand the reality of the studied population.

Many classification methods allow to use variables of various kinds, quantitative or qualitative, nominal or ordinal, and in general other restrictive assumptions such as normality and homogeneity of variances that are usual in other statistical techniques, are not necessary. A prior knowledge of the data is not necessary.

For these reasons the classification methods are often used for exploratory purposes, to establish a first approach to the data, and to generate ideas, raise hypotheses that can be contrasted with other techniques, or to initiate the construction of explanatory models.

\strong{XIV.1 CLASSIFICATION AND REGRESSION TREES (CARTs)}

The classification and regression trees are a non-parametric method of predicting a dependent variable based on a set of independent variables (Breiman et al., 1984). Its non-parametric nature does not require any hypothesis relating to the distribution of the dependent and independent variables, nor to the relationship between them and their possible interactions.  The dependent variable can be categorical (Classification Trees), different species such as, rejection of a treatment, presence/absence of cancer, etc.
 
The dependent variable can also be continuous (Regression Trees), as for example the body mass index, blood glucose, etc. , in both cases, trees of Classification and Regression (CARTs), the aim is to identify the variables that best identify the dependent variable. For example, to determine which are the clinical, genetic and/or environmental features that can be used to predict if a person can have a certain cancer, or be prone to a heart attack, etc.

Amigo  et al. (2007) applied CARTs to the body mass index (BMI) in children and determined that the mother, the consumption of lipids and the hours of television on Sunday, were the variables that best classified children depending on their BMI. A CARTs analysis generally consists of three steps (Guisande & Vaamonde , 2012):

1. \strong{Tree Construction}. In the tree, the root node represents the entire population. This root node is divided into two subgroups on the basis of the partition of a independent or predictor variable. Children nodes are divided by means of the partition of a variable, that can be the same as before or a new one. The process is successively repeated until a stopping condition is met. The divisions are selected so that the "impurity" or heterogeneity of the children nodes would be lesser than that of the parent node. The function of impurity or partition criterion is a measure for determining the quality of a child node, and decides how the partition of a node is carried out in their two children nodes. There are different types of indices to quantify the impurity of the partitions (Breiman et al., 1984).

2. \strong{Tree Pruning}. The tree that has been built is generally over-fitted, i.e., it contains a large amount of levels and a greater complexity does not necessarily mean a better classification. Let us imagine that we are working with different species and want to determine which are the variables that allow distinguish them better. The tree can continue dividing into nodes until the last individual is classified, using a larger number of variables at each step and a more complex model to achieve a zero percentage of poorly sorted individuals. With the increasing complexity of a model, a better setting is always obtained, but sometimes simply very specific peculiarities of the data are collected, which are not useful for describing the behavior of the new data (data validation). Pruning consists of, once built the tree, deleting backwards partitions that do not represent a significant increase in the total capacity of prediction.

3. \strong{Tree validation}. As pruning the complexity of the tree is reduced but the number of individuals poorly classified can increase. The best tree will be one that has the optimum ratio of the rate of poor classification (ratio between the observations wrongly classified and the total number of observations) and the complexity of the tree.

The selection of the best tree for validation is performed. The procedure consists in separating a portion of the sample, which is not used for the construction of the tree, but only for the prediction, measuring the percentage of success in it. It is also often use a cross-validation method, which is to divide the sample into several mutually exclusive groups (usually 10 groups) of approximately equal size, and make the tree leaving a group outside, which is used for the prediction and measurement of the degree of success. The process is repeated until all the groups are used and finally the tree with the least aggregate rate of misclassification (average of the ten groups) is selected.

\strong{FUNCTIONS}

For the estimation of the CART, the function \link[rpart]{rpart} of the package rpart (Therneau et al., 2014) is used and for its representation, the function \link[rpart.plot]{rpart.plot} of the package rpart.plot (Milborrow, 2014) is used. 

\strong{EXAMPLE}

The example uses demographic data of 2010 of the 19 regions or Autonomous communities in Spain published by the National Institute of Statistics (\url{http://www.ine.es}). The goal is to determine if it is possible to classify the different regions based on the following demographic variables: number of children per mother, average age of the mother when she has her first child, average percentage of unmarried women with children, the life expectancy of men and women, and the number of births, population mortality and infant mortality (children under 1 year), the last three demographic parameters per 1000 inhabitants.

The dependent variable is the regions and the independent variables or predictors are all the demographic indicators. With the argument \emph{method}, the method of partitioning is defined; if the dependent variable is categorical, as in our example, the \emph{method='class'} will be placed. The method can be omitted, that is what has been done in the example, in which case the function itself decides the most appropriate method depending on the type of dependent variable.

With the argument \emph{control}, and using the function \emph{rpart.control()}, important aspects of the tree can be modified. With the argument \emph{minsplit} the minimum number of observations that must exist in a node are specified for the partition, i.e., as smaller the tree, this will have more nodes. With \emph{minbucket} the minimum number of observations in a terminal node is defined and, therefore, like the previous argument, as it is smaller, it goes more deeply into the tree, i.e., has more nodes and is more complex.

With \emph{cp} the complexity is controlled and allows to save time in the process of pruning, which is the fraction (default 0.01) in which the adjustment indicator must improve to continue the construction of the tree. If the improvement is less than \emph{cp} the process stops. If the user decides to delve deeper and make the tree very complex (\emph{cp} small), or have a more simple tree (\emph{cp} larger).

With \emph{surrogatestyle} the criterion for choosing the best substitute variable for the partition on each node is controlled. If it is 0 the variable with the largest number of items rated correctamentees used, and if it is 1 that has the highest percentage of elements correctly classified on the number of valid cases of that variable; the first option penalises the variables that have missing values.

In the function \link[rpart.plot]{rpart.plot} with the argument \emph{type} the format of the chart is selected, i.e., the way the information comes from the selected variables in each partition and the predominant categories in each node. With the argument \emph{extra} the additional information in the nodes can be displayed, as in this example, it is requested that the number of cases correctly classified as opposed to total are shown on each node.

With \emph{varlen=0}  is defined that when the texts of the nodes are complete they are not cut. With \emph{ycompress=TRUE} is defined that when labels overlap, they must move vertically to avoid the overlap. 

For more details see the arguments on the help menus of functions \link[rpart]{rpart} and \link[rpart.plot]{rpart.plot} and/or Guisande & Vaamonde (2012).

CART is shown in Figure XIV.1. The numbers indicate the provinces that have been correctly classified and the total number of provinces in each region. For example, there are 8 provinces of the region of a total of 9 in the group that shows Castilla and Leon. There is a group that displays 8 provinces of Andalusia from a total of 9.

In general it is observed that many regions are well identified. For example, in the Canary Islands, Galicia, Castile La Mancha and Valencia, all the provinces of the region are within the same group. In others, such as Andalusia, Catalonia, Basque Country, etc., almost all provinces are in the same group. This means that there are demographic differences between regions in Spain, as it is possible to identify relatively well each of the Regions on the basis of these demographic indicators.

The first variable is the life expectancy of men, which separates a group of regions with men who have a life expectancy of less than 78 years to the left and more than 78 to the right. The average number of children per mother and mother's age when she has the first child are also important variables as they will appear in many nodes. The number of births per 1000 deaths is also an important variable indicating that regions grow at different rates. In the tree, it has been chosen not to identify all cases properly, that is to say, there are terminal groups where there are cases of different categories, to make the tree not very complex. What is important in this example is to see if the demographic indicators differ to the regions, and which of these indicators are the most important for this.
\tabular{c}{
\strong{Figure XIV1.1.} Demographic parameters that best differenciate the regions of Spain.\cr
\figure{FXIV1}{options: width=5.5in}
}
}
\references{
Amigo, H., Bustos, P., Erazo, M., Cumsille, P. & Silva, C. (2007) Factores determinantes del exceso de peso en escolares. Un estudio multinivel. \emph{Revista Mdica de Chile}, 57: 353-357.

Breiman, L., Friedman, J., Olshen, R. & Stone, C. (1984) \emph{Classification and Regression Trees}. Wadsworth.

Guisande, C. & Vaamonde, A. (2012) \emph{Grficos estadsticos y mapas con R}. Ediciones Daz de Santos, Madrid, 367 pp.

Milborrow, S. (2014) Plot rpart models. An enhanced version of plot.rpart. R package version 1.4-4. Available at: \url{http://CRAN.R-project.org/package=rpart.plot}.

Therneau, T., Atkinson, B. & Ripley B (2014) Recursive Partitioning and Regression Trees. R package version 4.1-8. Available at: \url{http://CRAN.R-project.org/package=rpart}.
}
\examples{
\dontrun{

data(ZXIV1)

XIV1(data=ZXIV1, cat="Region", var= c("Children.Mother", "Mother.Age",
"Unmarried.Percent", "Life.expectancy.male", "Life.expectancy.female",
"Birthrate","Mortality", "Infant.mortality"))

}
}
\keyword{XIV1}
