\name{XIV2}
\alias{XIV2}
\encoding{latin1}
\title{DISCRIMINANT ANALYSIS}
\description{Two types of discriminant analysis are applied: Linear and Quadratic.} 
\usage{
XIV2(data, cat, var, ellipse=TRUE, convex=FALSE, quadratic=FALSE, expand=TRUE,
dimS=c(1,2), ResetPAR=TRUE, PAR=NULL, CANDISC1=NULL, CANDISC2=NULL, CANPLOT=NULL,
SCATTERPLOT=NULL, COLOR=NULL, PCH=NULL, TEXT=NULL, LEGEND=NULL, AXIS=NULL,
MTEXT=NULL, arrows=TRUE, larrow=0.95, colArrows="black", file1="Var loadings-Linear.csv",
file2="Cat loadings-Linear.csv",file3="Table cross-validation-Linear.csv",
file4="Cases cross-validation-Linear.csv", 
file5="Table cross-validation-Quadratic.csv",
file6="Cases cross-validation-Quadratic.csv", na="NA", dec=",", row.names=TRUE)
}
\arguments{
  \item{data}{Data file.}
  \item{cat}{Categories of cases.}
  \item{var}{Variables included in the analysis.}
  \item{ellipse}{If it is TRUE the ellipses with the levels of significance to the 0.5 (inner ellipse) and 0.95 (outer ellipse) of each category of the variable \emph{cat} are depicted. These levels of significance can be modified by entering the function \link[car]{scatterplot} using the argument \emph{SCATTERPLOT} and modifying the argument \emph{levels=c(0.5,0.95)}.}
  \item{convex}{If it is TRUE the convex hull is depicted for each category.}
  \item{quadratic}{If TRUE, a Quadratic Discriminant Analysis is performed, in addition to the Linear Discriminant Analysis.}
  \item{expand}{If TRUE, the coordinates of the categories, in the graph \emph{biplot}, are adjusted to the scale of the coordinates of the cases.}
  \item{dimS}{Dimensions that are represented in the graph \emph{biplot}.}
   \item{ResetPAR}{If it is FALSE, the default condition of the function \link{PAR} are not placed and those defined by the user on previous graphics are maintained.}
  \item{PAR}{It accesses the function \link{PAR} that allows to modify many different aspects of the graph.}
  \item{CANDISC1}{It accesses the function \link[candisc]{candisc} of the candisc package, performing the one-Dimensional Linear Discriminant Analysis.}
  \item{CANDISC2}{It accesses the function \link[candisc]{candisc} of the candisc package which performs the Two-Dimensional Linear Discriminant Analysis.}
  \item{CANPLOT}{It accesses the function \link[candisc]{plot.cancor} of the candisc package, performing the one-dimensional discriminant graph.}
  \item{SCATTERPLOT}{It accesses the function \link[car]{scatterplot} of the car package, with the graph \emph{biplot} that performs the Two-Dimensional Linear Discriminant Analysis.}
  \item{COLOR}{It allows to modify the colors of the graph \emph{biplot}, that should be as many as different groups the variable \emph{cat} has.}
  \item{PCH}{Vector with the symbols of the graph \emph{biplot}, that should be as many as different groups the variable \emph{cat} has. If NULL, they are automatically calculated starting with the symbol 15.}
  \item{TEXT}{It accesses the function that allows to modify the labels of the cases in the graph \emph{biplot}.}
  \item{LEGEND}{It allows to include a legend.}
  \item{AXIS}{It allows to add axes.}
  \item{MTEXT}{It allows to add texts in the margins of the graph.}
\item{arrows}{If it is TRUE the arrows are shown in the scatterplot.}
  \item{larrow}{It modifies the length of the arrows.}
  \item{colArrows}{Color de las flechas.}
  \item{file1}{CSV FILE. Name of the output file with the coordinates of the variables in the graph of the Linear Discriminant Analysis.}
  \item{file2}{CSV FILE. Name of the output file with the coordinates of the categories in the graph of the Linear Discriminant Analysis.}
  \item{file3}{CSV FILE. Name of the output file with the table of predictions using the cross validation of the Linear Discriminant Analysis.}
  \item{file4}{CSV FILE. Name of the output file with the group to which each case belongs and the prediction of the Discriminant Analysis using cross validation of the Linear Discriminant Analysis.}
  \item{file5}{CSV FILE. Name of the output file with the table of predictions using the cross validation of the Quadratic Discriminant Analysis.}
  \item{file6}{CSV FILE. Name of the output file with the group to which each case belongs and the prediction of the discriminant analysis using cross validation of the Quadratic Discriminant Analysis.}
  \item{na}{CSV FILES. Text that is used in the cells without data.}
  \item{dec}{CSV FILES. It defines if a comma "," or a dot "." is used as decimal separator.}
  \item{row.names}{CSV FILES. Logical value that defines if identifiers are put in rows or a vector with a text for each of the rows.}
}
\value{For the Linear Discriminant Analysis a graph with the first dimension is obtained and the \emph{biplot} with the first two dimensions, which can be other option that the user can select in case there are more than two categories. In the window of \emph{Replies} the variance explained by each discriminant function is obtained (only for the Linear Discriminant Analysis) and the percentage of cases correctly identified, also by cross validation, for the two types of discriminant. The CSV files that are obtained for the Linear Discriminant Analysis are: the coordinates of the cases and variables in the axes, a table with a number of classified individuals in each group by cross-validation and a file with the actual group that belongs to each case and the prediction that the model makes. For Quadratic Discriminant Analysis a table with the number of classified individuals in each group by cross-validation is obtained and a file with the real group to which each case belongs and the prediction that the model makes.}
\details{
\strong{XIV. MULTIVARIATE ANALYSIS OF CLASSIFICATION}

\strong{XIV.2. DISCRIMINANT ANALYSIS}

A multivariate statistical technique widely used to characterize classes of elements when there is a certain number of variables is the discriminant analysis, that allows -from an initial classification- to get a new classification based on the observed values of a set of variables. The method consists in the determination of some functions of the original variables, called discriminant functions, which allow to decide in which class each element must be, using as a criterion for assigning the proximity (or similarity) of each element to the different classes or existing groups. It can be used, for example, to identify the geographical origin of a sample of unknown honey, when there are multiple samples of each area, using the contents or concentrations of different types of sugars that have been analytically determined in all the samples.

The construction of the discriminant functions, linear combinations of the original variables, is carried out by finding those that do the maximum separation between groups, which is equivalent to minimize the variability within the classes. The functions obtained enable to discriminate in the best possible way between the elements belonging to the different classes or groups. The allocation of the elements to classes is performed using the Bayes approach: each element is assigned to the class for which it is greater the conditioned probability of belonging by values that take the discriminant functions.

\strong{XIV.2.1. Hypothesis}

The Linear Discriminant Analysis requires, so that it can be used correctly, the hypothesis of homogeneity of variances, i.e., that the covariance matrices of each class are equal, or that the dispersion is similar in each class for all the variables. The M-box test is applied to test this hypothesis of homogeneity. It is also necessary that the discriminant functions have Normal distribution. Both of these assumptions of normality of residuals and homogeneity of variances were used in the calculation of the probabilities of assignment of the elements for the various classes. However, these do not usually be checked in practice as the tests M-box and contrasts of normality are very sensitive to small deviations and with actual data they are not virtually met. If these are checked, the Linear Discriminant Analysis can never be applied.

The Linear Discriminant Analysis is reasonably robust against a partial default on these hypotheses (enough when these are fulfilled in an approximate way), and that failure is not critical if the hit ratio in the classification (especially in the cross-validation) is high. It is necessary that the hit ratio is high not only in the whole of the elements, but also in each of the groups. In practical terms what is checked is, therefore, the percentage of success in the cross-validation, and it is neither necessary nor advisable to check the assumptions, unless there is clear evidence that they are unfulfilled (by the type of data, for example when the explanatory variables are binary), in which case it may not be correct to use the Linear Discriminant Analysis. If the hit ratio is low, this could be due to the failure of the assumptions, but in that case there is no need to be checked, because what is prudent is to give up when the discriminant analysis classifies wrongly.

If the argument \emph{quadratic=TRUE} performs a Quadratic Discriminant Analysis, which does not require the homogeneity of variances (Venables & Ripley, 2002), in addition to the linear method. The comparison of the percentage of correct cases classfied, by cross-validation, obtained with the Quadratic Discriminant Analysis and Linear could be used as an indicator of how robust the straight-line method is, since if two percentages are similar, this would indicate that the Linear Discriminant Analysis is correct. However, the Quadratic Discriminant Analysis cannot be applied when any category has only a few cases, usually less than 5. In addition, it is frequent for this error \emph{rank deficiency in group ... } when applying the quadratic method, in which case, it would have to specify the argument \emph{quadratic=FALSE}, so that it cannot be done.

\strong{XIV.2.2. Step by step method}

The step-by-step approach can be used for the discriminant analysis, with which the variables with the greatest capacity of discrimination are successively and automatically selected in accordance with a particular statistical criterion (for example the minimum value of the coefficient Wilks' lambda), which are incorporated into a set of variables that are involved in the analysis. In some steps a variable previously entered can be ruled out, but when other new variables are considered, these will no longer provide the ability to set a significant discrimination. However it is preferable select the variables that should not automatically be used, but with technical or scientific criteria - non-statistical - by applying those that have a priori a direct relationship (for example type of cause-effect) with the classification.

\strong{XIV.2.3.  Influence of the different independent variables}

The solution obtained to classify cases whose group is unknown a priori is generally obtained, i.e. for identification purposes or prediction. It is also used to reclassify the elements or reassign the elements to the different classes when this classification is not reliable or is only indicative, to study the effect of the different explanatory variables on the classification. With the latter objective the standard coefficients of the first discriminant functions are used: the higher the coefficient, the greater the effect of this variable.

Also the so-called "coefficients of structure," or correlation coefficients between the discriminant functions and the independent variables (which have been used for its construction) can be used. Generally, the older structure coefficients in absolute value correspond to the highest coefficients standard, although on occasions the high coefficient of structure corresponds to a standard low ratio, which allows to detect redundant variables, or vice versa, a coefficient of structure under with a high standard ratio, which identifies a confounding variable, which interacts with the remaining ones distorting the results. Usually both types of variables should be excluded from the analysis.

Univariate ANOVAs are often used to compare the hypothesis that the means of each independent variable are the same for all groups. These also allow to measure the importance or capacity of discrimination of the different variables. If the means are equal, the variable in general will have little or no capacity for discrimination.

\strong{XIV.2.4.  Validation}

When the number of variables is large in relation to the size of the sample, a problem of overfitting may appear. The discriminant functions allow to classify with a high degree of success the elements of the sample, but if we apply these same functions to the classification of new elements, which are not used for the construction of the discriminant functions, the degree of success substantially decreases.

In such cases the peculiarities of the displays are being used to properly assign a high number of cases, but the functions are not valid -are not representative- for the population from which comes the sample. It is necessary to perform some type of validation to ensure that the procedure will be valid for the population and not just for the sample. One option is to set aside a portion of the sample (for example 10 items), which are not used to build the discriminant functions, but are assigned together with them to the various classes. If the proportion of elements correctly classified with this sample of validation is also high, the discriminant analysis will be adequate.

Another possibility is the so-called cross-classification leaving one out. A discriminant analysis is carried out excluding the first item in the sample, then this element is assigned using the discriminant functions obtained. Later the same thing is done with each of the elements of the sample. In this way all the elements of the sample are allocated, without using the corresponding element in the calculations of the discriminant functions and, therefore, all data have been used as sample of validation. If the percentage of success with this cross-validation is high and similar, or only slightly lower than, the hit ratio of discriminant analysis with the whole sample, the validation is positive, and discriminant analysis is suitable for such data.

\strong{FUNCTIONS}

The Linear Discriminant Analysis was performed with the functions \link[candisc]{candisc} of the candisc package (Friendly, 2007; Friendly & Fox, 2013) and \link[MASS]{lda} of the MASS package (Venables & Ripley, 2002; Ripley et al., 2014). The Quadratic Discriminant Analysis was performed with the function \link[MASS]{qda} of the MASS package (Venables & Ripley, 2002; Ripley et al., 2014). The graph with one dimension was performed with the function \link[candisc]{plot.cancor} of the candisc package (Friendly, 2007; Friendly & Fox, 2013). To perform the graph \emph{biplot} the function \link[car]{scatterplot} was used of the car package (Fox et al., 2014). The arrows are depicted with the function \link[IDPmisc]{Arrows} of the package IDPmisc (Locher & Ruckstuhl, 2014). The convex hull is estimated with the function \link[grDevices]{chull} of the package grDevices.

\strong{EXAMPLE 1}

The data correspond to a study conducted in lakes in Colombia where the abundance of phytoplankton and the concentration of some nutrients are analyzed. The objective is to determine if it is possible to discriminate between regions on the basis of the concentration of nutrients. In the script the argument \emph{quadratic=TRUE} has been defined to perform the Quadratic Discriminant Analysis.

With the straight-line method, 97.67\% of the cases are correctly assigned. However, the cross-validation shows that the percentage of cases correctly allocated is lower (94.19\%), although still high.

The Quadratic method displays a percentage by cross validation of the 95.3\%, which is very similar to that obtained with the linear method. Therefore, the regions are distinct from depending on nutrient concentrations. The lakes region of the Andes is distinguished by its low concentration of nutrients (Figure XIV.2) and the first discriminant axis explains 78.3\% of the variability.

The second axis, which absorbs a 21.7\% of the variance and differentiate between the lakes of the Amazon Basin and the Caribbean (Figure XIV.3). The ellipses show the levels of significance to the 0.5 (inner ellipse) and 0.95 (outer ellipse) of each of the regions. It is an indicator of the degree of overlap between regions. These levels can be modified by entering the function \link[car]{scatterplot} using the \emph{SCATTERPLOT} argument and modifying the argument \emph{levels=c(0.5,0.95)}.
\tabular{c}{
\strong{Figure XIV.2.} Axis I of the discriminant analysis discriminating\cr
regions, depending on nutrient concentration.\cr
\figure{FXIV2}{options: width=3.3in}
}
\tabular{c}{
\strong{Figure XIV.3.} Axes I and II of the discriminant analysis discriminating\cr
regions, depending on nutrient concentration.\cr
\figure{FXIV3}{options: width=2.8in}
}
\strong{EXAMPLE 2}

In the second example the same previous data are used but the differentiation is carried out at the level of lake instead of region with the argument \emph{cat="Lake"} and the abundance of phytoplankton is also included. In this case the 94.19\% is properly identified, and cross-validation is the 90.7\% with the linear method. Logically, it is more difficult to differentiate the lakes regions. Although the argument \emph{quadratic=TRUE} has been defined, the function will not automatically applies the quadratic method, as there are categories with few cases. The first axis separates Lake Tota well for its high concentrations of cyanobacteria and Chlorophyceae as well as and low concentrations of nutrients (Figure XIV.4). The second axis, which absorbs a 16.99\% of the variance, is mainly determined by the differences in the silicate (\eqn{S_iO_2}) and for the abundance of Chrysophyceae and Dinophyceae (Figure XIV.5).
\tabular{c}{
\strong{Figure XIV.4.} Axis I of the discriminant analysis applied to species of phytoplankton\cr
discriminating lakes depending on the composition of the\cr
phytoplankton and nutrients concentration.\cr
\figure{FXIV4}{options: width=5in}
}
\tabular{c}{
\strong{Figure XIV.5.} Axes I and II of the discriminant analysis applied to species of phytoplankton\cr
discriminating lakes, depending on the composition of the\cr
phytoplankton and nutrients concentration.\cr
\figure{FXIV5}{options: width=3in}
}
\strong{EXAMPLE 3}

Data obtained from a flow cytometer of size, roughness and emission of radiation at different wavelengths, from cells that belong to different species of phytoplankton: \emph{Rhodomonas baltica}, \emph{Alexandrium tamarense}, and two strains of \emph{Alexandrium minutum}. The objective is to determine if with the characteristics of the cells obtained in the flow cytometer is possible to discriminate between the different species and strains within the same species. Convex hull instead on the ellipses is estimated with the arguments \emph{ellipse=FALSE} and \emph{convex=TRUE}.

The results show that the 100\% of the cases are assigned correctly. The cross validation with the linear and quadratic methods show an identical value, still a high degree of cases correctly assigned (99.29\%), in such a way that only a case of \emph{A. minutum-1} is identified as \emph{A. tamarense}. The first axis (Figure XIV.6) explains a 78.7\% of the variance and clearly differentiates the species \emph{A. tamarense} for other species, by the emitted radiation between 650 and 700 nm. Sometimes, as shown in the Figure XIV.7 two axes that do not explain a high proportion of the variance, as in this case, the axis II (18.49\%) and III (2.81\%), can clearly differentiate the groups.
\tabular{cc}{
\strong{Figures XIV.6. and XIV.7} Axes I and II of the discriminant analysis applied\cr
to species of phytoplankton using cell characteristics.\cr
\figure{FXIV6}{options: width=4in}
\cr
\figure{FXIV7}{options: width=2.6in}
}
}
\references{
Fox, J., Weisberg, S., Adler, D., Bates, D., Baud-Bovy, G., Ellison, S., Firth, D., Friendly, M., Gorjanc, G., Graves, S., Heiberger, R., Laboissiere, R., Monette, G., Murdoch, D., Nilsson, H., Ogle, D., Ripley, B., Venables, W. & Zeileis, A. (2014) Companion to Applied Regression. R package version 2.0-20. Available at: \url{http://CRAN.R-project.org/package=car}.

Friendly, M. (2007) HE plots for Multivariate General Linear Models. \emph{Journal of Computational and Graphical Statistics}, 16: 421-444.

Friendly, M. & Fox, J. (2013) Visualizing Generalized Canonical Discriminant and Canonical Correlation Analysis. R package version 0.6-5. Available at: \url{http://CRAN.R-project.org/package=candisc}.

Locher, R. & Ruckstuhl, A. (2014) Utilities of Institute of Data Analyses and Process Design. R package version 1.1.17. Available at: \url{http://CRAN.R-project.org/package=IDPmisc}.

Ripley, B., Venables, B., Bates, D.M., Hornik, K., Gebhardt, A. & Firth, D. (2014) Support Functions and Datasets for Venables and Ripley's MASS. R package version 7.3-33. Available at: \url{http://CRAN.R-project.org/package=MASS}.

Venables, W.N. & Ripley, B.D. (2002) \emph{Modern Applied Statistics with S}. Springer, fourth edition, New York. \url{http://www.stats.ox.ac.uk/pub/MASS4}.
}
\examples{
\dontrun{
data(ZXIV2)

#Example 1. Differences in the physical-chemistry between regions

XIV2(data=ZXIV2, cat="Area", var=c("NO2","NO3","NH4","SiO2"), quadratic=TRUE,
MTEXT=c("text='Nutrients in regions of Colombia'", "side=3",
"line=1", "cex=1.7", "font=2"))

#Example 2. Differences in the abundance of phytoplankton among lakes 

XIV2(data=ZXIV2, cat="Lake", var=c("NO2","NO3","NH4","SiO2", "Cianophyceae",
"Euglenophyceae", "Clorophyceae", "Zygophyceae", "Bacillariophyceae",
"Dinophyceae", "Xanthophyceae", "Crysophyceae", "Cryptophyceae"),
quadratic=TRUE, LEGEND=c("x='topright'", "legend=unique(datos3[,1])", "bty='n'",
"col=color1", "pch=pcht"), MTEXT=c("text='Nutrients  and abundance of 
phytoplankton\n in lakes of Colombia'", "side=3", "line=0", "cex=1.6", "font=2"))

#Example 3

data(ZXIV3)

XIV2(data=ZXIV3, cat=("Species"), var=c("Roughness","Size","F.515.550","F.560.600","F.650.700"),
quadratic=TRUE, dimS=c(2,3),LEGEND=c("x='bottomleft'", "legend = unique(datos3[,1])",
"bty='n'", "col=color1","pch=pcht"),
MTEXT=c("text= 'Identification of phytoplankton species\nby flow cytometry'",
"side=3", "line=0", "cex=1.7", "font=2"), ellipse=FALSE, convex=TRUE)
}
}
\keyword{XIV2}
