\name{XIV3}
\alias{XIV3}
\encoding{latin1}
\title{DISCRIMINANT ANALYSIS AND PRINCIPAL COMPONENTS}
\description{A Discriminant Analysis and, subsequently, a Principal Component Analysis is applied to each one of the groups of the discriminant analysis.} 
\usage{
XIV3(data, cat, var, labels=NULL, dimS=c(1,2), ResetPAR=TRUE, PAR=NULL,
DAPC=NULL, SCATTERDAPC=NULL, COLOR=NULL,TEXT=NULL, LEGEND=NULL, AXIS=NULL,
MTEXT= NULL, file="Output.txt")
}
\arguments{
  \item{data}{Data file.}
  \item{cat}{Case categories.}
  \item{var}{Variables that are included in the analysis.}
  \item{labels}{Variable that allows to show a label for each case.}
  \item{dimS}{Dimensions that are represented on the graph.}
   \item{ResetPAR}{If it is FALSE, the default condition of the function \link{PAR} is not placed and maintained those defined by the user on previous graph.}
  \item{PAR}{It accesses the function \link{PAR} that allows to modify many different aspects of the graph.}
  \item{DAPC}{It accesses the function \link[adegenet]{dapc} of the adegenet package, that performs the Discriminant and Principal Component Analyses.}
  \item{SCATTERDAPC}{It accesses the function \link[adegenet]{scatter.dapc} of the adegenet package, performing the graph that shows the Discriminant and Principal Component Analyses.}
  \item{COLOR}{It allows to modify the colors of the graph, but they must be as many as different groups the variable \emph{cat} has.}
  \item{TEXT}{It accesses the function that allows to modify the labels of the cases of the graph.}
  \item{LEGEND}{It allows to include a legend.}
  \item{AXIS}{It allows to include axes.}
  \item{MTEXT}{It allows to include text in the margins of the graph.}
  \item{file}{TXT FILE. Output file name with the results.}
}
\value{A graph is obtained with Discriminant and Principal Component Analyses and a TXT file with all information about both analyses.}
\details{
\strong{XIV. MULTIVARIATE ANALYSIS OF CLASSIFICATION}

\strong{XIV.3. DISCRIMINANT ANALYSIS AND PRINCIPAL COMPONENTS}

This function combines the power of the Discriminant Analysis, which enables to determine if some categories can be differentiated on the basis of some variables, and then apply a Principal Components Analysis to each of the categories, to determine which variables have the greatest variation within each category. Principal Components Analysis is explained in the section \emph{details} of the function \link{XIII2} and the Discriminant Analysis in the same section of the function \link{XIV2}.

\strong{FUNCTIONS}

The Discriminant Analysis and Principal Components was carried out with the function \link[adegenet]{dapc} and the graph with the function \link[adegenet]{scatter.dapc}, both from the adegenet package (Jombart et al., 2014).

\strong{EXAMPLE}

The study was to analyze the demographic parameters of 57 countries in Europe, Africa and America. The variables used were male and female life expectancy at birth (in years of life), the mortality rates, infant mortality, birth, and fertility, the gross domestic product per capita (in thousands of dollars per year) and the literacy rate for men and women (in percentage).

The aim is to determine whether it is possible to discriminate continents based on these demographic parameters and identify which parameters are responsible for any possible differences between them. In addition, to determine, within each continent, which are the parameters that have a higher variability among countries.

In Figure XIV.8 elements (countries) are shown forming defined groups by the class (continent) to which they belong, that can be identified by the color. For each group the centroid or mid-point is represented, from which rays are drawn vectors to each of the countries.

An ellipsoid of variability allows to appreciate the association of the elements of each class (within the ellipsoid is the 95\% of group elements), and find out which are the elements that appear to differ from the rest of the group.

Thus, in the group of Latin American countries, Guatemala and Haiti, the least developed of the whole, seem to approach the  African side; Tanzania, Senegal and Uganda, among the poorest of this continent, they move away from the media in the opposite direction, while Gabon, with important oil resources, approaches slightly to the European group.

Within the European group, some countries (Greece, Portugal, Ireland, Spain, in that order) seem to announce future challenges in the development of the oncoming crisis, with anticipated data in more than a decade.
\cr
\tabular{c}{
\strong{Figure XIV.8.} Axes I and II of discriminant analysis showing the differences between\cr
continents and the variability observed with Principal Component Analysis\cr
in demographic parameters between countries in each continent.\cr
\cr
\figure{FXIV8}{options: width=3.2in}
}
\tabular{c}{
\figure{RXIV1}{options: width=5in}
}
As regards the importance of each variable for each of the two discriminant (the first on the horizontal axis, the second on the vertical one) then it is clear that the first is \emph{Birthrate} (63.78\%), \emph{Mortality} (12.54\%), and \emph{LifeExpM} (9.25\%), and the second \emph{LiteracyF} (58.06\%) and \emph{LiteracyM} (33.52\%). The variables that have the greatest influence in this group are those of highest contribution: Birth rate, Mortality rate and Life expectancy.
\tabular{c}{
\figure{RXIV2}{options: width=3.8in}
}
The fact that the countries in each class (in this case, each continent) are grouped together forming homogeneous sets and differentiated on the basis of the socio-economic variables (without using at any time to the classification or for the geographic criteria chart) indicates that the economic development occurs by areas, and that the progress of a country is no stranger to that of its neighbors.

Conversely, if the groups shown in the graph were overlapping or mixed, this would mean that the classification criterion is not related, or what is to a limited extent, with all quantitative variables used in the application of the method.
}
\references{
Jombart, T., Collins, C., Solymos, P., Ahmed, I., Calboli, F. & Cori, A  (2014) adegenet: an R package for the exploratory analysis of genetic and genomic data. R package version 1.4-2. Available at: \url{http://CRAN.R-project.org/package=adegenet}.
}
\examples{
\dontrun{

data(ZXIII2)

XIV3(data=ZXIII2, cat="Continent", var=c("LifeExpF", "LifeExpM", "Mortinf",
"PIB_cap", "Birthrate", "Mortality", "Fertility", "LiteracyM", "LiteracyF"),
labels="Country", MTEXT = c("text=c('Can1','Can2','Discriminant and\n
Principal Component Analyses')", "side = c(1,2,3)", "line = c(3.5,3.5,-1.5)",
"cex = c(1.4,1.4,1.6)", "font = c(2,2,2)"))
}
}
\keyword{XIV3}
