\name{XIV4}
\alias{XIV4}
\encoding{latin1}
\title{DENDROGRAM}
\description{A hierarchical classification is applied (Dendrogram).} 
\usage{
XIV4(data, var, cat=NULL, ResetPAR=TRUE, PAR=NULL, HCLUST=NULL, PLOT1=NULL,
PLOT2=NULL, LEGEND=NULL, AXIS=NULL, MTEXT= NULL, TEXT=NULL)
}
\arguments{
  \item{data}{Data file.}
  \item{var}{Variables that are included in the analysis.}
  \item{cat}{Case categories.}
  \item{ResetPAR}{If it is FALSE, the default condition of the function \link{PAR} is not placed and maintained those defined by the user on previous graph.}
  \item{PAR}{It accesses the function \link{PAR} that allows to modify many different aspects of the graph.}
  \item{HCLUST}{It accesses the function \link[stats]{hclust} of the stats package.}
  \item{PLOT1}{It accesses the function that allows to modify the graphical representation of the dendrogram if the argument \emph{cat} is not \emph{NULL}.}
  \item{PLOT2}{It accesses the function that allows to modify the graphical representation of the dendrogram if the argument is \emph{cat=NULL}.}
  \item{LEGEND}{It allows to include a legend.}
  \item{AXIS}{It allows to add axes.}
  \item{MTEXT}{It allows to add text in the margins of the graph.}
  \item{TEXT}{It allows to add text in any area of the inner part of the graph.}
 }
\value{A graph called dendrogram is obtained.}
\details{
\strong{XIV. MULTIVARIATE ANALYSIS OF CLASSIFICATION}

\strong{XIV.4. DENDROGRAM}

It is one of the most commonly used methods. A sequence of partitions (classifications) hierarchically organized is obtained, from a single class which contains all of the elements, until \emph{n} classes, each of them with a single element. The sequence can be graphically represented by a tree.

Firstly, the algorithm consists of joining the two closest elements among themselves; the resulting class is considered a new element that replaces the previous two. Then the two closest elements that will join in a new class are searched again. The process continues, and the various classes are successively joining in larger classes, until all of the items are eventually a single class.

\strong{XIV.4.1. Distance criterion}

To decide which are the elements of the sample closest to each other, it is necessary to have a distance criterion. There are different definitions or types of distance and it is necessary to choose the most appropriate for the data used.

\emph{Euclidean}: is the most used, and corresponds with the usual geometric distance in a multidimensional space. It is defined as the square root of the sum of the squares of the differences in the values of each variable for the two elements. Most of the statistical programs consider the Euclidean distance as an option by default Euclidean distance squared: assigns a greater weight to the more distant objects.

\emph{Manhattan Distance}: It is the average of the difference between dimensions. The name comes from its relationship with the real distance between two points in a city with streets that are cut at right angles, where in general the straight line is not a possible way.

\emph{Mahalanobis Distance}: Each dimension is weighted by the inverse of its standard deviation. This distance is an important property: it is invariant to changes in the unit of measure, which makes it especially useful when the variables are heterogeneous.

\strong{XIV.4.2. Clustering Agglomeration Criterion}

When the process of classification was started, to unite in a single class the two closest elements among themselves, this class passes to be considered a new element that replaces the former two. To continue the algorithm is now necessary to calculate the distance between this new element and all of the above, and for this there are various options, which determine the criterion of agglomeration or conglomeration.

There are different criteria of distance between classes, or between classes and elements, which correspond to the mathematical concept of ultrametric, more restrictive than the classic concept of distance or metric:

\emph{Simple link} (nearest neighbor): The distance between the two groups is the distance between the two closest objects between the different groups. Sometimes, using this procedure of conglomeration can lead to a "chaining effect of", by which each phase in a class with an isolated element is joined instead of joining two classes between them with several items each, giving rise to a hierarchical sequence of atypical classifications of little practical use.

\emph{Complete link} (farthest neighbor): The distance between two groups is the longest distance between two objects in both groups.

\emph{Mean link } or inter-group link: mean distance between all pairs of objects in the two groups. 

\emph{Intra-group link}: average distance between all pairs of objects from the union of two groups. It considers not only the average distances between elements of the two groups, but also the distances between elements of the same group.

\emph{McQuitty method}: the distance to any object from a group that is a union of two other groups. It is the average of the distances of those two, weighted by the number of units of each group.

\emph{Link of centroids}: distance between the mean or centroid of the two groups.

\emph{Ward method}: In each step, the two elements that give rise to a lower loss of information are joined together, it is considered as the sum of squares of distances of each object at the center of its class (minimum variance or inertia).

\strong{XIV.4.3. Dendrogram}

The main result of this technique is a graph, called dendrogram or Classification tree, which allows to view the entire classification process since its inception with each element in a class until the end with a single class in which all elements of the sample are. In this graph, all partitions or classifications obtained and their hierarchical relationship are observed. For better interpretation cases or classified items can be labeled.
 
From the dendrogram, it is possible to choose the partition of interest, depending on the distances between classes, which are measured in the lateral scale. The distance between two classes is given by the length of the branch which unites them in the tree; generally in the tree the greater separation between partitions is sought, that allows to view the most natural classification of all objects.

The algorithm in each step requires the calculation of the matrix of distances between all the elements; when the sample contains a large number of objects (several hundred, or more than a thousand) the procedure is excessively slow, in such a way that many minutes may be required or even hours before reaching the final result.

On the other hand, the graph obtained, dendrogram, is not easily interpretable when it is too large. The method of hierarchical classification is not useful for large samples, although in that case this can still be applied to a part of the data (a random sample of the data).

\strong{FUNCTIONS}

The function \link[stats]{hclust} of the stats package is used.

\strong{EXAMPLE}

Data on the relative concentration of 19 pigments, in relation to the concentration of chlorophyll a, phytoplankton species that belong to different classes of algae: Diatoms, Chlorophyceae, Dinophyceae, Cyanobacteria and Cryptophyceae. The objective is to determine if it is possible to differentiate the kinds of algae according to their relative composition of pigments.

In a graph obtained (Figure XIV.9), it is observed that the different classes of algae are perfectly grouped depending on the type of pigments that these have. Diatoms are a group very different from the rest, as well as cryptophyceae and dinophyceae algae.
\tabular{c}{
\strong{Figure XIV.9.} Hierarchical classification of species of phytoplankton\cr
from its pigment composition.\cr
\figure{FXIV9}{options: width=3.5in}
}
}
\examples{
\dontrun{

data(ZXIV4)

XIV4(data = ZXIV4 , cat = "Species" , var = c("Chlorophyll.c2", "Chlorophyll.c1",
"Methyl.chlorophyllide.a", "Peridin", "Fucoxanthin", "cis.neoxanthin",
"Violaxanthin", "Diadinoxanthin", "Dinoxanthin", "Alloxanthin", "Zeaxanthin",
"Lutein", "Chlorophyll.b", "Chl.b.epir", "Chlorophyll.a.alllomer",
"Chlorophyll.a.epimer", "beta.u.carotene", "beta.e.carotene", "beta.beta.carotene"),
PLOT1 = c("main='Pigments in algae'", "sub=''", "xlab=''", "ylab='Hight'"))

}
}
\keyword{XIV4}
