\name{XIV5}
\alias{XIV5}
\encoding{latin1}
\title{HEAT MAP}
\description{A heat map is applied.} 
\usage{
XIV5(data, cat, var, ResetPAR=TRUE, PAR=NULL, HEATMAP=NULL, mean=TRUE,
LEGEND=NULL, AXIS=NULL, MTEXT= NULL, TEXT=NULL)
}
\arguments{
  \item{data}{Data file.}
  \item{cat}{Case categories.}
  \item{var}{Variables that are included in the analysis.}
   \item{ResetPAR}{If it is FALSE, the default condition of the function \link{PAR} is placed and maintained those defined by the user on previous graph.}
  \item{PAR}{It accesses the function \link{PAR} that allows to modify many different aspects of the graph.}
  \item{HEATMAP}{It accesses the function \link[stats]{heatmap} of the stats package.}
  \item{mean}{If TRUE, the heat map is performed using the average value of each of the groups of the variable \emph{cat}, instead of using all cases.}
  \item{LEGEND}{It allows to include a legend.}
  \item{AXIS}{It allows to add axes.}
  \item{MTEXT}{It allows to add text in the margins of the graph.}
  \item{TEXT}{It allows to add text in any place of the inner part of the graph.}
 }
\value{A heap map graph is obtained.}
\details{
\strong{XIV. MULTIVARIATE ANALYSIS OF CLASSIFICATION}

\strong{XIV.5. HEAT MAP}

The heat map shows, with different colors and tones, the intensity of the relationship between the groups defined by the user. This applied to an array of data, with cases and variables (rows and columns), sorts both simultaneously developing a marginal dendrogram for the rows and another for the columns, jointly sorted. The colors indicate the intensity of the relationship or the values of the variable represented, from white (maximum ratio or highest value), passing by the yellow and orange to deep red (minimum value), although these colors by default can be freely modified by the user.

\strong{FUNCTIONS}

The function \link[stats]{heatmap} of the stats package is used.

\strong{EXAMPLE}

Morphometric data from various species of the order Characiformes, such as the length of the base of the dorsal fin (M12), height of the body (M11), and so on. For more details see Guisande et al. (2010). The objective is to determine which are the variables that best differentiate among genera.

In the script, the argument \emph{margin} is a vector with 2 numbers that specify the margins left for the rows and columns.
\tabular{c}{
\strong{Figure XIV.10.} Heat map of the morphometric variables that\cr
best differentiate among genera of the Order Charciformes.\cr
\cr
\figure{FXIV10}
}
In a heat map variables that have the same hue, that is to say, that are of the same color throughout the gradient, they are the least affecting the classification. On the morphology of the fish, the variables that less influence in the classification are the group of variables on the left, of the M3 to M5, which form a distinct group in the dendrogram of the top (columns). This group of variables contribute less to distinguish the genus of fish, since they all have almost the same shade and, therefore, form a single rectangle, almost in its entirety of red color, on the left side of the graph. The group of variables of the M21 to M19 allow greater discrimination than the old ones, because they have a greater variety of wholes. The variable M7 and M6 also contribute to differentiate the genera, and the fact that are differentiated in a separate block seems to indicate that discriminate well to any particular genus. There are also differences among genera, in the group of variables on the right, of the M10 to the M11.
}
\references{
Guisande, C., Manjarrs-Hernndez, A., Pelayo-Villamil, P., Granado-Lorencio, C., Riveiro, I., Acua, A., Prieto-Piraquive, E., Janeiro, E., Matas, J.M., Patti, C., Patti, B., Mazzola, S., Jimnez, S., Duque, V. & Salmern, F. (2010) IPez: An expert system for the taxonomic identification of fishes based on machine learning techniques. \emph{Fisheries Research}, 102, 240-247.
}
\examples{
\dontrun{

data(ZX3)

XIV5(data=ZX3,  cat="Genus", var=c("M2", "M3", "M4", "M5", "M6", "M7" ,"M10",
"M11", "M12" ,"M13", "M14", "M15", "M16", "M17", "M19", "M20", "M21", "M23",
"M24", "M25", "M26", "M27", "M28"), HEATMAP=c("margins=c(5,10)",
"xlab ='MORPHOMETRIC VARIABLES'", "ylab= 'GENERA'", "main = 'Morphometry of characiformes'"))

}
}
\keyword{XIV5}
