\name{XV1}
\alias{XV1}
\encoding{latin1}
\title{ARIMA MODEL}
\description{Manual and automated ARIMA models are applied.}
\usage{
XV1(data, varY, varX=NULL, frequency, start, order=NULL, seasonal=NULL,
ResetPAR=TRUE, PAR=NULL, TS=NULL, PLOTFORECAST1=NULL, PLOTFORECAST2=NULL,
TSDISPLAY=NULL, NDIFFS=NULL, ARIMA=NULL, AUTOARIMA=NULL, FORECAST=NULL,
LINES=NULL, SEASONPLOT=NULL, file="Output.txt")
}
\arguments{
  \item{data}{Data file.}
  \item{varY}{Dependent variable.}
  \item{varX}{Independent variables.}
  \item{frequency}{Number of observations per unit of time.}
  \item{start}{The date of the first observation. It can be a single number or a vector of two integers, specifying a natural time unit.}
  \item{order}{Non-seasonal component of the model. Vector with three numbers (\emph{p}, \emph{d}, \emph{q}) that correspond to the auto regressive component (\emph{p}), integration component (\emph{d}), and moving average component (\emph{q}).}
  \item{seasonal}{Seasonal component of the model. Vector with three numbers (\emph{p}, \emph{d}, \emph{q}) that correspond to the auto regressive component (\emph{p}), integration component (\emph{d}), and moving average component (\emph{q}).}
  \item{ResetPAR}{If it is FALSE, the default condition of the function \link{PAR} are not placed and those defined by the user on previous graphics are maintained.}
  \item{PAR}{It accesses the function \link{PAR} that allows to modify many different aspects of the graph.}
  \item{TS}{It accesses the function \link[stats]{ts} that allows to modify the parameters of the time series.}
  \item{PLOTFORECAST1}{It accesses the function \link[forecast]{plot.forecast} that allows to modify the graphs of the variables over time.}
  \item{PLOTFORECAST2}{It accesses the function \link[forecast]{plot.forecast} that allows to modify the forecasting graph.}
  \item{TSDISPLAY}{It accesses the function \link[forecast]{tsdisplay} which allows to modify the residual plot and the graphs of the simple autocorrelation function (\emph{ACF}) and partial correlation coefficient (\emph{ACF} partial or \emph{PACF}).}
  \item{NDIFFS}{It accesses the function \link[forecast]{ndiffs} that calculates whether the series is stationary or non-stationary.}
  \item{ARIMA}{It accesses the function \link[forecast]{Arima} that estimated the manual ARIMA model.}
  \item{AUTOARIMA}{It accesses the function \link[forecast]{auto.arima} that estimates the automated ARIMA model.}
  \item{FORECAST}{It accesses the function \link[forecast]{forecast} that performs the predictions of the model.}
  \item{LINES}{It accesses the function \link[graphics]{lines} that allows to modify lines from graph lines used to make predictions.}
  \item{SEASONPLOT}{It accesses the function \link[forecast]{seasonplot} representing the seasonal chart.}
  \item{file}{TXT FILE. Name of the output file with the results of the analysis.}
}
\value{The following graphs are displayed: 1) changes in variables over time (only if independent variables are included), 2) residuals, the simple autocorrelation function (\emph{ACF}) and the partial correlation coefficient (\emph{PACF}), 3) the model predictions, 4) Ljung-Box  test for each delay of the model, 5) the seasonal chart and 6) the graph seasonally adjusted, the last two are displayed if the argument \emph{frequency} is greater than 1.}
\details{
\strong{XV1. TIME SERIES}

A time series is a set of observations from a variable taken over regular intervals of time, such as the number of cars sold by a manufacturer each month during the last ten years. The time series appear in virtually all fields of activity. The interest of its statistical analysis lies in the study of the behavior of the series, which helps explain their variations and, above all, the possibility to predict future values.

The fundamental principle that underlies the analysis of time series is that the current values (and future) of the series depend to a certain extent on the values that has taken in the past, so that we might consider that the series has a certain amount of inertia that prevents -or recently probable - overly abrupt changes in short periods of time. That inertia can be used for prediction, admitting that in the future will behave in a similar way as it did in the past. The success in the analysis and prediction of future values will depend largely on the availability of a wide and reliable sample, and the regularity of the series. Unfortunately, many series are dynamic or changing, and do not behave in accordance with rigid formulas, so that the statistical model used is merely an approximation more or less reasonable to the true operation of the series. In such cases the predictions should be done only in the short term, and with a limited degree of reliability.

In a time series the most frequent studies that often are made are the creation of a model and the analysis of the cycles. For more details on time series see Guisande et al. (2011).

\strong{XV1.1. ARIMA MODEL}

There are many statistical models applied to the time series, among which the ARIMA model stands out for its power and effectiveness (Box & Jenkins, 1976).

At the time of making a model one must take into account the following analysis: the autocorrelation, if the series grows, decreases or is stationary, seasonality, and, finally, see if there are variables which may be related to the dependent variable.

\strong{XV1.1.1. Autocorrelation}

To know more about the series it is useful to study the correlation or association between the values of the series in each period and the values in the previous periods, i.e., the relationship between the series and itself (autocorrelation) moved one or more periods.

The simple autocorrelation function (ACF) tends to be typically used, which shows the set of coefficients of autocorrelation, and indicates to what extent the variable depends on itself.

\strong{XV1.1.2. Stationary and non-stationary series}

The ARIMA model assumes as a precondition, that the series is stationary, i.e., that the behavior remains unchanged in the long term, because the whole approach of this methodology is based on the fact that trends in the future will be similar to that which has been in the past (inertia of the series). In particular, it must be verified that its average value remains stable (no trend increasing or decreasing) and its variability is also stable, does not change (no increases or decreases). If these conditions are not met, it is necessary to make any type of transformation of the variable, usually simple, leading to a stationary series. If there is no appropriate transformation, the ARIMA model should not be applied.

Dickey & Fuller (1979) developed a procedure for testing whether a variable has a unit root or, equivalently, that the variable follows a random walk. There is an extension of the Dickey-Fuller test called the augmented Dickey-Fuller test (ADF), which removes all the structural effects (autocorrelation) in the time series. This test was also used to determine whether the series is stationary.

\strong{XV1.1.3. Seasonality}

The time series, can be seasonal or non-seasonal. Many time series contain seasonal variations, or behavior patterns that are repeated on a regular basis: The number of tourists is consistently higher in summer than in winter, the volume of purchases in a few department stores is highest during the first few days of each month, the number of cars that pass by a street is greater between the 19h and 21h in the range 22h-24h. Therefore, the seasonal component is defined as those movements of the series that are repeated on a regular basis, being the periodicity lower than a year. Seasonality can be related to different periods of time (months, days, hours, etc. ), and in some cases it is extremely regular. To detect patterns of seasonality is very useful to graphically represent the series.

The ARIMA models allow you to include a seasonal component, that can be used for forecasting purposes, and which has the same structure (\emph{p}, \emph{d}, \emph{q}) as the non-seasonal part. These components (\emph{p}, \emph{d}, \emph{q}) are explained later, when considering the construction of the ARIMA model.

In those time series in which there is seasonality, it is necessary to correct this effect for a better interpretation of the model, and is resorted to the seasonally or seasonal correction. To perform this operation is necessary to isolate in the first place the seasonal component, which will enable its subsequent elimination.

\strong{XV1.1.4. Covariates}

In addition, it is possible to include other explanatory variables or covariates in the model that supposedly have a causal relationship with the dependent variable, or at least are closely related to it.

Thus, in addition to identifying possible variables that influence our time series, if the relationship between these covariates and our dependent variable is significant, it should  be expected to improve the model, i.e., to be more predictive.

\strong{XV1.1.5. Model building}

In the ARIMA models series values are obtained through a combination of three components (\emph{AR}, \emph{I}, \emph{MA}) or also called (\emph{p}, \emph{d}, \emph{q}):

1) Auto Regressive Component (\emph{p}). This shows the part of the value of the variable that depends on the values above, in the history of the series. This is obtained by a linear regression model in which the dependent variable is the component \emph{AR} of the current period, and the explanatory or independent variable the value immediately preceding or a certain number \emph{p} from previous values of the same series. For example, the value AR of the month of June depends on the value of the series in the month of May (\emph{p} = 1), or of the values of March, April and May (\emph{p} = 3). The value of \emph{p}, the order of auto regression, must be specified for each application.

2) Integration component (\emph{d}). A series is stationary if its media, its variability, and its structure of correlations do not change with time. If the series is not stationary, but that has an increasing or decreasing global behavior, there is an integration component that must be determined in the first place. The elimination of this component allows to consider the series as stationary, and subsequently it must be integrated through a reverse process to its elimination. For the calculation of the integration component differences between consecutive values of the series are obtained, by repeating this procedure on the differences obtained the necessary number of times \emph{d} (order of integration) to achieve a stationary series.

3) Component of moving average (\emph{q}). In general the series do not behave in the same way in relation to the model, but there is a residual element, that explains the differences between the observed value in each period and the value obtained by the auto regressive model. This element represents the innovation in the series, the part that does not respond to the inertia or the previous historical behavior, but that is new in each period. Analyzing the series we can determine these residuals or terms of innovation in the time periods already elapsed. The component MA of each period is obtained as an average of a certain number \emph{q} of these residuals in previous periods, and \emph{q} the order of moving averages.

In general, the values of \emph{p}, \emph{d} and \emph{q} are small (zero or one). The higher values of these parameters of the model allow a better fit to the data of the sample, but these can also produce an effect of overfitting in the model by introducing specific aspects of the available sample, not representative of the population from which they were obtained but specific to the sample so that the model can be very suitable for the sample, but inappropriate for the population from which it comes. In general, a simple model, that it may be more suitable for the purposes of prediction, is preferred, especially if the sample is not very large, or if the series is not very stationary in their behavior but slightly changing.

\strong{FUNCTIONS}

The time series is performed with the function \link[stats]{ts} of the base package stats. The manual ARIMA model with the function \link[forecast]{Arima} and the automated ARIMA model is estimated with the function \link[forecast]{auto.arima}. The graph, representing the variables in the time, it is performed with the function \link[forecast]{plot.forecast}, to represent the simple autocorrelation function (\emph{ACF}) and the partial correlation coefficient (\emph{partial ACF} or \emph{PACF}) the function \link[forecast]{tsdisplay} is used. To calculate if the series is stationary or non-stationary, the function \link[forecast]{ndiffs} is used. The predictions of the model are estimated using the function \link[forecast]{forecast} and the seasonal chart is performed with the function \link[forecast]{seasonplot}, all of them from the forecast package (Hyndman et al., 2018). The lines on the chart of predictions are carried out with the function \link[graphics]{lines} of the base package graphics. The Box-Ljung test is performed with the function \link[stats]{Box.test} and the normality of residuals is analyzed with the function \link[stats]{shapiro.test}, both of the base package stats. The function \link[nortest]{lillie.test} of the package nortest (Gross, 2013) is also used to perform the Kolmogorov-Smirnov Normality test with the correction of Lilliefors to the residuals. The augmented Dickey-Fuller test was performed with the function \link[tseries]{adf.test} of package tseries (Trapletti & Hornik 2017).

\strong{EXAMPLE}

The monthly condition factor (\emph{FC}) of the anchovy (\emph{Engraulis encrasicolus}) over several years is an indicator of the reproductive status of individuals. The objective is to determine the effect of the average monthly values of temperature (in degree C), chlorophyll (in \eqn{mg m^{-3}}) and stability of the water column (in \eqn{m^ {3}s^{-3}}) on the reproductive status of this species in the Strait of Sicily (Basilone et al., 2006). As a \emph{FC} and the rest of variables can covariate over time, it is necessary to quantify the possible effect of time on \emph{FC}, in other words, to enter the potential effect of time on \emph{FC} in the model, to be able to determine the actual effect of the variables listed above on \emph{FC}. Therefore, it is first always useful to analyze the temporal evolution of the series, in this case of \emph{FC}, without taking into account the effect of the independent variables.

It is important to mention that it is not necessary to have complete series, because it makes an estimate of the missing data. However, it is necessary that this row indicates the date to which it corresponds. For example, if the data, in January  1998, is missing, it is necessary to display the row indicating that it is January 1998, and then leaving blank missing columns.

\strong{AUTOMATED ARIMA MODEL WITHOUT INDEPENDENT VARIABLES}

To be the monthly sampling, in the script in the argument \emph{frequency= 12} the year is considered as a unit of time. The argument \emph{start=c(1997,10)} because the first sampling was in October of 1997. When you do not specify anything in the arguments \emph{order} and \emph{seasonal}, which are the default condition, then the automated ARIMA model, i.e., an ARIMA model is built using an expert modeler.

\strong{Autocorrelation}

There is a clear annual seasonality (Figure XV1.1), since all
years the same pattern is repeated, with low values of \emph{FC} in winter and higher in summer. On the other hand, the series as a whole seems not to show a trend (is horizontal), or cycle.
\cr
\tabular{c}{
\strong{Figure XV1.1.} Temporary representation of the  condition factor\cr
of the anchovy, and values of ACF and ACFP.\cr
\figure{FXV1}{options: width=3.1in}
}
The role of simple autocorrelation (\emph{ACF}), which is shown in Figure XV1.1, shows a set of coefficients of autocorrelation, and indicates the extent to which the variable depends on it. When the value of the series \eqn{Y_t} strongly depends on the previous value \eqn{Y_t-1} there is a high correlation coefficient \eqn{A_1} between the series and the same series displaced a period, but given that \eqn{Y_t-1} in turn, depends on the previous value to the \eqn{Y_t-2}, also the correlation coefficient will be high along with the series shifted two periods, \eqn{R_2}, and so on. The graph shows coefficients that diminish gradually. In this function, it is represented the coefficient corresponding to zero delay, which always worth one (it should not be interpreted, only serves as a reference for comparison).

It is possible that a part of such dependence measures the simple correlation coefficient can be indirect, through the intermediate values, so that only the values closest to the current one should be considered (perhaps one or two only).  Therefore, the partial correlation coefficient (\emph{partial ACF} or \emph{PACF}) is more appropriate to analyze these relationships of dependence than the simple correlation coefficient, since by eliminating the influence of the remaining variables (intermediate values) this isolates the effect of each delay on the present value of the series, and allows to study the correlation between the series and the same series delayed without including the indirect effects.

In the partial autocorrelation function (Figure XV1.1) we see that only the first two are significant, and the first has a high value. With these results, an appropriate model could have \emph{p} = 1 or \emph{p} = 2 and \emph{q} = 0.

\strong{Stationary or non-stationary series}

The results show that the series has a value \emph{d = 0}, therefore, the series is stationary. If the series was not stationary then it would be sufficient to put the value of \emph{d} recommended in the ARIMA model, since what the ARIMA model does is differentiate the series \emph{d} times, with what the series becomes stationary, and once the model is applied the resulting series integrates \emph{d} times to undo the change.

The result of the augmented Dickey-Fuller test (ADF) corroborates that the series is stationary, because the probability is 0.99, so null hypothesis that the time series is stationary is accepted.
\tabular{c}{
\figure{RXV7}{options: width=2.9in}
}
\strong{Construction of the automated ARIMA model}

The function has a procedure that finds the most suitable model between the different values of the parameters \emph{p}, \emph{q}, and \emph{d}, for both the regular part as to the seasonal one. This uses the algorithm of Hyndman & Khandakar (2008), that choose the parameters by minimizing the \emph{AIC}, and the values of \emph{d} and \emph{D} through the unit root test. A step-by-step approach that allows to limit the search field, reducing the effort of calculation and the total time needed (in any case, the process may take several minutes). In the example this method finds and adjusts an ARIMA model (0,0,1) (1,1,0), which is considered as optimal.
\tabular{c}{
\figure{RXV1}{options: width=2.9in}
}
\strong{Prediction of future values}

This function calculates the predictions for the number of periods \emph{h} desired, which can be changed by accessing the function \link[forecast]{forecast} with the argument \emph{FORECAST} and by changing the value of \emph{h}.  These predictions are shown in figure XV1.2 with confidence intervals. Confidence bands can be colored by specifying \emph{shaded=TRUE} argument within the \emph{FORECAST}, or simply drawing lines. The argument \emph{LINES} allows to modify the adjusted values, or model predictions for all observed periods.
\tabular{c}{
\strong{Figure XV1.2.} Predictions of the ARIMA model.\cr
\figure{FXV2}{options: width=2.1in}
}
\strong{Model diagnostics}

It is advisable to check that the chosen model is complete and new elements should not be added. For this, the analysis of residuals is started with a graph (Figure XV1.3). There, it is possible to check how the residuals seem to behave randomly, without predictable sequences or a structure of autocorrelations, that is to say, in accordance with the model referenced above as "white noise". The \emph{graph} ACF should not show significant autocorrelations (remembering that the first, always equal to 1, is not taken into account), as in this example.

Noting the \emph{p}-values corresponding to the Ljung-boxs test, the assumption that autocorrelations estimated with zero mean and variance \eqn{\frac{1}{n}} are normal, is not rejected for all the delays. All or almost all of the \emph{p} values must be above the dotted blue line of 5\%, as in this example. Therefore, it seems reasonable to conclude that residuals behave like white noise, and the model is adequate. 
\tabular{c}{
\strong{Figure XV1.3.} Residual graphs, \emph{FAS} of residuals,and \emph{p}\cr
values of the Ljung-Box test for every delay of the automated ARIMA model.\cr
\figure{FXV3}{options: width=4.5in}
}
The Box-Ljung test, as shown below, performs a test set to contrast the null hypothesis that it is white noise. The p-value = 0.305 higher than the usual significance level of 0.05 indicates that you can accept that this is white noise and, therefore, the residuals do not retain a structure that must be explained by a more complex model.
\tabular{c}{
\figure{RXV2}{options: width=3.4in}
}
It is also possible to check the normal distribution of the residuals, applying the Shapiro-Wilk test and the Kolmogorov-Smirnov with the correction of Lilliefors to residuals. The residuals do not have a Normal distribution, since both the Shapiro-Wilk test as in the Kolmogorov-Smirnov p < 0.05 .
\tabular{c}{
\figure{RXV3}{options: width=3.4in}
}
\strong{Deseasonalization}

In series with marked seasonality, such as this example, it is difficult to appreciate the variations hidden or masked behind the seasonality and, therefore, to find out the changes that occur. For this reason, seasonal variations can be analyzed in more detail and seasonality of the series eliminated to study the rest.
\tabular{c}{
\strong{Figure XV1.4.} Monthly values of seasonality in the series.\cr
\figure{FXV4}{options: width=2.4in}
}
Figure XV1.4 shows the values of monthly seasonality. As can be clearly seen, highly seasonal values are those corresponding to the month of August and next to this month, and the low seasonality occurs from November to February, all of them at similar levels.

Figure XV1.5 shows the seasonally adjusted series, where changes in the series discounting the effect of seasonality can be observed.
\tabular{c}{
\strong{Figure XV1.5.} Seasonally adjusted series.\cr
\figure{FXV5}{options: width=5.3in}
}
\strong{MANUAL ARIMA MODEL WITHOUT INDEPENDENT VARIABLES}

Instead of using the Expert Modeler, -from autocorrelation plots or knowledge of the series- a particular model can be determined, especially in this case that the normality of residuals is not complied.

This requires defining the arguments \emph{order} (non-seasonal component of the model) and \emph{seasonal} (seasonal component of the model). Both arguments are a vector with three numbers (\emph{p}, \emph{d}, \emph{q}) that correspond to the auto regressive component (\emph{p}), integration component (\emph{d}), and moving average component (\emph{q}).

The automated ARIMA model selected (0,0,1) parameters for non-seasonal component and (1,1,0) for the seasonal component. In the manual model we chose the following parameters: \emph{order=c(0,0,1)} and \emph{seasonal=c(2,1,0)}. That is to say, the only change is that the value of \emph{p} was changed in the seasonal component, which was 1 to a value of 2. Therefore, we believe that the autocorrelation occurs not only with the previous month, but a month is also correlated with the value of two months ago.

It makes no sense to change the integration component (\emph{d})  in the manual model, since the series was stationary and, therefore, the value zero is the most appropriate.

It would be possible to make tests and also change the component \emph{q}, if it is considered that there is innovation in the series, that is to say, that there are a few changes that do not respond to the inertia or the previous historical behavior, but that are new in each period. As already explained in the introduction, it is always a good idea that the model be as simple as possible, i.e., that the values of \emph{p}, \emph{d} and \emph{q} be smaller

The autocorrelation and if the series is stationary or non-stationary are the same results that were automated with the model.

To see if this model is better than that obtained with the expert system, the estimated variance of residuals \emph{sigma^2 estimated} should be small, and the value of \emph{AIC} is best smaller (or more negative). In the case of the automated model the lowest AIC value was -381.8. In the results shown below of the manual model is noted that the value of \emph{AIC} is -380.1. Therefore, the model obtained by the manual system is the best.
\tabular{c}{
\figure{RXV4}{options: width=5.3in}
}
\strong{Model Diagnostics}

As before, it is necessary to check that the chosen model is complete and new elements should not be added. To do this, the analysis of residuals with a graph (figure XV1.6) starts again.

There, it is possible to check how the residuals seem to behave randomly, without predictable sequences or a structure of autocorrelations, that is to say, in accordance with the model referenced above as "white noise".  The graph \emph{ACF} should not show significant autocorrelations (remembering that the first, always equal to 1, is not taken into account), as in this example.

Noting the \emph{p} -values corresponding to the Ljung-boxs test, the assumption that autocorrelations estimated with zero mean and variance \eqn{\frac{1}{n}} are normal is not rejected for all the delays. All or almost all of the \emph{p} values must be above the dotted blue line of 5\%, as in this example.
\tabular{c}{
\cr
\strong{Figure XV1.6.} Residual graphs, \emph{FAS} of residuals, and \emph{p}\cr
values of the Ljung-Box test for every delay of the manual ARIMA model.\cr
\figure{FXV6}{options: width=5.5in}
}
The Box-Ljung test, as shown below, performs a test set to contrast the null hypothesis that it is white noise. The p-value = 0.344 higher than the usual significance level of 0.05 indicates that there may be accepted that this is white noise and, therefore, the residuals do not retain a structure that must be explained by a more complex model.

Unlike the automated model, in this case the residuals have a Normal distribution, since both the Shapiro-Wilk test as in the Kolmogorov-Smirnov p > 0.05.
\tabular{c}{
\figure{RXV5}{options: width=5.3in}
}
\strong{ARIMA MANUAL MODEL WITH INDEPENDENT VARIABLES}

Once our time series has already been analyzed, you can now determine the effect of variables on it. In our example, the objective was to determine the effect of the average monthly values of temperature, chlorophyll, and stability of the water column on the \emph{FC} of the anchovy.

To include independent variables in the model, simply specify them in the argument \emph{varY}.  These variables can be included in both the automated model as in the manual. Since the manual model was a bit better than the automated, the example will be made including the independent variables with the manual model.

When independent variables are included in the model, a graph it comes out as a result of those shown above (Figure XV1.7), which shows the temporal evolution of the series (condition factor of the anchovy, \emph{FC}) and also of the independent variables (chlorophyll, temperature and stability).
\tabular{c}{
\strong{Figure XV1.7.} Temporary representation of the condition factor of the\cr
anchovy, stability, temperature, and chlorophyll, in the Strait of Sicily.\cr 
\figure{FXV7}{options: width=5in}
}
The value of AIC with the covariates is -376.5 , while without them was (-380.1). The difference is so small that it can be stated that the covariates do not add useful information and, therefore, the \emph{FC} of the anchovy does not depend on the temperature, chlorophyll, and stability in the water column. 
\tabular{c}{
\figure{RXV6}{options: width=4.5in}
}
}
\references{
Basilone, G., Guisande, C., Patti, B., Mazzola, S., Cuttitta, A., Bonanno, A., Vergara, A.R. & Maneiro, I. (2006) Effect of habitat conditions on reproduction of the European anchovy (\emph{Engraulis encrasicolus}) in the Strait of Sicily. \emph{Fisheries Oceanography}, 15: 271-280.

Box, G.E.P. & Jenkins, J.M. (1976) \emph{Time series analysis: Forecasting and control}. Holden-Day,San Francisco, CA.

Dickey, D.A. & Fuller, W.A. (1979) Distribution of the estimators for autoregressive time series with a unit root. \emph{Journal of the American Statistical Association}, 74, 427-431. 

Gross, J. (2013) Tests for Normality. R package version 1.0-2. Available at: \url{http://CRAN.R-project.org/package=nortest}.

Guisande, C., Vaamonde, A. & Barreiro, A. (2011) \emph{Tratamiento de datos con R, STATISTICA y SPSS}. Ediciones Daz de Santos, Madrid, 978 pp.

Hyndman, R.J. & Khandakar, Y. (2008) Automatic Time Series Forecasting: The forecast Package for R. \emph{Journal of Statistical Software}, 27: 1-22.

Hyndman, R.J., Athanasopoulos, G.,Razbash, S., Schmidt, D., Zhou, Z., Khan, Y., Bergmeir, C. & Wang, E. (2018) Forecasting functions for time series and linear models. R package version 8.3. Available at: \url{http://CRAN.R-project.org/package=forecast}.

Trapletti, A & Hornik, K. (2017) tseries: Time Series Analysis and Computational Finance. R package version 0.10-38. Available at: \url{https://CRAN.R-project.org/package=tseries}.
}
\examples{
\dontrun{

data(ZXV1)

#Automated Arima Model without independent variables

XV1(data=ZXV1, varY="FC", frequency=12, start=c(1997,10))

#ARIMA manual model without independent variables 

XV1(data=ZXV1, varY="FC", frequency=12, start=c(1997,10), order=c(2,0,0),
seasonal=c(2,0,0))

#ARIMA manual model with independent variables

XV1(data=ZXV1, varY="FC", frequency=12, start=c(1997,10), varX=c("Chlorophyll",
"Temperature", "Stability"), order=c(2,0,0), seasonal=c(2,0,0))
}
}
\keyword{XV1}
