\name{XV2}
\alias{XV2}
\encoding{latin1}
\title{CYCLES}
\description{Identification of cycles and analysis of the relationship between cycles.}
\usage{
XV2(data, varY, varX=NULL, frequency, start, ResetPAR=TRUE, PAR=NULL,
TS=NULL, PLOTSERIE=NULL, SPECPGRAM=NULL, SPECAR=NULL, COHERENCE=NULL,
SPECTRUM=NULL, PLOTSPECTRUM=NULL, file="Output.txt")
}
\arguments{
  \item{data}{Data file.}
  \item{varY}{Dependent variable.}
  \item{varX}{Independent variable.}
  \item{frequency}{Number of observations per unit of time.}
  \item{start}{The date of the first observation. It can either be a single number or a vector of two integers, specifying a natural unit of time.}
  \item{ResetPAR}{If it is FALSE, the default condition of the function \link{PAR} are not placed and those defined by the user on previous graphics are maintained.}
  \item{PAR}{It accesses the function \link{PAR} which allows to modify many different aspects of the graph.}
  \item{TS}{It accesses the function \link[stats]{ts} that allows to modify the parameters of the time series.}
  \item{PLOTSERIE}{It accesses the function that allows to modify the first graph with the time series.}
  \item{SPECPGRAM}{It accesses the function \link[stats]{spec.pgram} which allows to modify the periodogram of the dependent variable.}
  \item{SPECAR}{It accesses the function \link[stats]{spec.ar} that allows to modify the density plot of the dependent variable.}
  \item{COHERENCE}{It accesses the function \link[seewave]{coh} which allows to modify the graph of coherence between the dependent and independent variable.}
  \item{SPECTRUM}{It accesses the function \link[stats]{spectrum} which calculates the time-lag between the dependent and independent variable.}
  \item{PLOTSPECTRUM}{It accesses the function which allows to modify the graph that shows the lag between the dependent variable and the independent.}
  \item{file}{TXT FILE. Output file name with the results of the analysis of the cycles.}
}
\value{The following graphs are represented: 1) changes in variables over time, 2) periodogram of the dependent variable, 3) spectral density plot of the dependent variable, 4) graphic coherence between the dependent and independent variable and 5) diagram phase between the dependent and independent variable. The last two graphs are displayed if there is an independent variable.}
\details{
\strong{XV1. TIME SERIES}

\strong{XV1.2 CYCLES}

The cycle is a common component in the time series (Guisande et al., 2011). Its typical form is sinusoidal, with a phase of growth to reach the maximum value, followed by a declining phase until reaching its minimum value, repeating this scheme indefinitely. Unlike the seasonal variations, it is not always regular, and the length of the different stages is often changing, which makes it difficult to perform its analysis. This is present in virtually all economic series, without knowing the reasons for its occurrence or the root causes of the existence of cycles.

Spectral analysis is a statistical procedure that can be used to identify periodic behavior in a time series, and to study the existence of cycles or regular variations whose length (period) is usually higher than a year. The process breaks down the set of all observations on the series in recurring (components) elements of different frequencies, and allows to identify the most relevant ones. It is particularly useful for detecting complex cyclical structures, i.e., when there are several cycles of different overlapping cycles, since when there is a single cyclical pattern, a graphical representation (sequential chart) may be sufficient to identify this.

\strong{FUNCTIONS}

The time series is performed with the function \link[stats]{ts}, the function \link[stats]{spec.pgram} is used to obtain the periodogram of the dependent variable, the function \link[stats]{spec.ar} is used to represent the graph of density of the dependent variable and the time lag between the dependent variable and the independent is obtained with the function \link[stats]{spectrum}, all of them from the base package stats.

The graph of consistency between the dependent and independent variable is performed with the function \link[seewave]{coh} of the package seewave (Sueur et al., 2014).

The estimation of missing values is performed with the function \link[zoo]{na.approx} of the zoo package (Zeileis et al., 2014).

\strong{EXAMPLE}

The angle between the sun and the moon is one of the main causes of the changes that occur in the tides. When the sun and moon are aligned, i.e., the angle is 0 (full and new moon), differences in height between high and low tides are highest. By contrast, when the sun and moon are at an angle of 90 (crescent and gibbous) differences in height between high and low tide are minimal.

The data used are the angles between the sun and moon day, and the difference in meters between daily high and low tide, for 428 North and 141 West from 1/1/2004 to 14/3/2004.

The first objective is to determine the tidal cycle. The second objective is to demonstrate the effect of the angle between the sun and moon on the tides.

The function estimates the missing values, if any, but it is necessary that the row with the date exists. In this example there is a missing date, specifically on 3/1/2004.

Figure XV2.1 shows a clear cyclical variation in both time series, with 5 oscillations in a period of 74 days, which corresponds to a period of approximately 15 days.

We can delve into a spectral analysis, which looks at the behavior or the response of the series to each different frequency. In the periodogram shown in the Figure XV2.2, it can be clearly observed a peak that stands out over the rest of values. This indicates the maximum frequency of the cycle that we have previously observed in the graph of sequence. If there were more overlapping cycles, we would find other peaks in the spectrogram showing the frequencies associated with them.
\tabular{c}{
\strong{Figure XV2.1.} Temporal evolution of the angle between the sun and the moon,\cr
and the difference between high and low tide.\cr
\figure{FXV8}{options: width=3.7in}
}
\tabular{c}{
\strong{Figure XV2.2.} Periodogram of the time series of the difference between high and low tide.\cr
\figure{FXV9}{options: width=3.7in}
}
The previous periodogram can be represented by the spectral density plot (Figure XV2.3), which is simply a smoothed version of the periodogram, eliminated by filtering the noise formed by the random variations, or generally any high frequency variation. The effect of smoothing the data allows to see more clearly the peak observed in the periodogram.
\tabular{c}{
\strong{Figure XV2.3.} Spectral density plot.\cr
\figure{FXV10}{options: width=4.2in}
}
The results show that using the first graph (\emph{Raw periodogram}) the period is 15 days, whereas the second graph (\emph{spectral density}) is 14.89 days. It may be more convenient to use the first graph when many missing values in the series, i.e., the periodogram.

The second objective is to find out if the difference between high tide and low tide is related to the angle between the sun and the moon. For that reason, we must build the cross-spectrum for both variables. The cross spectrum usually is interpreted on the basis of some processed variables. One of the most important is the coherence square, represented in the diagram below, which takes values between 0 and 1. A value close to 0 indicates that both variables are not related, and close to 1 indicates a near-linear relationship between the two. The horizontal scale shows the frequency in khz, since it is the most useful unit for the study of signals in the field of electronics in which this technique is usually applied. The values should be multiplied by a thousand to interpret them directly as a fraction of the time unit used.

As figure XV2.4 shows, there is a value close to 1 that stands out clearly, showing the frequency corresponding to a sharp cyclical relationship between two variables. The results show that a consistency of 14.4 days is obtained, which would be the cycle shared between the two time series.
\tabular{c}{
\strong{Figure XV2.4.} Graph of coherence between the angle that the sun\cr
the moon and the tidal cycle form.\cr
\figure{FXV11}{options: width=3.5in}
}
\tabular{c}{
\strong{Figure XV2.5.} Phase diagram of the angle between the sun\cr
and the moon, and the tidal cycle.\cr
\figure{FXV12}{options: width=3.5in}
}
Even with a cycle coincident in time duration for the two variables, it is possible that there is a lag or delay between the two. To find out, we build the phase diagram shown in Figure XV2.5. In the diagram there are irregular oscillations - random occurrence - about zero, with amplitude between -3 and 3 days, for the majority of the frequencies, but for the matching frequency that we have detected, below the frequency 0.1 , there are several values that seem to stabilize around -2.

The lag that is obtained (\emph{lag}) is 1.8, which means that the effect of the angle between the sun and the moon on the tides occurs with a delay of 1.8 days.}
\references{
Guisande, C., Vaamonde, A. & Barreiro, A. (2011) \emph{Tratamiento de datos con R, STATISTICA y SPSS}. Ediciones Daz de Santos, Madrid, 978 pp.

Sueur, J., Aubin, T., Simonis, C.,  Brown, E.C., Desjonqueres, C., Gasc, A., LaZerte, S., Lees, J., Lellouch, L., Pavoine, S., Villanueva-Rivera, L.J., Ross, Z. & Witthoft, C.G. (2014) Sound analysis and synthesis. R package version 1.7.6. Available at: \url{http://CRAN.R-project.org/package=seewave}.

Zeileis, A., Grothendieck, G., Ryan, J.A. & Andrews, F. (2014) Sound analysis and synthesis. R package version 1.7-11. Available at: \url{http://CRAN.R-project.org/package=zoo}.
}
\examples{
\dontrun{

data(ZXV2)

XV2(data=ZXV2, varY="Tidal.range", varX="Angle.Sun.Moon", frequency=30, start=c(1,1))
}
}
\keyword{XV2}
