\name{XV3}
\alias{XV3}
\encoding{latin1}
\title{PREDICTIVE POWER OF A BINOMIAL LOGISTIC REGRESSION}
\description{It allows to evaluate the predictive power of a binomial logistic regression.} 
\usage{
XV3(data, cat, var, resp, start=NULL, nsubsets=20, ResetPAR=TRUE, PAR=NULL,
PLOT=NULL, YLAB=NULL, XLAB=NULL, CEXPCH=1, COLABLINE="black", COLOR="black", PCH=15,
file1="Test.csv", file2="Coefficients.csv", na="NA", dec=",", row.names=FALSE)
}
\arguments{
  \item{data}{Data file.}
  \item{cat}{Dependent variable.}
  \item{var}{Independent variables.}
  \item{resp}{Category that will be the reference for the dependent variable.}
  \item{start}{Number of data randomly selected at the beginning.}
  \item{nsubsets}{Number of random subsets.}
  \item{ResetPAR}{If it is FALSE, the default condition of the function \link{PAR} is not placed and maintained those defined by the user in previous graphics.}
  \item{PAR}{It accesses the function \link{PAR} which allows to modify many different aspects of the graph.}
  \item{PLOT}{It accesses the function \link{plot.default} which allows to modify the graph of the regression.}
  \item{YLAB}{Legend of the axis Y.}
  \item{XLAB}{Legend of the axis X.}
  \item{CEXPCH}{Size of the graphic symbols.}
  \item{COLABLINE}{Color of the line of the regression model.}
  \item{COLOR}{Color symbols.}
  \item{PCH}{Type of symbol.}
  \item{file1}{CSV FILE. Filename with the percentage of cases correctly identified for each random subset.}
  \item{file2}{CSV FILE. Filename with the coefficients of the regression models.}
  \item{na}{CSV FILES. Text that is used in the cells without data.}
  \item{dec}{CSV FILES. It defines if the comma "," is used as decimal separator or the dot ".".}
  \item{row.names}{CSV FILES. Logical value that defines if identifiers are put in rows or a vector with a text for each of the rows.}
}
\value{A TXT file is obtained, which is called "Output.TXT" with the equations of the four accumulation regressions. A CSV file with the coefficients of the accumulation regressions. A graph with the four accumulation regressions relating the number of randomly selected data and the percentage of cases correctly identified. A CSV file is also obtained, which is called "Model predictions.CSV" with the predictions for each case, resulting from applying the logistic regression to the last random subsample. Finally, the replies window shows the percentage of cases correctly identified that each accumulation regression predicts in the asymptote.}

\details{Once a logistic regression model is obtained, which in principle using a series of qualitative and quantitative variables, it may be valid for predicting to what category a case belongs, the idea now is to be able to evaluate the predictive power of the model.

The algorithm consists of taking a number of random samples from the data set, elaborating the logistic regression model with this data and estimating the percentage of cases correctly identified considering the total data set.

Finally, we apply the four accumulation regressions described in the function \link[StatR]{XI2}, to relate the number of data chosen randomly in the subsample and the percentage of cases correctly identified.

A logistic regression would have a high predictive power, if a percentage of success close to 100\% is achieved using half of the data.

\strong{FUNCTIONS}

It uses the function \link[nortest]{lillie.test} of the package (Gross, 2013) to perform the test Kolmogorov-Smirnov normality with Lilliefors' correction and the function \link[stats]{nls} of the base package stats for the estimation of the models.

To estimate binomial logistic regression, the \link[stats]{glm} function of the package stats is used. To estimate the model by steps, the \link[MASS]{stepAIC} function of the package MASS (Venables & Ripley, 2002; Ripley et al., 2014) was used.

\strong{EXAMPLE}

The study was to examine patients who have been diagnosed with a type of cancer, as well as a sample of people who do not. The objective is to determine if variables such as gender, age, marital status (unmarried, married and separated) and presence/absence of blood in the urine, can be an indicator of the presence of cancer.

As samples are chosen randomly, each time the function is executed, the logistic regression models that are estimated can vary and, therefore, also the accumulation curves.

The graph shows that the best adjustments are given by the Rational, Clench and Saturation curves. When half of the data is used to construct the logistic regression model, the asymptote is already reached and the model predicts about 88\% of cases correctly. Therefore, the prediction power of the model has been clearly identified.
\tabular{clll}{
\figure{FXV13}{options: width=3.7in}
}
}
\references{
Gross, J. (2013) Tests for Normality. R package version 1.0-2. Available at: \url{http://CRAN.R-project.org/package=nortest}.

Ripley, B., Venables, B., Bates, D.M., Hornik, K., Gebhardt, A. & Firth, D. (2014) Support Functions and Datasets for Venables and Ripley's MASS. R package version 7.3-33. Available at: \url{http://CRAN.R-project.org/package=MASS}.

Venables, W.N. & Ripley, B.D. 2002. \emph{Modern Applied Statistics with S}. Springer, fourth edition, New York. \url{http://www.stats.ox.ac.uk/pub/MASS4}.
}
\examples{
\dontrun{

data(ZXI7)

XV3(data=ZXI7, cat="Cancer" , var=c("Age", "Gender", "Status", "Blood"),
gruporesp="Si", start=10)
}
}
\keyword{XV3}

