\name{XV4}
\alias{XV4}
\encoding{latin1}
\title{PREDICTIVE POWER OF A MULTINOMIAL LOGISTIC REGRESSION}
\description{It allows to evaluate the predictive power of a multinomial logistic regression.} 
\usage{
XV4(data, cat, var, start=NULL, nsubsets=20, ResetPAR=TRUE, PAR=NULL,
PLOT=NULL, YLAB=NULL, XLAB=NULL, CEXPCH=1, COLABLINE="black", COLOR="black", PCH=15,
file1="Test.csv", file2="Coefficients.csv", na="NA", dec=",", row.names=FALSE)
}
\arguments{
  \item{data}{Data file.}
  \item{cat}{Dependent variable.}
  \item{var}{Independent variables.}
  \item{start}{Number of data randomly selected at the beginning.}
  \item{nsubsets}{Number of random subsets.}
  \item{ResetPAR}{If it is FALSE, the default condition of the function \link{PAR} is not placed and maintained those defined by the user in previous graphics.}
  \item{PAR}{It accesses the function \link{PAR} which allows to modify many different aspects of the graph.}
  \item{PLOT}{It accesses the function \link{plot.default} which allows to modify the graph of the regression.}
  \item{YLAB}{Legend of the axis Y.}
  \item{XLAB}{Legend of the axis X.}
  \item{CEXPCH}{Size of the graphic symbols.}
  \item{COLABLINE}{Color of the line of the regression model.}
  \item{COLOR}{Colour symbols.}
  \item{PCH}{Type of symbol.}
  \item{file1}{CSV FILE. Filename with the percentage of cases correctly identified for each random subset.}
  \item{file2}{CSV FILE. Filename with the coefficients of the regression models.}
  \item{na}{CSV FILES. Text that is used in the cells without data.}
  \item{dec}{CSV FILES. It defines if the comma "," is used as decimal separator or the dot ".".}
  \item{row.names}{CSV FILES. Logical value that defines if identifiers are put in rows or a vector with a text for each of the rows.}
}
\value{
As mentioned in the same section of the function \link[StatR]{XV3}.
}
\details{
As mentioned in the same section of the function \link[StatR]{XV3}.

\strong{FUNCTIONS}

It uses the function \link[nortest]{lillie.test} of the package (Gross, 2013) to perform the test Kolmogorov-Smirnov normality with Lilliefors' correction and the function \link[stats]{nls} of the base package stats for the estimation of the models.

To estimate binomial logistic regression, the \link[stats]{glm} function of the package stats is used. To estimate the model by steps, the \link[MASS]{stepAIC} function of the package MASS (Venables & Ripley, 2002; Ripley et al., 2014) was used.

\strong{EXAMPLE}

The data are body measures of several species of fish (continuous variables), as well as the type of mouth they have (categorical variable).  The objective is to determine, if it is possible to identify, which family an individual belongs in function of biometrics.

As samples are chosen randomly, each time the function is executed, the logistic regression models that are estimated can vary and, therefore, also the accumulation curves.

The graph shows that the best adjustments are Rational, Clench and Saturation curves. When half of the data is used for the logistic regression model, a value is obtained around 97\% and, according to the accumulation curves, the asymptote is around 100\%. Therefore, it may be possible that with more data, a 100\% of identification success would be achieved with half of the data set.
\tabular{clll}{
\figure{FXV14}{options: width=3.7in}
}
}
\references{
Gross, J. (2013) Tests for Normality. R package version 1.0-2. Available at: \url{http://CRAN.R-project.org/package=nortest}.

Ripley, B., Venables, B., Bates, D.M., Hornik, K., Gebhardt, A. & Firth, D. (2014) Support Functions and Datasets for Venables and Ripley's MASS. R package version 7.3-33. Available at: \url{http://CRAN.R-project.org/package=MASS}.

Venables, W.N. & Ripley, B.D. 2002. \emph{Modern Applied Statistics with S}. Springer, fourth edition, New York. \url{http://www.stats.ox.ac.uk/pub/MASS4}.
}
\examples{
\dontrun{

data(ZXI9)

XV4(data=ZXI9, cat="Family", var=c("M2","M6","M8","M9", "M12","M13",
"M15","M16","M17","M21","M22","Mouth"), start=50)
}
}
\keyword{XV4}

