\name{XV7}
\alias{XV7}
\encoding{latin1}
\title{DETECTION OF OUTLIERS IN SINGLE VARIABLES}
\description{Outliers are detected in single variables and they may also automatically deleted.}
\usage{
XV7(data, var, cat=NULL, varCode=NULL, remove=FALSE, Nan=FALSE, quant1=0.05,
quant2=0.95, file="Outliers.csv", na="NA", dec=",", row.names=FALSE)
}
\arguments{
  \item{data}{Data file.}
  \item{var}{Variables to detect outliers.}
  \item{cat}{If a variable is specified, the outliers are calculated considering each group of that variable. For example, if the variable includes different species, instead of looking for the outliers based on all the data of the variable, it is only considered the data of each species separately.}
  \item{varCode}{Optionally, variables of the original matrix can be selected, which are exported in the output file with the variables in which outliers are detected. For example, this allows to choose variables which are codes of rows.}
  \item{remove}{If TRUE, the rows that have some variable with outliers are removed. If it is FALSE, the outliers are indicated with the value -9999.}
  \item{Nan}{If it is TRUE the outliers are shown as NA instead of -9999.}
  \item{quant1}{Quantile of the lower end to the elimination of outliers.}
  \item{quant2}{Quantile of the upper end to the elimination of outliers.}
  \item{file}{CSV FILE. Name of the file with the variables showing the outliers or with the variables with the outliers removed.}
  \item{na}{CSV FILE. Text that is used in the cells without data.}
  \item{dec}{CSV FILE. It defines if the comma "," is used as decimal separator or the dot ".".}
  \item{row.names}{CSV FILE. Logical value that defines if identifiers are put in rows or a vector with a text for each of the rows.}
 }
\value{A CSV file is exported with the variables showing the outliers and with the variables included in the argument \emph{varCode} if any variable was included in this argument. If the option \emph{remove=TRUE} the rows are deleted if any variable has an outlier.}
\details{
Outliers are considered those that are outside 1.5*IQR (interquartile range). IQR is the difference between the value specified in the arguments \emph{quant2} and \emph{quant1}. By default are 0.95 and 0.05, but for example in the boxplot are usually 0.75 and 0.25.

\strong{EXAMPLE}

Outliers are detected in some morphometric variables of fish and with the argument \emph{remove=TRUE} the rows with any outlier are removed.
}
\examples{
\dontrun{

data(ZX3)

XV7(data=ZX3, var=c("M2", "M3", "M4", "M5", "M6", "M7", "M8"), cat="Species",
varCode=c("Order", "Family", "Genus", "Species"), remove=TRUE)}
}
\keyword{XV7}
