\name{XV8}
\alias{XV8}
\encoding{latin1}
\title{DENDROGRAM ON A CORRESPONDENCE ANALYSIS}
\description{A Dendrogram is applied on a Correspondence analysis.} 
\usage{
XV8(data, var, labels, cat=NULL, por=80, k=NULL, pthreshold=0.05,
ellipse=FALSE, convex=FALSE, dim=c(1,2), size=c(1,5), showCluster=TRUE,
method="overlap", minimum=TRUE, ResetPAR=TRUE, PAR=NULL, SCATTERPLOT=NULL,
HCLUST=NULL, CLUSTER=NULL, BOXPLOT=NULL, mfrowBOXPLOT=NULL,
LabelCat=NULL, COLOR=NULL, COLORC=NULL, COLORB=NULL,
PCH=NULL, XLIM=NULL, YLIM=NULL, XLAB=NULL, YLAB=NULL, ylabBOXPLOT=NULL,
LEGEND=NULL, MTEXT= NULL, TEXTvar=NULL, TEXTlabels=NULL, arrows=TRUE,
larrow=0.7, colArrows="black", quadratic=FALSE, file1="Output.txt",
file2="Cat loadings.csv", file3="Descriptive statistics of clusters.csv",
file4="Original data and cluster number.csv", file5="Var loadings-Linear.csv",
file6="Cat loadings-Linear.csv", file7="Table cross-validation-Linear.csv",
file8="Cases cross-validation-Linear.csv", file9="Table cross-validation-Quadratic.csv",
file10="Cases cross-validation-Quadratic.csv", file11="Plots VARSEDIG.pdf",
file12="U Mann-Whitney test.csv", na="NA", dec=",", row.names=TRUE)
}
\arguments{
  \item{data}{Data file.}
  \item{var}{Variables that are included in the analysis. If they are factors or characters, they are transformed into numerics and a table with the numerical value assigned to each category is shown in the results.}
  \item{labels}{Variable that allows to display a label for each case.}
  \item{cat}{Optionally you can specify a variable to show a grouping in the plot of the Correspondence analysis.}
  \item{por}{Cut-off threshold specifying the cumulative variance percentage, to determine how many axes are selected from the Correspondence analysis. By default it is 80\%, which means that the axes are selected until reaching an accumulated variance percentage of 80\%.}
  \item{k}{Number of clusters in which the Dendrogram is divided. If it is NULL, the algorithm select automatically the maximum number of clusters in which the Dendrogram can be divided, which are those groups that are statistically different in at least one variable according to the U Mann-Whitney test.}
  \item{pthreshold}{Threshold probability of the U Mann-Whitney test.}
  \item{ellipse}{If it is TRUE, the ellipses with the levels of significance to the 0.5 (inner ellipse) and 0.95 (outer ellipse) of each category of the variable \emph{cat} are depicted. These levels of significance can be modified by entering the function \link[car]{scatterplot} using the argument \emph{SCATTERPLOT} and modifying the argument \emph{levels=c(0.5,0.95)}. If it is TRUE, the ellipses of the clusters in the Discriminant analysis and in the polar coordinate plot of the VARSEDIG algorithm are also calculated.}
  \item{convex}{If it is TRUE, the convex hull is calculated for each category in the Correspondence analysis, but only if some variable has been selected in the argument \emph{cat}. If TRUE, the convex hull of the clusters is also calculated in the Discriminant analysis and in the polar coordinate plot of the VARSEDIG algorithm.}
  \item{dim}{Vector with two values indicating the axes that are shown in the Correspondence analysis.}
  \item{size}{Size range of bubbles. Two values: minimum and maximum size.}
  \item{showCluster}{If it is TRUE, the number of each cluster is shown in the Dendrogram.}
  \item{method}{Three different methods for prioritizing the variables according to their capacity for discrimination can be used in the VARSEDIG algorithm. If the method is "overlap", a density curve is obtained for each variable and the overlap of the area under the curve between the two groups of the variable \emph{group} is estimated for all variables. Those variables with lower overlap should have better discrimination capacities and, hence, all variables are ordered from lowest to highest overlap; in other words, from the highest to lowest discrimination capacity. If the method is "Monte-Carlo", a Monte-Carlo test is performed comparing all values of group 1 with group 2, and all values of group 2 with 1. The variables are prioritized from the variable with the lowest mean of all p-values (highest discrimination capacity) to the variable with the highest mean of all p-values (lowest discrimination capacity). If the method is "logistic regression", then a binomial logistic regression is calculated and only significant variables are selected for further analyses with the regression performed by steps using the Akaike Information Criterion (AIC).}
  \item{minimum}{If it is TRUE, the algorithm is designed to find a significant discrimination between both groups with the minimum possible number of significant variables. Therefore, only the variables with higher discrimination capacity are selected. If it is FALSE, the algorithm selects all significant variables, and not only those with higher discrimination capacity. This argument is only valid with the methods "Monte-Carlo" and "overlap" and it is useful in those cases that discrimination between the groups is difficult and requires to include as many as variables as possible.}
   \item{ResetPAR}{If it is FALSE, the default condition of the function \link{PAR} are not placed and those defined by the user on previous graphics are maintained.}
  \item{PAR}{It accesses the\link{PAR} function that allows to modify many different aspects of the graphs.}
  \item{SCATTERPLOT}{It accesses the function \link[car]{scatterplot} of the car package.}
  \item{HCLUST}{You may access the function \link[stats]{hclust} of the stats package.}
  \item{CLUSTER}{Access to the function that allows to modify the graphic representation of the Dendrogram.}
  \item{BOXPLOT}{Allows to specify the characteristics of the boxplot.}
  \item{mfrowBOXPLOT}{It allows to specify the boxplot panel. It is a vector with two numbers, for example c(2,5) which means that the boxplots are put in 2 rows and 5 columns.}
  \item{LabelCat}{It allows to specify a vector with the names of the clusters in the boxplots. They must be as many as clusters.}
\item{COLOR}{It allows to modify the colours of the graphic in the Correspondence analysis, but they must be as many as different groups have the variable \emph{cat}.}
\item{COLORC}{It allows to modify the colours of the clusters in the Dendrogram, but they must be as many as what is specified in the argument \emph{k}.}
\item{COLORB}{It allows to modify the colours of the clusters in the boxplots, but they must be as many as what is specified in the argument \emph{k}.}
  \item{PCH}{Vector with the symbols of the Correspondence analysis plot, which must be as many as different groups have the variable \emph{cat}. If it is NULL they are calculated automatically starting with the symbol 15.}
  \item{XLIM, YLIM}{Vectors with the axes limits \emph{X} and \emph{Y} of the Correspondence analysis plot.}
  \item{XLAB, YLAB}{Legends of the axes \emph{X} and \emph{Y} of the Correspondence analysis plot.}
  \item{ylabBOXPLOT}{You can specify a vector with the legends of the axes \emph{Y} of the boxplots. They should be as many as the number of variables.}
  \item{LEGEND}{It allows to include or to modify a legend in the Correspondence analysis plot.}
  \item{MTEXT}{It allows to add text in the margins of the Correspondence analysis plot.}
  \item{TEXTvar}{It allows to modify the labels of the variables in the Correspondence analysis plot.}
  \item{TEXTlabels}{It allows to modify the labels of the cases in the graph in the Correspondence analysis.}
  \item{arrows}{If it is TRUE the arrows are shown in the scatterplot of the Correspondence analysis.}
  \item{larrow}{It modifies the length of the arrows in the Correspondence analysis plot.}
  \item{colArrows}{Colours of the arrows in the Correspondence analysis plot.}
  \item{quadratic}{If TRUE, a Quadratic Discriminant Analysis is performed, in addition to the Linear Discriminant Analysis.}
  \item{file1}{TXT FILE. Name of the output file with the results.}
  \item{file2}{CSV FILE. Name of the output file with the coordinates of the cases of the Correspondence analysis plot.}
  \item{file3}{CSV FILE. Name of the output file with the descriptive statistics of each variable for each of the clusters obtained in the Dendrogram.}
  \item{file4}{CSV FILE. Name of the output file with the original data of the variables and the cluster to which each case belongs.}
  \item{file5}{CSV FILE. Name of the output file with the coordinates of the variables in the Linear Discriminant Analysis plot.}
  \item{file6}{CSV FILE. Name of the output file with the coordinates of the categories in the Linear Discriminant Analysis plot.}
  \item{file7}{CSV FILE. Name of the output file with the prediction table using the cross-validation of the Linear Discriminant Analysis.}
  \item{file8}{CSV FILE. Name of the output file with the group to which each case belongs and the prediction of the Discriminant Analysis using the cross-validation of the Linear Discriminant Analysis.}
  \item{file9}{CSV FILE. Name of the output file with the predictions table using the cross-validation of the Quadratic Discriminant Analysis.}
  \item{file10}{CSV FILE. Name of the output file with the group to which each case belongs and the prediction of the Discriminant Analysis using the cross-validation of the Quadratic Discriminant Analysis.}
  \item{file11}{PDF File. Name of the output file with the graphics obtained from the VARSEDIG algorithm.}
  \item{file12}{CSV FILE. Name of the output file with the obtained probabilities of comparing all the variables among all the clusters with the U Mann-Whitney test.}
  \item{na}{CSV FILES. Text that is used in the cells without data.}
  \item{dec}{CSV FILES. It defines if a comma "," or a dot "." is used as decimal separator.}
  \item{row.names}{CSV FILES. Logical value that defines if identifiers are put in rows or a vector with a text for each of the rows.}
}
\value{
It is obtained:

1. A TXT file with the results of the Correspondence analysis. The file is called by default "Output.TXT".

2. A CSV FILE with the coordinates for each case of the Correspondence analysis. The file is called by default "Cat loadings.CSV".

3. A CSV FILE with the descriptive statistics of each variable for each of the clusters obtained in the Dendrogram. The file is called by default "Descriptive statistics of clusters.CSV".

4. A CSV FILE with the original data of the variables and the cluster to which each case belongs. The file is called by default "Original data and cluster number.CSV".

5. A CSV FILE with the coordinates of the variables in the Linear Discriminant Analysis plot. The file is called by default "Var loadings-Linear.csv"

6. A CSV FILE with the coordinates of the categories in the Linear Discriminant Analysis plot. The file is called by default "Cat loadings-Linear.csv".

7. A CSV FILE with the predictions table using the cross-validation of Linear Discriminant Analysis. The file is called by default "Table cross-validation-Linear.csv".

8. A CSV FILE with the group to which each case belongs and the prediction of the Discriminant Analysis using the cross-validation of the Linear Discriminant Analysis. The file is called by default "Cases cross-validation-Linear.csv".

9. A CSV file with the predictions table using the cross-validation of the Quadratic Discriminant Analysis. The file is called by default "Table cross-validation-Quadratic.csv".

10. A CSV file with the group to which each case belongs and the prediction of the Discriminant Analysis using the cross-validation of the Quadratic Discriminant Analysis. The file is called by default "Cases cross-validation-Quadratic.csv".

11. A CSV file with the obtained probabilities of comparing all the variables among all the clusters with the U Mann-Whitney test.

12. A PDF file with the graphics obtained from the VARSEDIG algorithm.

13. A scatterplot of the Correspondence analysis.

14. A Dendrogram grouping by clusters according to the scores of the Correspondence analysis.

15. A graphic panel with a boxplot for each variable comparing the values of these variables between each of the clusters obtained in the Dendrogram.

16. A Graph of the Discriminant Analysis showing the influence of the variables on the discriminant axis I, differentiating the different clusters.

17. A graph of the Discriminant Analysis showing the scores of the discriminant axes I and II, differentiating the different clusters.

18. A bubble chart with the number of variables that are statistically different between clusters.
}
\details{
The aim of this analysis is to determine what statistically different groups are formed by applying a Correspondence analysis.

This analysis can be useful to find different groups when you really do not know what they are. For example, find different species using qualitative variables, without really knowing how many potential species there are and to what species each individual belongs.

However, it is important to note that only different groups will be detected if the variables that have more variability give rise to different groups. It is possible that a variable does not present a great variability, but it is important for discriminating groups. This type of differentiation based on variables that do not have high variance, would not be detected in this analysis.

To detect the potential groups being formed, a Dendrogram is applied to the scores obtained from the axes that absorb a greater variance. By default, the axes that absorb 80\% of the variability are chosen, but this value can be modified by the user.

Subsequently, a Discriminant Analysis is carried out to determine if the clusters that have been generated are well discriminated, that is, to determine the number of correctly identified cases in each cluster.

Next, a U Mann-Whitney test is performed to determine if there are significant differences in the variables between the clusters.

Finally, the algorithm of the VARSEDIG function is applied (see for more details Guisande et al 2016: Guisande, 2018). With this algorithm it is possible to determine if all the cases of each cluster are statistically different from the other clusters.

The idea of this function is to find the largest possible number of clusters with the highest discrimination percentage. To do this the user should perform tests, modifying the cut-off threshold by specifying the cumulative variance percentage to determine how many axes are selected from the Main Components (by default \emph{by=80}) and the variables to be included, eliminating those that are not correlated and are not useful in the Correspondence analysis, as well as those that have little discrimination power in the Discriminant Analysis.

\strong{FUNCTIONS}

The Correspondence analysis was performed with the \link[ca]{ca} function of the package ca (Greenacre & Pardo, 2006; Greenacre, 2007; Nenadic & Greenacre, 2007; Greenacre, 2013).

It was used the \link[car]{scatterplot} function of the car package was used (Fox et al., 2018) for performing the \emph{biplot} graph. 

The arrows are depicted with the function \link[IDPmisc]{Arrows} of the package IDPmisc (Locher & Ruckstuhl, 2014).

The convex hull is estimated with the function \link[grDevices]{chull} of the package grDevices.

The U Mann-Whitney test is performed with the \emph{wilcox.test} function of the base stats package.

The comparison between clusters with the VARSEDIG algorithm is done with the VARSEDIM function of the VARSEDIG package (Guisande et al., 2016: Guisande, 2018).

The Linear Discriminant Analysis was performed with the functions \link[candisc]{candisc} of the candisc package (Friendly, 2007; Friendly & Fox, 2017) and \link[MASS]{lda} of the MASS package (Venables & Ripley, 2002; Ripley et al., 2018).

The Quadratic Discriminant Analysis was performed with the function \link[MASS]{qda} of the MASS package (Venables & Ripley, 2002; Ripley et al., 2018).

The graph with one dimension in the Discriminant analysis was performed with the function \link[candisc]{plot.cancor} of the candisc package (Friendly, 2007; Friendly & Fox, 2017).

\strong{EXAMPLE}

In the example, valuation criteria are used, on a scale of 0 to 10, of 48 candidates who apply for a job. The objective is to see which groups are formed from the Correspondence analysis.

Figures XV8.1 shows that in the right end of the first axis the variables are experience, the suitability for the job and letter of motivation.

In the left end of the first axis motivation and confidence are associated. The second axis is associated with the business sense in the upper end, while at the lower end are honesty and level of studies.

The eigenvalues show the variance percentage of the axes: 32.9\% first axis, 25.7\% the second, 11.3\% the third, etc.
\tabular{c}{
\strong{Figure XIII.1.} Correspondence analysis showing the observed variability\cr
in the qualities of candidates for a job.\cr
\figure{FXV21}{options: width=3.7in}
}
Inertia (\emph{Inertia}) indicates the relative weight or the different importance of each variable. The highest values are for the experience (0.0271), level of studies (0.0168), honesty (0.0155), motivation letter (0.015), adequacy (0.0149), commercial sense (0.012, \emph{Ability.to.sell}), etc.

In the example, the option \emph{kmethod= automatically"} was chosen and it is observed in Figure XV8.2 that there are only 2 statistically significant clusters with at least one variable different according to the Mann-Whitney U test.\tabular{c}{
\strong{Figure XV8.2.}Dendrogram with the scores of the axes\cr
selected from the Correspondence analysis.\cr
\figure{FXV22}{options: width=5.9in}
}
In Figure XV8.3 the differences between clusters for each of the variables are observed. Both clusters differ significantly in almost all variables, specifically in 13 of them (Figure XV8.4). There are only no differences in honesty and in the level of studies.
\tabular{c}{
\strong{Figure XV8.3.} Boxplot obtained for each of the variables\cr
with the averaged values for each cluster.\cr
\cr
\figure{FXV23}{options: width=5.9in}
}
\tabular{c}{
\strong{Figure XV8.4.} Plot where the bubbles represent the number of variables.\cr
that are statistically different (p <= 0.05) between clusters.\cr
\figure{FXV25}{options: width=3.3in}
}
The Discriminant analysis shows that it is possible to correctly discriminate 87.5\% of cases by cross-validation with the Linear method. All the variables seem to be important for discrimination, with the exception of the level of studies and honesty, in which the arrows are small (Figure XV8.5).
\tabular{c}{
\strong{Figure XV8.5.} Axis I of the Discriminant analysis.\cr
\cr
\figure{FXV24}{options: width=5.2in}
}
Finally, in a pdf, the graphics obtained from applying the VARSEDIG algorithm are saved. The aim of this algorithm is to compare all the clusters with each other.

Figure XV8.6 shows the example of the comparison of cluster 1 with 2. It is observed that the variables that discriminate significantly between both clusters are the potential, comprehensibility, lucidity and charisma (upper right panel).

The Monte-Carlo test showed that the candidate that most resembles cluster 2 in cluster 1 (lower left panel) there are significant differences on the X axis (p = 0.023) and almost on the Y axis (p = 0.068). However, the candidate that most resembles cluster 1 to cluster 2 does not have differences on the X axis (p = 0.167) nor on the Y axis (p = 0.167). Therefore, it cannot be concluded that cluster 1 and 2 are different.
\tabular{c}{
\strong{Figure XV8.6.} Plots obtained from VARSEDIG algorithm. It is\cr
shown the comparison of the cluster 1 with the cluster 2.\cr
\figure{FXV26}{options: width=5.5in}
}
Therefore, according to the tests carried out with the U Mann-Whitney test, the clusters are statistically different from each other. In the Discriminant, a complete separation of both groups was not achieved. In the algorithm VARSEDIG showed that all the candidates from cluster 2 are different from cluster 1, but not all from cluster 1 are different from cluster 2. However, it is very important to note that the VARSEDIG algorithm considers two statistically different groups if the case that the more it resembles each group the other, it is statistically different using the Monte-Carlo test. The Monte-Carlo test needs a large number of cases in each group for detecting significant differences. In the case of group 2 the number of candidates is very small and, therefore, it is not possible to determine that the differences are not by chance.
}
\references{
Fox, J., Weisberg, S., Adler, D., Bates, D., Baud-Bovy, G., Ellison, S., Firth, D., Friendly, M., Gorjanc, G., Graves, S., Heiberger, R., Laboissiere, R., Monette, G., Murdoch, D., Nilsson, H., Ogle, D., Ripley, B., Venables, W. & Zeileis, A. (2018) Companion to Applied Regression. R package version 3.0-0. Available at: \url{http://CRAN.R-project.org/package=car}.

Friendly, M. (2007). HE plots for Multivariate General Linear Models. \emph{Journal of Computational and Graphical Statistics}, 16: 421-444.

Friendly, M. & Fox, J. (2017) Visualizing Generalized Canonical Discriminant and Canonical Correlation Analysis. R package version 0.8-0. Available at: \url{http://CRAN.R-project.org/package=candisc}.

Greenacre, M. (2013).  Simple, Multiple and Joint Correspondence Analysis. R package version 0.53. Available at: \url{http://CRAN.R-project.org/package=ca}.

Greenacre, M. (2007) \emph{Correspondence Analysis in Practice}. Second Edition. London: Chapman & Hall / CRC.

Greenacre, M.J. & Pardo, R. (2006) Subset correspondence analysis: visualizing relationships among a selected set of response categories from a questionnaire survey. \emph{Sociological Methods and Research}, 35: 193-218.

Guisande, C., Vari, R.P., Heine, J., Garca-Rosell, E., Gonzlez-Dacosta, J., Prez-Schofield, B.J., Gonzlez-Vilas, L. & Pelayo-Villamil, P. (2016) VARSEDIG: an algorithm for morphometric characters selection and statistical validation in morphological taxonomy. \emph{Zootaxa}, 4162: 571-580.

Guisande, C. (2018) An Algorithm for Morphometric Characters Selection and Statistical Validation in Morphological Taxonomy. R package version 1.8. Available at: \url{http://CRAN.R-project.org/package=VARSEDIG}.

Locher, R. & Ruckstuhl, A. (2014) Utilities of Institute of Data Analyses and Process Design. R package version 1.1.17. Available at: \url{http://CRAN.R-project.org/package=IDPmisc}.

Nenadic, O. & Greenacre, M. (2007) Correspondence analysis in R, with two- and three-dimensional graphics: The ca package. \emph{Journal of Statistical Software}, 20: 1-13.

Ripley, B., Venables, B., Bates, D.M., Hornik, K., Gebhardt, A. & Firth, D. (2018) Support Functions and Datasets for Venables and Ripley's MASS. R package version 7.3-50. Available at: \url{http://CRAN.R-project.org/package=MASS}.

Venables, W.N. & Ripley, B.D. (2002) \emph{Modern Applied Statistics with S}. Springer, fourth edition, New York. \url{http://www.stats.ox.ac.uk/pub/MASS4}.}
\examples{
\dontrun{

data(ZXIII1)

XV8(data=ZXIII1, var=c("Motivation.letter", "Presentation", "Studies",
"Sympathy", "Self.confidence", "Lucidity", "Honesty", "Ability.to.sell",
"Experience", "Charisma", "Ambition", "Comprehension.capacity",
"Potential", "Job.motivation", "Suitableness"), labels="Candidate",
XLIM=c(-4,7), YLIM=c(-6,4))
}
}
\keyword{XV8}
