\name{XV9}
\alias{XV9}
\encoding{latin1}
\title{ DETECTION OF OUTLIERS IN A COMBINATION OF VARIABLES}
\description{Outliers are detected in a combination of variables and they may also automatically deleted.}
\usage{
XV9(data, var, cat=NULL, varCode=NULL, remove=FALSE, Nan=FALSE,
quant=0.95, file="Outliers.csv", na="NA", dec=",", row.names=FALSE)
}
\arguments{
  \item{data}{Data file.}
  \item{var}{Variables to be combined for detecting outliers.}
  \item{cat}{If a variable is specified, the outliers are calculated considering each group of the combination of variables. For example, if the variable includes different species, instead of looking for the outliers based on all the data of the variable, it is only considered the data of each species separately.}
  \item{varCode}{Optionally, variables of the original matrix can be selected, which are exported in the output file with the variables in which outliers are detected. For example, this allows to choose variables which are codes of rows.}
  \item{remove}{If it is TRUE, the rows that have some variable with outliers are deleted in the output file, but the outliers are still shown in the graph. If it is FALSE, the outliers are indicated with the value -9999.}
  \item{Nan}{If it is TRUE the outliers are shown as NA instead of -9999.}
  \item{quant}{Quantile of the upper end to the elimination of outliers.}
  \item{file}{CSV FILE. Name of the file with the variables showing the outliers or with the variables with the outliers removed.}
  \item{na}{CSV FILE. Text that is used in the cells without data.}
  \item{dec}{CSV FILE. It defines if the comma "," is used as decimal separator or the dot ".".}
  \item{row.names}{CSV FILE. Logical value that defines if identifiers are put in rows or a vector with a text for each of the rows.}
 }
\value{ 
It is exported:

1. A CSV file with the independent variables and the Malahanobis distance resulting from the combination of the variables, where the outliers are shown. The variables included in the argument \emph{varCode} are also exported if any variable was included in this argument. If the option \emph{remove=TRUE} the rows are eliminated if the distance of Malahanobis is an outlier.

2. A Q-Q plot with the ordered Mahalanobis distances versus estimated quantiles (percentiles) for a sample of size \emph{n} from a chi-squared distribution with \emph{p} degrees of freedom (number of variables). The outliers are highlighted in red on the plot. If you chose to perform the estimation by categories, a Q-Q plot is shown for each category.
}
\details{
In some statistical analyses such as MANOVA and Principal Component analysis, we work with a combination of variables, instead of with the variables independently. It is possible that some variables do not have outliers when they are analysed independently, but the combination of them may result in atypical values. Therefore, a statistical method is needed to detect outliers when combining variables and the Mahalanobis distance is frequently used for that purpose (Mahalanobis, 1936).

The Mahalanobis distance is a measure of the distance between a point P and a distribution D. It is a multi-dimensional generalization of the idea of measuring how many standard deviations away P is from the mean of D. This distance is zero if P is at the mean of D, and grows as P moves away from the mean along each principal component axis, the Mahalanobis distance measures the number of standard deviations from P to the mean of D. If each of these axes is re-scaled to have unit variance, then the Mahalanobis distance corresponds to standard Euclidean distance in the transformed space. The Mahalanobis distance is thus unitless, scale-invariant, and takes into account the correlations of the data set. The equation is the following:

\deqn{D^2=(x-\mu)^{'}C^{-1}(x-\mu)}

where \eqn{C^{-1}} is the inverse covariance matrix and \eqn{\mu} is the center.

Once the distance is calculated we have the problem of how to detect the outliers. For relatively large samples, the estimated Mahalanobis distances have a distribution that approximates a chi-square. This result can be used to evaluate (subjectively) whether a data point can be an outlier. For this, a Q-Q plot is usually used to represent the Mahalanobis distances of the sample. The basic idea is the same as in a Normality distribution graph.

For multivariate data, the ordered Mahalanobis distances versus quantiles estimated for a sample of size \emph{n} are plotted from a chi-square distribution with \emph{p} degrees of freedom (number of variables that are combined). This should resemble a straight line for data from a normal multi-variable distribution. The outliers will be shown as points on the upper right side of the graph for which the Mahalanobis distance is markedly larger than the chi-square quantile value.

The quantiles are determined as follows:

1. The \emph{ith} estimated quantile is determined as the chi-square value (with df=p) for which the cumulative probability is \eqn{(i-0.5)/n}.

2. To determine the full set of estimated chi-square quantiles, this is done for value of \emph{i} from 1 to \emph{n}.

The problem is that the method is subjective, that is, it is up to the user to decide, based on the graph obtained, which points are eliminated. To eliminate this subjectivity, in this function an algorithm is introduced, which using the described criterion to detect outliers in independent variables defined in the function \link{XV7}, those Mahalanobis distances that are outside the upper quantile (by default 0.95) are considered outliers.

The values considered to be atypical are highlighted in red in the Q-Q plot, so that the user can decide if the selection has been correct.

\strong{FUNCTIONS}

The Mahalanobis distance is calculated with the \link[stats]{mahalanobis} function of the base stats package.

\strong{EXAMPLE}

Outliers are detected in the combination of morphometric variables of fish. The outliers are shown with the -9999 value in the obtained file.

As in the script it was selected to perform the calculations by genus, \emph{cat="Genus"}, a Q-Q plot is depicted for each genus.

In the Q_Q plots shown below, in which the Mahalanobis distance is related to the quantiles estimated from a chi-square distribution with 7 degrees of freedom (since there are 7 variables to be combined), only ouliers are detected in the genera \emph{Triporheus} and \emph{Roeboides}, with the default quantile of 0.95.

It is interesting to note that in the case of the genus \emph{Poptella}, since the data number is not very large, the points do not fit the straight line of the chi-square distribution of the Q-Q plot.
\tabular{c}{
\figure{FXV27}{options: width = 5.5in}
}

}
\references{
Mahalanobis, P.C. (1936) On the generalised distance in statistics. \emph{Proceedings of the National Institute of Sciences of India}, 2: 49-55.
}

\examples{
\dontrun{
data(ZX3)

XV9(data=ZX3, var=c("M2", "M3", "M4", "M5", "M6", "M7", "M8"), cat="Genus",
varCode=c("Order", "Family", "Genus", "Species"))
}
}
\keyword{XV9}
