\name{XVI1}
\alias{XVI1}
\encoding{latin1}
\title{Multivariate analysis of variance (MANOVA)}
\description{An analysis of variance is applied considering several dependent quantitative variables.} 
\usage{
XVI1(data, var, Factor, SS="III", trans=NULL, pthreshold=0.05, psig=FALSE,
ellipse=FALSE, convex=TRUE, PCH=rep(16,100), order=TRUE, cor=TRUE,
file1="Output.txt", file2="Multinormality.csv", file3="Post hoc pvalues.csv",
na="NA", dec=",", row.names=TRUE)
}
\arguments{
  \item{data}{Data file.}
  \item{var}{Dependent variables.}
  \item{Factor}{Variables with the factors.}
  \item{SS}{When there are several factors, the decomposition of the sum of squares in parts attributed to each one of the factors is not unique. Four types of sums of squares are commonly used: type I for nested models, type II for balanced models, type III for unbalanced models (also balanced), and type IV for models with empty boxes. The type III is suitable for most applications, so it will be the one used by default. This description is very simplified; interested readers should consult supplementary bibliography for a correct use of the ANOVA models.}
  \item{trans}{Type of transformation that is applied to the data:

1. NULL (untransformed)

2. 1/x2

3. 1/x

4. LN

5. LOG

6. SQR (square root)

7. x2

8. x3

9. EXP (exponential)

10. ASN (arcsine)
}
  \item{pthreshold}{Threshold probability that is used to group the categories of each factor, based on the probabilities obtained in the post hoc analysis.}
  \item{psig}{If TRUE, in the post hoc inter-group comparison file, only those that are significant with a probability value equal to or less than the cut-off value specified in the argument \emph{pthreshold} are shown.}
  \item{ellipse}{If it is TRUE, the ellipses with the levels of significance to the 0.5 (inner ellipse) and 0.95 (outer ellipse) of each category of the factors are depicted.}
  \item{convex}{If it is TRUE, the convex hull is depicted for each category.}
  \item{PCH}{Symbols of each category of the factors.}
  \item{order}{If it is TRUE, the first variable of the polar coordinates is the one that best discriminates the categories. The objective is to show the greatest possible separation between the categories in the plots. If it is FALSE, the first variable is the one specified by the user in the argument \emph{var}.}
  \item{cor}{If TRUE, the variables are ordered according to the correlation between them when estimating the polar coordinates. Therefore, the next variable to another variable is the one with the highest positive correlation. The objective is to show the greatest possible separation between the categories in the plots. If it is FALSE and the argument \emph{order=FALSE}, the variables are organized as they appear in the argument \emph{var}.}
  \item{file1}{TXT FILE. Name of the output file with the results.}
  \item{file2}{CSV FILE. Name of the file with the probabilities obtained from the multinormality analysis.}
  \item{file3}{CSV FILE. Name of the file with the probabilities obtained from the post hoc comparison between groups for each factor.}
  \item{na}{CSV FILE. Text that is used in the cells without data.}
  \item{dec}{CSV FILE. It defines if the comma "," is used as decimal separator or the dot ".".}
  \item{row.names}{CSV FILE. Logical value that defines if identifiers are put in rows or a vector with a text for each of the rows.}
}
\value{
It is exported:

1. A TXT file with the results of the VIF, the Box' M test and the results of the MANOVA.

2. A CSV file with the probabilities obtained from the multinormality analysis.

3. A CSV file with the probabilities obtained from the post hoc comparison between the groups of each factor.

4. Polar coordinate plots showing the separation between categories for each factor, the groups resulting from the post hoc analysis and the interactions between factors.
}
\details{
\strong{CONTRASTS OF HOMOGENEITY IN QUANTITATIVE VARIABLES}

\strong{Multivariate analysis of variance (MANOVA)}

The multivariate analysis of variance (MANOVA) is an extension of the univariate analysis of variance (ANOVA). In an ANOVA, we examine the statistical differences in a continuous dependent variable between the means of the categories of one or several factors. MANOVA extends this analysis taking into account multiple continuous dependent variables, and groups them into a weighted linear combination or compound variable. The MANOVA will compare whether the newly created combination differs or not according to the different groups or levels of each factor. In this way, MANOVA essentially tests whether the independent grouping variable (factor) explains a statistically significant amount of variance in the dependent variable created as a linear combination of all independent variables.

To perform a MANOVA it is necessary to fulfill the following assumptions:

 The dependent variables are continuous, random and independent, that is, there should be no relationship between the groups or within the groups of each factor. For example, it is not valid for the data of a group to derive from the data of another group (related samples) or to repeat data between groups.

 There are no univariate or multivariate outliers. The function \link{XV7} can be used to detect the outliers within each dependent variable, and for the multivariate outliers, that is, those that result from the combination of variables, it can be used the function \link{XV9}, both of StatR. The multivariate outliers are cases that have an unusual combination of scores in the dependent variables and, therefore, the combination that results from the dependent variables gives rise to an outlier.

 There must not be collinearity among the quantitative dependent variables. A value greater than around 10-12 of VIF would mean that there is collinearity.
 
 The relationship between the quantitative dependent variables is linear.

 It assumes multivariate normality, which means that the residuals are normal for each dependent variable, in each of the groups or categories of factors.

 Equality of the variances-covariances matrices is assumed in the residuals of the groups of the factors considered.

An original contribution of this function is that post hoc tests are carried out, which allows grouping the categories that are not statistically different and, therefore, showing how many real groups are different within each factor. Only post hoc tests are shown if there are more than two categories in the factor and if there are differences between some of the categories of the factor.
 
The algorithm consists of performing the MANOVA within each factor, but instead of comparing all the groups, each group is compared with the rest. The probabilities obtained are recorded in the file that is called by default "Post hoc pvalues.CSV". Subsequently, a matrix is generated where the rows are the categories and the columns are also categories. In each row it is indicated with a 1 the categories that are statistically different and with 0 if they are not. Therefore, each row shows with 1 and 0, what categories are or are not statistically different from the category that is considered in that row. This matrix allows us to know which categories are more similar to each other, depending on whether they have more significant categories in common.
 
This matrix is used to perform successive dendrograms, where different number of clusters are used. A MANOVA is applied to the clusters that are being formed and the algorithm stops when there are no longer any differences between any of the clusters. Therefore, the algorithm allows obtaining the largest possible number of different clusters within each factor, grouping in each cluster the categories that are not statistically different.

\strong{FUNCTIONS}

The \link[nortest]{lillie.test} function of the nortest package (Gross, 2015) is used to perform the Kolmogorov-Smirnov Normality test with the Lilliefors correction. The \link[stats]{shapiro.test} function is used to perform the Shapiro-Wilk test, the linear model is performed with the \link[stats]{lm} function, both of the base stats package. The MANOVA type II-III is performed with the \link[car]{Manova} function of the car package (Fox et al., 2018a). The MANOVA type I is done with the function \link[stats]{manova} of the base stats package. To determine the homogeneity of variances between the categories of the factors, the Box's M test was applied, for which the function \link[heplots]{boxM} of the heplots package (Fox et al., 2018b) was used. The function \link[usdm]{vif} of the usdm package (Naimi, 2013; Naimi et al., 2014) was used for the VIF estimation.

\strong{EXAMPLE}

The data are birth weight and weaning weight of calves. Individuals at weaning are different from those whose birth weight was measured. Therefore, the dependent variables are not related. The objective is to determine if there are significant differences in both weights depending on the sex or the father. The ultimate goal is to select parents that have calves with greater weight.

If an ANOVA is performed on each of the dependent variables, birth weight and weaning weight, there are no significant differences in birth weight between parents (p = 0.726) and sexes (p = 0.201). There are also no significant differences in weaning weight between parents (p = 0.109) and sexes (p = 0.431). However, the MANOVA shows something different.

In the TXT file of results, the first thing that is shown are the values of VIF, which are being small, so there is no collinearity among the dependent variables, which is one of the assumptions of MANOVA.
\tabular{c}{
\figure{RXV12}{options: width=1.5in}
}
The requirement of equality of variances between groups of factors is also fulfilled. The Box's M test shows that there is equality in the variances-covariances matrices in the residuals of the groups of the factors considered, both in the case of gender (p = 0.734) and among the parents (p = 0.957).
\tabular{c}{
\figure{RXV13}{options: width=3.3in}
}
In the file that is called by default "Multinormality.csv", it is observed that the multinormality is also fulfilled. The samples are normal in the two variables for all groups of the two factors.
\tabular{c}{
\figure{RXV14}{options: width=2.3in}
}
The following results are the MANOVA analysis. There are four tests that are used more frequently: Pillai, Wilks, Hotelling-Lawley and Roy. None of these tests can be clearly identified as the best test to be used in all situations (Lee, 1971, Pillai and Jayachandran, 1967). The comparative effectiveness of each of these tests changes in relation to the specific characteristics of the data. However, taking into account a wide spectrum of real data conditions, the Pillai, Wilks and Hotelling-Lawley tests generally work in a similar way, particularly when the assumptions are met (Johnson & Wichern, 2002; Finch & French, 2013).

The following table shows that in all cases the test values coincide. In the case of the father factor, there are significant differences, which means that the weight of the calves at birth and at weaning varies depending on the father (p = 0.010). However, there are no significant differences between sexes (p = 0.977) nor in the parent-gender interaction (p = 0.684). Non-interaction means that calves born from different parents do not have a different weight depending on whether they are male or female. In other words, significant interaction would mean that in some parents, male calves weigh more than females, and vice versa in other parents.
\tabular{c}{
\figure{RXV15}{options: width=3.3in}
}
Figure XVI1.1 shows the groups of parents in the graph of polar coordinates where it is observed that there are different groups, which corroborates the differences between parents that showed the MANOVA in the weights at birth and at weaning.
\tabular{c}{
\strong{Figure XVI1.1.} Polar coordinates of the different parents\cr
depending on the two dependent variables analysed.\cr
\figure{FXV28}{options: width=2.6in}
}
However, in the case of gender (Figure XVI1.2) two overlapping groups are observed, which also allows visualizing what is shown in the MANOVA, that there are no differences between sexes in the weight of the calves at birth and at weaning.
\tabular{c}{
\strong{Figure XVI1.2.} Polar coordinates of the factor gender\cr
depending on the two dependent variables analysed.\cr
\figure{FXV29}{options: width=3.4in}
}
In the function, an algorithm has been implemented that performs post hoc tests, which are detailed in the \emph{details} section. Only post hoc tests are shown if there are more than two categories in the factor and if there are differences between some of the factor categories. Therefore, in this example, there is no information about post hoc tests of the gender factor, since there are only two categories. In the case of the parent factor, two groups are generated. Group 1 includes parents 1, 2 and 3, and group 2 includes parents 4, 5 and 6, as can be seen in the table shown below and appears in the results file. Therefore, there are two significantly different groups of parents (Figure XVI1.3).
\tabular{c}{
\figure{RXV16}{options: width=2.0in}
}
Figure XVI1.3 shows the post hoc chart for the parent factor. To obtain the graph with the ellipses, it is necessary to run the script by adding the arguments \emph{convex = FALSE} and \emph{ellipse = TRUE}. The central point of the ellipses of each group allows to better differentiate that group 2 has a higher average weight, both at birth and at weaning.
\tabular{c}{
\strong{Figure XVI1.3.} Polar coordinates of the resulting groups of the parent factor, which\cr
show significant differences in the post hoc analysis.\cr
\figure{FXV30}{options: width=3.2in}
}
The last graph is that of interaction between both factors (Figure XVI1.4). It is more difficult to visualize, but it can be seen that, for the same father, for example father 6, the values are very similar in males and females. This is similar for the rest of the parents, which makes it possible to visualize that there is no significant interaction between the factors.
\tabular{c}{
\strong{Figure XVI1.4.} Polar coordinates of the interaction between both factors \cr
\figure{FXV31}{options: width=3.2in}
}
All these polar coordinate graphs can be modified to suit the user using the original data and the F46 function to perform polar coordinates available in the PlotsR package.
}
\references{
Finch, H & French, B. (2013) A Monte Carlo comparison of robust MANOVA. \emph{Test Statistics Journal of Modern Applied Statistical Methods}, 12: 35-81.

Fox, J., Weisberg, S., Adler, D., Bates, D., Baud-Bovy, G., Ellison, S., Firth, D., Friendly, M., Gorjanc, G., Graves, S., Heiberger, R., Laboissiere, R., Monette, G., Murdoch, D., Nilsson, H., Ogle, D., Ripley, B., Venables, W. & Zeileis, A. (2018a) Companion to Applied Regression. R package version 3.0-0. Available at: \url{http://CRAN.R-project.org/package=car}.

Fox, J, Friendly, M. & Monette, G. (2108b) Visualizing Hypothesis Tests in Multivariate Linear Models. R package version 1.3.5. Available at: \url{http://CRAN.R-project.org/package=heplots}.

Gross, J. (2015) Tests for Normality. R package version 1.0-4. Available at: \url{http://CRAN.R-project.org/package=nortest}.

Johnson, R.A. & Wichern, D.W. (2002) \emph{Applied multivariate statistical analysis}. Upper Saddle River, NJ: Prentice Hall.

Lee, Y.S. (1971) Asymptotic formulae for the distribution of a multivariate test statistic: Power comparisons of certain multivariate tests. \emph{Biometrika}, 58: 647-651.

Naimi, B. (2013) Uncertainty analysis for species distribution models. R package version 3.5-0. Available at: \url{http://CRAN.R-project.org/package=usdm}.

Naimi, B., Hamm, N.A.S., Groen, T.A., Skidmore, A.K., & Toxopeus, A.G. (2014) Where is positional uncertainty a problem for species distribution modelling? \emph{Ecography}, 37: 191-203.

Pillai, K.C.S. & Jayachandran, K. (1967) Power comparisons of tests of two multivariate hypotheses based on four criteria. \emph{Biometrika}, 54: 195-210.
}
\examples{
\dontrun{
data(ZXV3)

XVI1(data=ZXV3, var=c("Weaning.weight", "Birth.weight"), Factor=c("Father","Gender"))
}
}
\keyword{XVI1}

