\name{XVI2}
\alias{XVI2}
\encoding{latin1}
\title{Multivariate analysis of covariance (MANCOVA)}
\description{An analysis of covariance is applied considering several dependent quantitative variables.} 
\usage{
XVI2(data, var, Factor, Covar, SS="III", trans=NULL, pthreshold=0.05, psig=FALSE,
ellipse=FALSE, convex=TRUE, PCH=rep(16,100), order=TRUE, cor=TRUE,
file1="Output.txt", file2="Multinormality.csv", file3="Post hoc pvalues.csv",
na="NA", dec=",", row.names=TRUE)
}
\arguments{
  \item{data}{Data file.}
  \item{var}{Dependent variables.}
  \item{Factor}{Variables with the factors.}
  \item{Covar}{Covariates.}
  \item{SS}{When there are several factors, the decomposition of the sum of squares in parts attributed to each one of the factors is not unique. Four types of sums of squares are commonly used: type I for nested models, type II for balanced models, type III for unbalanced models (also balanced), and type IV for models with empty boxes. The type III is suitable for most applications, so it will be the one used by default. This description is very simplified; interested readers should consult supplementary bibliography for a correct use of the ANOVA models.}
  \item{trans}{Type of transformation that is applied to the data:

1. NULL (untransformed)

2. 1/x2

3. 1/x

4. LN

5. LOG

6. SQR (square root)

7. x2

8. x3

9. EXP (exponential)

10. ASN (arcsine)
}
  \item{pthreshold}{Threshold probability that is used to group the categories of each factor, based on the probabilities obtained in the post hoc analysis.}
  \item{psig}{If TRUE, in the post hoc inter-group comparison file, only those that are significant with a probability value equal to or less than the cut-off value specified in the argument \emph{pthreshold} are shown.}
  \item{ellipse}{If it is TRUE, the ellipses with the levels of significance to the 0.5 (inner ellipse) and 0.95 (outer ellipse) of each category of the factors are depicted.}
  \item{convex}{If it is TRUE, the convex hull is depicted for each category.}
  \item{PCH}{Symbols of each category of the factors.}
  \item{order}{If it is TRUE, the first variable of the polar coordinates is the one that best discriminates the categories. The objective is to show the greatest possible separation between the categories in the plots. If it is FALSE, the first variable is the one specified by the user in the argument \emph{var}.}
  \item{cor}{If TRUE, the variables are ordered according to the correlation between them when estimating the polar coordinates. Therefore, the next variable to another variable is the one with the highest positive correlation. The objective is to show the greatest possible separation between the categories in the plots. If it is FALSE and the argument \emph{order=FALSE}, the variables are organized as they appear in the arguments \emph{var} and \emph{Covar}.}
  \item{file1}{TXT FILE. Name of the output file with the results.}
  \item{file2}{CSV FILE. Name of the file with the probabilities obtained from the multinormality analysis.}
  \item{file3}{CSV FILE. Name of the file with the probabilities obtained from the post hoc comparison between groups for each factor.}
  \item{na}{CSV FILE. Text that is used in the cells without data.}
  \item{dec}{CSV FILE. It defines if the comma "," is used as decimal separator or the dot ".".}
  \item{row.names}{CSV FILE. Logical value that defines if identifiers are put in rows or a vector with a text for each of the rows.}
}
\value{
It is exported:

1. A TXT file with the results of the VIF, the Box' M test and the results of the MANCOVA.

2. A CSV file with the probabilities obtained from the multinormality analysis.

3. A CSV file with the probabilities obtained from the post hoc comparison between the groups of each factor.

4. Polar coordinate plots showing the separation between categories for each factor, the groups resulting from the post hoc analysis and the interactions between factors.
}
\details{
\strong{CONTRASTS OF HOMOGENEITY IN QUANTITATIVE VARIABLES}

\strong{Multivariate analysis of covariance (MANCOVA)}

The multivariate analysis of covariance (MANCOVA) is an extension of the univariate analysis of covariance (ANCOVA). Part of the variability observed in the dependent variables may be due to other variables. Therefore, if we really want to know if one or several factors explain the variability of dependent variables, it is necessary to eliminate any type of variation associated with other variables, which is done by introducing these variables as covariates. The reader is advised to read the \emph{details} section of the \link{IX4} function about ANCOVA, since, as mentioned above, the MANCOVA is an extension of the ANCOVA.

The assumptions of the MANCOVA are the same than as those of the MANOVA (see function \link{XVI1} for more details), with the addition that the covariates must also be independent and there must be a linear relationship between the dependent variables and the covariates.

\strong{FUNCTIONS}

The \link[nortest]{lillie.test} function of the nortest package (Gross, 2015) is used to perform the Kolmogorov-Smirnov Normality test with the Lilliefors correction. The \link[stats]{shapiro.test} function is used to perform the Shapiro-Wilk test, the linear model is performed with the \link[stats]{lm} function, both of the base stats package. The MANCOVA type II-III is performed with the \link[car]{Manova} function of the car package (Fox et al., 2018a). The MANCOVA type I is done with the function \link[stats]{manova} of the base stats package. To determine the homogeneity of variances between the categories of the factors, the Box's M test was applied, for which the function \link[heplots]{boxM} of the heplots package (Fox et al., 2018b) was used. The function \link[usdm]{vif} of the usdm package (Naimi, 2013; Naimi et al., 2014) was used for the VIF estimation.

\strong{EXAMPLE}

Biometric data of two species of sharks (\emph{Scyliorhinus canicula} and \emph{Galeus melastomus}), which were taken by two researchers in four zones (two in the Mediterranean and two in the Atlantic).

The aim is to determine if there are differences in the base of the anal fin and the height of the anal fin, between species and researchers, considering the effect of the total length of the shark.

In the script the argument \emph{trans="SQR"} was included, that is, the dependent variables are transformed with the square root, in order to meet the requirements of multinormality and equality of the variances-covariances matrices in the residuals of the groups of factors.

In the TXT file of the results, the first thing that is observed are the VIF values, which show that there is a bit of collinearity among the dependent variables. If the analysis is done without transforming the data, this collinearity is not observed, but the requirements of multinormality and homogeneity of variances are not met.
\tabular{c}{
\figure{RXV17}{options: width=1.3in}
}
The assumption of equality of variances between groups of factors is also fulfilled in both factors: researcher (p = 0.151) and species (p = 0.497).
\tabular{c}{
\figure{RXV18}{options: width=3.4in}
}
\tabular{c}{
\figure{RXV19}{options: width=2.9in}
}
In the file that is called by default "Multinormality.csv", it is observed that the multinormality is also fulfilled (see table showed above). The samples are normal in both variables for all groups of the two factors, although in a couple of groups there are discrepancies between the two normality test.

The following results are the MANCOVA analysis. There are four tests that are used more frequently: Pillai, Wilks, Hotelling-Lawley and Roy. The following table shows that in all cases the test values coincide. The covariate total length is clearly related to the dependent variables (p <0.001). However, there are no significant differences between species (p = 0.207), nor among researchers (p = 0.534), nor are there any researcher-species interactions (p = 0.27). Non-interaction means that the two researchers measure the two species equally.
\tabular{c}{
\figure{RXV20}{options: width=3.5in}
}
Figure XVI2.1 shows that there are no differences between species, which corroborates the MANCOVA results. It is important to mention that the plot includes the covariates, in order to better visualize the effect of them on the dependent variables.
\tabular{c}{
\strong{Figure XVI2.1.} Polar coordinates of the species as a function of\cr
the dependent variables and the covariate.\cr
\figure{FXV32}{options: width=2.5in}
}
In the researcher (Figure XVI2.2), no differences are observed between them.
\tabular{c}{
\strong{Figure XVI2.2.} Polar coordinates of the species as a function of\cr
the dependent variables and the covariate.\cr
\figure{FXV33}{options: width=3.0in}
}
There is no information about the post hoc tests nor the file with the comparison probabilities or the graphics, because in both factors there are only two groups.

The last plot is that of the interaction between both factors (Figure XVI2.3), where it is seen that both researchers measure both species equally and, therefore, there is no interaction.
\tabular{c}{
\strong{Figure XVI2.3.} Polar coordinates of the interaction between both factors\cr
\figure{FXV34}{options: width=3.0in}
}
All these polar coordinate graphs can be modified to suit the user using the original data and the F46 function to perform polar coordinates available in the PlotsR package.
}
\references{
Fox, J., Weisberg, S., Adler, D., Bates, D., Baud-Bovy, G., Ellison, S., Firth, D., Friendly, M., Gorjanc, G., Graves, S., Heiberger, R., Laboissiere, R., Monette, G., Murdoch, D., Nilsson, H., Ogle, D., Ripley, B., Venables, W. & Zeileis, A. (2018a) Companion to Applied Regression. R package version 3.0-0. Available at: \url{http://CRAN.R-project.org/package=car}.

Fox, J, Friendly, M. & Monette, G. (2108b) Visualizing Hypothesis Tests in Multivariate Linear Models. R package version 1.3.5. Available at: \url{http://CRAN.R-project.org/package=heplots}.

Gross, J. (2015) Tests for Normality. R package version 1.0-4. Available at: \url{http://CRAN.R-project.org/package=nortest}.

Naimi, B. (2013) Uncertainty analysis for species distribution models. R package version 3.5-0. Available at: \url{http://CRAN.R-project.org/package=usdm}.

Naimi, B., Hamm, N.A.S., Groen, T.A., Skidmore, A.K., & Toxopeus, A.G. (2014) Where is positional uncertainty a problem for species distribution modelling? \emph{Ecography}, 37: 191-203.
}
\examples{
\dontrun{
data(ZIX3)

XVI2(data=ZIX3, var=c("Anal.base", "Anal.height"), Factor=c("Species",
"Researcher"), Covar="Total.length", trans="SQR", ellipse=TRUE, convex=FALSE)
}
}
\keyword{XVI2}

